pro constrain_model3,beta,tau,icongood
;
; for imodel=3:
; checks values of jump factors and time constants for two illuminations
; ILLCON1 and ILLCON2, held in common SCCONSTRAIN, which are typically the 
; lowest and highest illuminations encountered. If these derived detector 
; parameters are in range for both ILLCON1 and ILLCON2 then ICONGOOD is 
; passed back with ICONGOOD=1. Here the parameters being in range means,
; at both ILLCON1 and ILLCON2, that the long and short time constants
; (denoted in the comment here as taulong, taushort) and the long and
; short jump factors (denoted as betalong, betashort), must satisfy:
;
; In all cases:
; 0 < taushort < taulong 
; 0 < betalong <= 1.0
; 
; additionally, as a function of limits held in the 
; common block SCCONSTRAIN (which is typically set up by the calling program):
;
; BETALONGCONMIN  <= betalong  <= BETALONGCONMAX
; BETASHORTCONMIN <= betashort <= BETASHORTCONMAX
; TAULONGCONMIN   <= taulong   <= TAULONGCONMAX
; TAUSHORTCONMIN  <= taushort  <= TAUSHORTCONMAX
;
; other input parameters - BETA, TAU (the constants as input to EXPSHOOT)
;
; Note that this scheme is watertight, providing a constrain for all
; illuminations between ILLCON1 and ILLCON2, since for imodel 3 the flux 
; dependence of all parameters is monotonic. 
;
@common_scconstrain
;common scconstrain,illcon1,illcon2,betalongconmin,betalongconmax,$
;betashortconmin,betashortconmax,taulongconmin,taulongconmax,$
;taushortconmin,taushortconmax,idriftrancon
;
; idriftrancon is ignored by CONSTRAIN_MODEL3 - it is only used by DRIFTCORR
;
icongood=1
iconcheck=1 ; =0 to short circuit routine
if(iconcheck eq 0)then goto,c999
;
setshootbeta_model3,beta,illcon1,betalong1,betashort1
setshootbeta_model3,beta,illcon2,betalong2,betashort2
setshoottime_model3,tau,illcon1,taulong1,taushort1
setshoottime_model3,tau,illcon2,taulong2,taushort2
;
if(betalong1 le 0.0 or betalong2 le 0.0)then begin
;if(betalong1 lt 0.0 or betalong2 lt 0.0)then begin
icongood=0
goto,c999
endif ; betalong1 le 0.0 or betalong2 le 0.0
;
if(betalong1 gt 1.0 or betalong2 gt 1.0)then begin
icongood=0
goto,c999
endif ; betalong1 gt 1.0 or betalong2 gt 1.0
;
if(taulong1 lt 0.0 or taulong2 lt 0.0)then begin
icongood=0
goto,c999
endif ; taulong1 lt 0.0 or taulong2 lt 0.0
;
if(taushort1 lt 0.0 or taushort2 lt 0.0)then begin
icongood=0
goto,c999
endif ; taushort1 lt 0.0 or taushort2 lt 0.0
;
if(taushort1 ge taulong1)then begin
icongood=0
goto,c999
endif ; taushort1 ge taulong1
;
if(taushort2 ge taulong2)then begin
icongood=0
goto,c999
endif ; taushort2 ge taulong2
;
if(betalong1 lt betalongconmin or betalong2 lt betalongconmin)then begin
icongood=0
goto,c999
endif ; betalong1 lt betalongconmin or betalong2 lt betalongconmin
;
if(betalong1 gt betalongconmax or betalong2 gt betalongconmax)then begin
icongood=0
goto,c999
endif ; betalong1 gt betalongconmax or betalong2 gt betalongconmax
;
if(betashort1 lt betashortconmin or betashort2 lt betashortconmin)then begin
icongood=0
goto,c999
endif ; betashort1 lt betashortconmin or betashort2 lt betashortconmin
;
if(betashort1 gt betashortconmax or betashort2 gt betashortconmax)then begin
icongood=0
goto,c999
endif ; betashort1 gt betashortconmax or betashort2 gt betashortconmax
;
if(taulong1 lt taulongconmin or taulong2 lt taulongconmin)then begin
icongood=0
goto,c999
endif ; taulong1 lt taulongconmin or taulong2 lt taulongconmin
;
if(taulong1 gt taulongconmax or taulong2 gt taulongconmax)then begin
icongood=0
goto,c999
endif ; taulong1 gt taulongconmax or taulong2 gt taulongconmax
;
if(taushort1 lt taushortconmin or taushort2 lt taushortconmin)then begin
icongood=0
goto,c999
endif ; taushort1 lt taushortconmin or taushort2 lt taushortconmin
;
if(taushort1 gt taushortconmax or taushort2 gt taushortconmax)then begin
icongood=0
goto,c999
endif ; taushort1 gt taushortconmax or taushort2 gt taushortconmax
;
c999:
;
return
end

