pro createsky,icompressy,icompressz,beamextentin,specparin,$
icamin,backsim,nsource,sourceparin
;
; The noiseless sky brightness distribution convolved with the beam, SKYBEAM, 
; and the distribution not convolved with the beam, SKY, are created by 
; CREATESKY, which produces a map gridded with a submultiple of the grid 
; spacings in Y and Z of the P32 natural grid, such that (1) the maps are 
; oversampled (2) each direction on the the P32 natural grid is exactly 
; sampled by a subsample of the pixels of SKY and SKYBEAM (3) The boundary
; of SKY corresponds to the boundary of the P32 natural grid). CREATESKY also
; produces a map of the beam, BEAM, covering an extent about 2*BEAMEXTENT
; arcsec centred on the same grid as in SKYBEAM, SKY, by calling the 
; CREATEBEAM subroutine. The BEAM cam be specified according to a source colour
; (moncromatic, planckian or power law) if the option in CREATEBEAM using
; the ISOCAM beam generator is selected. The sky brightness 
; distribution is first created on a larger area than SKY, SKYPLUS, which 
; extends each of the 4 bounding sides of SKY by the radial extent BEAMEXTENT
; of BEAM. SKPLUS is built as the superposition of NSOURCE sources, each of 
; which can be specified as a point, truncated gaussin or truncated 
; exponential according to the parameters in the SOURCEPARIN array.
; The positions of the sources can be specified outside the boundary of SKYPLUS
; and SKY, but they only contribute to SKYBEAM if there is emission within the 
; boundary of SKYPLUS. All pixels within a submap around each source
; covering the extent of the source are added to SKYPLUS. After all sources
; have been added to SKYPLUS a planar background is added (BACKSIM). SKY
; and SKYBEAM are then extracted as subarrays of SKYPLUS and the convolution 
; of SKYPLUS with BEAM respectively. All background and source fluxes are 
; specified in arbitary units - normally the calling program SIMUL32 would
; treat these as V/s.
;
; input: 
;   CFILTER (integer common NAMES) 
;                    = either 50,60,70,90,100,105,120,135,160,180,200
;   ICOMPRESSY, ICOMPRESSZ integer factors by which the sampling is compressed
;                    in Y, Z compared to natural map
;   CALDIR  (common NAMES) string denoting CALG directory 
;                          (needed by CREATEBEAM)
;                eg '/d12/vlk/cgabriel/pia_7.3/calg/'     
;   BEAMEXTENTIN radius in arcsec out to which the beam is specified
;   SPECPARIN  2D real array specifying spectrum of source assumed in 
;              calculating beam:
;                    for monocromatic source SPECPAR = [0,lamba/um]
;                    for planckian source SPECPAR = [1,temperature]
;                    for power law source SPECPAR = [2,spectral index +ve red] 
;   ICAMIN           is 1 if CAM simulated beam to be used
;                    is 0 for real PHT beams from CALG to be used
;                    is 2 for Gaussian beam of FWHM detector pixel to be used
;   BACKSIM - 3 element real array specifying a background of form 
;                    BACKSIM(0) + (Y-Y0)*BACKSIM(1) + (Z-Z0)*BACKSIM(2) 
;                    where Y-Y0 and Z-Z0 denote offsets in arcsec from the map
;                    centre. Units are V/s per square arcsec.
;   NSOURCE - number of sources simulated
;   SOURCEPARIN 2D real dimension NSOURCE,0<IPAR<=NPAR-1
;                    IPAR 0: source type 
;                            = 1. for point source
;                            = 2. for 2D truncated gaussian
;                            = 3. for 2D truncated exponential
;                    IPAR 1: Y offset in arcsec from map centre
;                            this can extend beyond the perimeter of SKY.
;                    IPAR 2: Z offset in arcsec from map centre
;                    IPAR 3: integrated flux density of source in V/s
;                    IPAR 4: PA of major axis of source
;                            in degrees antclockwise from top 
;                    IPAR 5: FWHM of major axis in arcsec
;                    IPAR 6: FWHM of minor axis in arcsec 
;                    IPAR 7: maximum diameter of source in both
;                            dimensions in units of FWHM 
;   from MAPPER common block: sgridy,sgridz,nygrid,nzgrid,ygrid,zgrid
;       from NAMES   common block:
;       CFILTER (integer) = either 50,60,70,90,100,105,120,135,160,180,200
;       CALDIR       string denoting CALG directory (needed by CREATEBEAM)
;                    eg '/d12/vlk/cgabriel/pia_7.3/calg/'     
;   from STEER1 common block: pixsize
;
; output:
;  NPAR    (common block CSKY) max. number of parameters for each source 
;                              = n_elements(sourceparin(0,*)) (normally 8)
;  SKY     (common CSKY) in units of V/s per simulated pixel area
;  SKYBEAM (common CSKY) in units of V/s /detector pixel area (ie the actual 
;                        V/s that would be measured if the detector were 
;                        pointed towards the simulated grid points
;  SKYPLUS (common CSKY) in units of V/s per simulated pixel area
;  NYGRIDSIM, NZGRIDSIM (common CSKY): dimensions of SKY and SKYBEAM
;  SGRIDYSIM,SGRIDZSIM (common CSKY) sampling interval (arcsec) for 
;                                           SKY, BEAM, SKYBEAM, SKYPLUS 
;  YGRIDSIM,ZGRIDSIM (common CSKY): offset in arcsec of positions in 
;                     each coordinate of SKY, SKYBEAM (1D arrays dimension 
;                     NYGRIDSIM or NZGRIDSIM)
;  SOURCEPAROUT (common CSKY) 2D real dimension NSOURCE,0<IPAR<=NPAR-1
;              IPAR 0: source type 
;                      = 1. for point source
;                      = 2. for 2D truncated gaussian
;                      = 3. for 2D truncated exponential
;              IPAR 1: actual Y offset in arcsec from map centre (CREATESKY
;                      shifts the source centre from the position specified in
;                      SOURCEPARIN to the centre of the nearest grid point on
;                      the simulated array. This is to speed up computations
;                      (avoid DO LOOPS) to allow use of CREATESKY and SIMUL32 
;                      in interative optimisation applications, and to avoid
;                      ambiguities when input position is on a boundary of
;                      a pixel in SKY     
;              IPAR 2: actual Z offset in arcsec from map centre
;              IPAR 3: integrated flux density of source in V/s within
;                      boundary of SKY array
;              IPAR 4: PA of major axis of source in degrees antclockwise from
;                      top 
;              IPAR 5: FWHM of major axis in arcsec
;              IPAR 6: FWHM of minor axis in arcsec 
;              IPAR 7: maximum diameter of source in both dimensions in units 
;                      of FWHM 
;
;  BEAM          (common BM)
;  NYB, NZB      (common BM): dimensions of BEAM 
;  YGRIDB,ZGRIDB (common BM): offset in arcsec of positions in each coordinate
;                             of BEAM (1D arrays dimension NYB or NZB)      
;  BEAMEXTENT    (common BM) if input BEAMEXTENTIN is larger than the 17*7.5 = 
;                        127.5 arcsec in the CALG files then for option ICAM=0 
;                        BEAMEXTENT is reduced to 127.5 arcsec (C1) or 255 (C2)
;  SPECPAR       (common BM = SPECPARIN): 2 element real array specifying 
;                             spectrum of source assumed in calculating beam:
;         for monocromatic source (ICAM=1) SPECPAR = [0,lamba/um]
;         for planckian source (ICAM=1)    SPECPAR = [1,temperature]
;         for power law source (ICAM=1)    SPECPAR = [2,spectral index +ve red]
;                specpar is only used for ICAM = 1 or 2  
;  ICAM          (common BM = ICAMIN): is 1 if CAM simulated beam to be used
;                             is 0 for real PHT beams from CALG to be used
;                             is 2 for a gaussian beam with FWHM of detector 
;                             pixel
;
;common names,tdtnam,iseq,dirnam,caldir,cfilter
@common_names
@common_steer1
;common steer1,npix,pixsize,pixpitch,pixoff,nchop,dcy,dry,drz
@common_mapper
;common mapper,sgridy,sgridz,nygrid,nzgrid,ygrid,zgrid,errflag
@common_csky
;common csky,sky,skybeam,skyplus,nygridsim,nzgridsim,ygridsim,zgridsim,$
;sgridysim,sgridzsim,sourceparout,npar
@common_bm
;common bm,beam,nyb,nzb,ygridb,zgridb,beamextent,specpar,icam
;
; in the simulation of sources no integration is done over the simulated
; map grid pixel of the analytical function. Errors due to this can be
; reduced by increasing ICOMPRESSY, ICOMPRESSZ
;
; Establish grids. The definition ensures that all the natural grid directions
; are exactly sampled by a subset of the simulation grid. However, the
; simulation grid can be either even or odd. (Which causes a shift of
; centrally positioned point sources for even simulated grids) according to 
; the definition for pointsources adopted below.
;
print,'CREATESKY:'
print,'icompressy,icompressz = ',icompressy,icompressz

if(icompressy lt 2 or icompressz lt 2)then begin
print,'CREATESKY: warning - natural sampling used for simulation'
print,'... in one or more dimensions ... icompressy,icompressz = ',$
icompressy,icompressz
endif ; icompressy lt or icompressz lt 2
;
nygridsim=(nygrid-1)*icompressy+1
nzgridsim=(nzgrid-1)*icompressz+1
sgridysim=sgridy/float(icompressy)
sgridzsim=sgridz/float(icompressz)
ygridsim=sgridysim*findgen(nygridsim)
zgridsim=sgridzsim*findgen(nzgridsim)
ygridsim=ygridsim-sgridysim*float(nygridsim/2)
zgridsim=zgridsim-sgridzsim*float(nzgridsim/2)
evenodd,nygridsim,iyodd
evenodd,nzgridsim,izodd
if(iyodd eq 0)then ygridsim=ygridsim+sgridysim/2.0
if(izodd eq 0)then zgridsim=zgridsim+sgridzsim/2.0
print,'CREATESKY: nygridsim,sgridysim = ',nygridsim,sgridysim
print,'           nzgridsim,sgridzsim = ',nzgridsim,sgridzsim
;
; first set up set up beam and beam grid in common block BM
;
icam=icamin
beamextent=beamextentin
specpar=specparin
createbeam,sgridysim,sgridzsim
print,'radial beam extent (arcsec) = ',beamextent
nybr=nyb/2 ; nyb always odd half radius of beam in units of SKY pixels
nzbr=nzb/2 
nybgridsim=nyb ; internal work parameter
nzbgridsim=nzb
ybgridsim=ygridb ; internal work parameters
zbgridsim=zgridb
print,'           nybgridsim = ',nybgridsim
print,'           nzbgridsim = ',nzbgridsim
;
; set up array SKYPLUS over extended sky grid to deal with beam response of 
; any sources with emission extending beyond or from beyond the area SKY
; covered by the P32 natural grid. A subimage of the
; convolution of SKYPLUS with BEAM will be SKYBEAM, and the same subimage area
; of SKYPLUS will be SKY. We convolve SKYPLUS rather than each source
; component in SKYPLUS as this is faster for crowded fields.
;
nyplus=nygridsim+2*nybr
yplus=sgridysim*findgen(nyplus)
nzplus=nzgridsim+2*nzbr
zplus=sgridzsim*findgen(nzplus)
yplus=yplus-sgridysim*float(nyplus/2)
zplus=zplus-sgridzsim*float(nzplus/2)
evenodd,nyplus,iyplusodd
evenodd,nzplus,izplusodd
if(iyplusodd eq 0)then yplus=yplus+sgridysim/2.0
if(izplusodd eq 0)then zplus=zplus+sgridzsim/2.0
print,'           nyplus = ',nyplus
print,'           nzplus = ',nzplus
;
; create SKYPLUS array and fill it with emission from sources and background
; initialise SKYBEAM and SKY array 
;
skyplus=fltarr(nyplus,nzplus)
skybeam=fltarr(nygridsim,nzgridsim)
sky=skybeam
npar=n_elements(sourceparin(0,*))
sourceparout=sourceparin
;
for isource=0,nsource-1 do begin
;
; find nearest pixel iy0,iz0 to source centred on SKYPLUS
;
testy=(yplus-sourceparin(isource,1))/sgridysim
;print,'yplus:',yplus
;print,'testy:',testy
ii=where(abs(testy) eq min(abs(testy)),nii)
iy0=ii(0)
;print,'iy0:',iy0
sourceparout(isource,1)=yplus(iy0)
testz=(zplus-sourceparin(isource,2))/sgridzsim
ii=where(abs(testz) eq min(abs(testz)),nii)
iz0=ii(0)
sourceparout(isource,2)=zplus(iz0)
;
if(sourceparin(isource,0) eq 1)then begin ; point source
;
if(iy0 lt 0 or iy0 gt nyplus-1)then goto, c100 ; point source not enclosed
if(iz0 lt 0 or iz0 gt nzplus-1)then goto, c100 ; by SKYPLUS
;
skyplus(iy0,iz0)=sourceparin(isource,3)
;
endif ; point source
;
if(sourceparin(isource,0) eq 2 or sourceparin(isource,0) eq 3)then begin 
; truncated gaussian or truncated exponential
;
; create unrotated array with major axis pointing up within
fwhmz=sourceparin(isource,5)/sgridzsim 
fwhmy=sourceparin(isource,6)/sgridysim
ztrunc=fwhmz*sourceparin(isource,7)
ytrunc=fwhmy*sourceparin(isource,7)
; calculate array dimensions
;nyg=ytrunc*sqrt(2) ; sqrt(2) multiplication unnecessary as creategauss
; and createexp give circular spatial truncations
nyg=ceil(ytrunc) 
evenodd,nyg,ioddyg
if(ioddyg eq 0)then nyg=nyg+1 ; ensure odd array in case FWHM << sampling  
;nzg=ztrunc*sqrt(2)            ; and to avoid complications in ROT
nzg=ceil(ztrunc)
evenodd,nzg,ioddzg
if(ioddzg eq 0)then nzg=nzg+1
ang=0.0-sourceparin(isource,4) ; angle of rotation
if(nyg ne nzg and ang ne 0.0)then begin
idum=max([nyg,nzg])
nyg=idum ; to handle worst case of 90 degrees rotation with nyg ne nzg
nzg=idum
endif ; nyg ne nz
;
; we now see whether a nyg x nzg odd x odd array centred on iy0 iz0 of the 
; SKYPLUS array overlaps with the SKYPLUS array. If not, forget about 
; this source.
;
i1=iy0-nyg/2
i2=iy0+nyg/2
j1=iz0-nzg/2
j2=iz0+nzg/2
if(i2 lt 0 or i1 gt nyplus-1)then goto,c100
if(j2 lt 0 or j1 gt nzplus-1)then goto,c100
;
flux=sourceparin(isource,3)
;
if(sourceparin(isource,0) eq 2)then $
creategauss,flux,fwhmy,fwhmz,ytrunc,ztrunc,nyg,nzg,subim
print,'flux,fwhmy,fwhmz,ytrunc,ztrunc,nyg,nzg:'
print,flux,fwhmy,fwhmz,ytrunc,ztrunc,nyg,nzg
;
if(sourceparin(isource,0) eq 3)then $
createexp,flux,fwhmy,fwhmz,ytrunc,ztrunc,nyg,nzg,subim
;
if(sourceparin(isource,4) ne 0.0)then begin 
; rotate according to minus position angle
;
subim=rot(subim,ang,/interp) 
; rotation of an odd * odd array about central pixel
; For more accuracy try /cubic in ROT
;
endif ; rotate
;
; add overlapping part of SUBIM into SKYPLUS
;
ii1=0 ; counter for subim
ii2=nyg-1
jj1=0
jj2=nzg-1
if(i1 lt 0)then begin
ii1=ii1-i1
i1=0
endif ; i1 lt 0
if(j1 lt 0)then begin
jj1=jj1-j1
j1=0
endif ; j1 lt 0
if(i2 gt nyplus-1)then begin
ii2=ii2-(i2-nyplus+1)
i2=nyplus-1
endif ; i2 gt nyplus-1
if(j2 gt nzplus-1)then begin
jj2=jj2-(j2-nzplus+1)
j2=nzplus-1
endif ; j2 gt nzplus-1
;
skyplus(i1:i2,j1:j2)=skyplus(i1:i2,j1:j2)+subim(ii1:ii2,jj1:jj2)
;
sourceparout(isource,3)=total(subim(ii1:ii2,jj1:jj2))
;
endif ; truncated gaussian or truncated exponential
;
;
c100:
;
endfor ; isource
;
; add background to SKYPLUS
;
createback,backsim,sgridysim,sgridzsim,nyplus,nzplus,backim
skyplus=skyplus+backim
; 
; now convolve BEAM with SKYPLUS to get SKYBEAM. Create SKY as a
; simple subimage of SKYPLUS
;
skybeam=convol(skyplus,beam)
; since beam has unity area the input sky (in units of V/s/simulated
; pixel) will have the same numerical value as the output skybeam for a flat
; sky. But we measure the flux onto the solid angle of the detector pixel.
; Hence skybeam must be multiplied ...
factor=pixsize*pixsize/(sgridysim*sgridzsim)
skybeam=skybeam*factor   ; in flux units (either V/s or Jy) per detector pixel
; overwrite skybeam to remove edge effects, leaving just the area
; covered by the mapping observation
i1=nybr ; check this!!
i2=i1+nygridsim-1
j1=nzbr
j2=j1+nzgridsim-1
skybeam=skybeam(i1:i2,j1:j2)
sky=skyplus(i1:i2,j1:j2)
;
return
end









