;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PIA P32 Processing Tools Software.              !
;! Designed by: Nanyao Lu at IPAC (lu@ipac.caltech.edu)                        !
;!              Bernhard Schulz at Vilspa (bschulz@iso.vilspa.esa.es)          !
;! Developed by: Iffat Khan at IPAC (irk@ipac.caltech.edu)                     !
;!                                                                             !
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       GET_CONV_S2B      
;       (originated from ERD2MAP initial interface written by 
;        Carlos Gabriel @Vilspa)
;
; PURPOSE:
;       This routine computes the responsivity using FCS1 and/or FCS2 measurements
;
; DESCRIPTION:
;
; CATEGORY:
;       PIA - P32     
;
; CALLING SEQUENCE:
;       der_resp_2fcs, det, FCSS=fcss, ERROR=error
;
; INPUTS:
;       det: Selected measurement
;
; OPTIONAL INPUTS:
;       None.
;
; OUTPUTS:
;          
; KEYWORDS:
;       FCSS: Ids of FCS1 and/or FCS2 measurements
;       ERROR:  = 1 if FCS measurements are not found in SCP
;               = 0 otherwise
;
; CALLED ROUTINES:
;       RESPONS_INTERPOL
;      	PIA_LOAD_ISCP
;       PIA_RESPONS
;
; CALLED FROM:    
;       GET_CONV_S2B 
;
; COMMON BLOCKS:
;
; PROCEDURE:
;       @phtscp
;
; SIDE EFFECTS:
;       None.
;
; RESTRICTIONS:
;
;
; MODIFICATION HISTORY:
;	Modified design, Version 1.1 IRK        Jan 08, 2001
;-
;-----------------------------------------------------------------------
;
PRO der_resp_2fcs, det, fcss=fcss, error=error

@phtscp
        	      

      error = 0
      fcs_pos = INTARR(2)
      fcs_pos(*) = -1
      FOR I=0,N_ELEMENTS(fcss)-1 DO BEGIN
;      print,'i=',i
          indx = WHERE(phtscp.admn EQ fcss(i), ncount)
          IF ncount GT 0 THEN $
            fcs_pos(i) = indx(0)
      ENDFOR
      tst = WHERE(fcs_pos GE 0, tstcnt)
      IF tstcnt EQ 0 THEN BEGIN
         error = 1
         RETURN
      ENDIF 

      IF N_ELEMENTS(fcss) EQ 2 THEN $	
       respons_interpol, fcs_pos(0), fcs_pos(1), resps $
      ELSE BEGIN
       	pia_load_iscp, phtscp(fcs_pos(0)), tmpdata
	PIA_RESPONS, tmpdata, newheader
      ENDELSE
       
      RETURN
      END

