pro detdefaultsetup,ifirstinit,imodel
;
; initialises common block DETDEFAULT according to value of IMODEL. 
; To be called by DRIFT32 and SIMUL32. DETDEFAULT contains
; detector model parameters, and search ranges and search precision 
; for the parameters in FCS and self cal applications.
;
; input:  IMODEL (NOT contained as usual in common DRIFTPAR, to allow calls 
;                 SIMUL32 with different values of imodel)
;         ARRAY  (common STEERIN)
;         IFIRSTINIT =1 to initialise the common block DETPARS
;                       containing override parameters with the same values
;                       placed in DETDEFAULT
;                    =0 not to initialise the common block DETPARS as
;                       well as the common block DETDEFAULT. DETDEFAULTINIT
;                       should be called with IFIRSTINIT=0 from DRIFT32 and
;                       with IFIRSTINIT=1 from the calling script each time 
;                       the model or jump conditions is changed or the 
;                       observation is changed
;
; output: common DETDEFAULT
;
@common_steerin
;common steerin,array,nptin,npt,ninramp,imeas,osamp
@common_detdefault
;common detdefault,betadefault,taudefault,gammaexpdefault,$
;betashootdefault,taushootdefault,gammaexpshootdefault,$
;betacoeffdefault,betaexpdefault,tauoffsetdefault,$
;betacoeffshootdefault,betaexpshootdefault,tauoffsetshootdefault,$
;betaup,betadown,tauup,taudown,gammaexpup,gammaexpdown,$
;betashootup,betashootdown,taushootup,taushootdown,$
;gammaexpshootup,gammaexpshootdown,$
;betacoeffup,betacoeffdown,betaexpup,betaexpdown,$
;tauoffsetup,tauoffsetdown,betacoeffshootup,betacoeffshootdown,$
;betaexpshootup,betaexpshootdown,tauoffsetshootup,tauoffsetshootdown,$
;betaprec,tauprec,gammaexpprec,betashootprec,taushootprec,gammaexpshootprec,$
;betacoeffprec,betaexpprec,tauoffsetprec,$
;betacoeffshootprec,betaexpshootprec,tauoffsetshootprec
;
if(imodel lt 1 or imodel gt 3)then begin
print,'DETDEFAULTSETUP: aborting - detector model not supported - imodel = ',$
imodel
goto,c999
endif ; imodel lt 1 or imodel gt 3
;
; default assignments to all parameters, even those not used by the
; model specified by IMODEL
;
if(array eq 'c100')then begin
;
taudefault=35.0*[1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0] ; 
betadefault=0.39*[1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0] 
gammaexpdefault=0.49*[1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0] 
betashootdefault=0.2*[1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0] ; ...
taushootdefault=1.0*[1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]  ; ...
gammaexpshootdefault=gammaexpdefault                       ; - these parameters
tauoffsetdefault=10.0*[1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0] ; are only used
betaexpdefault=0.5*[1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]    ; for imode=3
betacoeffdefault=-0.04*[1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0] ; ...
betacoeffshootdefault=0.0*[1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]
betaexpshootdefault=0.0*[1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]
tauoffsetshootdefault=0.0*[1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]
;
betaup=betadefault
betadown=betadefault
betaup(*)=0.99 ; upper limit for search range for finding beta from data
betadown(*)=0.01 ; lower limit to search range
tauup=taudefault
taudown=taudefault
tauup(*)=taudefault(*)*7.0
taudown(*)=taudefault(*)/7.0
gammaexpup=gammaexpdefault
gammaexpdown=gammaexpdefault
gammaexpup(*)=1.5
gammaexpdown(*)=0.25
betashootup=betashootdefault
betashootdown=betashootdefault
betashootup(*)=0.99
betashootdown(*)=0.01
gammaexpshootup=gammaexpshootdefault
gammaexpshootdown=gammaexpshootdefault
gammaexpshootup(*)=1.5
gammaexpshootdown(*)=0.25
betacoeffup=1.0*[1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0] ; dummy initialisations..
betacoeffdown=0.0*[1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]
betaexpup=1.0*[1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]
betaexpdown=0.0*[1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]
tauoffsetup=1.0*[1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]
tauoffsetdown=0.0*[1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]
betacoeffshootup=1.0*[1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]
betacoeffshootdown=0.0*[1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]
betaexpshootup=1.0*[1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]
betaexpshootdown=0.0*[1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]
tauoffsetshootup=1.0*[1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]
tauoffsetshootdown=0.0*[1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]
taushootup=1.0*[1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]
taushootdown=0.0*[1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]
;
betaprec=0.02 ; target precision for self cal
tauprec=1.0
gammaexpprec=0.1
betashootprec=betaprec ; target precision for self cal
taushootprec=0.1
gammaexpshootprec=gammaexpprec
betacoeffprec=1.0 ; following just for initialisation
betaexpprec=1.0
tauoffsetprec=1.0
betacoeffshootprec=1.0
betaexpshootprec=1.0
tauoffsetshootprec=1.0
;
endif ; array eq 'c100'
;
if(array eq 'c200')then begin
taudefault=[52.34,24.297,21.15,22.72] 
betadefault=[0.8056,0.8350,0.8075,0.8716] 
gammaexpdefault=0.89*[1.0,1.0,1.0,1.0] 
betashootdefault=0.2*[1.0,1.0,1.0,1.0]
taushootdefault=1.0*[1.0,1.0,1.0,1.0]
gammaexpshootdefault=1.0*[1.0,1.0,1.0,1.0]
betaexpdefault=[0.544,1.258,1.315,0.534] ; just for initialisation ...
betacoeffdefault=[-0.038,-0.0035,-0.0030,-0.053] ; ...
;tauoffsetdefault=[6.57,5.59,4.37,6.33]
tauoffsetdefault=[5.92,5.59,4.37,4.92]  ; JUN00
betacoeffshootdefault=0.0*[1.0,1.0,1.0,1.0]
betaexpshootdefault=0.0*[1.0,1.0,1.0,1.0]
tauoffsetshootdefault=0.0*[1.0,1.0,1.0,1.0]
;
betaup=betadefault
betadown=betadefault
betaup(*)=0.99 ; upper limit for search range for finding beta from data
betadown(*)=0.01 ; lower limit to search range
tauup=taudefault
taudown=taudefault
tauup(*)=taudefault(*)*7.0
taudown(*)=taudefault(*)/7.0
;
gammaexpup=gammaexpdefault
gammaexpdown=gammaexpdefault
gammaexpup(*)=1.5
gammaexpdown(*)=0.25
betashootup=betashootdefault
betashootdown=betashootdefault
betashootup(*)=0.99
betashootdown(*)=0.01
gammaexpshootup=gammaexpshootdefault
gammaexpshootdown=gammaexpshootdefault
gammaexpshootup(*)=1.5
gammaexpshootdown(*)=0.25
betacoeffup=1.0*[1.0,1.0,1.0,1.0] ; all these just for initialisation
betacoeffdown=0.0*[1.0,1.0,1.0,1.0]
betaexpup=1.0*[1.0,1.0,1.0,1.0] 
betaexpdown=0.0*[1.0,1.0,1.0,1.0]
tauoffsetup=1.0*[1.0,1.0,1.0,1.0] 
tauoffsetdown=0.0*[1.0,1.0,1.0,1.0] 
betacoeffshootup=1.0*[1.0,1.0,1.0,1.0] 
betacoeffshootdown=0.0*[1.0,1.0,1.0,1.0]
betaexpshootup=1.0*[1.0,1.0,1.0,1.0] 
betaexpshootdown=0.0*[1.0,1.0,1.0,1.0]
tauoffsetshootup=1.0*[1.0,1.0,1.0,1.0] 
tauoffsetshootdown=0.0*[1.0,1.0,1.0,1.0] 
taushootup=1.0*[1.0,1.0,1.0,1.0] 
taushootdown=0.0*[1.0,1.0,1.0,1.0] 
;
betaprec=0.02 ; target precision for self cal
tauprec=1.0
gammaexpprec=0.1
betashootprec=betaprec ; target precision for self cal
taushootprec=0.1
gammaexpshootprec=gammaexpprec
betacoeffprec=1.0 ; following just for initialisation
betaexpprec=1.0
tauoffsetprec=1.0
betacoeffshootprec=1.0
betaexpshootprec=1.0
tauoffsetshootprec=1.0
;
endif ; array eq 'c200'
;
;  initialise or overwrite detector parameters in the common block DETDEFAULT
;
if(imodel eq 1)then model1setup
if(imodel eq 2)then model2setup
if(imodel eq 3)then model3setup
;
; initialise or overwrite the common block DETPARS (used for the override 
; options ICALMETHOD=4 and ICALMETHOD=5) with the detector parameters in the 
; common block DETDEFAULT. This shouold only be done once each time the model 
; or jump conditions or observation is changed; other wise one would overwrite
; any information contained in common DETPARS from self calibrations or
; manual overrides when calling INITDETPARS. Thus, DETDEFAULTSETUP should
; be called only with IFIRSTINIT=0 from DRIFT32 and with IFIRSTINIT=1 from the
; calling script each time the detector model or jump conditions or observation
; is changed.
;
if(ifirstinit eq 1)then initdetpars
;
c999:
;
return
end









