pro displaycomposite,ipix,ipoint,ident,idefcal,ps
;
; displays composite chopper sweep for pixel ipix s/c pointing ipoint and
; readout identifier (in ramp) ident. If ident is -1 all reads are plotted.
; if ident is -2 plot the 50 ppercent of points with best statistics 
; it is assumed that the expanded array data has already been filled with the 
; call expand32,1 (for real data)
;
; calculates and overplots illumination from a simulated point source 
; (from common PSSIM).
;
@common_all
@colour_indices
;common pssim,psflux,psmap,vsmap,psconv1,psconv2,compositeweight,illsim
;
;
wintit='COMPOSITE SWEEP'
if(ipix eq 0)then pt=' PIXEL 0'
if(ipix eq 1)then pt=' PIXEL 1'
if(ipix eq 2)then pt=' PIXEL 2'
if(ipix eq 3)then pt=' PIXEL 3'
if(ipix eq 4)then pt=' PIXEL 4'
if(ipix eq 5)then pt=' PIXEL 5'
if(ipix eq 6)then pt=' PIXEL 6'
if(ipix eq 7)then pt=' PIXEL 7'
if(ipix eq 8)then pt=' PIXEL 8'
wintit=wintit+pt
window,0,tit=wintit,xs=350,ys=350
;
findkeypoint,ipix,eytrue,eztrue,keypoint
;
if(array eq 'c100')then vignecorr32,1,ipix,echop,vig
if(array eq 'c200')then vignecorr32,2,ipix,echop,vig
;
findplateau,fpoint,keypoint,vig,$
nplat,nplateau,from,to,vigp,$
keyp,finep,pident,0 ; notverbose
;
startendpoint,ipoint,ipoint,$
irasterstart,irasterstop,istartnoexpand,istopnoexpand,$
irasterstarte,irasterstope,istartexpand,istopexpand 
;
signal=fltarr(n_elements(es(0,*)))
signal(*)=es(ipix,*)
erms=signal
iorig=where(ireduce eq 0,niorig)
erms(iorig)=rms(ipix,iorig) ; real rms
itransin=1-ireduce
eytruein=eytrue(ipix,*)
eztruein=eztrue(ipix,*)
t=etime
mask=itransin
mask(*)=ebad(ipix,*)
ech=estep
;signal(*)=1.0 ; test
;signal(*)=ech(*) ; test
;
createcomposite,istartexpand,istopexpand,from,to,keyp,vigp,nplateau,$
t,signal,erms,itransin,mask,keypoint,ech,finep,pident,eytruein,eztruein,$
fpoint,vig,vigc,finepc,pidentc,eytruec,eztruec,fpointc,nplatc,nplateauc,$
signalc,tc,rmsc,itransc,echc,maskc,inrampidentc,keypointc,iptc1,iptc2,$
toc,fromc,vigpc,keypc,nc
;
;ii=where(maskc eq 0 and nc gt max(nc)/2,nii) ; only plot points with
;                                              good statistics
if(ident ge 0)then ii=where(maskc eq 0 and inrampidentc eq ident,nii)
if(ident eq -1)then ii=where(maskc eq 0,nii)
if(ident le -2)then ii=where(maskc eq 0 and nc gt max(nc)/2,nii) ; only plot 
;                                            points with good statistics
;
loadct,2 ; GRN-RED-BLU-WHT
;
;
; calculate and simulated illumination in blue from a point source
; of integrated flux PSFLUX (input parameter from common PSSIM in Jy) on a 
; background BACKPRED (input parameter from common DRIFTPAR in MJy/sterad)
;
vsmap=fltarr(n_elements(psmap(0,*,0)),n_elements(psmap(0,0,*)))
;vsmap(*,*)=(backpred/psconv1(ipix)) + (psflux*psmap(ipix,*,*))
;
; properly take into account signal non-linearity in converting to V/s ERD
; (which have not been corrected for signal non-linearity):
;
vsmap(*,*)=backpred + (psconv1(ipix)*psflux*psmap(ipix,*,*)) ; in MJy/sterad
dummy1=fltarr(nygrid*nzgrid)
dummy1(*)=vsmap(*,*)
mjtovs,ipix,idefcal,dummy1,dummy2
vsmap(*,*)=dummy2 ; in V/s
;
ktoyz,keypointc,iy,iz
if(max(iz) ne min(iz))then begin
print,'DISPLAYCOMPOSITE aborting: error in determination of simulated ',$
'illumination'
printf,iunit,$
'DISPLAYCOMPOSITE aborting - error in determination of simulated illumination'
goto, c999
endif ; max(iz) ne min(iz)
illsim=signalc ; initialisation
illsim(*)=vigc(*)*vsmap(iy,iz(0))
;
; signal in red
if(ps eq 'ps')then color=red
if(ps ne 'ps')then color=red
ymax=max(signalc(ii))*1.1
ymax=max([ymax,1.1*illsim(ii)])
ymin=0.0
plot,tc(ii),signalc(ii),xst=1,xran=[-tc(toc(0)),tc(ii(nii-1))+tc(toc(0))],$
yst=1,yran=[ymin,ymax],color=color,xtit='TIME (S)',ytit='SIGNAL (V/s)'
; overplot boundaries of chopper plateaus
if(array eq 'c200')then nchop=7
if(array eq 'c100')then nchop=13
n=n_elements(echc)-1
test=fltarr(n)
test(*)=float(echc(1:n)-echc(0:n-1))
iii=where(abs(test) gt 0.5,niii)
oplot,[dtime,dtime],[ymin,ymax],linestyle=1
oplot,[max(tc)+dtime,max(tc)+dtime],[ymin,ymax],linestyle=1
for i=0,niii-1 do begin
oplot,[tc(iii(i)+1),tc(iii(i)+1)],[ymin,ymax],linestyle=1
endfor ; i=0,nchop-1
;oplot,tc(ii),0.1*float(nc(ii)) ; diagnostics
;oplot,tc(ii),100.0*rmsc(ii)
;
oplot,tc(ii),signalc(ii),psym=3
;
; predicted illumination in violet:
if(ps eq 'ps')then color=lila
if(ps ne 'ps')then color=lila
if(compositeweight(1) ne 0.0)then oplot,tc(ii),illsim(ii),color=color
;
c999:
;
return
end







