pro driftcorr,beta,tau,signal0,sillum0,sky,ngrid,keypoint,fpoint,itrans,$
ytrue,ztrue,mask,vig,t,signal,rms,imodel,isquare,islewmethod,ifinemethod,$
fitresult,modelfit,respcorr,niter,backminv,ierr
;
;help,beta
;help,tau
;help,signal0
;help,sillum0
;help,ngrid
;help,keypoint
;help,fpoint
;help,itrans
;help,ytrue
;help,ztrue
;help,mask 
;help,vig
;help,t
;help,signal
;help,rms
;help,imodel
;help,isquare
;help,islewmethod
;help,niter
;help,backminv
;
; to do: - niter loop with better signal0 and sillum0
;        - test simple pass and optimisation (ie only run findillumhist 
;          after each complete pass through the data set until convergence.
;
; Force ISLEWMETHOD=2 for first loop (is in absence of input 
; map data. Keep it as a parameter for input map data and for a second 
; iteration in the first call to DRIFTCORR
;
;
; do inscan flat field in calling routine to get additional
; precision on plateaus being input for second iteration. And also
; do weights by rms?
;
; solves for a detector responsivity drift model (at moment only foukes 
; schubert is catered for) on a full series of chopper plateaus
; seen through a P32 observation by a single detector pixel.
;
; To come: input parameter ngrid and have subroutines m2to1 and m1to2 to
; convert 2d to 1d maps etc using common grid
;
; in this subroutine overwrite input data into a working array, created
; for the whole of ERDTOMAP in wrk common block
;
; To come: input of sky illumination array to use as array to find starting
; states. Useful eg to use estimates from other detector pixels
; in determination of illumination history.
;
; to come: add switch to stop initial iteration with continually updated
; data. This is not appropriate when we are specifying an input sky 
; illumination array and one should go straight to the second do loop 
; in which the previous pointing plateaus are fixed by the previous best
; estimates of the sky illumination from
; 
; To come output a best estimate illumination timeline (A final call to
; FINFDILLHIST - this might be output as the MODELFIT array, in which
; on the fly data points are treated according to the ISLEWMETHOD flag.
;
; To come: maybe we should put the determination of the to and from and kp and
;          nplateau to a separate subroutine and have them as input parameters
;          to this routine. Especially as we call the routine more than once 
;          and these should be same for different pixels. Also if we call
;          a routine to get an estimate for signal0.
;
; To come: subroutine to estimate starting state of detector and output
;          this estimate for starting estimate of the detector. This could eg 
;          be done by a search in two parameters for sillum0 and signal0
;          (or one - signal0 - if we are sure we know how the chopper was 
;          moving on the first spacecraft raster position and it's position in
;          the instant just before the first transmitted data point) by 
;          solving only for the first s/c raster pointing or first user-
;          supplied no. of s/c raster points (eg the first raster points
;          in which the chopper translation gives an overlap with the first 
;          chopper sweep) and minimising the mis-fit between
;          best fit model and data. This may ultimately give a solution for
;          the long term drift "switch-on" effect.
;          This option could be done in the case that we input a 
;          sky illumination array. Perhaps this subroutine should
;          be called from the calling routine.
;          
;
;
; RJT notes: before this program can be run expand32 must give reliable
; chopper because of the vignetting. Also include fpoint in expand32 if it
; is not already there.
;
; To add for first chopper plateau work backwards to find what SIGNAL0 SILLUM0
; give the observed trend on the first plateau, given the ILLUM derived from
; the second observations on that plateau, for which the memory effect from the
; initial should have died out. Otherwise we will tend to get innacurate first
; plateaus. Alternatively, always work in pairs with optimisation starting at
; last point and proceeding back in time after going forward in time, keeping
; going back and forth until the solution does not change.
;
;
; input:  BETA detector model constant
;         TAU (VOLTS) detector model constant
;         SIGNAL0     (single number in V/s): input guess for actual 
;                     (noiseless) detector response at time zero prior to the  
;                     1st data sample. Note this number would normally not be 
;                     numerically identical to the first measured point due to
;                     (1) noise on the measured point (2) due to any 
;                     residual drifts between time zero and the time of the
;                     first measured point for the case that the detector
;                     was not stabilized before the observation started and
;                     (3) because the vignetting may have been different 
;                     if the chopper was moving at time zero. Setting SIGNAL0
;                     equal to SILLUM0 means the detector would be stabilized.
;                     SIGNAL0 must be positive.
;         SILLUM0     (single number in V/s): input guess at illumination
;                     prior to the first data point. Must be positive.
;                     One would expect SILLUM0 to be close (within the
;                     vignetting variations) to the illumination on the first
;                     plateau.
;         NITER       number of passes through the data. Should be at least 2,
;                     as early determinations of plateau illuminations
;                     in the first pass are not constrained by the information
;                     on these plateaus gathered later in the dataset when
;                     the detector pixel passes again over the same sky
;                     position. 3 iterations are desirable as the second
;                     uses improved estimates in place of the initial
;                     user guess for SILLUM0 and SIGNAL0
;         NGRID       number of map pixels on the P32 natural grid
;                     (NGRID = NYGRID * NZGRID)
;         KEYPOINT   (1D array INTEGER). For each time sample 
;                    (including data taken on board but not transmitted 
;                     in fast readout modes) this contains the integer key K
;                     to the nearest direction on the P32 natural grid.
;                     K= iy + iz * nygrid,  where iy,iz are the 2D
;                     pointing positions and the grid has dimensions NYGRID,
;                     NZGRID, though this information is not needed, and not
;                     used by this routine.
;         FPOINT     (1D array INTEGER) For each time sample 
;                    (including data taken on board but not transmitted 
;                     in fast readout modes) this contains 1 if the 
;                     on target flag (OTF) was set (as defined by ERDTOMAP)
;                     and zero if the OTF is not set - ie when the data
;                     is taken on the fly.
;         ITRANS     (1D array INTEGER) This is set to 1 for data which is
;                     transmitted to the ground and zero for data not
;                     transmitted (in the fast readout modes).  
;         MASK       (1D array integer) = 1 for data to be ignored. We have
;                     to import all time sampling points in the time array
;                     T in order to follow the illumination history
;                     so for ease of programming we import all data
;                     too, necessitating a mask.
;         VIG        (1D floating array) This is set to the attenuation
;                     due to vignetting (VIG <= 1) as a function of chopper
;                     position in the sense detector signal = vig * sky
;                     As the same sky direction is viewed by the same pixel
;                     in different chopper offsets, the detector pixel
;                     illumination can vary even if the same sky direction is
;                     viewed.
;         T           (array in s) This array contains times for each read
;                     (including times where data is read on board but not
;                      transmitted since time=0 at start of observation.
;                      T refers to the time at which the detector
;                      is actually read. Note this is a non-PIA standard, and
;                      follows the time assignment in the SIGNALCREATE.PRO 
;                      routine - ie T(0) should actually be a small positive
;                      number, normally the non-destructive read interval. 
;                      *** BEWARE that
;                      if T(0) is zero spurious results can be obtained.
;         SIGNAL       (real 1D aray) measured detector signal at times in T 
;                      since time zero. All points must be
;                      positive 
;         RMS          (array in V/s) RMS uncertainty in SIGNAL
;         YTRUE        (1D array in arcsec - dimension full dataset)
;         ZTRUE        (1D array in arcsec - dimension full dataset) 
;         IMODEL       = 1 for Foukes-Schubert
;         ISQUARE      parameter specifying which quantity the optimisation
;                      seeks to minimise. The minimum value of the quantity
;                      found is output as FITRESULT.
;                      ISQUARE=1: square root of AVERAGE of sum of squares
;                                 of residuals between model and data, after
;                                 dividing each residual by RMS.
;                                 Best for clean data without glitches.
;                      ISQUARE=2: modulus of median of residuals between 
;                                 model and data. After taking the median the
;                                 median is divided by the mean RMS. 
;                                 Best for data still containing glitches.
;                      ISQUARE=0: modulus of mean of residuals between
;                                 model and data. After taking the mean the
;                                 mean is divided by the mean RMS. 
;                                 Best for clean data where the model is
;                                 not giving a good representation of the
;                                 detector response to illumination steps.
;
;          ISLEWMETHOD (Integer flag).
;                      Determined method to get the illumination history
;                      during slews. This is particularly problematic when
;                      there is no transmission to ground at intervals during 
;                      a slew. The input parameter is used for iterations
;                      other than the first, for which ISLEWMETHOD = 2
;                      should be used 
;                  = 1 use the nearest P32 natural grid pixel
;                      to define the illumination for all points 
;                      (all combinations of FPOINT ITRANS)
;                  = 2 Use the measured sky points where they exist
;                      (from SKYPASS array)
;                      (ie ITRANS=1) and linearly interpolate in time
;                      where the points don't exist (ITRANS=0). Neighboring
;                      fine pointings not used.
;                  = 3 Perform a spline fit versus position for the points 
;                      taken from SKYPASS array in the slew constraining by 
;                      surrounding fine pointings too from BESTSKY (as
;                      the fine pointings are calculated before the points
;                      on the fly).
;                  = 4 use linear interpolation between nearest P32 natural
;                      grid pixels
;                  = 5 as for 2 but neighboring fine pointings are used
; Note that ISLEWMETHOD only controls information for the calculation of
; detector state at the start of each plateau. The calculation of restored
; data on the slew is not changed in any way - ie not treated as samples
; on the nearest grid point and not interpolated.
;
;         IFINEMETHOD (Integer Flag)
;                      Determines method to get the illumination
;                      on fine pointings when finding illumination history with
;                      FINDILLHIST
;                  = 1 mean
;                  = 2 weighted mean (using skyfoundnpt as weight)
;                  = 3 weighted mean (using 1/(skyfoundfitres)^2 as weight)
;                  = 4 median (using MEDIANTRUE routine)
;
; output: SKY         (1D array in V/s) This is the illumination that each 
;                      point on the natural sky grid would receive in the
;                      absence of vignetting. The dimension of sky is the
;                      total number of points on the natural P32 grid. 
;                      SKY is constrained to be positive.
;         FITRESULT    (1D real array) an output parameter normalised to RMS 
;                      indicating how good the fit is for each elementary 
;                      sample points (ie all individual points on plateau 
;                      calculated according to 
;                      the value of the input parameter ISQUARE (see above). 
;                      The lower the better. It can be used to identify 
;                      plateaus not fitted by the data. This enables plateaus 
;                      to be masked out by the calling program if required
;                      by the application eg mapping. Note that for plateaus 
;                      with only 
;                      one data point (eg points taken on the fly) FITRESULT
;                      will tend to zero, rather than RMS, as the number of 
;                      search iterations increases. Because there is no
;                      statistical information on the goodness of fit for
;                      single points, FITRESULT is set to 0.0 for single points
;                      The overall goodness of fit can be calculated by the
;                      calling program as appropriate for the investigation
;                      being conducted (eg one could just use fine pointing
;                      points and take some statistical difference between
;                      the input data and MODELFIT.
;         MODELFIT     (array in V/s): best fit model
;                      for the data. 
;         RESPCORR     (array, dimensioness) illumination/response calculated 
;                      from the vignetting and the model. This is the basic
;                      transient correction result.
;         BACKMINV     minimum (positive) value of brightness for search
;                      in V/s
;         IERR         =1 if an error occurred
;
; Internal derived parameters:
;         
;         NPLAT        number of pointing plateaus 
;                      (including single point plateaus on the fly)
;         VIGP         (real, nplat) 
;                       Vignetting attenuation on each pointing plateau
;         KEYP         (real, nplat)
;                       Nearest natural grid identifyer ffor each plateau
;         FROM         (integer, nplat)
;                       starting IDL identifier from complete time sampling
;                       (including bad or non-transmitted points)
;                       for each plateau
;         TO            stopping IDL identifier (ge FROM) for each plateau   
;
;
;common timer,time,dtime,complete
@common_timer
;
; first find SKYMAX (single REAL in V/s) which indicates maximum possible
; brightness which could be encountered. SKYMAX is used to define search
; space in the solution for the illumination for each plateau.
;
; internal parameters
;
igood=where(mask eq 0,nigood)
if(nigood le 0)then begin
print,'DRIFTCORR: aborting: no good points'
ierr=1
goto,c999
endif ; nigood le 0
;
smax=max(signal(igood))
skymax=4.0*smax ; factor of 4 absolute maximum for single step and beta 0.25
skymax=min([skymax,1.0/dtime]) ; otherwise saturation
;
print,'DRIFTCORR: upper limit for maximum signal set to ',skymax
if(smax*dtime ge 1.0)then print,'DRIFTCORR: warning: looks like saturated data'


; for each chopper plateau optimisation
; SILMIN,SILMAX (used minimum and maximum possible values for SILLUM 
; (used to control the cutting algorithm)
;
silmax=skymax
silmin=backminv 
print,'DRIFTCORR: upper limit for maximum signal set to ',silmin
fitprec=0.1

;         fitprec is internal constant giving gives the precision to 
;         which the best fit is found. The interval of search for 
;         ILLUM=SKYSOL*VIG for each plateau used by SOLVEILLUM1
;         ILLUM is RMS*FITPREC. Where SKYSOL is the solution for the
;         plateau, VIG is the vignetting for the plateau (<=1) and
;         RMS is the detector noise for the plateau.


if(min(rms) le 0.0)then begin
print,'DRIFTCORR: rms array zero or negative '
print,' for precision within the noise - fitprec = ',fitprec
ierr=1
goto,c999
endif
;
if(isquare lt 0 or isquare gt 2)then begin
print,'DRIFTCORR: isquare out of range - isquare = ',isquare
ierr=1
goto,c999
endif
;
if(imodel ne 1 and imodel ne 2)then begin
print,'DRIFTCORR: model must be Foukes-Schubert or exponential'
ierr=1
goto,c999
endif
;
if(backminv le 0.0)then begin
print,'DRIFTCORR: aborting: detector data must be positive - '
print,'backminv = ',backminv
ierr=1
goto,c999
endif
;
itest=where(mask eq 0 and itrans eq 1,nitest)
if(min(signal(itest)) lt backminv)then begin
print,'DRIFTCORR: aborting: detector data must be at least backminv - '
print,'backminv, min(signal) = ',backminv,min(signal)
ierr=1
goto,c999
endif
;
if(beta le 0.0 or beta gt 1.0)then begin
print,'DRIFTCORR: aborting: beta out of range - beta = ',beta
ierr=1
goto,c999
endif
;
if(fpoint(0) eq 0)then begin
print,'DRIFTCORR warning: observation does not start on a fine pointing'
endif
;
if(tau le 0.0)then begin
print,'DRIFTCORR: aborting: tau negative - tau = ',tau
ierr=1
goto,c999
endif
;
if(signal0 le 0.0)then begin
print,'DRIFTCORR: aborting: SIGNAL0 must be positive - signalprev = ',$
signalprev
ierr=1
goto,c999
endif
;
if(sillum0 le 0.0)then begin
print,'DRIFTCORR: '
print,'aborting: SILLUM0 must be positive - sillumprev = ',sillumprev
ierr=1
goto,c999
endif
;
if(min(t) le 0.0)then begin
print,'DRIFTCORR: aborting: time array t must be a positive interval since'
print,'the last destructive read - min(t) = ',min(t)
ierr=1
goto,c999
endif

if(niter le 1)then begin
print,'DRIFTCORR warning: need at least two iterations: niter = ',niter
;ierr=1
;goto,c999
endif

; find pointing plateaus from FPOINT and KEYPOINT arrays. 
findplateau,fpoint,keypoint,vig,nplat,nplateau,from,to,vigp,$
keyp,finep,0 ; notverbose

;nplat=n_elements(nplateau)
;print,'nplat = ',nplat ; number of plateaus
;print,'nplateau = ',nplateau ; array containing number of points per plateau
;print,'from = ',from
;print,'to = ',to
;
; initialize arrays to hold the accumulating information of estimates of 
; true sky illumination and errors etc in these estimates. We dimension 
; these arrays according to 
; [safety factor]/[(number of pointing plateaus not on fly)*(number of natural
;                                                            map grid points)] 
;
; set up YK ZK needed by findillumhist outside future niter loop
;
findkyz,yk,zk
;
; dimension arrays holding sky measurements
;
safe=3.0
ii=where(nplateau gt 1,nmore1)
if(nmore1 le 0)then begin
print,'DRIFTCORR warning: no pointing plateau has more than one point'
ndim=safe*2.0*float(nplat)/float(ngrid)
endif ; nmore1 le 0
if(nmore1 gt 0)then begin
ndim=safe*float(nmore1)/float(ngrid)
endif ; nmore1 gt 0
ndim=long(ndim+1.)
nskyfound=lonarr(ngrid) ; initialised to 0
skyfound=fltarr(ngrid,ndim)
skyfoundfitres=skyfound
skyfoundnpt=skyfound
;
skypass=t
skypass(*)=0.0
;
print,'ndim = ',ndim
;
; solve for the plateau illumination
; and sky brightness. In initial iteration update sky brightness stack as 
; go along
;
print,'DRIFTCORR: iplat from    to nigood keyp finep sigplat   skyguess',$
'    signalprev  sillumprev'
;print,' ... signalprev  sillumprev'
;
for iplat=0,nplat-1 do begin
;
; first establish whether there are any good data on this plateau:
;
ninplat=nplateau(iplat)
itransplat=itrans(from(iplat):to(iplat))
mplat=mask(from(iplat):to(iplat))
igood=where(mplat eq 0 and itransplat eq 1,nigood)
;
if(nigood ge 1)then begin
;
; Find SIGNALPREV, SILLUMPREV from all previous photometric information
;
;
; find best guess for sky BESTSKY(0:ngrid-1) (where ngrid is number of sample 
; points on natural p32 grid)from accumulated previous results using
; information in SKYPASS and in SKYFOUND, SKYFOUNDFITRES, SKYFOUNDNPT. Using
; BESTSKY and the inferred sky brightnesses encountered during slews stored in
; SKYPASS calculate illumination history ILLHIST
; up to point kk=from(iplat)-1. For plateaus with no information 
; (due to glitches or no transmission of data) use median of
; all SKYFOUND arrays or a simple interpolation between neighboring points
; which have information (program FINDILLHIST gives a warning). 
; If there has been NO previous results (eg all points flagged bad on first 
; plateau) then use SILLUM0.
;
kk=from(iplat)-1
if(kk ge 0)then begin
;
; for fine pointing use input value of islewmethod
if(finep(iplat) eq 1)then findillhist,islewmethod,ifinemethod,sillum0,$
nskyfound,skyfound,skyfoundfitres,skyfoundnpt,$
from,to,t,vig,keypoint,fpoint,ytrue,ztrue,skypass,$
ngrid,yk,zk,bestsky,nbestsky,kk,illhist,ierr
; for on the fly use islewmethod=2
if(finep(iplat) ne 1)then findillhist,2,ifinemethod,sillum0,$
nskyfound,skyfound,skyfoundfitres,skyfoundnpt,$
from,to,t,vig,keypoint,fpoint,ytrue,ztrue,skypass,$
ngrid,yk,zk,bestsky,nbestsky,kk,illhist,ierr
;
; illhist(kk) and resphist(kk) are signal and detector response 
; right at end of previous ramp to the one to be calculated:
;
sillumcalc=illhist(0:kk)
tcalc=t(0:kk)-t(0)+dtime
; calculate detector response to illumination history
if(imodel eq 1)then foukes,beta,tau,signal0,sillum0,sillumcalc,tcalc,resphist
if(imodel eq 2)then expfun,beta,tau,signal0,sillum0,sillumcalc,tcalc,resphist
;signalprev=illhist(kk)
;sillumprev=resphist(kk)
signalprev=resphist(kk)
sillumprev=illhist(kk)
endif ; kk ge 0
if(kk lt 0)then begin ; at first point
signalprev=signal0
sillumprev=sillum0
endif
;
;;;;;;;;;;;;;;;;;;;;;;;;; now we have signalprev,sillumprev
;
; now set up remaining input parameters for SOLVEILLUM1
tplat=t(from(iplat):to(iplat))
;if(iplat gt 0)then tplat=tplat-t(to(iplat-1))
if(iplat gt 0)then tplat=tplat-t(from(iplat))+dtime
if(iplat eq 0)then tplat=tplat-t(0)+dtime 
; to get zero time on final read of previous pointing plateau
mplat=mask(from(iplat):to(iplat))
sigplat=signal(from(iplat):to(iplat))
rmsplat=rms(from(iplat):to(iplat))
tplat=tplat(igood)
mplat=mplat(igood)
sigplat=sigplat(igood)
rmsplat=rmsplat(igood)
;
; find SILLUMPLAT and hence SKYGUESS with SOLVEILLUM1  
solveillum1,beta,tau,signalprev,sillumprev,sillumplat,tplat,sigplat,rmsplat,$
fitprec,imodel,silmin,silmax,isquare,fitresult,modelfit,ierr
skyguess=sillumplat/vigp(iplat)
;

print,byte(iplat),from(iplat),to(iplat),byte(nigood),byte(keyp(iplat)),$
byte(finep(iplat)),float(median(sigplat)),float(skyguess),$
float(signalprev),float(sillumprev)
;
; update arrays of previous results if on fine pointing
;
if(finep(iplat) eq 1)then begin
kp=keyp(iplat) ; natural grid 1D pointing identifier
nskyfound(kp)=nskyfound(kp)+1
nsf=nskyfound(kp)
;print,'iplat,kp,nigood,skyguess = ',iplat,kp,nigood,skyguess
if(nsf gt ndim)then begin
print,'DRIFTCORR error: array dimension SKYFOUND too small'
ierr=1
;print,'iplat,kp,nsf = ',iplat,kp,nsf
goto, c999
endif ; nsf gt ndim
skyfound(kp,nsf-1)=skyguess
skyfoundfitres(kp,nsf-1)=fitresult 
skyfoundnpt(kp,nsf-1)=nigood ; number of data points contributing to fit
endif ; finep(iplat) eq 1
;
; save solution as a simple sequence in i (to deal with slews with various
; options specified by ISLEWMETHOD in the FINDILLHIST routine.
;
iskypass=igood+from(iplat)
skypass(iskypass)=skyguess ; fill points on the plateau including slews
;
endif ; nigood ge 1
;
endfor ; iplat
;
c999:
;
return
end




