pro driftfoulkes,sillum0,sillum,sresp,beta,tau,dt
;
; plots signal response SRESP to illumination SILLUM
; for a pixel with time constant TAU/sillum and
; step constant BETA using the Foukes
; function. The detector is assumed to be stabilised 
; at an illumination sillum0 prior to the first read.
; It is assumed any illumination changes are made
; instananeously at the beginning of each integration
; period. DT is the primitive time sampling per 
; (non-destructive) read.
;
;
n=n_elements(sillum)
sresp=fltarr(n)
sf=sillum0 ; detector is assumed to be stabilised at sillum0 prior to 1st read
sillump=sillum0 ; previous illumination
;
for i=0,n-1 do begin ; i=0 corresponds to first signal
;
if(sillum(i) ne sillump or i eq 0)then begin ; we have changed illumination
;
if(i gt 0)then sf=sresp(i-1)
s0=beta*(sillum(i)-sillump)+sf
sillump=sillum(i) ; update
b=(s0-beta*sillum(i)) ; constants for each 'plateau'
a=(1.0-beta)*b*sillum(i)
c=sillum(i)-s0
d=beta*sillum(i)
e=dt*sillum(i)/tau
ii=i-1 ; reference read for when illumination actually changed.
;
endif ; sillum(i) ne sillump
;
ee=float(i-ii)*e
sresp(i)=a/(b+c*exp(-ee))
sresp(i)=sresp(i)+d
;
endfor ; i
;
return
end
