pro emap_bank,outdir,target,text,trans
;
; writes IDL saveset of s,bad,time,ytrue,ztrue,rms to disk
; examples: 
;  emap_bank,'','','' saves tdtname.dat (eg c10157901909.dat) to current dir
;  emap_bank, '/d24/vlk/rjt/PIA/VIRGO/V7_3/MAPS','VCC0066','DRIFTCORR' 
;            saves /d24/vlk/rjt/PIA/VIRGO/V7_3/MAPSVCC0066DRIFTCORR.dat 
;
; input: 
;    OUTDIR output directory for savesets 
;           eg '/d24/vlk/rjt/PIA/VIRGO/V7_3/MAPS'
;           if outdir is '' then the current directory is used
;           if outdir is dirnam then the directory of origin of
;           the PIA internal files read by ERDTOMAP is used
;    TARGET eg 'VCC0066'. If TARGET is '' then TDTNAM,ISEQ is used
;    TEXT: string to be appended to the output saveset file name
;          to denote stage of reduction (eg 'RAW' or 'DRIFTCORR')
; input (common NAMES)
;    TDTNAM: string denoting name of TDT eg '53801001'
;    ISEQ:   string denoting sequence number of target source map
;            (normally '01' or '03' or '05' for multifilter sequence separated
;             by FCS measurements) 
;    DIRNAM: dstring denoting irectory name for internal PIA files
;            eg '/d13/vlk/rjt/pia/p32p22p25/v7_3/'
;    CFILTER (integer) = either 50,60,70,90,100,105,120,135,160,180,200
;        (common STEERIN)
;    ARRAY   either 'c100' or 'c200'
;
; common names,tdtnam,iseq,dirnam,caldir,cfilter
@common_names
;common steerin,array,nptin,npt,ninramp,imeas,osamp
;common signal,rs,cs,nch,s_in,s,badin,bad,rel,rms,glitch,jf,njf,ninchmax,rd,$
;nkf,kf,nkfmax,irelstart,nchopmed,gbad,npolyrms,nrmsmed,sigmaxfract
;common timer,time
;common plotter,otfstart,otfstop,rdstat,chop,step,otf,rpid,yrel,zrel,$
;ytrue,ztrue,yzrpidcen,nyraster,nzraster
;
@common_steerin
@common_signal
@common_timer
@common_plotter
;
d=outdir
;
if(cfilter eq 50)then c='c50'
if(cfilter eq 60)then c='c60'
if(cfilter eq 70)then c='c70'
if(cfilter eq 90)then c='c90'
if(cfilter eq 100)then c='c100'
if(cfilter eq 105)then c='c105'
if(cfilter eq 120)then c='c120'
if(cfilter eq 135)then c='c135'
if(cfilter eq 160)then c='c160'
if(cfilter eq 180)then c='c180'
if(cfilter eq 200)then c='c200'
;
; default names
if(target eq '')then begin
if(array eq 'c100')then isav=d+'c1'+iseq+tdtnam+text+'.dat'
if(array eq 'c200')then isav=d+'c2'+iseq+tdtnam+text+'.dat'
endif ; target eq ''
if(target ne '')then begin
isav=d+target+c+text+'.dat'
endif ; target ne ''
;

IF trans EQ 'in' THEN BEGIN
  print,'DATASAVE: saving s,bad,time,ytrue,ztrue,rms to ',isav
  save,s,bad,time,ytrue,ztrue,rms,file=isav
ENDIF ELSE IF trans EQ 'out' THEN BEGIN
  print,'RESTORE: from ',isav
  restore, isav
ENDIF

;
return
end































