pro findback,backfract,back,imethod
;
; Finds statistical background in dataset for each pixel
;
; input: S,BAD     (common SIGNAL)
;        NPIX      (common STEER1)
;        BACKFRACT fraction of data or map pixels for each pixel to determine
;                  background about 0.2 is a good value to avoid the
;                  worst of the switch on effect in most small maps.
;        IMETHOD   = 0 finds level corresponding to first BACKFRACT of map 
;                      pixels (better in case of noisy data as it reduces
;                      bias of noisier pixels being lower for BACKFRACT less
;                      than 0.5. However slower)
;                  = 1 finds level orresponding to first BACKFRACT of 
;                      elementary data in S
;
; output BACK(npix) background level
;
;
;common signal,rs,cs,nch,s_in,s,badin,bad,rel,rms,glitch,jf,njf,ninchmax,rd,$
;nkf,kf,nkfmax,irelstart,nchopmed,gbad,npolyrms,nrmsmed,sigmaxfract
@common_signal
;common steer1,npix,pixsize,pixpitch,pixoff,nchop,dcy,dry,drz
@common_steer1
;
;print,'findback',npix
back=fltarr(npix)
;
for ipix=0,npix-1 do begin
;
if(imethod eq 1)then begin
;
igood=where(bad(ipix,*) eq 0,nigood)
;
if(nigood le 2.0/backfract)then begin
print,'FINDBACK: not enough good data to find a statistical background'
goto, c999
endif ; nigood le 1.0/backfrac
;
dum=s(ipix,igood)
dum=dum(sort(dum))
xf=backfract*float(nigood)
nxf=round(xf)
back(ipix)=dum(nxf-1)
;
endif ; imethod eq 1
;
if(imethod eq 0)then begin
makemap,1,ipix,mapb,mapr,mapd,mapy,mapz,mapn,0,1 ; use only fix pointing
                                                 ; data with no rms scaling
igood=where(mapn gt 0,nigood)
if(nigood le 1)then begin
print,'FINDBACK: not enough good map data to find a statistical background'
goto, c999
endif ; nigood le 1
dum=mapb(igood)
dum=dum(sort(dum))
xf=backfract*float(nigood)
nxf=round(xf)
back(ipix)=dum(nxf-1)
;
endif ; imethod eq 0
;
endfor ; ipix
;
c999:
;
return
end
