pro findbetatau,pixarray,imodel,isquare,ibefore,illumsky,$
illumskyprevfilter,betadown,betaup,taudown,tauup,betaout,tauout,sillumout,$
sillumbeforeraster,sillumshootbeforeraster,fraction,imedfilter,fitresultout
;
;print,'calling FINDBETATAUFCS with parameters'
;print,'pixarray,imodel,isquare,ibefore,illumsky,illumskyprevfilter'
;print,'betadown,betaup,taudown,tauup,fraction,imedfilter = '
;print,pixarray,imodel,isquare,ibefore,illumsky,illumskyprevfilter,$
;betadown,betaup,taudown,tauup,fraction,imedfilter
;
; For two long timeconstant free parameter (beta, tau) in the detector model 
; and a further free parameter sillumout for the fcs illumination find best 
; fits to detector response to sudden fcs illuminations at start or end of a 
; P32 observation in a particular filter, in each pixel in PIXARRAY. It is 
; assumed that the detector is in equilibrium prior to the fcs illumination, 
; with response=illumination from the sky viewed at the central chopper 
; position at the first or last s/c raster position. We note that this 
; assumption may be more readily met for the first fcs illumination for the 
; C100 detector due to the long stabilisation time, when the sky has strong 
; structure. FINDBETATAUFCS should normally be called at the second and 
; subsequent
; iterations of DRIFTCORR (ie after the first good prediction of sky 
; illumination is available). The fits are displayed on the screen. A warning
; is given if the parameters found are at the boundaries of the search range.
;
; The analysis is done from imported SRD 'internal PIA' datasets which should
; already have been corrected at the ERD stage for first stage deglitch, 
; non-linearity, linear ramp fit, standard selection (ignores 1st and 
; destructive read) and at the SRD stage for deglitchsecond stage, reset 
; correction, dark, responsivity drift recognition. Note that the 
; responsity drift recognition was done to get a first reasonable guess
; for the responsitvity for the target in the SCP to SPD processing
; (accessed by CAL32 in the ERDTOMAP suite). This is retained here since 
; all fcs and processed in parallel to the target fields in the PIA processing
; prior to ERDTOMAP but has no effect on the processing in this subroutine.
; 
; If the values for SILLUMOUT are close to those for SILLUPREV a warning
; is issued, since, without a flux step there can be no possibility 
; of finding beta and tau.
;
; The analysis proceeds by finding best fit for fcs illumination for trial 
; values of beta (binary chop) and tau (binary chop in called FINDTAU routine).
;
; Note. We assume a single time constant - not a fast and a long response.
; Therefore there should be no need to process at the ERD resolution.
;
; input (common NAMES):
;    TDTNAM: string denoting name of TDT eg '53801001'
;    ISEQ:   string denoting sequence number of target source map
;            (normally '01' or '04' or '07' for multifilter sequence separated
;             by FCS measurements) 
;    DIRNAM: string denoting irectory name for internal PIA files
;            eg '/d13/vlk/rjt/pia/p32p22p25/v7_3/'
;  input:
;    PIXARRAY = (integer*NPIXLOOP) array of pixels to correct for 
;               (useful for diagnostics
;    ARRAY   (common STEERIN) = 'c100' or 'c200'
;    IBEFORE = 1 to process preceding FCS illumination 
;            = 0 to process succeeding FCS illumination
;    BETADOWN,BETAUP ; search range for beta (single reals)
;    TAUDOWN,TAUUP ; search range for tau (single reals)
;    BETAOUT (1D array dimension NPIXLOOP): input best guess for first 
;                     detector model constant for pixels specified in PIXARRAY 
;                     derived from fcs illumination at start or end of 
;                     observation.
;    TAUOUT  (1D arrays in VOLTS dimension NPIXLOOP): input best guess
;                     for second detector model constant for pixels
;                     specified in PIXARRAY derived from fcs illumination at 
;                     start or end of observation.
;    ILLUMSKY (1D array in V/s dimension NPIXLOOP):
;            sky illumination immediately
;            prior to fcs illumination at start or end of observation  
;            (found in calling routine DRIFTCORR). (Note for succeedinf fcs
;            measurement this will depend on whether the NZ is even or odd).
;    ILLUMSKYPREVIOUSFILTER (1D array in V/s dimension NPIXLOOP):
;            value of ILLUMSKY for previous filter used in AOT. This is only
;            needed for the IBEFORE=1. It should be the SKT illumination
;            in the previous filter at the starting direction of the current
;            raster.
;    IMEDFILTER        if not 0 applies mean filter to FCS data, using AVRED
;                      routine with width 
;                      about 10 percent of data stream. (NB this should only
;                      be done when the actual time constant (illum/tau for
;                      Foukes Schubert  imodel=1) is longer than ca. 1/10 at 
;                      least of the FCS data stream. Median filtering
;                      improves results for glitchy data with long time 
;                      constants. For glitchy data with short time constants
;                      It is best to run FINDBETATAUFCS with a truncated data
;                      set (FRACTION < 1.0) and use ISQUARE=2.
;         FRACTION     0 < FRACTION <= 1 Only the first fraction FRACTION
;                      of the data is used in the fit. Gives improved results
;                      for fast detector response when the long term response
;                      is controlled by a long term responsivity drift
;                      independent of the short term effects. 
;         IMODEL       = 1 for Foukes-Schubert
;         ISQUARE      parameter specifying which quantity the optimisation
;                      seeks to minimise. The minimum value of the quantity
;                      found is output as FITRESULT.
;                      ISQUARE=1: square root of AVERAGE of sum of squares
;                                 of residuals between model and data, after
;                                 dividing each residual by RMS.
;                                 Best for clean data without glitches.
;                      ISQUARE=2: modulus of median of residuals between 
;                                 model and data. After taking the median the
;                                 median is divided by the mean RMS. 
;                                 Best for data still containing glitches.
;                      ISQUARE=0: modulus of mean of residuals between
;                                 model and data. After taking the mean the
;                                 mean is divided by the mean RMS. 
;                                 Best for clean data where the model is
;                                 not giving a good representation of the
;                                 detector response to illumination steps.
;
; output:
;         BETAOUT (1D array dimension NPIXLOOP): first 
;                     detector model constant for pixels specified in PIXARRAY 
;                     derived from fcs illumination at start or end of 
;                     observation.
;         TAUOUT  (1D arrays in VOLTS dimension NPIXLOOP): second 
;                     detector model constant for pixels
;                     specified in PIXARRAY derived from fcs illumination at 
;                     start or  end of observation.
;         SILLUMOUT (1D array dimension NPIXLOOP in V/s): best 
;                     fit constant 
;                     illumination for each pixel specified by PIAXARRAY from
;                     fcs illumination at start or end of observation.
;         SILLUMBEFORERASTER (1D array dimension NPIXLOOP in V/s): best 
;                     estimate of slow detector response SIGNAL at the 
;                     instant before 
;                     the raster starts (generally not equal to ILLUMSKY).
;                     This is obviously only useful for ibefore=1. Note that
;                     SILLUMBEFORERASTER=total signal before raster for
;                     imodel=1 or 2
;         SILLUMSHOOTBEFORERASTER (1D array dimension NPIXLOOP in V/s): best 
;                     estimate of fast detector response SIGNAL at the 
;                     instant before the raster starts. Only used if
;                     imodel ge 3 
;         FITRESULTOUT (1D array dimension NPIXLOOP) goodness of fit 
;                     - lower is better - according to
;                     value of input parameter ISQUARE - see description
;                     of isquare, above)
;
; output to common block FCSCAL: (these results will be needed by CAL32 to 
;                     correct the "responsivity drift recognition" result
;                     for residual systematic errors due to the transient 
;                     response of the fcs). If no results for any pixel have 
;                     previouslyb een obtained by FINDBETATAUFCS then all the 
;                     following arrays are first initialised with zeros.   
;         FOUNDBEFORE,FOUNDAFTER - (1D integer arrays V/s dimension NPIX where
;                     NPIX is total number of detector pixels)
;                     =1 if an fcs fit has been performed and the results
;                     stored in the arrays SILLUMPREVBEFORE, SILLUMPREVAFTER,
;                     ILLBEFORE ILLAFTER FOUNDBEFORE FOUNDAFTER
;                     =0 if an fcs fit has been performed. 
;                     The two arrays are for the cases before 
;                     and after the raster.
;         SILLUMBEFORE,SILLUMAFTER - (1D real arrays V/s dimension NPIX) fcs 
;                     illumination in V/s found by fitting routine for cases 
;                     before and after the raster.
;         FITENDBEFORE,FITENDAFTER - (1D real arrays V/s dim. NPIX). Value of
;                     Fit to FCS plateau at end of plateau (ie at time of last
;                     SRD plateau, not at infinity).
;         SILLUMPREVBEFORE, SILLUMPREVAFTER - (1D real arrays V/s dim. NPIX)
;                     Illumination before FCS switched on for cases FCS before 
;                     and after the raster. (Copied from input parameter
;                     ILLUMSKY).
;
;common names,tdtnam,iseq,dirnam,caldir,cfilter
@common_names
;common steerin,array,nptin,npt,ninramp,imeas,osamp
@common_steerin ; NB don't use nptin,npt,ninramp,imeas in this routine!
;common fcscal,foundbefore,foundafter,sillumbefore,sillumafter,$
;fitendbefore,fitendafter,sillumprevbefore,sillumprevafter
@common_fcscal
;
; internal constants controlling trade off between speed, precision and 
; robustness of fit
;
if(array eq 'c100')then begin
;betamin=0.1 ; search range for beta
;betamax=0.99 ; must be < 1.0
taumin=5.0 ; search range for tau
taumax=100.0 
endif ; array eq 'c100'
;
if(array eq 'c200')then begin
;betamin=0.5 ; search range for beta
;betamax=0.99 ; must be < 1.0
taumin=5.0; search range for tau
taumax=100.0 
endif ; array eq 'c200'
;
betamin=betadown
betamax=betaup
taumin=taudown
taumax=tauup
;
if(fraction le 0.0)then begin
print,'FINDBETATAUFCS - aborting since input parameter FRACTION = ',fraction
goto,c999 
endif ; fraction le 0.0
;
; control parameter for precision of fit in this routine and the called
; routines FINDTAU and SOLVEILLUM1:
;
;betaprec=0.01 ; precision in beta for this roution
;tauprec=0.1 ; (Volts) precision in tau for FINDTAU routine
betaprec=0.01
tauprec=0.1
;
; control parameter for major do loop to find FCS illumination
;
nmajiter=7
;
; control parameters for the cut in beta in this  routine:
niter=1 ; number of iterations in this routine 
;         for diagnostics - set to a large number to control convergence
;         by BETAPREC. In fact, though iter is bbuilt in to the logic, we
;         ignore it to avoid all possibility of getting a too crude
;         sampling of the minimum.
ncut=5 ; must be odd and at least 5
reduce=1.5 ; must be in range > 1.0 (slow  to 2.0 (fast)
irmswk=0 ; to tune tauprec in FINDTAU call to the search interval
;              in tau (for speed). Note a corresponding parameter (not passed)
;              also operates in FINDTAU. In fact this does not speed things
;              up much but can make the routine unreliable. Subsequent tests
;              showed this effect was due to the absoluet limit for tauprecwk 
;              being set to 1.0. It should really be a maximum of 0.5 for
;              isquare=1.
;
; Parameters for determination of detector illumination history and
; thereby detector state prior to FCS illumination and (for ibefore=1) prior
; to start at raster:
;
;tf2=2.0 ; time between FCS illumination and start of data taking
tf2=0.0 ; for consistency with self cal
if(array eq 'c100')then tf2=0.0 ; best for C100 Foukes
;
; read in data rms time flag for first and second fcs illumination to 
; fsig1, fsig2; frms1, frms2; t1, t2; flag1, flag2.
;
if(iseq eq '01')then begin
if(ibefore eq 1)then iseq1='00'
if(ibefore ne 1)then iseq1='02'
endif ; iseq eq '01'
if(iseq eq '04')then begin
if(ibefore eq 1)then iseq1='03'
if(ibefore ne 1)then iseq1='05'
endif ; iseq eq '04'
if(iseq eq '07')then begin
if(ibefore eq 1)then iseq1='06'
if(ibefore ne 1)then iseq1='08'
endif ; iseq eq '07'
if(iseq eq '10')then begin
if(ibefore eq 1)then iseq1='09'
if(ibefore ne 1)then iseq1='11'
endif ; iseq eq '10'
if(iseq eq '13')then begin
if(ibefore eq 1)then iseq1='12'
if(ibefore ne 1)then iseq1='14'
endif ; iseq eq '13'
if(iseq eq '16')then begin
if(ibefore eq 1)then iseq1='15'
if(ibefore ne 1)then iseq1='17'
endif ; iseq eq '16'
if(iseq eq '19')then begin
if(ibefore eq 1)then iseq1='18'
if(ibefore ne 1)then iseq1='20'
endif ; iseq eq '19
if(iseq eq '22')then begin
if(ibefore eq 1)then iseq1='21'
if(ibefore ne 1)then iseq1='23'
endif ; iseq eq '22'
;
if(array eq 'c100')then begin
isrd1 = dirnam+'C1'+iseq1+tdtnam+'.ISRD'
endif ; array eq 'c100'
if(array eq 'c200')then begin
isrd1 = dirnam+'C2'+iseq1+tdtnam+'.ISRD'
endif ; array eq 'c200'
print,'FINDBETATAUFCS: reading SRD file (FCS)',isrd1
;
@phtsrd
read_isrd,isrd1
imeas=N_ELEMENTS(phtsrd) -1
handle_value,phtsrd(imeas).slop,fsig1 ; signal array (npix+2,n1)
; note only the first npix elements of fsig1, fsig1(0:npix-1) contain data
handle_value,phtsrd(imeas).slun,frms1 ; signal uncertainty (npix+2,n1)
handle_value,phtsrd(imeas).stim,t1 ; time (n1)
;handle_value,phtsrd(imeas).temp,temp ; temperature (n1)
;plot,t1,temp,yran=[min(temp),max(temp)],xsty=1
;plot,temp,fsig1(0,*),xran=[min(temp),max(temp)],xsty=1
t1=t1-t1(0)+t1(1)-t1(0) ; needed for SOLVEILLUM1 and handling of FRACTION
;
tfcs=max(t1) ; needed for call to SOLVEFCSILLUMHIST
t1=t1+tf2
;
handle_value,phtsrd(imeas).flag,flag1 ; flag (n1)
n1=n_elements(fsig1(0,*)) ; number of data points
;
; process each pixel
;
npixloop=n_elements(pixarray)
;betaout=fltarr(npixloop)
;tauout=betaout
sillumout=fltarr(npixloop)
fitresultout=sillumout
signalendout=sillumout
sillumbeforeraster=sillumout
sillumshootbeforeraster=sillumout
f1=lonarr(n1)
;
; units 10 to 20 reserved for data (TIMELINEFIGURE.PRO)
if(ibefore eq 1)then iunit=20 ; counter for output plots
if(ibefore ne 1)then iunit=30
loadct,2 ; GRN-RED-BLU-WHT
silminlim=0.0001 ; minimum tolerated fcs signal
;
for pix=0,npixloop-1 do begin
;
ipix=pixarray(pix)
;
; plot fcs data for pixel ipix at start of observation
;
if(ipix eq 0)then tit=tdtnam+' '+iseq1+' FCS PIXEL 0'
if(ipix eq 1)then tit=tdtnam+' '+iseq1+' FCS PIXEL 1'
if(ipix eq 2)then tit=tdtnam+' '+iseq1+' FCS PIXEL 2'
if(ipix eq 3)then tit=tdtnam+' '+iseq1+' FCS PIXEL 3'
if(ipix eq 4)then tit=tdtnam+' '+iseq1+' FCS PIXEL 4'
if(ipix eq 5)then tit=tdtnam+' '+iseq1+' FCS PIXEL 5'
if(ipix eq 6)then tit=tdtnam+' '+iseq1+' FCS PIXEL 6'
if(ipix eq 7)then tit=tdtnam+' '+iseq1+' FCS PIXEL 7'
if(ipix eq 8)then tit=tdtnam+' '+iseq1+' FCS PIXEL 8'
iunit=iunit+ipix+1
window,iunit,tit=tit,xs=800,ys=400,xpos=470,ypos=570
f1(*)=flag1(ipix,*)
; rjt igood=where(f1 eq 1,nigood)
igood=where(f1 le 1,nigood)
igoodin=igood
nigoodin=nigood
if(nigood le 5)then begin
print,'FINDSBETATAUFCS: not enough good fcs data for iseq, ipix = ',iseq1,ipix
print,'... nigood = ',nigood
print,'... aborting'
goto, c999
endif ; nigood le 5
t=t1(igood)
signal=t
signal(*)=fsig1(ipix,igood)
signalin=signal
tin=t
;
if(imedfilter ne 0)then begin
;nmaxpt=7
nmaxpt=11 ; best to have odd value. This should be large enough to accomodate
;                                   the FRACTION used as the cut in SIGNAL
;                                   is made after the resampling of SIGNAL
;                                   using the subroutine AVRED
if(fraction lt 1.0)then begin
nmaxpt=long(float(nmaxpt)/fraction)
evenodd,nmaxpt,iodd
if(iodd eq 0)then nmaxpt=nmaxpt+1
if(nmaxpt gt nigood)then nmaxpt=nigood
endif ; fraction lt 1.0
if(nmaxpt lt nigood)then begin
dummy=signal
avred,dummy,signal,nmaxpt,1,idone ; resample to maximum of 10 points using 
;                                   median. Note media is better than mean
;                                   when the systematic data variation is 
;                                   larger than the noise and there is 
;                                   curvature
dummy=t
avred,dummy,t,nmaxpt,idone ; resample to a maximum of 10 points
endif ; nmaxpt lt nigood
endif ; imedfilter ne 0
;
nigood=n_elements(t)
; we can be less conservative here than on the short
; plateaus within an observation where *4.0 is used.
;
n2=14 ; take median of last 15 points from input data at original sampling
;
sillumend=median(signalin(nigoodin-1-n2:nigoodin-1)) ; 
; limits for FCS illumination
silmax=sillumend*1.1
silmin=sillumend/1.1
;
plot,tin,signalin,color=10,xran=[0.0,max(tin)],$
yran=[min([0.0, min(signalin)]),max(signalin)*1.25],xsty=1,ysty=1
;
; plot un filtered signal and frame in black
;
rmsval=median(frms1(ipix,igood))
rms=t
rms(*)=rmsval
;
; Note for quick time constants only the first few points will be
; decisive in finding the best fit. Hence in these circumstances
; we should not median filter but use small FRACTION
;
; Parameters TALL RMSALL SIGNALALL to be fed to SOLVEILLUM1
;
tall=t
rmsall=rms
signalall=signal
nigoodall=nigood
; remove negative points from SIGNALALL with a warning
ipos=where(signalall ge 0.0,nipos)
if(nipos lt nigoodall)then begin ; there are negative values still
print,'FINDBETATAUFCS: warning ...'
print,'... negative FCS signals have been censored in SIGNALALL'
signalall=signal(ipos)
rmsall=rms(ipos)
tall=t(ipos)
nigoodall=nipos
endif ; nipos ne nigoodall
;
; now condition SIGNAL RMS and T arrays to be fed to FINDTAU
; (i) remove negative points with a warning
; (ii) truncate array to use only data only up to time FRACTION of original
;      FCS duration. This gives a better fit to short term time constant
;      provided the FCS illumination is constrained to be a sensible value.
; (i) remove negative points with a warning
;ineg=where(signal le 0.0,nineg)
ipos=where(signal ge 0.0,nipos)
if(nipos lt nigood)then begin ; there are negative values still
print,'FINDBETATAUFCS: warning negative FCS signals have been censored'
signal=signal(ipos)
rms=rms(ipos)
t=t(ipos)
nigood=nipos
endif ; nipos ne nigood
;
; (ii) truncate array
if(fraction lt 1.0)then begin
tmax=fraction*max(t1) ; (t1 has been set above to count from zero)
ifract=where(t le tmax,nifract)
if(nifract lt 5)then begin
print,'FINDBETATAUFCS aborting - too few points in plateau fraction specified ...'
print,'... imedian, fraction, nifract = ',imedian, fraction, nifract
goto, c999
endif ; nifract lt 5
signal=signal(ifract)
rms=rms(ifract)
t=t(ifract)
nigood=nifract
endif ; fraction lt 1.0
;
; prepare parameters for FINDTAU 
;
sillumpr=illumsky(pix) ; (pix) is OK
signalprev=sillumpr
signalprevshoot=0.0
illumskypf=illumskyprevfilter(pix)
illumfcs=sillumend ; this is not important as the call to solvefcsillumhist
;                    is only to get the starting state for the detector
;                    before the fcs illumination sillumfcsprev,signalfcsprev
;
; note that tfcs was found on importing the fcs data
;
; find detector state immediately prior to the FCS illumination using input
; values for beta, tau BETAOUT,TAUOUT
;
idarkbefore=0 ; AOT not started from dark
solvefcsillumhist,betaout(pix),tauout(pix),imodel,sillumpr,illumskypf,$
idarkbefore,tf2,illumfcs,tfcs,sillumfcsprev,signalfcsprev,signalshootfcsprev,
signalbeforeraster,signalshootbeforeraster,fcsillum,fcstime,fcsresp,ibefore
;
sillumpr=sillumfcsprev
signalprev=signalfcsprev
signalprevshoot=signalshootfcsprev
;
if(silmax le silminlim)then begin
print,'FINDBETATAUFCS: fcs signal for iseq,ipix',iseq1,ipix
print,'... less than ',silminlim
print,'... aborting'
goto, c999
endif ; silmax le 0.0
;
if(silmin le 0.0 or silmin eq silmax)then begin
silmin=silminlim
print,'FINDBETATAUFCS: warning neg. or zero min fcs signal for iseq,ipix',$
iseq1,ipix
print,'... setting SILMIN to ',silmin
endif ; silmin le 0.0 or silmin eq silmax
;
; Major loop for finding sillumout(pix) - the FCS illumination
;
; set up initial values for convergence in both FCS illumination do loop
; and the nested chop in beta, tau, using default values for beta, tau and
; the value of sillumend set above
;
beta=betaout(pix)
tau=tauout(pix)
; find sillumend
solveillum1,beta,tau,signalprev,signalprevshoot,sillumpr,sillumend,$
tall,signalall,rmsall,0.1,imodel,silmin,silmax,isquare,fitresult,modelfit,ierr
findtau,beta,tau,signalprev,signalprevshoot,sillumpr,sillumend,t,signal,rms,$
tauprec,imodel,taumin,taumax,isquare,fitresult,modelfit
;
;print,'FINDBETATAUFCS: sillumend,beta,tau,fitresult = ',$
;sillumend,beta,tau,fitresult
;
fitresultmin=fitresult
fitresultbegin=fitresult
fitresultout(pix)=fitresultmin ; (pix) is OK!!
sillumout(pix)=sillumend
modelfitout=modelfit ; best model fit (for overplotting);
;
iexit=-1 ; to avoid an unnecessary solveillum1 call upon entering nmajiter loop
;
for imajiter=0,nmajiter-1 do begin ; 
;
; find new best estimate for sillumend from current best estimate of beta tau  
; by running solveillum1. Note that if on the previous iteration imajiter
; no new solution was found there is no point continuuing the do loop as
; the optimisation will be identical.
;
if(iexit eq 1)then begin
print,'FINDBETATAUFCS: exiting SILLUMEND LOOP with ...'
print,'... sillumout,beta,tau = ',sillumout(pix),betaout(pix),tauout(pix)
goto, c300
endif ; iexit eq 1
;
solveillum1,betaout(pix),tauout(pix),signalprev,signalprevshoot,sillumpr,$
sillumend,tall,signalall,rmsall,0.1,imodel,silmin,silmax,isquare,fitresult,$
modelfit,ierr
;
;
; update signalprev,sillumpr
;
solvefcsillumhist,betaout(pix),tauout(pix),imodel,sillumpr,illumskypf,$
idarkbefore,tf2,sillumend,tfcs,sillumfcsprev,signalfcsprev,signalshootfcsprev,$
signalbeforeraster,signalshootbeforeraster,fcsillum,fcstime,fcsresp,ibefore
;
sillumpr=sillumfcsprev
signalprev=signalfcsprev
signalprevshoot=signalshootfcsprev
sillumbeforeraster(pix)=signalbeforeraster
sillumshootbeforeraster(pix)=signalshootbeforeraster
;
; start cut scheme in beta for current value of sillumend
; for each trial beta in cut scheme find best fit for fcs illumination
; and tau, calling FINDTAU.
;
; derived controlling parameters for chop in beta
;
xncut=float(ncut)
top=betamax
bot=betamin
dcut=(top-bot)/(xncut-1.0)
betatrial=bot+dcut*findgen(ncut)
;
if(irmswk eq 0)then tauprecwk=tauprec
if(irmswk eq 1)then begin
tauprecwk=tauprec*(dcut/betaprec) ;     it is unnecessry to have high precision
if(tauprecwk lt tauprec)then tauprecwk=tauprec
if(tauprecwk gt 0.5)then tauprecwk=0.5 ; fits where the model parameters are
;                                        far from optimum
if(tauprecwk lt 0.1)then tauprecwk=0.1
endif ; irmswk eq 1
;
;print,'FINDBETATAUFCS: bot,top,dcut,betatrial = ',bot,top,dcut,betatrial
;
beta=betatrial(0)
;
icutmin=0
;
iexit=1
iter=0
;
c100:
;
for icut=0,ncut-1 do begin
;
beta=betatrial(icut)
; find sillum,tau combination giving best fit (with chi-squared-like 
; value FITRESULT and fit MODELFIT) for trial beta and fixed SIGNALPREV,
; SILLUMPR VALUES
;
findtau,beta,tau,signalprev,signalprevshoot,sillumpr,sillumend,t,signal,rms,$
tauprec,imodel,taumin,taumax,isquare,fitresult,modelfit
;
;print,'FINDBETATAUFCS: sillumend,beta,tau,fitresult,fitresultmin = ',$
;sillumend,beta,tau,fitresult,fitresultmin
;
if(fitresult lt fitresultmin)then begin ; found new minimum
icutmin=icut
fitresultmin=fitresult
fitresultout(pix)=fitresultmin ; (pix) is OK!!
tauout(pix)=tau
betaout(pix)=beta
sillumout(pix)=sillumend
iexit=0 ; prevents leaving itermaj do loop prematurely on next sillumend
        ; iteration.
modelfitout=modelfit ; best model fit (for overplotting)
;print,'FINDBETATAUFCS: iter,tauout,betaout,sillumout,fitresultmin = ',$
;iter,tauout(pix),betaout(pix),sillumout(pix),fitresultmin
endif ; fitresult lt fitresultmin
;
endfor ; icut
;
if(dcut le betaprec)then goto, c200
d=top-bot
d=d/reduce
d2=d/2.0
bot=betaout(pix)-d2
top=betaout(pix)+d2
bottmp=bot
toptmp=top
if(bot lt betamin)then begin
bottmp=betamin
toptmp=bottmp+d
endif ; bot
if(top gt betamax)then begin
toptmp=betamax
bottmp=toptmp-d
endif ; top
bot=bottmp
top=toptmp
dcut=(top-bot)/(xncut-1.0)
betatrial=bot+dcut*findgen(ncut)
;
if(irmswk eq 0)then tauprecwk=tauprec
if(irmswk eq 1)then begin
tauprecwk=tauprec*dcut/betaprec ;       it is unnecessry to have high precision
if(tauprecwk lt tauprec)then tauprecwk=tauprec
if(tauprecwk gt 0.5)then tauprecwk=0.5 ; fits where the model parameters are
;                                        far from optimum
if(tauprecwk lt 0.1)then tauprecwk=0.1
endif ; irmswk eq 1
;
; always find a new minimum for each value of dcut. Because the fit result is
; decreased not only due to the approach to the correct tau, but also by
; the decrease in FITPRECWK in each iteration:
;if(irmswk eq 1)then fitresultmin=fitresultbegin ; don't do this. It will
;                                ; make convergence happen at false minimum
iter=iter+1
;print,'FINDBETATAUFCS: iter,bot,top,betatrial ',iter,bot,top,betatrial
;
goto, c100
;
c200:
;
endfor ; imajiter=0,nmajiter-1
;
print,'FINDBETATAU: finished sillumend do loop with ...'
print,'... sillumout,beta,tau = ',sillumout(pix),betaout(pix),tauout(pix)
c300:
;
;oplot,t,modelfitout,color=50 ; overplot best fit (median filtered and clipped
;                                                  data)
;
; find model fit (SIGNALOUT array) at original time sampling (T1) 
; and take value at last sample of SIGNALOUT for SIGNALENDOUT
;
sillumoutarray=t1
sillumoutarray(*)=sillumout(pix)
;
if(imodel eq 1)then $
foukes,betaout(pix),tauout(pix),signalprev,sillumpr,sillumoutarray,$
t1,signalout ; (pix) is OK!!
if(imodel eq 2)then $
expfun,betaout(pix),tauout(pix),signalprev,sillumpr,sillumoutarray,$
t1,signalout ; (pix) is OK!!
if(imodel eq 3)then $
expshoot,betaout(pix),tauout(pix),signalprev,signalprevshoot,sillumpr,$
sillumoutarray,t1,signalout,signalslowout,signalshootout
;
nnnn=n_elements(signalout)
signalendout(pix)=signalout(nnnn-1) ; total signal for ech of imodel=1,2,3
;
oplot,t1,signalout,color=15 ; overplot best fit (sampled at all input time 
;                              intervals measured) in green
;
; plot level of illumination in red
oplot,[0,max(t1)],[signalendout(pix),signalendout(pix)],color=37 ; 
;
;
; overplot extension over whole time range from zero of fcs as dashed line
; including first part (TF2 seconds) of fcs exposure when no data was taken 
;
tdum=findgen(100)/99.0
tdum=tdum*max(t1)
if(imodel eq 1)then $
foukes,betaout(pix),tauout(pix),signalprev,sillumpr,sillumoutarray,$
tdum,signaloutdum ; (pix) is OK!!
if(imodel eq 2)then $
expfun,betaout(pix),tauout(pix),signalprev,sillumpr,sillumoutarray,$
tdum,signaloutdum ; (pix) is OK!!
if(imodel eq 3)then $
expshoot,betaout(pix),tauout(pix),signalprev,signalprevshoot,sillumpr,$
sillumoutarray,tdum,signaloutdum,signalslowoutdum,signalshootoutdum
;
oplot,tdum,signaloutdum,color=15,linestyle=2
;
endfor ; pix
;
; now output value of fits and asymptote to the FCSCAL common block
;
; create arrays if they don't exist:
if(array eq 'c100')then npix=9
if(array eq 'c200')then npix=4
if(n_elements(foundbefore) eq 0)then foundbefore=lonarr(npix)
if(n_elements(foundafter) eq 0)then foundafter=lonarr(npix)
if(n_elements(sillumbefore) eq 0)then sillumbefore=fltarr(npix)
if(n_elements(sillumafter) eq 0)then sillumafter=fltarr(npix)
if(n_elements(sillumprevbefore) eq 0)then sillumprevbefore=fltarr(npix)
if(n_elements(sillumprevafter) eq 0)then sillumprevafter=fltarr(npix)
if(n_elements(fitendbefore) eq 0)then fitendbefore=fltarr(npix)
if(n_elements(fitendafter) eq 0)then fitendafter=fltarr(npix)
;
if(ibefore eq 1)then begin
sillumprevbefore(pixarray)=illumsky(*)
sillumbefore(pixarray)=sillumout(*)
foundbefore(pixarray)=1
fitendbefore(pixarray)=signalendout(*)
endif ; ibefore eq 1
;
if(ibefore ne 1)then begin
sillumprevafter(pixarray)=illumsky(*)
sillumafter(pixarray)=sillumout(*)
foundafter(pixarray)=1
fitendafter(pixarray)=signalendout(*)
endif ; ibefore eq 1
;
print,'FINDBETATAUFCS results ....'
print,'ipix,illumsky,sillumbeforeraster,sillumshootbeforeraster,
signalendout,sillumout...'
print,'... betaout,tauout,fitresultout'
;
for pix=0, npixloop-1 do begin
;
ipix=pixarray(pix)
print,ipix,illumsky(pix),sillumbeforeraster(pix),sillumshootbeforeraster(pix),$
signalendout(pix),sillumout(pix)
print,betaout(pix),tauout(pix),fitresultout(pix)
if(betaout(pix) eq betamin or betaout(pix) eq betamax)then $
print,'warning - beta found is at boundary of search range'
if(tauout(pix) eq taumin or tauout(pix) eq taumax)then $
print,'warning - tau found is at boundary of search range'
test=(illumsky(pix)-sillumout(pix))/illumsky(pix)
if(abs(test) lt 0.1)then begin ; flux step may be too small for reliable
                               ; determination of detector parameters
print,'warning - fcs too closely matched to sky ...'
print,'ipix,illumsky,sillumout = ',ipix,illumsky(pix),sillumout(pix)
endif
;
endfor ; second pix loop
;
c999:
;
return
end





