pro findfitresult,signal,rms,model,fitresult,isquare
;
; Input: 
;       SIGNAL,RMS,MODEL (real arrays)
;       ISQUARE (INTEGER)
;
; Output: 
;       FITRESULT (real single value). Always initialised to 0.0
;                                      
;
; finds a chi-squared like number FITRESULT which measures the goodness
; of fit between input data and fitted arrays SIGNAL and MODEL where 
; RMS is an array denoting the rms of each data point in SIGNAL. FITRESULT
; is calculated according to the value of the input parameter ISQUARE as
; follows:
;
;         ISQUARE      parameter specifying which quantity the optimisation
;                      seeks to minimise. The minimum value of the quantity
;                      found is output as FITRESULT.
;                      ISQUARE=1: square root of AVERAGE of sum of squares
;                                 of residuals between model and data, after
;                                 dividing each residual by RMS.
;                                 Best for clean data without glitches.
;                      ISQUARE=2: modulus of median of residuals between 
;                                 model and data. After taking the median the
;                                 median is divided by the mean RMS. 
;                                 Best for data still containing glitches.
;                      ISQUARE=0: modulus of mean of residuals between
;                                 model and data. After taking the mean the
;                                 mean is divided by the mean RMS. 
;                                 Best for clean data where the model is
;                                 not giving a good representation of the
;                                 detector response to illumination steps.
; 
xnpt=float(n_elements(signal)) 
sumsq=0.0
fitresult=sumsq
;
if(isquare eq 1)then begin
res=signal-model
resrms=res/rms
sumsq=sqrt(total(resrms*resrms)/xnpt)
endif
;
; rjt sep11_99 if(isquare eq 0)then sumsq=abs(total(res)/xnpt)/rmsmean
;
if(isquare eq 0)then begin
res=signal-model
rmsmean=total(rms)/xnpt
sumsq=(total(abs(res))/xnpt) / rmsmean
endif
;
if(isquare eq 2)then begin
; rjt sep11_99 mediantrue,res,resmedtrue
; rjt sep11_99 sumsq=abs(median(resmedtrue))/rmsmean
res=signal-model
rmsmean=total(rms)/xnpt
mediantrue,abs(res),resmedtrue
sumsq=resmedtrue/rmsmean
endif ; isquare eq 2
;
fitresult=sumsq
;
return
end


