pro findillhist,islewmethod,sillum0,$
from,to,t,vig,keypoint,fpoint,ytrue,ztrue,skypass,ech,$
ngrid,yk,zk,bestsky,jj,kk,pident,illhist,ipix,ierr
;
;if(kk eq 3120)then save,/xdr,$
;islewmethod,sillum0,ech,pident,$
;from,to,t,vig,keypoint,fpoint,ytrue,ztrue,skypass,$
;ngrid,yk,zk,bestsky,jj,kk,$
;file='findillhist.xdr'
;
; find best guess for illumination history ILLHIST over the timeline from
; sample JJ to sample KK (including bad points and data not transmitted) and 
; the best guess sky on the fine pointings BESTSKY(0:ngrid-1) from accumulated 
; previous results using
; information in SKYPASS and in SKYFOUND, SKYFOUNDFITRES, SKYFOUNDNPT. ILLHIST
; is found from BESTSKY and the inferred sky brightnesses encountered during 
; slews stored in SKYPASS calculate illumination history ILLHIST (using 
; vignetting array VIG) up to point kk=from(iplat)-1. For plateaus with no 
; information use median of all SKYFOUND arrays or a simple interpolation 
; between neighboring points which have information (program FINDILLHIST 
; gives a warning). If there has been NO previous results (eg all points 
; flagged bad on first plateau with kk on first plateau) then use SILLUM0.
;
; Although it should be possible to run FINDILLHIST for any KK
; obviously best results will be obtained if KK is at the end of a 
; fine pointing plateau, to help the interpolation on interveing slews.
; For arbitrary kk one should thus use ISLEWMETHOD=2, whereas for
; fine pointing end points ISLEWMETHOD = 4 would be better.
;
; input:
;         JJ          (Integer) is the IDL identifier in the original full
;                     time sampled data set from which the illumination is
;                     to be calculated. JJ is rounded down on output to
;                     coincide with the start of a plateau.
;         KK          (Integer) is the IDL identifier in the original full
;                     time sampled data set up to and including which the 
;                     illumination history is to be found.
;         SILLUM0     (single number in V/s): guess at most probable sky
;                     illumination, to be used when no data can be found.
;                     For example it can be input as the median of the
;                     (unexpanded) data set.
;         NGRID       number of map pixels on the P32 natural grid
;                     (NGRID = NYGRID * NZGRID)
;         YK, ZK      1D real arrays dimension ngrid containing
;                     Y and Z positions in arcsec of fine pointing directions
;         KEYPOINT   (1D array INTEGER dimension full data set). 
;                     For each time sample 
;                    (including data taken on board but not transmitted 
;                     in fast readout modes) this contains the integer key K
;                     to the nearest direction on the P32 natural grid.
;                     K= iy + iz * nygrid,  where iy,iz are the 2D
;                     pointing positions and the grid has dimensions NYGRID,
;                     NZGRID, though this information is not needed, and not
;                     used by this routine. Note that the set of fine pointings
;                     covered by a single pixel will always be smaller than the
;                     set covered by the P32 standard grid. It is assumed that
;                     the calling routine can properly assign this even for 
;                     points on the fly. 
;         ECH        (1D array INTEGER of whole timeline of observation). 
;                      Chopper plateau identifier
;                     (1 to 13 for C100 1 to 7 for C200) for each time sample
;         FPOINT     (1D array INTEGER dimension full data set).
;                     For each time sample 
;                    (including data taken on board but not transmitted 
;                     in fast readout modes) this contains 1 if the 
;                     on target flag (OTF) was set (as defined by ERDTOMAP)
;                     and zero if the OTF is not set - ie when the data
;                     is taken on the fly.
;         VIG        (1D floating array, dimension full data set)
;                     This is set to the attenuation
;                     due to vignetting (VIG <= 1) as a function of chopper
;                     position in the sense detector signal = vig * sky
;                     As the same sky direction is viewed by the same pixel
;                     in different chopper offsets, the detector pixel
;                     illumination can vary even if the same sky direction is
;                     viewed.
;         T           (array in s - dimension full data set) 
;                      This array contains times for each read
;                     (including times where data is read on board but not
;                      transmitted since time=0 at start of observation.
;                      T refers to the time at which the detector
;                      is actually read. Time is include in 
;                      FINDILLHIST as it is (potentially) needed for 
;                      interpolations for signal versus time on the fly to
;                      fill in missing data not transmitted.
;         YTRUE        (1D array in arcsec - dimension full dataset)
;         ZTRUE        (1D array in arcsec - dimension full dataset) 
;                 FROM (integer array dimension NPLAT)
;                      identifier in original input time sequence of FIRST 
;                      sample in each pointing plateau, including single sample
;                      plateaus taken on the fly. The counter include data
;                      not transmitted.
;                   TO (integer array dimension NPLAT)
;                      identifier in original input time sequence of LAST 
;                      sample in each pointing plateau, including single sample
;                      plateaus taken on the fly. The counter include data
;                      not transmitted.
;         PIDENT       (integer array) plateau identifier of each elementary 
;                      input data point. Not to be confused with the 
;                      P32 grid identifier given by KEYPOINT.
;              SKYPASS (floating array of dimension full input data stream,
;                      including points taken on the fly and points not 
;                      transmitted. This should be previously filled by the
;                      calling routine with the sky brightnesse derived from
;                      the single step calculations of illumination by SILLUM1
;                      for each input sample up to and including KK. (ie after
;                      division of the illuminations by the vignetting).
;                      It is needed to provide estimate of the sky
;                      seen on the fly. If there are no sky estimate at 
;                      any point on the fly (eg due to non transmission of
;                      data or glitches) then SYKYPASS should take the value 
;                      0.0 at that point. This use of the values as a flag is
;                      possible as SILLUM1 forces solutions to be positive.
;          ISLEWMETHOD (Integer flag).
;                      Determines method to get the illumination history
;                      during slews. This is particularly problematic when
;                      there is no transmission to ground at intervals during 
;                      a slew. 
;                  = 1 use the nearest P32 natural grid pixel
;                      to define the illumination for all points 
;                      including masked or non-transmitted points.
;                      A warning is issued when there are no data from
;                      previous fixed pointings covered by the slew, in which
;                      case the illumination is set to the median of ALL
;                      previously found sky points, or, if there are no 
;                      previous data at all, from SILLUM0.
;                  = 2 Use the measured sky points where they exist
;                      (from SKYPASS array) and linearly interpolate in time
;                      where the points don't exist (due to glitches
;                      or on-board data compression etc). Neighbouring
;                      fine pointings not used. This is the most conservative
;                      approach and does not need a full set of fine pointing
;                      data to succeed. If there are no
;                      data in SKYPASS in the slew preceding KK, the 
;                      presence of a nearest natural grid value from a 
;                      fine pointing along the slew is searched for. In the 
;                      case this also fails to find a signal the 
;                      illumination is set to the median of ALL
;                      previously found sky points. This is suitable for
;                      the first iteration in DRIFTCORR.
;                  = 3 Perform a spline fit versus position for the points
;                      taken from SKYPASS array in the slew constraining by 
;                      surrounding fine pointings too from BESTSKY (as
;                      the fine pointings are calculated before the points
;                      on the fly). Probably the best solution for 
;                      Z slews in the high s/n limit
;                      and also not a bad solution in Y particularly
;                      when slewing through a bright source.
;                      NOT YET IMPLEMENTED.
;                  = 4 simple interpolation between fine pointings
; including information from bounding fine pointings. Interpolation
; is linear in position between the nearest 2 surrounding fine pointings 
; if only 2 different values for keypoint are present, or if the slew occurs 
; only in Y. The interpolation is on a plane given by the 3 nearest fine 
; pointings if 3 or more different values for keypoint are present diverging
; significantly from a straight line; this is the anticipated 
; situation when the chopper moves through several positions during a slew in
; Z. Note that this linear or planar interpolation will incurr some 
; interpolation errors which may dominate the random errors for very bright 
; sources. In principle this could be improved by spline fits, but in practice,
; since the illumination history is only used to derived the responsivity
; correction factors, this is not going to be a significant problem. (By
; contrast the spline fits to data on the fly are needed to reduce  the noise
; error. 
;                  = 5 as for 2 but neighbouring fine pointings are used
;                      as well in the case that either a preceding or a 
;                      postceding data point in slew cannot be found.
;                  = 6 (future implementation for the best possible solution
;                       when input fine pointing information is complete). 
;                      Do positional interpolation
;                      in 2D (if moving in z) from nearest points with
;                      fine pointings plus the points on the fly. Use weights
;                      according to distance (properly, conserving fourier
;                      components). If moving in Y only just do a 1d 
;                      spline interpolation between the nearest fine pointings.
;                      For this option we will have to input arrays with 
;                      nearest natural grid points in z, nearest grid points
;                      in Y, and the positions (in both Y and Z) of these
;                      points This will be memory consuming so maybe these are
;                      better calculated as one goes along from nearest
;                      row,  column and their positions.
;
; Note that ISLEWMETHOD only controls information for the calculation of
; detector state at the start of each plateau. The calculation of restored
; data on the slew is not changed in any way - ie not treated as samples
; on the nearest grid point and not interpolated.
;
;        BESTSKY      (1D array in V/s dimension NGRID) 
;                      This is the illumination that each 
;                      point on the natural sky grid would receive in the
;                      absence of vignetting. The dimension of sky is the
;                      total number of points on the natural P32 grid (NGRID)
;                      BESTSKY is left zero where there are no contributing 
;                      data points. It is calculated from the accumulated 
;                      information in the input SKYFOUND series of arrays.
;
; output: 
;         ILLHIST      (1D array in V/s dimensioned as KK+1). This is the
;                      illumination history (sky illumination * VIG) over
;                      the range JJ (output) to KK (IDL identifiers). The 
;                      points 0 to max([0,JJ-1]) are filled with zeros. 
;         IERR         =1 if an error occurred
;
@common_map3dref
;common map3dref,map3dref,map3drefrms,map3drefd,map3drefy,map3drefz,map3drefn
;
;
; first find best guess for sky on natural map pointing directions. 
; If any natural point has no data bestsky is set to 0.0 Note that since 
; the optimisation in the calling routine only admits positive values
; bestsky LE 0.0 can be taken as a sign that it contains no data for that
; data point.
;
;findbestsky,ifinemethod,nskyfound,skyfound,skyfoundfitres,skyfoundnpt,$
;ngrid,bestsky,nbestsky
;
; find median MEDIANALLSKY of all SKY data found.
; if there is no data use sillum0, ignoring vignetting
;
ii=where(bestsky gt 0.0,nii)
if(nii gt 0)then begin
test=bestsky(ii)
mediantrue,test,testmed
medianallsky=testmed
endif ; nii gt 0
if(nii le 0)then medianallsky=sillum0
;
ntotal=n_elements(keypoint)
;
illhist=fltarr(kk+1) ; SINCE KK IS THE IDL IDENTIFIER
;
; fill in data for fine pointing plateaus where this exists in BESTSKY.
; For plateaus with no data (eg masked due to telemetry drop or glitches)
; issue warning with position and use median of all data in BESTSKY. 
; If no data exists in BESTSKY (found from BESTSKY LE 0.0) fill with SILLUM0. 
; For points taken on the
; fly handle the position series of points between between neighbouring fine 
; pointings according to the value of ISLEWMETHOD (this data may only be
; partially filled or even not filled at all
; due to glitches or due to drops or on-board data reduction.
;
; find starting plateau containing input value of jj 
; and reassign jj to the first sample of this starting plateau
;
;itest=jj-to
;ips=where(itest le 0,nips)
;if(nips gt 0)then iplatstart=ips(0)
;if(nips le 0)then iplatstart=0
;jj=from(iplatstart)
;
;findramp,from,to,jj,jjout,iplatstart
;jj=jjout
;
iplatstart=pident(jj)
;
iplat=iplatstart-1
;
c100:
;
iplat=iplat+1
;
if(iplat ge n_elements(to))then goto,c200
if(from(iplat) gt kk)then goto, c200 ; we have got to end of history 
;                                    to be processed
n=to(iplat)-from(iplat)+1
iff=from(iplat)
f=fpoint(iff)
if(n eq 1 and kk ne ntotal-1)then f=0 ; treat single points taken near a 
;       fine pointing as on a slew (as these are generally due to a quick 
;       traverse of a fine pointing position during a slew) except for last 
;       point of dataset 
;
if(f eq 1.0)then begin ; fine pointing plateau 
iplat1=from(iplat)
iplat2=to(iplat)
if(iplat2 gt kk)then iplat2=kk
n=iplat1-iplat2+1 ; number of points on plateau within upper boundary kk
k=keypoint(iplat1)
test=bestsky(k)
;print,'test = ',test
;if(iplat1 lt 0 or iplat2 gt n_elements(illhist)-1)then begin ; diagnostic
;print,'iplat1,iplat2,kk, *** = ',iplat1,iplat2,kk
;endif ; iplat1 lt 0 or iplat2 gt n_elements(illhist)-1
if(test gt 0.0)then illhist(iplat1:iplat2)=test*vig(iplat1:iplat2)
if(test le 0.0)then begin ; there are no measurements for this fine pointing
;rjt JUL00 illhist(iplat1:iplat2)=medianallsky*vig(iplat1:iplat2)
; following added JUL00 RJT
;ktoyz,k,iy,iz
;if(map3drefn(ipix,iy,iz) gt 0)then begin
;illhist(iplat1:iplat2)=map3dref(ipix,iy,iz)
;endif ; map3drefn(ipix,iy,iz) gt 0
; in the absence of a bestsky value
; it is best to make sure the fit converges as closely as possible to the data.
illhist(iplat1:iplat2)=skypass(iplat1:iplat2)*vig(iplat1:iplat2)
;if(map3drefn(ipix,iy,iz) le 0)then begin
;illhist(iplat1:iplat2)=medianallsky*vig(iplat1:iplat2)
; end add JUL00 RJT
;print,'FINDILLHIST: illum for times',$
;float(t(iplat1)),float(t(iplat2)),' set to',float(illhist(iplat1))
;print,'... setting ILLHIST to ',medianallsky
;print,'... iplat1,iplat2,iplat= ',iplat1,iplat2,iplat 
;print,'... fpoint(iplat1:iplat2) = ',fpoint(iplat1:iplat2)
;print,'... keypoint(iplat1:iplat2) = ',keypoint(iplat1:iplat2)
;print,'... jj,kk = ',jj,kk
;endif ; map3drefn(ipix,iy,iz) le 0 ; added RJT JUL00
endif ; test le 0.0
goto,c100
endif ; f eq 1
;
if(f eq 0)then begin ; single point on slew
;
islew1=from(iplat) ; identifier of first (on board time sample) of slew
c300:
if(iplat lt n_elements(to))then iplat=iplat+1 ; test next plateau to see if 
;                                               still on slew
; diagnostic
 if(iplat ge n_elements(to) or iplat lt 0)then begin ; diagnostics
 print,'FINDILLHIST BUG:'
 print,'... iplat1,iplat2,iplat= ',iplat1,iplat2,iplat 
 print,'... fpoint(iplat1:iplat2) = ',fpoint(iplat1:iplat2)
 print,'... keypoint(iplat1:iplat2) = ',keypoint(iplat1:iplat2)
 print,'... jj,kk = ',jj,kk
 help,from,to,iplat
 endif ; diagnostics
if(to(iplat) gt kk)then goto, c400 ; last requested point kk is on slew
iff=from(iplat)
if(fpoint(iff) eq 0)then goto, c300
c400:
iplat=iplat-1 ; set to last plateau on slew or plateau containing kk
islew2=to(iplat)
if(islew2 gt kk)then islew2=kk
n=islew2-islew1+1 
;
; now we have islew1 islew2 for a slew up to at mosst kk. Now calculate
; the illuminations history along this slew according to the value of
; ISLEWMETHIOD, and assigning any points with no data with plausible
; values
;
if(islewmethod eq 1)then begin ; use nearest P32 natural grid as preference
;                                otherwise median of all sky or (in complete
;                                absence of data) SILLUM0
k=keypoint(islew1:islew2)
test=bestsky(k)
igood=where(test gt 0.0,nigood)
;
if(nigood eq n)then begin ; BESTSKY has data for all points on slew
illhist(islew1:islew2)=vig(islew1:islew2)*bestsky(k)
endif ; nigood eq n 
;
if(nigood lt n and nigood gt 0)then begin ; partial information from BESTSKY
testgood=test(igood)
mediantrue,testgood,testmed 
for i=islew1,islew2 do begin
k=keypoint(i)
if(bestsky(k) gt 0.0)then illhist(i)=vig(i)*bestsky(k)
if(bestsky(k) le 0.0)then illhist(i)=vig(i)*testmed ; set to median 
;                                                     of good points
endfor ; i
endif ; nigood lt n and nigood gt 0
;
if(nigood le 0)then begin ; no information from BESTSKY
print,'FINDILLHIST: warning - cannot find any data to fill slew ...'
print,'... setting ILLHIST to ',medianallsky
print,'islew1,islew2,k1,k2,islewmethod: ',islew1,islew2,keypoint(islew1),$
keypoint(islew2),islewmethod
illhist(islew1:islew2)=vig(islew1:islew2)*medianallsky
endif ; nigood le 0
;
goto,c100
endif ; islewmethod eq 1
;
if(islewmethod eq 2 or islewmethod eq 5)then begin 
; use measured sky points where they exist otherwise (eg for masked points
; or data not transmitted) interpolate in position
;
test=skypass(islew1:islew2)
igood=where(test gt 0.0,nigood)
if(nigood gt 0)then igoodorig=igood+islew1
if(nigood le 0)then igoodorig=-1 ; must overwrite previous array
;if(islew1 eq 70)then print,islew1,islew2,igoodorig,nigood ; diagnostics
;
if(n eq nigood)then begin ; data exists for all points
illhist(islew1:islew2)=vig(islew1:islew2)*skypass(islew1:islew2)
endif ; n eq nigood 
;
if(nigood lt n and nigood gt 0)then begin ; partial information from SKYPASS
;
for i=islew1,islew2 do begin
;
if(skypass(i) gt 0.0)then illhist(i)=vig(i)*skypass(i)
;
if(skypass(i) le 0.0)then begin 
; interpolate in position within slew
;
y=ytrue(i)
z=ztrue(i)
iminus=where(igoodorig lt i,niminus) ; preceding good points
;rjt if(nigood le 0)then niminus=0
if(niminus le 0)then niminus=0
if(niminus gt 0)then begin
i1=igoodorig(max(iminus)) ; nearest preceding good point
y1=ytrue(i1)
z1=ztrue(i1)
s1=skypass(i1)
;
;if(n_elements(ech) le i1 or i1 lt 0)then begin ; diagnostic
;help,i1
;help,ech
;save,/xdr,islewmethod,sillum0,ech,pident,$
;from,to,t,vig,keypoint,fpoint,ytrue,ztrue,skypass,$
;ngrid,yk,zk,bestsky,jj,kk,$
;file='findillhist.xdr'
;endif ; diagnostic
;
c1=ech(i1) ; integer identifier of chop position
endif ; niminus gt 0
iplus=where(igoodorig gt i,niplus) ; succeeding good points
; rjt if(nigood le 0)then niplus=0
if(niplus le 0)then niplus=0
;if(islew1 eq 70)then begin ; diagnostics
;print,'niplus,niminus = ',niplus,niminus
;endif ; diagn

if(niplus gt 0)then begin
i2=igoodorig(min(iplus)) ; nearest succeeding good point
y2=ytrue(i2)
z2=ztrue(i2)
s2=skypass(i2)
c2=ech(i2) ; integer identifier of chop position
endif ; niplus gt 0
if(niminus ne 0 and niplus ne 0)then begin ; interpolate or extrapolate
;                         according to whether or not the chopper changes
if(c1 eq c2)then begin ; interpolate within slew
; interpolate using LININT (assumes straight line path and noisy pointing data)
linint,y1,y2,z1,z2,s1,s2,y,z,s
;print,y1,y2,z1,z2,s1,s2,y,z,s
illhist(i)=vig(i)*s
endif ; c1 eq c2
if(c1 ne c2)then begin ; the nearest succeeding and preceding data points
;                        have a different chopper position so don't interpolate
if(c1 eq ech(i))then illhist(i)=vig(i)*s1
if(c2 eq ech(i))then illhist(i)=vig(i)*s2
if(c1 ne ech(i) and c2 ne ech(i))then illhist(i)=vig(i)*s1 ; if chopper is
;                             going crazy take previous value
endif ; c1 ne c2
; check for positive result 
if(illhist(i) le 0.0)then begin
print,'FINDILLHIST: warning - linear interp. to negative value on slew...'
print,'... resetting ILLHIST to ',medianallsky
illhist(i)=medianallsky*vig(i)
endif ; illhist(i) le 0.0
 
endif ; niminus ne 0 and niplus ne 0
;
if(niminus le 0 and niplus gt 0)then begin ; missing a preceding point
if(islewmethod eq 2)then illhist(i)=vig(i)*s2
;
if(islewmethod eq 5)then begin ; use preceding fine pointing if there is one
i1=islew1-1
flag=1 
if(i1 ge 0)then begin
k1=keypoint(i1)
s1=bestsky(k1)
if(s1 gt 0.0)then flag=0
endif ; i1 ge 0
if(i1 lt 0 or flag eq 1)then begin ; there is no preceding fine pointing data
;print,'FINDILLHIST: warning - cannot use ISLEWMETHOD=5 without data from '
;print,'surrounding fine pointings:' 
;print,'islew1,islew2,k1,k2,islewmethod: ',islew1,islew2,keypoint(islew1),$
;keypoint(islew2),islewmethod
; rjt illhist(i)=vig(i)*medianallsky
illhist(i)=vig(i)*s2 ; just use nearest succeeding point as in islewmethod 2
endif ; i1 lt 0 or flag eq 1
if(i1 ge 0 and flag eq 0)then begin ; there is preceding fine pointing data
y1=ytrue(i1)
z1=ztrue(i1)
linint,y1,y2,z1,z2,s1,s2,y,z,s
illhist(i)=vig(i)*s
; check for interpolation error giving negative or zero points ...'
if(s le 0.0)then begin
print,'FINDILLHIST: warning - linear interp. on slew gives neg or 0 ...'
print,'... resetting ILLHIST to ',medianallsky
illhist(i)=vig(i)*medianallsky
endif ; s le 0.0
endif ; i1 ge 0 and flag eq 0
endif ; islewmethod eq 5
;
endif ; niminus eq 0 and niplus gt 0
;
if(niplus eq 0 and niminus gt 0)then begin ; missing succeeding point
if(islewmethod eq 2)then illhist(i)=vig(i)*s1
;
if(islewmethod eq 5)then begin ; use succeeding fine pointing
i2=islew2+1
flag=1
; rjt this will never be satisfied if(i2 le kk)then begin
if(i2 le ntotal-1)then begin
k2=keypoint(i2) 
s2=bestsky(k2) ; estimate of sky brightness at end of slew from
;                a previously found fine pointing
if(s2 gt 0.0)then flag=0
endif ; i2 le ntotal-1
if(i2 gt ntotal-1 or flag eq 1)then begin ; there is no succeeding data
;print,'FINDILLHIST: warning - cannot use ISLEWMETHOD=5 without data from '
;print,'surrounding fine pointings:' 
;print,'islew1,islew2,k1,k2,islewmethod: ',islew1,islew2,keypoint(islew1),$
;keypoint(islew2)
; rjt illhist(i)=vig(i)*medianallsky
illhist(i)=vig(i)*s1
endif ; i2 le ntotal-1 or flag eq 1
if(i2 le ntotal-1 and flag eq 0)then begin ; there is succeeding data
y2=ytrue(i2)
z2=ztrue(i2)
linint,y1,y2,z1,z2,s1,s2,y,z,s
illhist(i)=vig(i)*s
; check for interpolation error
if(s le 0.0)then begin
print,'FINDILLHIST: warning - interpolation to 0 or -ve on slew ...'
print,'... setting illhist to vig *',medianallsky
illhist(i)=vig(i)*medianallsky
endif ; s le 0.0

endif ; i2 le ntotal-1 and flag eq 0
endif ; islewmethod eq 5
;
endif ; niplus eq 0 and niminus gt 0
;
endif ; skypass(i) le 0.0
;                                                     of good points
endfor ; i
;
endif ; nigood lt n and nigood gt 0
;
if(nigood le 0)then begin
;
if(islewmethod eq 2)then begin
;
; any fine point information to use?
;
k=keypoint(islew1:islew2)
strial=bestsky(k)
igs=where(strial gt 0.0,nigs)
if(nigs gt 0)then begin
sigs=total(strial(igs))/float(nigs)
illhist(islew1:islew2)=vig(islew1:islew2)*sigs
endif ; nigs gt 0
if(nigs le 0)then begin
print,'FINDILLHIST: warning - cannot find interpolation end points'
print,'islew1,islew2,k1,k2,islewmethod: ',islew1,islew2,keypoint(islew1),$
keypoint(islew2),islewmethod
illhist(islew1:islew2)=vig(islew1:islew2)*medianallsky
endif ; nigs le 0
endif ; islewmethod eq 2
if(islewmethod eq 5)then begin
;
i2=islew2+1
flag2=1
; rjt this can never be satisfied if(i2 le kk)then begin
if(i2 le ntotal-1)then begin
k2=keypoint(i2)
s2=bestsky(k2) ; estimate of sky brightness at end of slew from
;                a previously found fine pointing
if(s2 gt 0.0)then flag2=0
endif ; i2 le ntotal-1
if(i2 gt ntotal-1 or flag2 eq 1)then begin ; no preceding fine pointing data
print,'FINDILLHIST: warning - cannot use ISLEWMETHOD=5 without data from '
print,'surrounding fine pointings:' 
print,'islew1,islew2,k1,k2,islewmethod: ',islew1,islew2,keypoint(islew1),$
keypoint(islew2)
flag2=1
endif ; i2 le ntotal-1 or s2 le 0.0
y2=ytrue(i2)
z2=ztrue(i2)
;
i1=islew1-1
flag1=1
if(i1 ge 0)then begin
k1=keypoint(i1)
s1=bestsky(k1)
if(s1 gt 0.0)then flag1=0
endif ; i1 ge 0
if(i1 lt 0 or flag1 eq 1)then begin
print,'FINDILLHIST: warning - cannot use ISLEWMETHOD=5 without data from '
print,'surrounding fine pointings:' 
print,'islew1,islew2,k1,k2,islewmethod: ',islew1,islew2,keypoint(islew1),$
keypoint(islew2)
flag1=1
endif ; i1 lt 0 or flag1 eq 1
y1=ytrue(i1)
z1=ztrue(i1)
;
if(flag1 eq 0 and flag2 gt 0)then s2=s1
if(flag1 gt 0 and flag2 eq 0)then s1=s2
if(flag1 gt 0 and flag2 gt 0)then begin
s1=medianallsky
s2=medianallsky
endif ; flag1 gt 0 and flag2 gt 0
;
for i=islew1,islew2 do begin
y=ytrue(i)
z=ztrue(i)
linint,y1,y2,z1,z2,s1,s2,y,z,s
illhist(i)=vig(i)*s
if(s le 0.0)then begin
print,'FINDILLHIST: linear interpolation finds zero or negative ...'
print,'... resetting SILLUMHIST to vig * ',medianallsky
illhist(i)=vig(i)*medianallsky
endif ; s le 0.0
endfor ; i
;
endif ; islewmethod eq 5
;
endif ; nigood le 0
;
goto,c100
endif ; islewmethod eq 2 or islewmethod eq 5
;
if(islewmethod eq 4) then begin ; simple interpolation between fine pointings
; including information from bounding fine pointings. Interpolation
; is linear in position between the nearest 2 surrounding fine pointings 
; if only 2 different values for keypoint are present, or if the slew occurs 
; only in Y. The interpolation is on a plane given by the 3 nearest fine 
; pointings if 3 or more different values for keypoint are present diverging
; significantly from a straight line; this is the anticipated 
; situation when the chopper moves through several positions during a slew in
; Z. Note that this linear or planar interpolation will incurr some 
; interpolation errors which may dominate the random errors for very bright 
; sources. In principle this could be improved by spline fits, but in practice,
; since the illumination history is only used to derived the responsivity
; correction factors, this is not going to be a significant problem. (By
; contrast the spline fits to data on the fly are needed to reduce  the noise
; error. 
;
; now gather all data, starting with preceding fine pointing, if it exists:
;
stest=fltarr(1) ; array to fill with brightnesses of fine pointings encountered
ytest=stest     ; array to fill with positions of fine pointings encountered
ztest=stest     
;
flag=1 ; goodness of examined point (=0 for good)
flag1=1
npt=0 ; counter for number of good points including end fine pointings
;
i1=islew1-1 ; potential preceding pointing
if(i1 ge 0)then begin
k1=keypoint(i1)
s1=bestsky(k1)
y=yk(k1)
z=zk(k1)
if(s1 gt 0.0)then flag=0
flag1=flag
endif ; i1 ge 0
if(flag eq 0)then begin ; we have a good point to add to test
if(npt eq 0)then begin 
stest(0)=s1
ytest(0)=y
ztest(0)=z
endif ; npt eq 0
if(npt gt 0)then begin
stest=[stest,s1]
ytest=[ytest,y]
ztest=[ztest,z]
endif ; npt gt 0
npt=npt+1 ; new dimension of test arrays
flag1=flag
flag=1 ; reset flag for next point to be examined 
endif ; flag eq 0
;
; now add succeeding fine pointing
;
flag2=flag
i2=islew2+1
; rjt this can never be satisfied since kk=from(iplat)-1 
; when FINDILLHIST is called from DRIFTCORR if(i2 le kk)then begin
if(i2 le ntotal-1)then begin
k2=keypoint(i2) ; point to which it will come
s2=bestsky(k2)
y=yk(k2)
z=zk(k2)
if(s2 gt 0.0)then flag=0
flag2=flag
endif ; i2 le ntotal-1
if(flag eq 0)then begin
if(npt eq 0)then begin 
stest(0)=s2
ytest(0)=y
ztest(0)=z
endif ; npt eq 0
if(npt gt 0)then begin
stest=[stest,s2]
ytest=[ytest,y]
ztest=[ztest,z]
endif ; npt gt 0
npt=npt+1 ; new dimension of test arrays
flag2=flag
flag=1 ; reset flag for next point to be examined 
endif ; flag eq 0
;
; ... now add points on the fly covering new nearest positions to
;     fixed pointings with data, if these exist. They have to be
;     different from the fine pointings on the pointing plateaus 
;     at the start and end of the slew.
;
for i=islew1,islew2 do begin
;
k=keypoint(i)
s=bestsky(k)
if(k ne k1 and k ne k2 and s gt 0.0)then begin
; the point on the fly has moved over a new fine pointing pixel
; containing real data
if(npt eq 0)then begin 
y=yk(k) ; these are real pointings of the fine pointings - not of the
        ; points on the fly
z=zk(k)
stest(0)=s
ytest(0)=y
ztest(0)=z
endif ; npt eq 0
if(npt gt 0)then begin
stest=[stest,s]
ytest=[ytest,y]
ztest=[ztest,z]
endif ; npt gt 0
npt=npt+1 ; new dimension of test arrays
flag=1 ; reset flag for next point to be examined 
endif ; k ne k1 and k ne k2 and S gt 0.0
s=bestsky(k)
;
endfor ; i=islew1,islew2
;
; did we encounter any fine pointings with data?
;
if(npt eq 0)then begin
print,'FINDILLHIST: warning - should not use ISLEWMETHOD=4 without data from '
print,'fine pointings:' 
print,'islew1,islew2,k1,k2,islewmethod: ',islew1,islew2,keypoint(islew1),$
keypoint(islew2),islewmethod
illhist(islew1:islew2)=vig(islew1:islew2)*medianallsky
endif ; npt eq 0
;
if(npt eq 1)then begin
print,'FINDILLHIST: warning - should not use ISLEWMETHOD=4 with data from '
print,'only one fine pointing:' 
print,'islew1,islew2,k1,k2,islewmethod: ',islew1,islew2,keypoint(islew1),$
keypoint(islew2),islewmethod
illhist(islew1:islew2)=vig(islew1:islew2)*stest(0) 
; set to value of single pointing
endif ; npt eq 1
;
if(npt gt 1)then begin 
;
testdz1=max(ztest)-min(ztest) ; maximum variation along slew
testdz2=0.0
if(flag1 eq 0 and flag2 eq 0)then testdz2=abs(zk(k1)-zk(k2))
; variation between start and end point
;                               if these points exist
testdz=min([testdz1,testdz2]) ; only take Z deviation as real if
;                               shown by end points
;
threshdz=5.0 ; arcsec
;
if(testdz gt threshdz and npt gt 2)then begin   
; now find solution for slews traversing Y and Z using planar surface
;
for i=islew1,islew2 do begin
y=ytrue(i) ; real position of point
z=ztrue(i)
disty=y-ytest
distz=z-ztest
distr=sqrt(disty*disty+distz*distz)
iorder=sort(distr)
; nearest 3 points
i1=iorder(0)
i2=iorder(1)
i3=iorder(2)
y1=ytest(i1)
y2=ytest(i2)
y3=ytest(i3)
z1=ztest(i1)
z2=ztest(i2)
z3=ztest(i3)
s1=stest(i1)
s2=stest(i2)
s3=stest(i3)
;
p3,[y1,y2,y3],[z1,z2,z3],[s1,s2,s3],a,b,c
s = c + (a*y) + (b*z)
illhist(i)=vig(i)*s 
if(s le 0.0)then begin
print,'FINDILLHIST: warning - planar interp. on slew to negative or zero ...'
print,'... setting ILLHIST to vig *',medianallsky 
illhist(i)=vig(i)*medianallsky
endif ; s le 0.0
;
endfor ; i=islew1,islew2 (within testdz gt threshdz and npt gt 2)
;
endif ; testdz gt threshdz and npt gt 2
;
flagzz=0
if(testdz gt threshdz and npt eq 2)then flagzz=1
glagzz=0
if(testdz le threshdz and npt ge 2)then glagzz=1
;
if(glagzz eq 1 or flagzz eq 1)then begin   
; now find linear interpolation solution for inscan slews traversing Y only 
; or (flagzz eq 1) slews in Y and Z with only 2 points.
iorder=sort(ytest) ; we always assume the scan moves in Y 
;                    due to the chopper (even for Z slews)
stest=stest(iorder)
ytest=ytest(iorder)
ztest=ztest(iorder)
;
for i=islew1,islew2 do begin
;
y=ytrue(i) ; real position of point
z=ztrue(i)
if(y lt ytest(0))then s=stest(0)
if(y gt ytest(npt-1))then s=stest(npt-1)
;
if(y ge ytest(0) and y le ytest(npt-1))then begin
; find closest enclosing pair of points
;
dist=ytest-y
id=where(abs(dist) eq min(abs(dist)),nid) ; closest point
i1=id(0)
s1=stest(i1)
y1=ytest(i1)
z1=ztest(i1)
;
if(i1 eq 0)then i2=i1+1
if(i1 eq npt-1)then i2=i1-1
;
if(i1 gt 0 and i1 lt npt-1)then begin
ilow=i1-1
ihi=i1+1
if(dist(ilow)*dist(i1) le 0.0)then i2=i1-1
if(dist(ihi)*dist(i1) ge 0.0)then i2=i1+1
endif ; i1 gt 0 and i1 lt npt-1
;
s2=stest(i2)
y2=ytest(i2)
z2=ztest(i2)
;
linint,y1,y2,z1,z2,s1,s2,y,z,s
;
endif ; y ge ytest(0) and y le ytest(npt-1)
;
illhist(i)=vig(i)*s
if(s le 0.0)then begin
print,'FINDILLHIST: warning - linear interp. on slew with ISLEWMETHOD 4 ...'
print,' to negative or zero ... setting ILLHIST to vig *',medianallsky 
illhist(i)=vig(i)*medianallsky
endif ; s le 0.0
;
endfor ; i=islew1,islew2
;
endif ; glagzz eq 1 or flagzz eq 1
;
endif ; npt gt 1
;
goto,c100
;
endif ; islewmethod eq 4
;
endif ; f eq 0 ; end of on the fly loop
;
c200:
;
c999:
;
return
end






