pro findstartdetnew,istart,ipix,siginit,sillinit,sigstart
;
; updated May 2000 rjt to include a statistical average of all plateaus
; except that in the first chopper sweep and to differentiate between
; the first spacecraft pointing (prior chopper position is rest position)
; and subsequent pointings (prior chopper position is that of previous
; sample). Operates only on a single detector pixel as it is called
; within the IPIX loop in DRIFT32.
;
; finds siginit and sillinit - which define
; the state of the detector just prior to the start of a data sequence 
; beginning with (unexpanded) sample ISTART
;
; input: idy(npix,nptin), idz(npix,nptin) in common
; block wherepoint. These are the pointing directions on the natural grid
; in units of the natural grid identifier. These have to be set by a previous
; call to ASSIGNGRID.
;
; SIGSTART is output as the first signal on the starting plateau which
;          is a good data point. If no good data point is found on the first 
;          plateau then SIGSTART is set to 0.0
;
; Note (JUL00 RJT) this routine relies on the fact that changes in idy
; are synchronised to the otfstart and otfsstop arrays. This will be so,
; as POINT, after the JUL00 modifications, ensures that OTSFTART and OTFSTOP
; are at the first and last point of chopper plateaus, respectively.
;
; DUM array extended from 256 to 1024 to be able to process also long
; ramps  (CG) 
;
;common wherepoint,idy,idz
@common_wherepoint
;common signal,rs,cs,nch,s_in,s,badin,bad,rel,rms,glitch,jf,njf,ninchmax,rd,$
;nkf,kf,nkfmax,irelstart,nchopmed,gbad,npolyrms,nrmsmed,sigmaxfract
@common_signal
;common plotter,otfstart,otfstop,rdstat,chop,step,otf,rpid,yrel,zrel,$
;ytrue,ztrue,yzrpidcen,nyraster,nzraster,racenout,deccenout
@common_plotter
;
siginit=median(s(ipix,*)) ; initialisation
sillinit=siginit
sigstart=0.0
;
ipoint=-1
npoint=nyraster*nzraster
for i=0,npoint-1 do begin
if(istart eq otfstart(i))then ipoint=i
endfor ; i
;
if(ipoint lt 0)then begin
print,'FINDSTARTDETNEW: initial sample is not at start of a fine pointing ...'
print,'                 ... aborting'
goto,c999
endif ; ipoint lt 0
;
npix=n_elements(s(*,0))
;
; JUL00 RJT if(ipoint eq 0)then begin ; first fine pointing. Chopper previously
                                    ; at rest position
kstart=idy(ipix,istart)
;
; find SIGSTART
;
;print,'*** istart,kstart = ',istart,kstart
dum=fltarr(1024)
ninfirstplat=0
ii=istart-1
c8576:
ii=ii+1
if(idy(ipix,ii) ne kstart)then goto,c8577 ; end of plateau cont. 1st pt.
if(bad(ipix,ii) eq 0)then begin
dum(ninfirstplat)=s(ipix,ii)
ninfirstplat=ninfirstplat+1
;print,'*** ',ninfirstplat,ii,s(ipix,ii)
goto,c8576
endif ; bad(ipix,ii) eq 0
if(bad(ipix,ii) ne 0)then goto,c8576
;
c8577:
;
if(ninfirstplat gt 0)then begin
dum=dum(0:ninfirstplat-1)
sigstart=median(dum)
;print,'*** dum = ',dum
;print,'*** sigstart = ',sigstart
endif ; ninfirstplat gt 0
;
if(ipoint eq 0)then begin
;
if(npix eq 4)then kprev=kstart+3 ; C200 array
; JUL00 RJT endif ; npix eq 4
if(npix eq 9)then kprev=kstart+6 ; C100 array
;
endif ; ipoint eq 0
;
if(ipoint gt 0)then begin ; subsequent fine pointing. 
                                    ; Chopper previously at position of 
                                    ; preceding sample.
kprev=idy(ipix,istart-1)
;
endif ; ipoint gt 0
;
ii=where(idy(ipix,*) eq kprev and rd ge otfstart(ipoint) and $
rd le otfstop(ipoint),nii)
if(nii le 0)then begin
print,'FINDSTARTDETNEW: warning - no points found - taking median of dataset'
print,'                 ... istart,ipix,siginit,sillinit = ',$
istart,ipix,siginit,sillinit
goto,c999
endif ; nii le 0
;
if(nii gt 0)then begin
siginit=median(s(ipix,ii))
sillinit=siginit
endif ; nii gt 0
;
c999:
;
;print,'******** sigstart = ',sigstart
;print,'******** siginit  = ',siginit
;print,'******** sillinit = ',sillinit
;
return
end






