PRO give_conv, tmp, vs2mjy, resp, act_resp=act_resp

;+
; NAME:
;       GIVE_conv
;
; PURPOSE:
;	To get information for a given measurement
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       give_conv, tmp, vs2mjy, resp
;
; INPUTS:
;	tmp		A PIA data structure (ERD, SRD or SCP)
;
; OUTPUTS:
;	vs2mjy		Conversion factor from V/s -> MJy/sr [MJy/sr/(V/s)]
;			    signal = brightness * vs2mjy
;	resp		The responsivity array (orb. dependent default)

;
; COMMON BLOCKS:
;	@phtw2jy
;	@phtcs
;	
; PROCEDURES USED:
;       PIA Procedure(s):	GIVE_CS
;

;
; MODIFICATION HISTORY:
;       Written by:            Carlos Gabriel, Vilspa	     Nov 1999
;-
@phtw2jy
@phtcap
@phtdarkorb
	  
;	tmp = {admn:admn, det:det}
	GIVE_CS, tmp, cst, record
	filt = cst.c2ps(record)

; initializations
	IF N_ELEMENTS(w2jy_c) EQ 0 THEN phtw2jy_init
	
	IF det EQ 'C1' THEN BEGIN
	  pnum = 9
	  filter = filt-2
	  cap = c1cap
	  fxread,!calg+'PC1FLAT.FITS',ff_data,ff_hdr
	  fxread,!calg+'PC1RESP_02.FITS',resp_data,resp_hdr
	ENDIF ELSE IF det EQ 'C2' THEN BEGIN
	  pnum = 4
	  filter = filt-9
	  cap = c2cap
	  fxread,!calg+'PC2FLAT.FITS',ff_data,ff_hdr
	  fxread,!calg+'PC2RESP_02.FITS',resp_data,resp_hdr
  	ENDIF ELSE BEGIN
	  MESSAGE, /INFO, 'Only implemented for C1 and C2, returning'
	  RETURN
	ENDELSE
	
	ff=ff_data(*,filter,0)		; flatfield per pixel
	obs = 0.91			; obscuration factor 

	c_1=w2jy_c(filt-1)		; Famous C_1 constant

	omega=get_omega(det,indgen(pnum),filter)	; the solid angle

        IF KEYWORD_SET(act_resp) THEN $ 
		resp = act_resp ELSE BEGIN
		def_resp = default_response(tmp)
;rjt		resp = default_response(*,0,0)
                resp = def_resp(*,0,0)
	ENDELSE

;	resp=resp_data(40,*,0)	; r per pixel (def by orbpos 0.4 - Rev. > 150)

	vs2mjy =  c_1 * obs * omega(*,0) * resp * ff * 1.e6 / cap 
	  	
	RETURN
	END 
	  











