pro glitch1,sigclipdg1,nglmin
;
; find glitches (strenths placed into array glitch) and set flags (placed into
; array bad) by examining statistics for data on individual chopper plateau.
;
; input:
;         s(npix,nptin) Vs-1 (=V(i+1)-V(i)) relativised
;         rs(nptin) readout cycle (eg  1 2 3 4 1 .... for ninramp=4)
;         badin(npix,nptin) input flags, with reset and telemetry flags
;         rms(npix,nptin)
;         set on input
;         nch there are nch+2 chopper transitions
;         sigclipdg1 number of sigma above or below which a datum is deemed
;          to be a glitch
;         nglmin=5 minimum number of surviving points on a ramp to calculate
;          signal after deglitching in glitch1 routine. All points set bad if
;          number of points surviving within specified statistical tolerance
;          (sigclipdg1) is < nglmin
;       npolyrms (eg =2 for quadratic fit to ramps subtracted to find residuals)
;    KF=lonarr(nch+2,nkfmax) denotes identifiers within all the chopper plateaus
;         irrespective of readout class
;         NKF(nch+2) is number of reads on a given chopper plateau
;         NKFMAX=maximum of NKF
;         TIME time in sec (DOUBLE dim nptin)
;       sigmaxfract  maximum fraction of signals that can be flagged bad on
;        a chopper plateau by glitch1
;
; output: (all common block)
;         bad(npix,nptin) flags for each point. (marks all flagged points)
;         gbad(npix,nptin) (marks only points with glitches)
;         glitch(npix,nptin) glitch strengths for each point
;
;  Algorithm:
;
;  To avoid bias due to drifts and glitches before examining statistics do a 
;  polynomial fit to median filtered good signals on 
;  each plateau (from all ndrs) and find residue from fit.
;  Examine residue and find largest deviant. If 
;  largest deviant from residue is larger than sigclipdg1 sigma (in units of 
;  rms for that point) then flag bad. Re calculate polynomial fit. Proceed
;  until either there are no more deviant points > sigclipdg1, or there are
;  less than nglmin surviving points, in which case flag all points on plateau
;  bad. Place residue of input minus last polynomial fit into glitch array for
;  points flagged bad by this routine (not including points from telemtry etc
;  in badin) into gbad. Update bad to contain points from gbad too.
;  Plateaus with less than nglmin good points on input are ignored and
;  flagged bad. rms are not altered by the routine as this can only be
;  calculated sufficiently accurately by carefully averaging data from many 
;  plateaus (routine FINDRMS)
;  BAD and GLITCH annd GBAD are initialised by the routine. Note if rms
;  is INCREASED in a subsequent run of FINDRMS we would otherwise have 
;  overestimated glitches
;
;common steerin,array,nptin,npt,ninramp,imeas,osamp
;common steer1,npix,pixsize,pixpitch,pixoff,nchop,dcy,dry,drz
;common signal,rs,cs,nch,s_in,s,badin,bad,rel,rms,glitch,jf,njf,ninchmax,rd,$
;nkf,kf,nkfmax,irelstart,nchopmed,gbad,npolyrms,nrmsmed,sigmaxfract
;common timer,time
;
@common_steerin
@common_steer1
@common_signal
@common_timer
;
glitch=dblarr(npix,nptin)
gbad=lonarr(npix,nptin)
bad=badin
;
; rfit=dblarr(npolyrms+1)
;
for ipix=0L,npix-1 do begin             ; data
print,'GLITCH1: computing statistics for pixel',ipix+1
ngltot=0L ; counter for total number of glitches
ngltot1=0L ; counter for "dc" glitches
for ichop=-1L,nch do begin ; -1 to nch range is to include first and last too
;
ichopold=0L ; flag needed to find statistics prior to new flagging of data
dcflag=0L ; flag is 0 prior to dc flagging
;
; find fits to each ramp from median filtered good signals
;
goodpflag=1L ; good plateau flag set to 0 if there are too many bad points
;
i1=kf(ichop+1,0)
i2=i1+nkf(ichop+1)-1
nnn=i2-i1+1
x=dblarr(nnn)
t=x
b=lonarr(nnn)
x=s(ipix,i1:i2)
t=time(i1:i2)-time(i1)
r=rd(i1:i2)
sr=rms(ipix,i1:i2)
bbin=badin(ipix,i1:i2)
igoodin=where(bbin eq 0, ngoodin)
c99:
ichopold=ichopold+1
;print,'GLITCH1: TEST'
b=bad(ipix,i1:i2)
igood=where(b eq 0,ngood)
;
if(ngood gt 0)then begin ; rjt oct99
xgood=dblarr(ngood)
tgood=xgood
xgood=x(igood) 
tgood=t(igood)
rgood=r(igood)
srgood=sr(igood)
endif ; ngood gt 0
;
; escape to next plateau if more than the fraction sigmaxfract of points 
; have been flagged bad
; This was added as noise may have been underestimated on bright peaks
; and otherwise data would have been thrown away on bright peaks.
;
if(ngoodin le 0)then goto, c100 ; rjt oct99
fract=float(ngood)/float(ngoodin)
if((1.0-fract) gt sigmaxfract) then goto, c100
;
if(ngood lt nglmin)then begin
print,'GLITCH1: ngood lt nglmin): '
print,'GLITCH1: ngood nrmsmed npolyrms ipix ichop i1 i2 ='
print,ngood,nrmsmed,npolyrms,ipix,ichop,i1,i2
goodpflag=0L
bad(i1:i2)=1L
gbad(i1:i2)=1L
goto, c100
endif ; ngood lt nglmin ; so can't do good stats on glitches
if(ngood lt npolyrms+3)then begin
print,'GLITCH1: ngood lt npolyrms+3): '
print,'GLITCH1: ngood nrmsmed npolyrms ipix ichop i1 i2 ='
print,ngood,nrmsmed,npolyrms,ipix,ichop,i1,i2
goodpflag=0L
goto, c100
endif ; ngood lt npolyrms+3
;
if(ngood ge npolyrms+3)then begin
;
; "dc" correction
;
; flag point on a ramp for which the maximum of abs of 
; i-(i-1)/2-(i+1)/2 (i-(i+1) at start of plateau) or i-(i-1) at end of plateau
; is significantly greater than illumination step from previous PLATEAU
; and is significantly greater than average of neighboring points
; Only flag one point then go back to c99 and set up arrays again.
;
if(dcflag eq 1) then goto, c55 ; dc correction already applied
if(ichopold eq 1 and ichop ge 0)then xxxprev=xxx
;if(ichopold eq 1 and ichop lt 0)then xxxprev=0.0
if(ichopold eq 1 and ichop lt 0)then xxxprev=999999.0 ; we want to keep
;                                                       switch on effect
if(ichopold eq 1)then xxx=median(xgood)
xxxtest=abs(xxx-xxxprev) ; difference in illumination between current and
                         ; previous plateau.
xgtest=dblarr(ngood)
;xgtest(0)=xgood(0)-0.5*(xgood(1)+xgood(2))
;xgtest(ngood-1)=xgood(ngood-1)-0.5*(xgood(ngood-2)+xgood(ngood-3))
; 
;for i=1L,ngood-2 do begin
; above lines did not work as the double gradient was set at good points too
;
;xgtest(i)=xgood(i)-0.5*(xgood(i+1)+xgood(i-1))
;endfor
xgtest=xgood-median(xgood)
xgtest=abs(xgtest)
xgtestmax=max(xgtest)
idum=where(xgtest eq xgtestmax,nibadtest)
ibadtest=idum(0,0)
ii=rgood(ibadtest)
testglitch=xgtestmax/srgood(ibadtest)
;if(testglitch gt sigclipdg1*sqrt(1.5) and $
testcond=xxxtest+sigclipdg1*srgood(ibadtest)*sqrt(1.5)
if(xgtestmax gt testcond)then begin 
; sqrt(1.5) because of increased noise in 2nd differential
;
;print,'GLITCH1: TEST'                      
ngltot=ngltot+1
ngltot1=ngltot1+1
;help,ii
;print,ii
bad(ipix,ii)=1
gbad(ipix,ii)=1
;
;if(ipix eq 4 and i1 gt 5880 and i2 lt 5920)then begin ; diagnostic
;if(ipix eq 0 and ichop eq 138)then begin ; diagnostic
;print,'GLITCH1 diagnsotic for dc glitch one plateau:'
;print,'read set bad = ',ii
;help,xgtestmax,xxx,xxxprev,xxxtest,testcond
;print,'xgtestmax,xxx,xxxprev,xxxtest,testcond:'
;print,xgtestmax,xx,xxxprev,xxxtest,testcond
;help,xgood
;print,xgood
;help,rgood
;print,rgood
;help,xgtest
;print,xgtest
;endif ; diagnostic
;
goto, c99
endif ; testglitch for "dc" deglitch
;
c55:
dcflag=1 ; set after we have finished dc flagging to prevent further dc flagging
         ; when returning to c99
;
; if no further "dc" glitches found proceed to looking at differential curve
; which is a deeper search since individual points are compared to whole
; statistics of ramps rather than just two points in the "dc" deglitch
;
xx=median(xgood,nrmsmed)
ttest=poly_fit(tgood,xx,npolyrms)
;help,ttest
;print,ttest
rfit=ttest(0,0:npolyrms) ; eg 3 terms for npolyrms=2
;help,rfit
;print,rfit
y=rfit(0)+(rfit(1)*tgood)+(rfit(2)*tgood*tgood)
res=xgood-y ; residuals
;if(i1 lt 4790 and i2 gt 4790 and ipix eq 4)then begin ; diagnostic
;if (i1 lt 5900 and i2 gt 5900 and ipix eq 4)then begin ; dignostic plot
;window,12,xs=400,ys=400,tit='residual versus time pixel 5'
;plot,tgood,xgood,linestyle=0
;oplot,tgood,y,linestyle=1
;print,'GLITCH1: plotting pixel 5:'
;endif ; diagnostic plot
;print,'res:',res
absres=abs(res) ; 
idum=where(absres eq max(absres),nibadtest)
ibadtest=idum(0,0)
;help,ibadtest
;print,'ibadtest:',ibadtest
;help,srgood
;print,srgood
;help,absres
;print,absres
;help,rgood
;print,rgood
testglitch=absres(ibadtest)/srgood(ibadtest)
;help,testglitch
;print,testglitch
;help,sigclipdg1
;print,sigclipdg1
if(testglitch gt sigclipdg1)then begin
;print,'GLITCH1: TEST'
ngltot=ngltot+1
ii=rgood(ibadtest)
;help,ii
;print,ii
bad(ipix,ii)=1
gbad(ipix,ii)=1
goto, c99
endif
if(testglitch le sigclipdg1)then goto, c100
;
c100:
endif ; npolyrms + 2
;
; set up glitch using last polynomial fit to good signal
;
gb=gbad(ipix,i1:i2)
igbad=where(gb eq 1,ngbad)
if(ngbad le 0)then goto, c200 ; no glitches on plateau
tbad=t(igbad)
rbad=r(igbad)
if(goodpflag eq 0)then glitch(ipix,rbad)=s(ipix,rbad) ; bad plateau
if(goodpflag eq 1)then begin ; good plateau
glitch(ipix,rbad)=s(ipix,rbad)-(rfit(0)+(rfit(1)*tbad)+(rfit(2)*tbad*tbad))
endif ; goodpflag eq 1
;if(ipix eq 4 and i1 ge 13180 and i2 lt 13250)then begin ;diagnostic
;print,'ipix = 4: glitch(ipix,rbad for plateau containing 13185:',$
;glitch(ipix,rbad)
;help,rbad
;print,rbad
;help,igbad
;print,igbad
;endif ; diagnostic
c200:
;
; test diagnostics for idl pixel 4 spikely plateau over source
;
;if(ipix eq 4 and i1 gt 13000)then begin ; diagnostic
;print,'ii,ipix,testglitch,xgtestmax',ii,ipix,testglitch,xgtestmax
;print,'xgtest(ibadtest),xxxtest,ibadtest,srgood(ibadtest):',$
;xgtest(ibadtest),xxxtest,ibadtest,srgood(ibadtest)
;print,'xxx,xxxprev',xxx,xxxprev
;print,'glitch(ipix,i1:i2)',glitch(ipix,i1:i2)
;endif ; diagnostic
;if (i1 lt 5900 and i2 gt 5900 and ipix eq 4)then begin
;print,'GLITCH1: i1,i2,ipix = ',i1,i2,ipix
;print,'GLITCH1: s(ipix,i1:i2) = ',s(ipix,i1:i2)
;print,'GLITCH1: s residual = ',s(ipix,i1:i2)-$
;(rfit(0)+(rfit(1)*time(i1:i2)-time(i1))+$
;(rfit(2)*(time(i1:i2)-time(i1))*(time(i1:i2)-time(i1))))
;print,'GLITCH1: rms(ipix,i1:i2) = ',rms(ipix,i1:i2)
;print,'GLITCH1: badin(ipix,i1:i2) = ',badin(ipix,i1:i2)
;print,'GLITCH1: bad(ipix,i1:i2) = ',bad(ipix,i1:i2)
;print,'GLITCH1: gbad(ipix,i1:i2) = ',gbad(ipix,i1:i2)
;print,'GLITCH1: glitch(ipix,i1:i2) = ',glitch(ipix,i1:i2)
;window,12,xs=400,ys=400,tit='signal versus time pixel 5'
;print,'GLITCH1: plotting pixel 5:'
;plot,time(i1:i2),s(ipix,i1:i2),linestyle=1
;oplot,time(i1:i2),$
;(rfit(0)+(rfit(1)*(time(i1:i2)-time(i1)))+$
;(rfit(2)*(time(i1:i2)-time(i1))*(time(i1:i2)-time(i1)))),linestyle=1
;endif ; diagnostic plot
;
endfor ; ichop
;
print,'number of glitches found (total, "dc") = ',ngltot,ngltot1
endfor ; ipix
;
return
end
