pro griddisp,ny,nz,ipix,iotf,ishowpt,psplot
;
; displays grid and overplots data positions from pixel ipix on unit 20.
; if ipix (IDL notation) is negative then all pixels are plotted
;
; if iotf = 1 only data on target (defined by fpt) are plotted
; if iotf = 0 only data off target (defined by fpt) are plotted
; if iotf = -1 all data (defined by fpt) are plotted
;
; if ISHOWPT is 1 then for iotf = 1 the number of points
;    with fpt=1 (ON) are printed for each s/c fine pointing
;
;common mapper,sgridy,sgridz,nygrid,nzgrid,ygrid,zgrid,errflag
;common steerin,array,nptin,npt,ninramp,imeas,osamp
;common signal,rs,cs,nch,s_in,s,badin,bad,rel,rms,glitch,jf,njf,ninchmax,rd,$
;nkf,kf,nkfmax,irelstart,nchopmed,gbad,npolyrms,nrmsmed,sigmaxfract
;common plotter,otfstart,otfstop,rdstat,chop,step,otf,rpid,yrel,zrel,$
;ytrue,ztrue,yzrpidcen,nyraster,nzraster
;common steer1,npix,pixsize,pixpitch,pixoff,nchop,dcy,dry,drz
;common pinfo,fpt
;
@common_mapper
@common_steerin
@common_signal
@common_plotter
@common_steer1
@common_pinfo
;
if(n_elements(ny) eq 0)then begin
print,'griddisp,ny,nz,ipix,iotf,ishowpt,psplot'
goto,c999
endif
;
idum=where(fpt eq 1,ndum)
print,'GRIDDISP: number of points with fpt = 1:',ndum
idum=where(fpt eq 0,ndum)
print,'GRIDDISP: number of points with fpt = 0:',ndum
;
; plotting in correct proportions
;
; set plotting symbol ipsym for data 
;ipsym=0 ; for joined symbols
ipsym=3 ; for unjoined dots
;ipsym=1 ; for unjoined +
;
xsize=700.0 ; s/c Y window size in pixels
xborder=70 ; screen pixels border
;
x1=min(ygrid)-sgridy/2.0
x2=max(ygrid)+sgridy/2.0
y1=min(zgrid)-sgridz/2.0
y2=max(zgrid)+sgridz/2.0
ysize=xsize*(y2-y1)/(x2-x1)
if(psplot ne 'ps')then window,20,xs=xsize,ysize=ysize,title='PHT32 simple grid'
xr=[x1,x2]
yr=[y1,y2]
fract=1.0-(xborder/xsize) ; fraction of screen occupied by data
px1=x1*fract
px2=x2*fract
py1=y1*fract
py2=y2*fract
yborder=xborder*(y2-y1)/(x2-x1)
px1=xborder
px2=xsize-xborder
py1=yborder
py2=ysize-yborder
if(psplot ne 'ps')then begin
plot,[x1,x2,x2,x1,x1],[y1,y1,y2,y2,y1],pos=[px1,py1,px2,py2],psym=0,$
xstyle=1,ystyle=1,/device
endif
if(psplot eq 'ps')then begin
plot,[x1,x2,x2,x1,x1],[y1,y1,y2,y2,y1],$
pos=(17800.0/(px2-px1))*[px1,py1,px2,py2],psym=0,$
xstyle=1,ystyle=1,/device
endif
oplot,[x1,x2],[y1,y1],linestyle=0
for iz=1L,nzgrid do begin
y=y1+float(iz)*sgridz
oplot,[x1,x2],[y,y],linestyle=0
endfor ; iz
oplot,[x1,x1],[y1,y2],linestyle=0
for iy=1L,nygrid do begin
x=x1+float(iy)*sgridy
oplot,[x,x],[y1,y2],linestyle=0
endfor ; iy
;
; plot positions of data from reads n1 to n2
;
n1=0L
n2=nptin
print,'GRIDDISP: plotting data for pixel ipix (IDL notation) = ',ipix
;print,ytrue(ipix,0:10)
;print,ztrue(ipix,0:10)
if(ipix ge 0)then begin
if(iotf eq -1)then begin ; plot all data
igplt=where(rd(*) gt n1-1 and rd(*) lt n2+1 and bad(ipix,*) eq 0)
oplot,ytrue(ipix,igplt),ztrue(ipix,igplt),psym=ipsym
endif ; otf -1
if(iotf eq 1 or iotf eq 0)then begin 
igplt=where(rd(*) gt n1-1 and rd(*) lt n2+1 and bad(ipix,*) eq 0, nplt)
xplt=fltarr(nplt)
yplt=xplt
xplt=ytrue(ipix,igplt)
yplt=ztrue(ipix,igplt)
rplt=rd(igplt)
fptplt=fpt(igplt)
;for ixpt = 0L, ny-1 do begin
;for iypt = 0L, nz-1 do begin
if(iotf eq 1)then begin ; only points on fine pointing
;iplt=where(rplt ge otfstart(ixpt,iypt) and rplt le otfstop(ixpt,iypt) $
;and fptplt eq 1)
iplt = where(fptplt eq 1)
oplot,xplt(iplt),yplt(iplt),psym=ipsym

endif ; iotf 1
if(iotf eq 0)then begin
iplt=where(fptplt eq 0) ; only data away from fine pointing
oplot,xplt(iplt),yplt(iplt),psym=ipsym
endif ; iotf eq 0
;endfor ; iypt
;endfor ; ixpt
endif ; iotf eq 1 or iotf eq 0
endif ; ipix ge 0
;
if(ipix lt 0)then begin
for i=0L,npix-1 do begin
igplt=where(rd(*) gt n1-1 and rd(*) lt n2+1 and bad(i,*) eq 0, nplt)
rplt=rd(igplt)
fptplt=fpt(igplt)
xplt=fltarr(nplt)
yplt=xplt
xplt=ytrue(i,igplt)
yplt=ztrue(i,igplt)
if(iotf eq -1)then oplot,ytrue(i,igplt),ztrue(i,igplt),psym=ipsym ; all data
;
if(iotf eq 1 or iotf eq 0)then begin
if(ishowpt eq 0)then begin ; don't calculate number of points on 
;                             each fine pointing (quicker)
;for ixpt = 0L, ny-1 do begin
;for iypt = 0L, nz-1 do begin
if(iotf eq 1)then begin ; plot only on fine pointing positions 
;iplt=where(rplt ge otfstart(ixpt,iypt) and rplt le otfstop(ixpt,iypt))
iplt=where(fptplt eq 1,nonpoint)
oplot,xplt(iplt),yplt(iplt),psym=ipsym
;print,'GRIDDISP: iy iz n(ON) = ',byte(ixpt),byte(iypt),nonpoint
endif ; iotf eq 1
;
if(iotf eq 0)then begin ; only off fine pointings
iplt=where(fptplt eq 0,noffpoint)
oplot,xplt(iplt),yplt(iplt),psym=ipsym
endif ; iotf eq 0
;endfor ; iypt
;endfor ; ixpt
;
endif ; ishowpt eq 0
;
if(ishowpt eq 1)then begin ; calculate number of points on 
;                             each fine pointing (slow)
if(iotf eq 1)then begin ; plot only on fine pointing positions 
;
for ixpt = 0L, ny-1 do begin
for iypt = 0L, nz-1 do begin
;
iplt=where(rplt ge otfstart(ixpt,iypt) and $
rplt le otfstop(ixpt,iypt) and fptplt eq 1,nonpoint)
;iplt=where(fptplt eq 1,nonpoint)
if(nonpoint le 0)then print,'GRIDDISP: iy iz n(ON)  = ',byte(ixpt),byte(iypt),$
long(0)
if(nonpoint gt 0)then begin
oplot,xplt(iplt),yplt(iplt),psym=ipsym
print,'GRIDDISP: iy iz n(ON)  = ',byte(ixpt),byte(iypt),nonpoint
endif ; nonpoint gt 0
;
endfor ; iypt
endfor ; ixpt
;
endif ; iotf eq 1
;
;if(iotf eq 0)then begin ; only off fine pointings
;
;iplt=where(rplt lt otfstart(ixpt,iypt) or rplt gt otfstop(ixpt,iypt),noffpoint)
;if(noffpoint le 0)then print,'GRIDDISP: iy iz n(OFF)  = ',$
;byte(ixpt),byte(iypt),long(0)
;if(noffpoint gt 0)then begin
;oplot,xplt(iplt),yplt(iplt),psym=ipsym
;print,'GRIDDISP: iy iz n(OFF) = ',byte(ixpt),byte(iypt),noffpoint
;endif ; noffpoint
;
;endif ; iotf eq 0
;
if(iotf eq 0)then begin ; only off fine pointings
iplt=where(fptplt eq 0,noffpoint)
oplot,xplt(iplt),yplt(iplt),psym=ipsym
endif ; iotf eq 0
;
endif ; ishowpt eq 1
endif ; iotf eq 1 or iotf eq 0
;
endfor ; i as pixel counter
endif ; ipix
;
;print,ytrue(*,0)
;
c999:
;
return
end
