pro inversejump_model3,sillum,sillump,signalprev,signalshootprev,tlong,$
tlongprev,betalong,betalongprev,betash,betashprev,tshoot,tshootprev,s0,s0shoot
;
; finds signalprev and signalshootprev for detector model 3 as a function of 
; s0 and s0shoot. This is the inverse to setjump_model3.pro Input data is:
;
; SILLUM           illumination on current plateau
; SILLUMP          illumination on previous plateau
; S0               long signal immediately after jump
; S0SHOOT          shooting signal immediately after ump
; TLONG            long time constant on current plateau
; TLONGPREV        long time constant on previous plateau
; BETALONG         jump factor for long time constant on current plateau
; BETALONGPREV     jump factor for long time constant on previous plateau
; TSHOOT           long time constant on current plateau
; TSHOOTPREV       long time constant on previous plateau
; BETASH           jump factor for shooting time constant on current plateau
; BETASHPREV       jump factor for shooting time constant on previous plateau
;
; note that conservative and non-conservative jump conditions are equivalent
; if the beta and tau constants are independent of illumination
;
; s0, s0shoot as a function of signalprev,signalshootprev as calculated
; by setjump_model3.pro are given by (all statements until ---------
; should be commented):
;
@common_steerin
; common steerin,array,nptin,npt,ninramp,imeas,osamp
;
; conservative, standard imodel=3 
; (expshoot_standardintegralsubtraction.pro and 
;  expshoot_originalexpaddition.pro)
; s0=betalong*sillum+(tlongprev/tlong)*(signalprev-betalongprev*sillump) 
; s0shoot=betash*sillum+$
; (tshootprev/tshoot)*(signalshootprev-betashprev*sillump)
;
; non conservative, standard imodel=3
; (expshoot_standardintegralsubtraction.pro and 
;  expshoot_originalexpaddition.pro)
; s0=signalprev+(betalong*(sillum-sillump))
; s0shoot=betash*(sillum-sillump)+signalshootprev 
; 
; conservative, alternative empirical imodel=3
; (expshoot_alternativeempirical.pro)
; s0=betalong*sillum+(tlongprev/tlong)*(signalprev-betalongprev*sillump) 
; s0shoot=signalshootprev*(tshootprev/tshoot)
;
; non conservative, alternative empirical imodel=3
; (expshoot_alternativeempirical.pro)
;s0=signalprev+(betalong*(sillum-sillump))
;s0shoot=signalshootprev
;
;----------------------------------------------------------------
;
; The inverse relations for signalprev, signalshootprev are thus: 
;
; conservative, standard imodel=3 
; (expshoot_standardintegralsubtraction.pro and 
;  expshoot_originalexpaddition.pro) 
; signalprev=betalongprev*sillump+(tlong/tlongprev)*(s0-betalong*sillum)
; signalshootprev=betashprev*sillump+$
; (tshoot/tshootprev)*(s0shoot-betash*sillum)
;
; non conservative, standard imodel=3
; (expshoot_standardintegralsubtraction.pro and 
;  expshoot_originalexpaddition.pro)
; signalprev=s0-(betalong*(sillum-sillump))
; signalshootprev=s0shoot-(betash*(sillum-sillump))
;
; conservative, alternative empirical imodel=3
; (expshoot_alternativeempirical.pro)
 if(array eq 'c200')then begin
  signalprev=betalongprev*sillump+(tlong/tlongprev)*(s0-betalong*sillum)
  signalshootprev=s0shoot*(tshoot/tshootprev)
endif ; array eq 'c200'
;
; non conservative, alternative empirical imodel=3
; (expshoot_alternativeempirical.pro)
if(array eq 'c100')then begin
  signalprev=s0-(betalong*(sillum-sillump))
  signalshootprev=s0shoot
endif ; array eq 'c100'
;
return
end





