pro levfind,nlev,mcint,ilog,map,maprms,lev
;
; finds contour intervals lev for map(o:nygrid-1,0:nzgrid-1) over region 
; containing data within a frame o:nygrid-1,0:nzgrid-1
;
; if ilog is 0 NLEV linear levels are found from minimum to maximum 
;     value of MCINT ignored
;  if ilog is -1 linear leveels are found symetrically about zero, if
;     a zero exists, with interval MCINT
; if ilog is 1 log levels (doubling factor) are found after shifting 
;    minimum to the value of MCINT (normally mcint should be specified
;    as about 1.5 rms noise in this case).
;
; MAPRMS is input to act as a flag for pixels having no data, which are
;    not included in the calculation of statistics
;
; a maximum of NCMAX=30 levels are plotted otherwise IDL CONTOUR crashes, starting
; at the lowest level calculated as described above
;
;common mapper,sgridy,sgridz,nygrid,nzgrid,ygrid,zgrid,errflag
;common steerin,array,nptin,npt,ninramp,imeas,osamp
;common signal,rs,cs,nch,s_in,s,badin,bad,rel,rms,glitch,jf,njf,ninchmax,rd,$
;nkf,kf,nkfmax,irelstart,nchopmed,gbad,npolyrms,nrmsmed,sigmaxfract
;common plotter,otfstart,otfstop,rdstat,chop,otf,rpid,yrel,zrel,$
;ytrue,ztrue,yzrpidcen,nyraster,nzraster
;common steer1,npix,pixsize,pixpitch,pixoff,nchop,dcy,dry,drz
;common pinfo,fpt
;
@common_mapper
@common_steerin
@common_signal
@common_plotter
@common_steer1
@common_pinfo
;
NCMAX=100 ; 30 is maximum handled by CONTOUR. More must be done with succesive
          ; plots with overplotting
mapplot=map ; mapplot is array to be plotted (may be manipulated if ilog = 1)
;
; plotting in correct proportions
;
igood=where(maprms ne errflag,ngood) 
zmax=max(map(igood))
zmin=min(map(igood))
print,'LEVFIND: ngood, min, max: ',ngood,zmin,zmax
;
if(ilog eq 0)then begin ; nlev linear contours between max and min
if(nlev ge 2)then dc=(zmax-zmin)/float(nlev-1)
if(nlev lt 2)then begin
dc=(zmax-zmin)
print,'LEVFIND: warning - less than two contours to be plotted'
endif ; nlev lt 2
lev=zmin+findgen(nlev)*dc
;
endif ; ilog eq 0
;
if(ilog eq -1)then begin ; linear contours spaced by mcint symetrically around 
;                zero (if exists) between max and min. Negative plotted dotted.
;              
if(zmin ge 0.0 and zmax gt 0.0)then begin
zstart=mcint/2.0 
if(zmax lt mcint/2.0)then zstart=(zmin+zmax)/2.0
nnlev=1+long((zmax-zstart)/mcint)
lev=zstart+mcint*findgen(nnlev)
;print,'nnlev,lev =',nnlev,lev
endif ; zmin ge 0.0 and zmax gt 0.0
;
if(zmin lt 0.0 and zmax le 0.0)then begin
zstop=0.0-mcint/2.0
if(zmin gt zstop)then zstop=(zmin+zmax)/2.0
nnlev=1+long((zstop-zmin)/mcint)
lev=zstop-mcint*findgen(nnlev)
endif ; zmin lt 0.0 and zmax le 0.0
;
; case zmin lt 0.0 and zmax gt 0.0
if(zmin lt 0.0 and zmax gt 0.0)then begin
nneg=long(0.5+abs(zmin)/mcint) ; number of negative contours
if(nneg ge 1)then levneg=0.0-0.5*mcint-findgen(nneg)*mcint
npos=long(0.5+zmax/mcint) ; number of positive contours
;print,'nneg,npos: ',nneg,npos
if(npos ge 1)then levpos=0.0+0.5*mcint+findgen(npos)*mcint
;print,'levpos: ',levpos
;print,'levneg: ',levneg
if(nneg ge 1 and npos ge 1)then lev=[levneg,levpos]
if(nneg lt 1 and npos ge 1)then lev=levpos
if(nneg ge 1 and npos lt 1)then lev=levneg
if(nneg lt 1 and npos lt 1)then lev=(zmin+zmax)/2.0
;print,'lev = ',lev
; end case zmin lt 0.0 and zmax gt 0.0
endif ; zmin lt 0.0 and zmax gt 0.0
;
endif ; ilog eq -1
;
if(ilog eq 1)then begin ; log contours (doubling factor) starting at minimum
;    with first interval MCINT after shifting minimum to the value of MCINT 
;    if it is less than MCINT
;
if (zmin lt mcint)then mapplot=mapplot+(mcint-zmin) ; make sure minimum is 
;                                                     +ve , at least mcint
zzmin=min(mapplot(igood))
zzmax=max(mapplot(igood))
lfactor=2.0 ; logarithmic factor
; rjt sep 99 nnlev=alog10(zzmax/zzmin)/alog10(lfactor)
nnlev=alog10((zzmax-zzmin)/mcint)/alog10(lfactor)
nnlev=long(nnlev)
nnlev=nnlev+1
lev=zzmin-mcint+mcint*(lfactor^findgen(nnlev))
;
endif ; ilog eq 1
;
;
; remove levels if below or at map minimum and  if above map maximum 
ii=where(lev gt min(map(igood)) and lev le max(map(igood)),nii)
if(nii gt 0)then lev=lev(ii)
;
lev=lev(sort(lev)) ; get into ascending order
if(n_elements(lev) gt NCMAX)then begin
print,$
'LEVFIND: n_elements(lev) gt',ncmax,' - only lowest',ncmax,' contours plotted'
lev=lev(0:29)
endif ; n_elements(lev) gt 30
;
return
end





