pro mapback,templateback,templatesource,map,mapr,mapn,$
mapnoback,backmap,backmapn,backbright,errsys,errran,errtot,$
flux,fluxranerr,fluxsyserr,fluxerrtot
;
; Performs photometry of background and source.
;
; Background determination and photometry:
; Performs a weighted fit of a tilted plane to MAP sampled on the P32 natural 
; grid at directions given
; by TEMPLATEBACK, using the array of RMS MAPR to calculate the weights. 
; A background-subtracted map is output as MAPNOBACK and the map of the 
; background as BACKMAP. BACKMAPN is set to MAPN where MAPN and TEMPLATEBACK 
; are non zero, zero otherwise. The systematic rms fractional photometric 
; uncertainty in the input map scale factor (eg derived by running SKYFLAT on 
; un-flatfielded data) is input as ERRSYS. The random fractional error in the 
; background fit is output as ERRRAN, and the total fractional error in the
; background, calculated as the quadrature sum of errran and errsys, as ERRTOT.
; The mean of the fit to the tilted plane background is output as BACKBRIGHT.
;
; Source photometry is performed on MAPNOBACK as the sum of all map pixels 
; where TEMPLATESOURCE is non zero, to give:
;
; FLUX       integrated flux in Jy (for case that input units are MJy/sterad)
; FLUXRANERR random rms in flux (from background and source integrations)
; FLUXSYSERR systematic rms in flux
; FLUXERRTOT total rms in flux
;
@common_steer1
;common steer1,npix,pixsize,pixpitch,pixoff,nchop,dcy,dry,drz
@common_mapper
;common mapper,sgridy,sgridz,nygrid,nzgrid,ygrid,zgrid,errflag
;
if(n_elements(templateback) le 0)then begin
print,'mapback,templateback,templatesource,map,mapr,mapn,mapnoback,backmap,$'
print,'backmapn,backbright,errsys,errran,errtot,flux,fluxranerr,fluxsyserr,fluxerrtot'
print,'eg createtemplate,-1,1,1.,90.,0.,0.,templatesource ; create source mask'
print,'   createtemplate,1,1,1.,90.,0.,0.,templateback ; create background mask'
print,'   mapback,templateback,templatesource,map,mapr,mapn,mapnoback,backmap,$'
print,'   backmapn,backbright,0.066,errran,errtot,flux,fluxranerr,fluxsyserr,fluxerrtot'
goto,c999
endif 
;
nfitmin=3
backmapn=mapn
ii=where(templateback eq 0,nii) 
if(nii gt 0)then backmapn(ii)=0
ifit=where(backmapn gt 0,nfit)
if(nfit gt nfitmin)then $
print,'MAPBACK: fitting tilted plane with',nfit,' directions'
if(nfit le nfitmin)then begin
print,$
'MAPBACK aborting: insufficient background data to fit a tilted plane'
goto,c999
endif ; nfit lt nfitmin
;
; perform fit
;
a=fltarr(3,3) ; fiducial matrix
b=fltarr(3)
mapw=1.0/(mapr*mapr)
mapi=map
mapi(*,*)=0
mapj=mapi
;help,map,mapi
for i=0,nygrid-1 do mapi(i,*)=float(i)
for j=0,nzgrid-1 do mapj(*,j)=float(j)
mapij=mapi*mapj
mapi2=mapi*mapi
mapj2=mapj*mapj
;
;map=1.0+0.1*mapi+0.2*mapj ; for debugging
;
a(0,0)=total(mapw(ifit))
a(1,0)=total(mapi(ifit)*mapw(ifit))
a(0,1)=a(1,0)
a(0,2)=total(mapj(ifit)*mapw(ifit))
a(2,0)=total(mapj(ifit)*mapw(ifit))
a(1,1)=total(mapi2(ifit)*mapw(ifit))
a(1,2)=total(mapij(ifit)*mapw(ifit))
a(2,1)=a(1,2)
a(2,2)=total(mapj2(ifit)*mapw(ifit))
b(0)=total( map(ifit)*mapw(ifit) )
b(1)=total( mapi(ifit)*map(ifit)*mapw(ifit) )
b(2)=total( mapj(ifit)*map(ifit)*mapw(ifit) )
;
aa=invert(a)
;
sol=fltarr(3)
for i=0,2 do begin
for j=0,2 do begin
sol(i)=sol(i)+aa(i,j)*b(j)
endfor ; j
endfor ; i
;
backmap=sol(0)+sol(1)*mapi+sol(2)*mapj
mapnoback=map-backmap
;
backbright=total(backmap)/float(nygrid*nzgrid)
;
;
; find random uncertainty in DC offset in fit from simple weighted average
; of directions used to obtain the fit:
;
rmsprop,map(ifit),mapr(ifit),xmean,xrmssig,xrmsmean,1 ; weighted mean as for 
;
;                                                       fiducial solution 
errran=xrmsmean/backbright
errtot=sqrt(errran*errran+errsys*errsys) ; total fractional error in background
if(nfit gt 1)then xfactor=sqrt(float(nfit-1))
if(nfit le 1)then xfactor=sqrt(float(nfit))
errranmeas=xfactor*xrmssig ; measured rms over map (not rms in mean)
;
; conversion factors between brightness and flux on P32 natural grid. Multiply
; data in MJy/sterad by RATIO to convert to Jy/map pixel and by RATIOD
; to convert to Jy/detector pixel
; 
fluxbright,ratio,ratiod
;
;arcsperster=(180.0*3600)/!pi
;pixa=sgridy*sgridz/(arcsperster*arcsperster) ; pixel size in sterad
;ratio=pixa*1.0e+06 ; conversion factor to convert MJy/sterad to Jy/mappixel
;pixd=pixsize*pixsize/(arcsperster*arcsperster) ; detector pixel size in sterad
;ratiod=pixd*1.0e+06 ; conversion factor to convert MJy/sterad to Jy/detpixel
;
print,'MAPBACK: fit to tilted plane      = ',float(sol)
print,''
print,'MAPBACK: background statistics on',nfit,' map pixels:'
print,'mean brightness                   = ',float(backbright)
print,'fractional systematic uncertainty = ',float(errsys)
print,'systematic uncertainty            = ',float(errsys*backbright)
print,'fractional random uncertainty     = ',float(errran)
print,'random uncertainty                = ',float(errran*backbright)
print,'measured  random uncertainty      = ',float(xrmssig)
print,'measured rms (Jy/detector pixel)  = ',$
float(errranmeas*ratiod)
print,'random + systematic uncertainty   = ',float(errtot*backbright)
print,''
;
; source photometry
;
ii=where(templatesource gt 0,nii)
if(nii le 0)then begin
print,'MAPBACK: no source directions defined - aborting'
goto,c999
endif ; nii le 0
;
itest=where(templateback(ii) gt 0,nitest)
if(nitest gt 0)then begin
print,$
'MAPBACK: warning - background template overlaps with source integration area'
endif ; nitest gt 0
;
bsource=mapnoback(ii)
source=ratio*mapnoback(ii)
rsource=ratio*mapr(ii)
nsource=mapn(ii)
;
jj=where(nsource gt 0,njj)
if(njj ne n_elements(nsource))then begin
print,'MAPBACK: warning - number of source directions missing = ',$
n_elements(nsource)-njj
endif ; njj ne n_elements(nsource)
flux=total(source(jj))
fluxranerrsource=sqrt(total(rsource(jj)*rsource(jj)))
fluxsyserr=flux*errsys
fluxranerrback=errran*backbright*ratio*float(njj) ; in Jy
fluxranerr=$
sqrt(fluxranerrsource*fluxranerrsource+fluxranerrback*fluxranerrback)
fluxerrtot=sqrt(fluxranerr*fluxranerr+fluxsyserr*fluxsyserr)
;
;print,flux,fluxranerrsource,fluxranerrback,fluxranerr,fluxsyserr,fluxerrtot
;
print,'MAPBACK: source statistics on    ',njj,' map pixels:'
print,'integrated flux                   =',float(flux)
print,'total random error in flux        =',float(fluxranerr)
print,'detection ratio                   =',float(flux/fluxranerr)
print,'random error in backgr. integral  =',float(fluxranerrback)
print,'random error in source integral   =',float(fluxranerrsource)
print,'systematic flux scale uncertainty =',float(fluxsyserr)
print,'random + systematic uncertainty   =',float(fluxerrtot)
print,''
; find peak brightness
im=where(mapnoback eq max(bsource(jj)),nim)
bmax=mapnoback(im(0))
for i=0,nygrid-1 do begin
for j=0,nzgrid-1 do begin
if(mapnoback(i,j) eq bmax)then begin
imax=i
jmax=j
endif ; mapnoback(i,j) eq bmax
endfor ; j
endfor ; i
print,'MAPBACK: statistics for background-subtracted peak brightness:'
print,'position of  peak brightness      =',imax,jmax
print,'peak surface brightness (MJy/sr)  =',float(bmax)
errranmaxb=mapr(im(0))
errranmaxb=sqrt(errranmaxb*errranmaxb+errran*backbright*errran*backbright)
errsysmaxb=bmax*errsys
errtotmaxb=sqrt(errsysmaxb+errsysmaxb+errranmaxb*errranmaxb)
print,'random error in peak SB (MJy/sr)  =',float(errranmaxb)
print,'sys. error in peak SB (MJy/sr)    =',float(errsysmaxb)
print,'total error in peak SB (MJy/sr)   =',float(errtotmaxb)
;
c999:
;
return
end







