pro mapcontourmult,igridover,nlev,mcint,ilog,map,maprms,psplot
;
; contours map(0:npix-1,o:nygrid-1,0:nzgrid-1) with common intervals
; displaying contours on sqrt(npix) * sqrt(npix) panels. Each panel contains
; data over region within a frame o:nygrid-1,0:nzgrid-1 on unit 23
;
; if igridover is 1 the map grids are overlaid
; if ilog is 0 NLEV linear contours are plotted from minimum to maximum with 
;     negative contours dashed; value of MCINT ignored
;  if ilog is -1 linear contours are plotted symetrically about zero, if
;     a zero exists, with interval MCINT
; if ilog is 1 log contours (doubling factor) are plotted after shifting 
;    minimum to the value of MCINT (normally mcint should be specified
;    as about 1.5 rms noise in this case).
;
; Perimeter with value of errflag is not plotted
;
; MAPRMS is input to act as a flag for pixels having no data, which are
;    not plotted and which are not included in the calculation of statistics
;
; a maximum of NCMAX=30 contours are plotted otherwise IDL crashes, starting
; at the lowest contour calculated as described above
;
;common mapper,sgridy,sgridz,nygrid,nzgrid,ygrid,zgrid,errflag
;common steerin,array,nptin,npt,ninramp,imeas,osamp
;common signal,rs,cs,nch,s_in,s,badin,bad,rel,rms,glitch,jf,njf,ninchmax,rd,$
;nkf,kf,nkfmax,irelstart,nchopmed,gbad,npolyrms,nrmsmed,sigmaxfract
;common plotter,otfstart,otfstop,rdstat,chop,otf,rpid,yrel,zrel,$
;ytrue,ztrue,yzrpidcen,nyraster,nzraster
;common steer1,npix,pixsize,pixpitch,pixoff,nchop,dcy,dry,drz
;common pinfo,fpt
;
@common_mapper
@common_steerin
@common_signal
@common_plotter
@common_steer1
@common_pinfo
;
; plotting in correct proportions
;
xsize=800.0 ; s/c Y window size in pixels
xborder=40 ; screen pixels border
;
xnum=sqrt(float(npix))
nxdiv=long(xnum) ; there are nxdiv * nxdiv panels in picture
x1=min(ygrid)-sgridy/2.0
x2=max(ygrid)+sgridy/2.0
y1=min(zgrid)-sgridz/2.0
y2=max(zgrid)+sgridz/2.0
ysize=xsize*(y2-y1)/(x2-x1) ; still OK for multiple plots
if(psplot ne 'ps')then window,23,xs=xsize,ysize=ysize,title=' '
fract=1.0-(xborder/xsize) ; fraction of screen occupied by data
px1=x1*fract ; in data units (arcsec) for each panel
px2=x2*fract
py1=y1*fract
py2=y2*fract
yborder=xborder*(y2-y1)/(x2-x1)
px1=xborder ; complete frame in physical units (screen pixels)
px2=xsize-xborder
py1=yborder
py2=ysize-yborder
pxf1=fltarr(nxdiv) ; starting x in physical units for panels 
pxf2=pxf1
pyf1=pxf1
pyf2=pxf1
for i=0L,nxdiv-1 do begin
ddx=(px2-px1)/float(nxdiv)
ddy=(py2-py1)/float(nxdiv)
pxf1(i)=xborder+float(i)*ddx
pxf2(i)=pxf1(i)+ddx
pyf1(i)=yborder+float(i)*ddy
pyf2(i)=pyf1(i)+ddy
endfor ; i
;
; plot first frame in bottom left hand corner
;
mmap=fltarr(nygrid,nzgrid)
mmaprms=mmap
;plot,[x1,x2,x2,x1,x1],[y1,y1,y2,y2,y1],pos=[pxf1(0),pyf1(0),pxf2(0),pyf2(0)],$
;psym=0,xstyle=5,ystyle=5,/device ; establishes data to physical units
;                               xstyle=5 means exact scaling with no axis drawn
;
;axis,x1,y1,xstyle=5,xax=0,/noerase
;axis,x1,y1,xstyle=5,yax=0,/noerase
;if(igridover eq 1)then drawgrid
;mmap(*,*)=map(0,*,*)
;mmaprms(*,*)=maprms(0,*,*)
;levfind,nlev,mcint,ilog,mmap,mmaprms,lev ; find contour levels LEV
;findgoodarea,mmaprms,i1,i2,j1,j2 ; clip off edges containing 
;                                 only dummy data from plot
;print,'MAPCONTOURMULT: pixels plotted for pixel 0: ',i1,i2,j1,j2
;print,'MAPCONTOURMULT: levels plotted for pixel 0: ',lev
;yplot=min(ygrid)+sgridy*float(i1)+findgen(i2-i1+1)*sgridy
;zplot=min(zgrid)+sgridz*float(j1)+findgen(j2-j1+1)*sgridz
;contour,mmap(i1:i2,j1:j2),yplot,zplot,$
;lev=lev,C_LINESTYLE = (lev LT 0.0),/overplot
;
; plot axes and remaining frames
;
iipix=-1
print,'MAPCONTOURMULT:'
for i=0L,nxdiv-1 do begin
for j=0L,nxdiv-1 do begin
;
iipix=iipix+1
print,'pixel,i+1,j+1: ',iipix+1,i+1,j+1
if(psplot ne 'ps')then begin
plot,[x1,x2,x2,x1,x1],[y1,y1,y2,y2,y1],pos=[pxf1(i),pyf1(j),pxf2(i),pyf2(j)],$
psym=0,xstyle=5,ystyle=5,/device,/noerase ; establishes data to physical units
;                               xstyle=5 means exact scaling with no axis drawn
;
endif
if(psplot eq 'ps')then begin
plot,[x1,x2,x2,x1,x1],[y1,y1,y2,y2,y1],pos=[pxf1(i),pyf1(j),pxf2(i),pyf2(j)],$
psym=0,xstyle=5,ystyle=5,/noerase ; establishes data to physical units
;                               xstyle=5 means exact scaling with no axis drawn
;
endif
oplot,[x2-0.1,x2-0.1],[y1,y2],psym=0,thick=2 ; to emphasise panel outline
; and since RHS for some reason is not drawn by above
oplot,[x1,x2],[y2-0.1,y2-0.1],psym=0,thick=2 
if(j eq 0)then axis,x1,y1,xstyle=5,xax=0,/noerase
if(i eq 0)then axis,x1,y1,xstyle=5,yax=0,/noerase
if(igridover eq 1)then drawgrid
mmap=fltarr(nygrid,nzgrid)
mmaprms=mmap
mmap(*,*)=map(iipix,*,*)
mmaprms(*,*)=maprms(iipix,*,*)
levfind,nlev,mcint,ilog,mmap,mmaprms,lev ; find contour levels LEV
findgoodarea,mmaprms,i1,i2,j1,j2 ; clip off edges containing 
;                                 only dummy data from plot
print,'pixels plotted: ',i1,i2,j1,j2
print,'levels plotted: ',lev
yplot=min(ygrid)+sgridy*float(i1)+findgen(i2-i1+1)*sgridy
zplot=min(zgrid)+sgridz*float(j1)+findgen(j2-j1+1)*sgridz
contour,mmap(i1:i2,j1:j2),yplot,zplot,$
lev=lev,C_LINESTYLE = (lev LT 0.0),/overplot
;
endfor ; i
endfor ; j
;
return
end
