pro mapflat1,i1,i2,j1,j2,mappix,ifindf,fmultout,ifindh,hmultout,ufract,icover
;
; finds flat fielding parameter FMULTOUT(npixarray) for multiplictive scaling
; factors and/or additive constants HMULTOUT(npixarray) between a subset npix 
; out of npixarray pixels specified in the array MAPPIX (in IDL notation). 
; If IFINDF is 1 a multiplictive factor FMULTOUT is found such that data = 
; datainput*fmultout corrects the data for the case IFINDF=1 IFINDH=0
; If IFINDH is 1 an additive factor HMULTOUT is found such that data =
; datainput+HMULTOUT corrects the data for the case IFINDH=1 IFINDF=0
; If both IFINDF and IFINDH are 1 then multiplictive factors FMULTOUT and
; additive factors HMULTOUT are simultaneously found and implemented to correct
; the data as data = (datainput*fmultout)+hmultout. Obviously, the 
; multiplicative and additive corection factors found are only meaningful if
; MAPFLAT1 is run on a map area containing background and structure.
; The area i1:i2 j1:j2 on the P32 natural grid is 
; used to find the flat field. ICOVER is input as 0 if there is no direction
; viewed by all pixels.
;
; MAPFLAT1 does not implement the corrections.
;
; If ufract is > 0.0 then only points on source above a fraction UFRACT
; of the data points for each detector pixel are used for that detector pixel.
; This is useful for maps containing significant signal with a variable
; zero level for each detector pixel which is not a responsivity effect, and
; for maps where only the brightest points have a significant signal to noise.
;
; - make map for each pixel. 
;   
; - find average of pixel values for pixels common to pairs of maps
; - solve fiducial equations to find solution for multiplicative factors
;   FMULT for each pixel such that average of FMULT=1.0
;
;common mapper,sgridy,sgridz,nygrid,nzgrid,ygrid,zgrid,errflag
;common steerin,array,nptin,npt,ninramp,imeas,osamp
;
@common_mapper
@common_steerin
;
isubtract=1 ; internal option - if isubtract=1 and ifindf and ifindh are
            ;                   both 1 the flat is found by subtracting a
            ;                   quartile, running FLATMAT1, and then looking
            ;                   at the offsets of the residues.
            ;                   if isubtract=0  and ifindf and ifindh are
            ;                   both 1 the flat is found by a single call to 
            ;                   FLATMAT2. At present FLATMAT2 has some bug
            ;                   so we have to use the option isubtract=1.
;
if(i1 lt 0 or i1 gt i2 or i1 ge nygrid)then begin
print,'MAPFLAT1 - aborting - incorrect i1 of ',i1
endif ; i1 lt 0 or i1 gt i2 or i1 ge nygrid
;
if(j1 lt 0 or j1 gt j2 or j1 ge nzgrid)then begin
print,'MAPFLAT1 - aborting - incorrect j1 of ',j1
endif ; j1 lt 0 or j1 gt j2 or j1 ge nzgrid
;
npix=n_elements(mappix)
mapmed=fltarr(npix)
mapq1=mapmed
mapq3=mapmed
if(array eq 'c100')then npixarray=9
if(array eq 'c200')then npixarray=4
fmultout=fltarr(npixarray)
hmultout=fmultout
fmultout(*)=1.0
hmultout(*)=0.0
fmult=fltarr(npix) 
hmult=fmult
fmult(*)=1.0 
hmult(*)=0.0
thresh=fltarr(npix)
; make npix maps with equal input weights, only for points with otf set
makemapmulti,$
npix,mappix,mapallb,mapallrms,mapalldisp,mapally,mapallz,mapalln,0,1
; for testing use MAPCREATE
;mapcreate,npix,mappix,mapallb,mapallrms,mapalldisp,mapally,mapallz,mapalln,0,1
;
mapallborig=mapallb
;
; find good map pixels in area i1:i2 j1:j2 common to all detector pixel maps
;
nygridwk=i2-i1+1
nzgridwk=j2-j1+1
igoodpoint=lonarr(nygridwk*nzgridwk)
igoodpoint(*)=1
work=fltarr(nygridwk*nzgridwk)
workn=work
for ip=0,npix-1 do begin
work(*)=mapallb(ip,i1:i2,j1:j2)
workn(*)=mapalln(ip,i1:i2,j1:j2)
ibad=where(workn eq 0 or work eq errflag,nibad)
if(nibad gt 0)then igoodpoint(ibad)=0
if(nibad eq nygridwk*nzgridwk)then begin
print,'MAPFLAT1: no good points for detector pixel ',mappix(ip)
endif ; nibad eq nygridwk*nzgridwk
endfor ; ip=0,npix-1
;
; find median of good points on specified area of sky for each specified pixel
; for case ifindf=ifindh=1=isubtract=1 subtract median from maps
; for case ifindf=0 ifindh=1 extract HMULT directly
; find upper threshold for upper ufract of points for each pixel
;
for ip=0,npix-1 do begin
work(*)=mapallb(ip,i1:i2,j1:j2)
workn(*)=mapalln(ip,i1:i2,j1:j2)
igood=where(workn gt 0 and work ne errflag and igoodpoint eq 1,nigood)
test=fltarr(nigood)
test=work(igood)
stat,test,testmin,testmax,testmedtrue,testq1,testq3,testsigequiv,testav,$
testsig,0
;mapmed(ip)=median(test)
;mapmed(ip)=total(test)/float(nigood)
mapmed(ip)=testmedtrue
mapq1(ip)=testq1
mapq3(ip)=testq3
if(ifindf eq 1 and ifindh eq 1 and isubtract eq 1)then begin
;test=test-mapmed(ip)
;mapallb(ip,*,*)=mapallb(ip,*,*)-mapmed(ip)
test=test-mapq1(ip)
mapallb(ip,*,*)=mapallb(ip,*,*)-mapq1(ip)
endif ; ifindf eq 1 and ifindh eq 1 and isubtract eq 1
;print,'pixel, Q1,Q2,Q3 = ',mappix(ip),mapq1(ip),mapmed(ip),mapq3(ip)
test=test(sort(test))
thresh(ip)=min(test)-1.0
if(ufract gt 0.0 and ufract lt 1.0)then thresh(ip)=test(ufract*nigood)
endfor ; ip
;
mapmedav=total(mapmed(0:npix-1))/float(npix)
mapq1av=total(mapq1(0:npix-1))/float(npix)
if(ifindh eq 1 and ifindf eq 0)then begin
for ip=0,npix-1 do begin
hmult(ip)=mapmedav-mapmed(ip) ; best for signaless cases
;hmult(ip)=mapq1av-mapq1(ip) ; only good if soome fraction of 
;                              map covered by source
endfor ; ip=0,npix-1
goto, c452
endif ; ifindh eq 1 and ifindf eq 0
;
if(icover eq 0)then begin ; no direction viewed by all pixels
; NB replace this by splitting into combinations with a common direction
avmapmed=total(mapmed)/float(npix)
for ip=0,npix-1 do begin
fmult(ip)=avmapmed/mapmed(ip)
endfor ; ip
goto, c452 ; no direction viewed by all pixels
endif ; icover
;
xnover=lonarr(npix,npix)
beta=fltarr(npix,npix)
xi=fltarr(nygridwk*nzgridwk)
xj=xi
rmsi=xi
rmsj=xi
ni=lonarr(nygridwk*nzgridwk)
nj=ni
for i=0,npix-1 do begin
xi(*)=mapallb(i,i1:i2,j1:j2)
ni(*)=mapalln(i,i1:i2,j1:j2)
rmsi(*)=mapallrms(i,i1:i2,j1:j2)
for j=0,npix-1 do begin
xj(*)=mapallb(j,i1:i2,j1:j2)
nj(*)=mapalln(j,i1:i2,j1:j2)
rmsj(*)=mapallrms(j,i1:i2,j1:j2)
;ij=where(ni gt 0 and nj gt 0 and xi gt thresh(i) and xj gt thresh(j),nij)
ij=where(ni gt 0 and nj gt 0 and xi gt thresh(i) and xj gt thresh(j) $
and igoodpoint eq 1,nij)
;ij=where(ni gt 0 and nj gt 0,nij)
if(nij ge 1)then begin
avij=total(xi(ij))/float(nij)
avji=total(xj(ij))/float(nij)
;beta(i,j)=avij*float(nij) ; can't do this if we include offsets too
;beta(j,i)=avji*float(nij)
beta(i,j)=avij
beta(j,i)=avji
rmsimean=total(rmsi(ij))/float(nij)
rmsjmean=total(rmsj(ij))/float(nij)
xnover(i,j)=total(float(ni(ij))/(rmsimean*rmsimean))
xnover(j,i)=total(float(nj(ij))/(rmsjmean*rmsjmean))
endif ; nij ge 1
if(nij le 0)then print,'MAPFLAT1: no good points for ipix,i,j = ',$
mappix(ip),i,j
endfor ; j
endfor ; i
xnover=xnover/total(xnover)
;
; solve fiducial equations for scaling
;
;flatmat1,beta,npix,fmult
if(ifindf eq 1 and ifindh eq 0)then flatmat1,beta,xnover,npix,fmult
if(ifindf eq 1 and ifindh eq 1 and isubtract eq 1)then $
flatmat1,beta,xnover,npix,fmult
if(ifindf eq 1 and ifindh eq 1 and isubtract eq 0)then $
flatmat2,beta,xnover,npix,fmult,hmult
;
; for case ifindf=ifindh=1=isubtract correct internal map with the FMULT arrays
; and then find the HMULT factors:
;
if(ifindf eq 1 and ifindh eq 1 and isubtract eq 1)then begin
;
for ip=0,npix-1 do begin
;
mapallb(ip,*,*)=fmult(ip)*mapallborig(ip,*,*)
; should just include background
work(*)=mapallb(ip,i1:i2,j1:j2)
workn(*)=mapalln(ip,i1:i2,j1:j2)
igood=where(workn gt 0 and work ne errflag and igoodpoint eq 1,nigood)
test=fltarr(nigood)
test=work(igood)
stat,test,testmin,testmax,testmedtrue,testq1,testq3,testsigequiv,testav,$
testsig,0
;mapmed(ip)=median(test)
;mapmed(ip)=total(test)/float(nigood)
mapmed(ip)=testmedtrue
mapq1(ip)=testq1
;print,'pixel, data quartile,median = ',mappix(ip),mapq1(ip),mapmed(ip)
;
endfor ; ip
;
mapmedav=total(mapmed(0:npix-1))/float(npix)
mapq1av=total(mapq1(0:npix-1))/float(npix)
for ip=0,npix-1 do begin
;hmult(ip)=mapmedav-mapmed(ip)
hmult(ip)=mapq1av-mapq1(ip)
endfor ; ip=0,npix-1
;
; average additive correction to original map should be zero
; NB this means that the sum of HMULT will not be zero
;
hmultorigtot=total(hmult/fmult)
finvtot=total(1.0/fmult) 
deltaback=0.0-hmultorigtot/finvtot
hmult=hmult+deltaback
;
endif ; ifindf eq 1 and ifindh eq 1 and isubtract eq 1
;
c452:
;
fmultout(mappix)=fmult
hmultout(mappix)=hmult
if(ifindf eq 1)then print,'MAPFLAT1: FMULT = ',fmultout
if(ifindh eq 1)then print,'MAPFLAT1: HMULT = ',hmultout
;
return
end




