pro mapflatend,pixarray,mapoutb,mapoutr,mapoutd,mapouty,mapoutz,mapoutn,n_end
;
; Makes maps flat fielded in 2D:
; uses N_END points at start and end of each scan to get zero level, for
; detector pixels given by PIXARRAY, and combines the pixel data to get 
; a brightness map MAPOUTB with corresponding positional rms dispersion
; exposure data MAPOUTR MAPOUTD MAPOUTN MAPOUTY,MAPOUTZ.
;
; N_END must be at least 4 for c200 to get overlap in Y between all pixels
; N_END must be at least 7 for c100 to get overlap in Y between all pixels
;
@common_mapper
;common mapper,sgridy,sgridz,nygrid,nzgrid,ygrid,zgrid,errflag
@common_steerin
;common steerin,array,nptin,npt,ninramp,imeas,osamp
;
if(array eq 'c200')then begin
if(n_end lt 3)then print,'MAPFLATEND: warning - n_end must be at least 3'
endif ; array eq 'c200'
;
if(array eq 'c100')then begin
if(n_end lt 6)then print,'MAPFLATEND: warning - n_end must be at least 6'
endif ; array eq 'c100'
;
np=n_elements(pixarray)
mapoutb=fltarr(nygrid,nzgrid)
mapoutr=mapoutb
mapoutd=mapoutb
mapoutn=mapoutb
mapouty=mapoutb
mapoutz=mapoutb
mapworkb=fltarr(np,nygrid,nzgrid)
mapworkn=mapworkb
mapworknn=mapworkb ; set to zero if no flat field could be found
mapworkr=mapworkb
mapworkd=mapworkb
mapworky=mapworkb
mapworkz=mapworkb
bstart=fltarr(np,nzgrid)
bstop=bstart
bflag=lonarr(np,nzgrid) ; set to 0 if no map data for input pixels
back=fltarr(nygrid)
;
for ip=0,np-1 do begin
;
ipix=pixarray(ip)
makemap,1,[ipix],mapb,mapr,mapd,mapy,mapz,mapn,0,1 
mapworkb(ip,*,*)=mapb
mapworkr(ip,*,*)=mapr
mapworkn(ip,*,*)=mapn
mapworkd(ip,*,*)=mapd
mapworky(ip,*,*)=mapy
mapworkz(ip,*,*)=mapz
;
for izgrid=0,nzgrid-1 do begin
;
iidata=where(mapn(*,izgrid) gt 1,niidata)
if(niidata gt 0)then begin ; there is data from this pixel in map row IZGRID
;
bflag(ip,izgrid)=1
;
ii=where(mapn(0:n_end-1,izgrid) gt 1,nii)
if(nii le 0)then begin
print,'MAPFLATEND: aborting at start of row for ipix,izgrid = ',ipix,izgrid
;goto,c999
bflag(ip,izgrid)=0
endif ; nii le 0
if(nii gt 0)then bstart(ip,izgrid)=total(mapb(ii,izgrid))/float(nii)
;
ii=where(mapn(nygrid-n_end:nygrid-1,izgrid) gt 1,nii)
if(nii le 0)then begin
print,'MAPFLATEND: aborting at end of row for ipix,izgrid = ',ipix,izgrid
;goto,c999
bflag(ip,izgrid)=0
endif ; nii le 0
if(nii gt 0)then bstop(ip,izgrid)=$
total(mapb(nygrid-n_end+ii,izgrid))/float(nii)
;
endif ; niidata gt 0
;
endfor ; izgrid=0,nzgrid-1
;
endfor ; ip
;
;print,bflag
save,/xdr,mapworkb,mapworkn,mapworkr,mapworky,mapworkz,bflag,bstart,bstop,$
file=!INTDIR+'diagflat.xdr'
;
for izgrid=0,nzgrid-1 do begin
iipix=where(bflag(*,izgrid) gt 0,niipix) ; there is data at start and end of
                                         ; map row for these pixels
if(niipix gt 0)then begin
;
bstartav=total(bstart(iipix,izgrid))/float(niipix)
bstopav=total(bstop(iipix,izgrid))/float(niipix)
;
for ip=0,niipix-1 do begin
iip=iipix(ip)
back(*)=bstart(iip,izgrid)+$
(bstop(iip,izgrid)-bstart(iip,izgrid))*findgen(nygrid)/float(nygrid-1)
;
; multiplicative correction
backcorr=(bstartav+bstopav)/(2.0*back) 
mapworkb(iip,*,izgrid)=mapworkb(iip,*,izgrid)*backcorr(*)
mapworkr(iip,*,izgrid)=mapworkr(iip,*,izgrid)*backcorr(*)
mapworkd(iip,*,izgrid)=mapworkd(iip,*,izgrid)*backcorr(*)
mapworknn(iip,*,izgrid)=float(mapworkn(iip,*,izgrid))

;
endfor ; ip=0,niipix-1
;
endif ; niipix gt 0
;
endfor ; izgrid=0,nzgrid-1
;
; mapworkb array now contains data flat fielded individually in rows but not 
; in columns
;
; create output maps; for moment simple weighting with numbers, not rms
;
for iygrid=0,nygrid-1 do begin
for izgrid=0,nzgrid-1 do begin
;
xntot=float(total(mapworknn(*,iygrid,izgrid)))
;
if(xntot ge 1.0)then begin
mapoutb(iygrid,izgrid)=$
total(mapworkb(*,iygrid,izgrid)*mapworknn(*,iygrid,izgrid))/xntot
mapoutd(iygrid,izgrid)=$
total(mapworkd(*,iygrid,izgrid)*mapworknn(*,iygrid,izgrid))/xntot
mapoutr(iygrid,izgrid)=$
total(mapworkr(*,iygrid,izgrid)*mapworkr(*,iygrid,izgrid)*$
mapworknn(*,iygrid,izgrid))/xntot
mapoutr(iygrid,izgrid)=sqrt(mapoutr(iygrid,izgrid))
mapouty(iygrid,izgrid)=$
total(mapworky(*,iygrid,izgrid)*mapworknn(*,iygrid,izgrid))/xntot
mapoutz(iygrid,izgrid)=$
total(mapworkz(*,iygrid,izgrid)*mapworknn(*,iygrid,izgrid))/xntot
mapoutn(iygrid,izgrid)=xntot
endif ; xntot ge 1.0
;
endfor ; izgrid
endfor ; iygrid
;
; now z flatfield output map
;
xn1=float(total(mapoutn(0:n_end-1,0:nzgrid-1)))
xn2=float(total(mapoutn(nygrid-n_end:nygrid-1,0:nzgrid-1)))
b1=total(mapoutn(0:n_end-1,0:nzgrid-1)*mapoutb(0:n_end-1,0:nzgrid-1))
b2=total(mapoutn(nygrid-n_end:nygrid-1,0:nzgrid-1)*$
mapoutb(nygrid-n_end:nygrid-1,0:nzgrid-1))
background=(b1+b2)/(xn1+xn2)
print,'MAPFLATEND: background = ',background
;
for izgrid=0,nzgrid-1 do begin
xn=total(mapoutn(0:n_end-1,izgrid))+$
total(mapoutn(nygrid-n_end:nygrid-1,izgrid))
;
if(xn gt 0.0)then begin
b=total(mapoutn(0:n_end-1,izgrid)*mapoutb(0:n_end-1,izgrid))+$
total(mapoutn(nygrid-n_end:nygrid-1,izgrid)*$
mapoutb(nygrid-n_end:nygrid-1,izgrid))
b=b/xn
mapoutb(*,izgrid)=mapoutb(*,izgrid)*background/b
mapoutr(*,izgrid)=mapoutr(*,izgrid)*background/b
mapoutd(*,izgrid)=mapoutd(*,izgrid)*background/b
endif ; xn gt 0.0
;
endfor ; izgrid=0,nzgrid-1
;
c999:
;
return
end

