pro mapsave,outdir,target,text,outmap
; 
; writes FITS file of map OUTMAP to disk with minimal header
; examples: 
;  mapsave,'','','' saves tdtname.FITS (eg c10157901909.FITS) to current dir
;  mapsave, '/d24/vlk/rjt/PIA/VIRGO/V7_3/MAPS','VCC0066','RMS_DRIFTCORR' 
;            saves /d24/vlk/rjt/PIA/VIRGO/V7_3/MAPSVCC0066RMS_DRIFTCORR.dat 
;
; input: 
;    OUTDIR output directory for maps 
;           eg '/d24/vlk/rjt/PIA/VIRGO/V7_3/MAPS'
;           if outdir is '' then the current directory is used
;           if outdir is dirnam then the directory of origin of
;           the PIA save sets read by ERDTOMAP is used
;    TARGET eg 'VCC0066'
;    TEXT: string to be appended to the output name of map (eg 'RMS_DRIFTCORR'
;          or 'RAW' to denote content of map and stage of reduction
;    OUTMAP 2D array of map to be output 
; input (common NAMES)
;    TDTNAM: string denoting name of TDT eg '53801001'
;    ISEQ:   string denoting sequence number of target source map
;            (normally '01' or '03' or '05' for multifilter sequence separated
;             by FCS measurements) 
;    DIRNAM: dstring denoting irectory name for internal PIA files
;            eg '/d13/vlk/rjt/pia/p32p22p25/v7_3/'
;    CFILTER (integer) = either 50,60,70,90,100,105,120,135,160,180,200
;        (common STEERIN)
;    ARRAY   either 'c100' or 'c200'
;
; common names,tdtnam,iseq,dirnam,caldir,cfilter
@common_names
;common steerin,array,nptin,npt,ninramp,imeas,osamp
;common signal,rs,cs,nch,s_in,s,badin,bad,rel,rms,glitch,jf,njf,ninchmax,rd,$
;nkf,kf,nkfmax,irelstart,nchopmed,gbad,npolyrms,nrmsmed,sigmaxfract
;common timer,time
;common plotter,otfstart,otfstop,rdstat,chop,step,otf,rpid,yrel,zrel,$
;ytrue,ztrue,yzrpidcen,nyraster,nzraster
;
@common_steerin
@common_signal
@common_timer
@common_plotter
;
;
d=outdir
;
if(cfilter eq 50)then c='_C50'
if(cfilter eq 60)then c='_C60'
if(cfilter eq 70)then c='_C70'
if(cfilter eq 90)then c='_C90'
if(cfilter eq 100)then c='_C100'
if(cfilter eq 105)then c='_C105'
if(cfilter eq 120)then c='_C120'
if(cfilter eq 135)then c='_C135'
if(cfilter eq 160)then c='_C160'
if(cfilter eq 180)then c='_C180'
if(cfilter eq 200)then c='_C200'
;
; default names
if(target eq '')then begin
if(array eq 'c100')then isav=d+'c1'+iseq+tdtnam+text+'.FITS'
if(array eq 'c200')then isav=d+'c2'+iseq+tdtnam+text+'.FITS'
endif ; target eq ''
if(target ne '')then begin
isav=d+target+c+text+'.FITS'
endif ; target ne ''
;
print,'DATASAVE: writing ',isav
writefits,isav,outmap
;
return
end

