pro mapscan,iwindow,map,mapnum,maprms,i1,i2,irow,psplot,iover
;
; plots the scan MAP(i1:i2,irow) on unit iwindow
;
; if i2 <= i1 MAP(0:nygrid-1,irow) is plotted
;
; if IOVER is greater than 0, the data only is overplotted without error bars
; on an existing frame using linestyle IOVER.
; if IOVER is 0 or -1, the frame and data is overplotted 
; with error bars with linestyle 0.
; if IOVER is less than -1, the data over is overplotted without error bars
; on an existing frame using linestyle abs(IOVER+1)
;
; If psplot is 'ps' and iover is 0 a file 'mapscan.ps' is opened and
; the frame and data is sent to a ps file and the file is then closed.
; If psplot is 'ps' and iover is -1, a file 'mapscan.ps' is opened and
; the frame and is sent to a ps file but this is not closed.
; If psplot is 'ps' and iover is positive, the data is overplotted with
; linestyle IOVER to the already open file 'mapscan.ps' and the file 
; is not closed.
; If psplot is 'ps' and iover is less than -1, the data is overplotted with
; linestyle abs(IOVER+1) to the already open file 'mapscan.ps' and the file 
; is not closed.
; 
; In this case the routine calls
; set_plot,'ps'   
; device,filename='mapscan.ps',xs=***,ys=***
; before the contour (where the sizes *** are calculated to give 
; the correct aspect ratio), followed by
; device,/close 
; set_plot,'x' 
;
; MAPRMS is input to overplot error bars. It should be the 1 sigma on a map 
; pixel
;
; MAPNUM is the number of elementary data samples contributing to each map 
; point
;
;common mapper,sgridy,sgridz,nygrid,nzgrid,ygrid,zgrid,errflag
;common steerin,array,nptin,npt,ninramp,imeas,osamp
;common signal,rs,cs,nch,s_in,s,badin,bad,rel,rms,glitch,jf,njf,ninchmax,rd,$
;nkf,kf,nkfmax,irelstart,nchopmed,gbad,npolyrms,nrmsmed,sigmaxfract
;common plotter,otfstart,otfstop,rdstat,chop,otf,rpid,yrel,zrel,$
;ytrue,ztrue,yzrpidcen,nyraster,nzraster
;common steer1,npix,pixsize,pixpitch,pixoff,nchop,dcy,dry,drz
;common pinfo,fpt
;
@common_mapper
@common_steerin
@common_signal
@common_plotter
@common_steer1
@common_pinfo
;
if(n_elements(iwindow) eq 0)then begin
print,'mapscan,iwindow,map,mapnum,maprms,i1,i2,irow,psplot,iover'
print,'eg: mapscan,5,mapb,mapn,mapr,0,nygrid-1,nzgrid/2,'',0 ; to window 5'
print,'    mapscan,5,mapbeam,mapn,mapr,0,nygrid-1,nzgrid/2,'',1 ; overplot
print,'    mapscan,5,mapb,mapn,mapr,0,nygrid-1,nzgrid/2,''ps'',-1 ; same to ps'
print,'    mapscan,5,mapbeam,mapn,mapr,0,nygrid-1,nzgrid/2,''ps'',-2 ; same overplot'
goto,c999
endif
;
; plotting in correct proportions
;
if(i2 le i1)then begin
i1=0
i2=nygrid-1
endif ; i2 le i1
;
linestyle=0
if(iover ne 0)then begin
if(iover eq -1)then begin ; start sequence of plots - for ps files open but
linestyle=0               ; not close file
goto,c444
endif ; iover eq -1
if(iover lt -1)then begin
linestyle=abs(iover+1)
goto,c555
endif ; iover lt -1
; case iover positive:
linestyle=iover
goto,c555
endif ; iover ne 0
;
c444:
;
xsize=600.0 ; window size in pixels
ysize=300.0
xborder=50 ; screen pixels border
yborder=50
;
x1=ygrid(i1)-sgridy/2.0
x2=ygrid(i2)+sgridy/2.0
ymax=max(map(i1:i2,irow))
ymin=min([0.,min(map(i1:i2,irow))])
ydiff=ymax-ymin
y1=ymin-0.1*ydiff
y2=ymax+0.1*ydiff
if(psplot ne 'ps')then window,iwindow,xs=xsize,ysize=ysize,title=' '
xr=[x1,x2] ; in arcsec
yr=[y1,y2] ; in map units
fractx=1.0-(xborder/xsize) ; fraction of screen occupied by data
fracty=1.0-(yborder/ysize)
px1=x1*fractx
px2=x2*fractx
py1=y1*fracty
py2=y2*fracty
px1=xborder
px2=xsize-xborder/10.0
py1=yborder
py2=ysize-yborder/10.0
if(psplot ne 'ps')then begin
plot,[x1,x2,x2,x1,x1],[y1,y1,y2,y2,y1],pos=[px1,py1,px2,py2],psym=0,xstyle=1,$
ystyle=1,/device,xtit='OFFSET Y (arcsec)',ytit='BRIGHTNESS'
endif
;
if(psplot eq 'ps' and iover eq 0 or iover eq -1)then begin
;
set_plot,'ps'
;
;print,'setting line and character widths for ps file ...'
!p.charsize=1.3 ; annotation size for axes
!p.charthick=2.5 ; thickness for annotation 
!p.thick=2.0  ; thickness for plotted points
!x.thick=2.5  ; thickness of x axis
!y.thick=2.5  ; thickness of y axis
;
xsize=17.0
ysize=10.0
;
x1=ygrid(i1)-sgridy/2.0
x2=ygrid(i2)+sgridy/2.0
ymax=max(map(i1:i2,irow))
ymin=min([0.,min(map(i1:i2,irow))])
ydiff=ymax-ymin
y1=ymin-0.1*ydiff
y2=ymax+0.1*ydiff
device,filename='mapscan.ps',xs=xsize,ys=ysize 
; for ps plots the aspect ratio is taken care of properly in the plot
; call without need for px1 etc
plot,[x1,x2,x2,x1,x1],[y1,y1,y2,y2,y1],psym=0,xstyle=1,ystyle=1,$
xtit='OFFSET Y (arcsec)',ytit='BRIGHTNESS'
;
endif ; psplot eq 'ps'
;
oplot,[x1,x2],[0.,0.],linestyle=2 ; plot zero level
;
; scan MAP
;
c555:
;
print,'MAPSCAN: plotting row ',irow,' with linestyle = ',linestyle
iplot=-1
for i=i1,i2 do begin
;
if(mapnum(i,irow) le 0)then goto, c277
iplot=iplot+1
if(iplot eq 0)then oplot,[ygrid(i)-sgridy/2.0,ygrid(i)-sgridy/2.0],$
[-1000.,map(i,irow)],linestyle=linestyle
if(iplot ne 0)then oplot,[ygrid(i)-sgridy/2.0,ygrid(i)-sgridy/2.0],$
[map(i-1,irow),map(i,irow)],linestyle=linestyle
oplot,[ygrid(i)-sgridy/2.0,ygrid(i)+sgridy/2.0],[map(i,irow),map(i,irow)],$
linestyle=linestyle
;
if(iover eq 0 or iover eq -1)then begin ; plot error bars always linestyle=0
oplot,[ygrid(i),ygrid(i)],$
[map(i,irow)-maprms(i,irow),map(i,irow)+maprms(i,irow)],linestyle=0
endif ; iover eq 0 or iover eq -1
;
c277:
;
endfor ; for i=i1,i2
;
print,'MAPSCAN: pixels plotted:    ',i1,i2
print,'MIN, MAX BRIGHTNESS plotted:',min(map(i1:i2,irow)),max(map(i1:i2,irow))
;
if(psplot eq 'ps' and iover eq 0 or iover lt -1)then begin
device,/close
set_plot,'x'
print,'written scan to file mapscan.ps';
;print,'re-setting line and character widths for screen plot...'
!p.charsize=1.0 ; annotation size for axes
!p.charthick=1.0 ; thickness for annotation 
!p.thick=1.0  ; thickness for plotted points
!x.thick=1.0  ; thickness of x axis
!y.thick=1.0  ; thickness of y axis
endif ; psplot eq 'ps'
;
c999:
;
return
end




