pro mapscanmulti,iwindow,map,mapnum,maprms,i1,i2,irow,psplot
;
; plots scans from MAP(0:npix-1,i1:i2,irow) on unit iwindow. No overplotting
; is permitted.
;
; if i2 <= i1 MAP(0,npix-1,0:nygrid-1,irow) is plotted
;
; If psplot is 'ps' a file 'mapscanmulti.ps' is opened and
; the frame and data is sent to a ps file and the file is then closed.
; In this case the routine calls
; set_plot,'ps'   
; device,filename='mapscanmulti.ps',xs=***,ys=***
; before the plot, followed by
; device,/close 
; set_plot,'x' 
;
; MAPRMS is input to overplot error bars. It should normally be the 1 sigma 
; on a map pixel
;
; MAPNUM is the number of elementary data samples contributing to each map 
; point
;
;common mapper,sgridy,sgridz,nygrid,nzgrid,ygrid,zgrid,errflag
;common steerin,array,nptin,npt,ninramp,imeas,osamp
;common signal,rs,cs,nch,s_in,s,badin,bad,rel,rms,glitch,jf,njf,ninchmax,rd,$
;nkf,kf,nkfmax,irelstart,nchopmed,gbad,npolyrms,nrmsmed,sigmaxfract
;common plotter,otfstart,otfstop,rdstat,chop,otf,rpid,yrel,zrel,$
;ytrue,ztrue,yzrpidcen,nyraster,nzraster
;common steer1,npix,pixsize,pixpitch,pixoff,nchop,dcy,dry,drz
;common pinfo,fpt
;
@common_mapper
@common_steerin
@common_signal
@common_plotter
@common_steer1
@common_pinfo
;
if(n_elements(iwindow) le 0)then begin
print,'mapscanmulti,iwindow,map,mapnum,maprms,i1,i2,irow,psplot'
print,'eg: mapscanmulti,4,mapb,mapn,mapr,0,nygrid-1,3,'''' ; map row 3 window 4'
print,'    mapscanmulti,4,mapb,mapn,mapr,0,nygrid-1,3,''ps''  ; same to ps'
goto,c999
endif
;
mmaprms=maprms
;ii=where(mmaprms eq errflag,nii)
ii=where(mmaprms lt 0.0,nii)
if(nii gt 0)then mmaprms(ii)=0.0
;
; plotting in correct proportions
;
if(i2 le i1)then begin
i1=0
i2=nygrid-1
endif ; i2 le i1
;
print,'MAPSCANMULTI: map pixels plotted: ',i1,i2
print,'MAPSCANMULTI: map row plotted:    ',irow
;
for ipix=0,npix-1 do begin
;
linestyle=0
;
c444:
;
xsize=600.0 ; window size in pixels
ysize=800.0
xborder=50 ; screen pixels border
yborder=50
;
x1=ygrid(i1)-sgridy/2.0
x2=ygrid(i2)+sgridy/2.0
ymax=max(map(0:npix-1,i1:i2,irow)+abs(mmaprms(0:npix-1,i1:i2,irow)))
ymin=min([0.,min(map(0:npix-1,i1:i2,irow)-abs(mmaprms(0:npix-1,i1:i2,irow)))])
ydiff=ymax-ymin
y1=ymin-0.1*ydiff
y2=ymax+0.1*ydiff
if(psplot ne 'ps' and ipix eq 0)then $
window,iwindow,xs=xsize,ysize=ysize,title=' '
xr=[x1,x2] ; in arcsec
yr=[y1,y2] ; in map units
fractx=1.0-(xborder/xsize) ; fraction of screen occupied by data
fracty=1.0-(yborder/ysize)
px1=xborder
px2=xsize-xborder/10.0
pybot=yborder
pytop=ysize-yborder/10.0
pyframesize=(pytop-pybot)/float(npix)
py1=yborder+pyframesize*findgen(npix)
py2=py1+pyframesize
;
if(psplot ne 'ps')then begin
;
; xstyle=9 draws no annotations on upper horizontal frame border
if(ipix eq 0)then ytit='PIXEL 0'
if(ipix eq 1)then ytit='PIXEL 1'
if(ipix eq 2)then ytit='PIXEL 2'
if(ipix eq 3)then ytit='PIXEL 3'
if(ipix eq 4)then ytit='PIXEL 4'
if(ipix eq 5)then ytit='PIXEL 5'
if(ipix eq 6)then ytit='PIXEL 6'
if(ipix eq 7)then ytit='PIXEL 7'
if(ipix eq 8)then ytit='PIXEL 8'
if(ipix eq 0)then $
plot,[x1,x2,x2,x1,x1],[y1,y1,y2,y2,y1],pos=[px1,py1(ipix),px2,py2(ipix)],$
psym=0,xstyle=9,ystyle=1,/device,xtit='OFFSET Y (arcsec)',ytit=ytit
if(ipix ne 0 and ipix ne npix/2)then $
plot,[x1,x2,x2,x1,x1],[y1,y1,y2,y2,y1],pos=[px1,py1(ipix),px2,py2(ipix)],$
psym=0,xstyle=9,ystyle=1,ytit=ytit,/device,/noerase
if(ipix eq npix/2)then $
plot,[x1,x2,x2,x1,x1],[y1,y1,y2,y2,y1],pos=[px1,py1(ipix),px2,py2(ipix)],$
psym=0,xstyle=9,ystyle=1,/device,ytit='BRIGHTNESS',/noerase
;
endif ; psplot ne 'ps'
;
if(psplot eq 'ps')then begin
;
set_plot,'ps'
;
;print,'setting line and character widths for ps file ...'
!p.charsize=1.3 ; annotation size for axes
!p.charthick=2.5 ; thickness for annotation 
!p.thick=2.0  ; thickness for plotted points
!x.thick=2.5  ; thickness of x axis
!y.thick=2.5  ; thickness of y axis
;
xsize=17.0
ysize=25.0
xborder=2.0
yborder=2.0
xsize=15000
ysize=15000
xborder=4000
yborder=0
;
x1=ygrid(i1)-sgridy/2.0
x2=ygrid(i2)+sgridy/2.0
ymax=max(map(0:npix-1,i1:i2,irow)+abs(mmaprms(0:npix-1,i1:i2,irow)))
ymin=min([0.,min(map(0:npix-1,i1:i2,irow)-abs(mmaprms(0:npix-1,i1:i2,irow)))])
ydiff=ymax-ymin
y1=ymin-0.1*ydiff
y2=ymax+0.1*ydiff
px1=xborder
px2=xsize-xborder/10.0
pybot=yborder
pytop=ysize-yborder/10.0
pyframesize=(pytop-pybot)/float(npix)
py1=yborder+pyframesize*findgen(npix)
py2=py1+pyframesize
;
if(ipix eq 0)then ytit='PIXEL 0'
if(ipix eq 1)then ytit='PIXEL 1'
if(ipix eq 2)then ytit='PIXEL 2'
if(ipix eq 3)then ytit='PIXEL 3'
if(ipix eq 4)then ytit='PIXEL 4'
if(ipix eq 5)then ytit='PIXEL 5'
if(ipix eq 6)then ytit='PIXEL 6'
if(ipix eq 7)then ytit='PIXEL 7'
if(ipix eq 8)then ytit='PIXEL 8'
;
if(ipix eq 0)then device,filename='mapscanmulti.ps',xs=xsize,ys=ysize 
; for ps plots the aspect ratio is taken care of properly in the plot
; call without need for px1 etc
; xstyle=9 draws no annotations on upper horizontal frame border
if(ipix eq 0)then $
plot,[x1,x2,x2,x1,x1],[y1,y1,y2,y2,y1],pos=[px1,py1(ipix),px2,py2(ipix)],$
psym=0,xstyle=9,ystyle=1,/device,xtit='OFFSET Y (arcsec)',ytit=ytit
if(ipix ne 0 and ipix ne npix/2)then $
plot,[x1,x2,x2,x1,x1],[y1,y1,y2,y2,y1],pos=[px1,py1(ipix),px2,py2(ipix)],$
psym=0,xstyle=9,ystyle=1,ytit=ytit,/device,/noerase
if(ipix eq npix/2)then $
plot,[x1,x2,x2,x1,x1],[y1,y1,y2,y2,y1],pos=[px1,py1(ipix),px2,py2(ipix)],$
psym=0,xstyle=9,ystyle=1,/device,ytit='BRIGHTNESS',/noerase
;
endif ; psplot eq 'ps'
;
oplot,[x1,x2],[0.,0.],linestyle=2 ; plot zero level
;
; scan MAP
;
c555:
;
;print,'MAPSCANMULTI: plotting row ',irow,' with linestyle = ',linestyle
iplot=-1
iplotlast=-1
for i=i1,i2 do begin
;
if(mapnum(ipix,i,irow) le 0)then goto, c277
iplot=iplot+1
iplotlast=i
if(iplot eq 0)then oplot,[ygrid(i)-sgridy/2.0,ygrid(i)-sgridy/2.0],$
[-1000.,map(ipix,i,irow)],linestyle=linestyle
if(iplot gt 0)then $ 
oplot,[ygrid(i)-sgridy/2.0,ygrid(i)-sgridy/2.0],$
[map(ipix,i-1,irow),map(ipix,i,irow)],linestyle=linestyle
oplot,[ygrid(i)-sgridy/2.0,ygrid(i)+sgridy/2.0],[map(ipix,i,irow),$
map(ipix,i,irow)],linestyle=linestyle
;
; plot error bars always linestyle=0
oplot,[ygrid(i),ygrid(i)],$
[map(ipix,i,irow)-mmaprms(ipix,i,irow),map(ipix,i,irow)+mmaprms(ipix,i,irow)],$
linestyle=0
;
c277:
;
endfor ; for i=i1,i2
;
if(iplotlast ge 0)then oplot,$
[ygrid(iplotlast)+sgridy/2.0,ygrid(iplotlast)+sgridy/2.0],$
[map(ipix,iplotlast,irow),-1000.],linestyle=linestyle
;
print,'MIN, MAX, LINESTYLE plotted:',$
min(map(ipix,i1:i2,irow)),max(map(ipix,i1:i2,irow)),linestyle
;
endfor ; for ipix=0,npix-1
;
if(psplot eq 'ps')then begin
device,/close
set_plot,'x'
print,'written scan to file mapscanmulti.ps';
;print,'re-setting line and character widths for screen plot...'
!p.charsize=1.0 ; annotation size for axes
!p.charthick=1.0 ; thickness for annotation 
!p.thick=1.0  ; thickness for plotted points
!x.thick=1.0  ; thickness of x axis
!y.thick=1.0  ; thickness of y axis
endif ; psplot eq 'ps'
;
c999:
;
return
end








