pro mjtovs,ipix,idefcal,xin,xout
;
; converts a single value or array XIN in units of true MJy/sr into an array
; XOUT in V/s, uncorrected for non-linearity correction (and thus directly
; comparable with the V/s from ERDTOMAP). Use is made of the approximate non-
; linearity correction factors from NONLINCORR.
;
;common nonlin,xnlin,sarray
@common_nonlin
@common_steerin
;common steerin,array,nptin,npt,ninramp,imeas,osamp

wk=fltarr(n_elements(sarray(0,*)))
wk(*)=sarray(ipix,*) ; should be V/s from 1 to 100
wk=[0.01,wk] ; add a very smalll amount to get behaviour near zero
;
; find multiplicive factors to convert V/s (uncorrected for signal non-
; linearity) into MJy/sr:
;
;if(idefcal eq 1)then cal32,result1,result2,1 ; default
;if(idefcal eq 0)then cal32,result1,result2,0 ; actual


;CG - take now conversion routine - take result2 = result1 in this case

		get_conv_s2b, imeas, idefcal, result1
result2=result1

nonlincorr,ipix,wk,wkcorr ; non-linearity correction for WK V/s array
fcorr1=wkcorr/wk ; fractional non-linearity correction
bench=result2(ipix) ; benchmark uncorrected V/s for 
;                     conversion factor RESULT1(ipix)
nonlincorr,ipix,bench,benchcorr ; non-linearity correction for BENCHMARK V/s
fcorr2=benchcorr/bench
factor=fcorr1*result1(ipix)/fcorr2 ; multiply raw V/s in WK array by FACTOR
                                      ; to get true MJy/st
farray=wk*factor ; array in MJy/s giving WK
factor=1.0/factor ; now multiply true MJy/st by FACTOR to get raw MJy/st
farraym=rotate(farray,2)
farray=[-farraym,0.0,farray] ; extend symmetrically to negative values
wkm=rotate(wk,2)
wk=[-wkm,0.0,wk]
factorm=rotate(factor,2)
factor=[factorm,factor(0),factor] ; mirror over neg range of farray and wk too
;
; we now have wk extending monotonically from negative to positive V/s
; and farray extending monotonically from negative to positive MJy/sr
; corresponding to wk and factor, the ratio between them
;
xout=fltarr(n_elements(xin))
farraymin=min(farray)
wkmin=min(wk)
farraymax=max(farray)
wkmax=max(wk)
for i=0,n_elements(xin)-1 do begin ; xin in MJy/st
xx=xin(i)
if(xx le farraymin)then xout(i)=xx*(wkmin/farraymin)
if(xx ge farraymax)then xout(i)=xx*(wkmax/farraymax)
if(xx gt farraymin and xx lt farraymax)then begin
ii=where(xx ge farray,nii)
i1=max(ii)
i2=i1+1
f1=farray(i1)
f2=farray(i2)
wk1=wk(i1)
wk2=wk(i2)
xout(i)=((xx-f1)*wk2+(f2-xx)*wk1)/(f2-f1)
endif ; xx gt farraymin and xx lt farraymax
endfor ; i
;
return
end
