pro model3setup
;
; ALTERNATIVEEMPIRICAL CONSERVATIVE (C200) and NON-CONSERVATIVE (C100)
;
; overwrites that subset of contents of common block DETDEFAULT which
; are used in calculations with IMODEL=3 (expshoot model)
;
; To be called by DETDEFAULT. 
;
; input: ARRAY (common STEERIN)
;
; output: common DETDEFAULT
;
; Note that of the 12 parameters the long constants (beta,betaexp,betacoeff,
; tau,tauoffset,gammaexp) are normally fixed via statistical analysis of FCS 
; results from analysis of many FCS observations. Each FCS observation
; is fitted to obtain a single flux level and beta and tau. Trends in beta and
; tau wil fcs illumination are fitted with the additional offset and exponent
; parameters. 
;
; The short model parameters (betashoot,betaexpshoot,betacoeffshoot,
; taushoot, tauoffsetshoot,gammaexpshoot) are normally optimized by a self 
; calibration on bright sources with various contrasts to the background.
; Typically, the parameters betashoot, betacoeffshoot, tauoffsetshoot and 
; taushoot are fitted simulateously with selfcalibrations on adjacent pointings
; on bright point sources wwith the self calibration mode icalmethod=3, with
; betaexpshoot and gammaexpshoot constrained to be 1.0, thus approximating the
; illumination dependence of the shooting parameters as linear. In this way,
; 4 parameters, rather than two as with the FCS are needed to be fitted since 
; a large range of brightnesses are fitted, and some crude indication must be 
; found of the flux dependence off the shooting parameters. In an external 
; statistical analysis of the results for all the available point source 
; observations, the dependence of the shooting beta and tau factors on the peak
; and background illuminations is found, and trends found are used to obtain
; the exponents betaexpshoot and gammaexpshoot.
;
; The ***down ***up limits and defaults are intended for a self cal analysis.
; They are intended for perturbations to the standard analysis only.
; Revolutionary changes can be effected by overwrites from the 
; ***down and ***up arrays in the second panel below. 
; The limits and defaults for the individual FCS fits should be taken
; by uncommenting the first panel below, and commenting the second panel; these
; are appropriate for a simple step function in illumination specified
; by eg a simple two parameter exponential function.
; Basics constraints are specified by the routine CONSTRAIN_MODEL3.
; called in the DETSELFCAL routine.
;
; An important feature of the flux dependence of beta and tau 
; and of betashoot and taushoot is that it is monotonic. Then, the 
; value of the composite (as found from setshootbeta_model3 and 
; setshoottime_model3 routines) of beta, tau and betashoot and taushoot at the
; extreme values of the 
; encountered illumination range also gives the extreme values of beta, tau. 
; and betashoot and taushoot. This feature is used in DETSELFCAL to avoid 
; trials giving beta, tau, betashoot, taushoot outside a physically plausible 
; range. Thus, for example, self calibration the fits can be constrained to be
; overshooting or undershooting above or below a specified illumination, 
; and negative time constants avoided. The actual limits on the composite
; parameters are given by the constants in common block SCCONSTRAIN,
; (which should normally be initialised by the highest calling routine) and
; implemented within DETSELFCAL by calls to CONSTRAIN_MODEL3.
;
@common_steerin
;common steerin,array,nptin,npt,ninramp,imeas,osamp
@common_detdefault
;common detdefault,betadefault,taudefault,gammaexpdefault,$
;betashootdefault,taushootdefault,gammaexpshootdefault,$
;betacoeffdefault,betaexpdefault,tauoffsetdefault,$
;betacoeffshootdefault,betaexpshootdefault,tauoffsetshootdefault,$
;betaup,betadown,tauup,taudown,gammaexpup,gammaexpdown,$
;betashootup,betashootdown,taushootup,taushootdown,$
;gammaexpshootup,gammaexpshootdown,$
;betacoeffup,betacoeffdown,betaexpup,betaexpdown,$
;tauoffsetup,tauoffsetdown,betacoeffshootup,betacoeffshootdown,$
;betaexpshootup,betaexpshootdown,tauoffsetshootup,tauoffsetshootdown,$
;betaprec,tauprec,gammaexpprec,betashootprec,taushootprec,gammaexpshootprec,$
;betacoeffprec,betaexpprec,tauoffsetprec,$
;betacoeffshootprec,betaexpshootprec,tauoffsetshootprec
;
;if(imodel ne 3)then begin
;print,'MODEL3SETUP: aborting - IMODEL not 3' 
;goto,c999
;endif ; imodel ne 3
;
if(array eq 'c100')then begin
;
;---------------------------------------------------------------
; values from statistical analysis of many FCS fits for slow parameters.
;
; The ***down ***up limits and defaults are intended for a self cal analysis.
; They are intended for perturbations to the standard analysis only.
; Revolutionary changes can be effected by overwrites from the 
; ***down and ***up arrays in the second panel below. 
; The limits and defaults for the individual FCS fits should be taken
; by uncommenting the first panel below, and commenting the second panel; these
; are appropriate for a simple step function in illumination specified
; by eg a simple two parameter exponential function.
; Basics constraints like positivity of time constants are specified by the 
; routine GLOBALSEARCHCHECK called in the DETSELFCAL routine.
;
; a(0)
betadefault=[0.995,6.10,2.17,1.20,2.12,6.68,4.63,0.96,2.19]
betadown=betadefault-0.4 ; set generously to 
betaup=betadefault+0.4   ; compensate for shooting
betaprec=0.02
;
; a(2)
betacoeffdefault=[-0.69,-5.36,-1.52,-0.56,-1.82,-5.96,-3.95,-0.28,-1.89]
betacoeffdown=betacoeffdefault-0.5
betacoeffup=betacoeffdefault+0.5
betacoeffprec=0.05
;
; + a(1)
betaexpdefault=[0.059,0.023,0.049,0.092,0.022,0.018,0.032,0.075,0.036]
betaexpdown=betaexpdefault-0.05
betaexpup=betaexpdefault+0.05
betaexpprec=0.005
;
; a(0)
tauoffsetdefault=[6.16,5.80,7.50,6.63,6.92,5.07,5.72,7.73,8.60]
tauoffsetdown=tauoffsetdefault-2.0
tauoffsetup=tauoffsetdefault+2.0
tauoffsetprec=0.2
;
; a(2)
taudefault=[7.75,17.25,12.90,12.41,4.28,12.34,12.69,11.60,1.04] ; pixel 8 OK
taudown=taudefault-4.0
tauup=taudefault+4.0
tauprec=0.4
;
; -a(1)
gammaexpdefault=[0.65,1.28,1.04,0.88,1.22,0.65,0.88,1.28,2.32]
gammaexpdown=gammaexpdefault-0.5
gammaexpup=gammaexpdefault+0.5
gammaexpprec=0.05
;
; self CAL results for fast parameters
;
; a(0) non-conservative jump expshoot_alternativeempirical.pro
betashootdefault=[0.661,5.866,5.868,0.732,-0.534,6.49,4.40,1.171,0.140]
betashootdown=betashootdefault-0.25
betashootup=betashootdefault+0.25
betashootprec=0.01
;
; a(2) non-conservative jump expshoot_alternativeempirical.pro
betacoeffshootdefault=$
[-0.488,-5.52,-5.515,-0.423,0.723,-6.11,-4.133,-0.870,0.0]
betacoeffshootdown=betacoeffshootdefault-0.2
betacoeffshootup=betacoeffshootdefault+0.2
betacoeffshootprec=0.02
;
; +a(1) non-conservative jump expshoot_alternativeempirical.pro
betaexpshootdefault=$
[0.0284,0.00814,0.00434,0.0395,-0.0103,0.00459,0.0114,-0.0145,0.0]
betaexpshootdown=betaexpshootdefault-0.05
betaexpshootup=betaexpshootdefault+0.05
betaexpshootprec=0.005
;
; a(0) non-conservative jump expshoot_alternativeempirical.pro
tauoffsetshootdefault=$
[0.376,0.301,0.388,0.330,14.89,0.766,0.664,0.333,0.605]
tauoffsetshootdown=tauoffsetshootdefault-1.0
tauoffsetshootup=tauoffsetshootdefault+1.0
tauoffsetshootprec=0.02
;
; a(2) non-conservative jump expshoot_alternativeempirical.pro
taushootdefault=$
[0.324,0.257,0.305,0.368,-14.24,0.647,0.139,0.381,0.577]
taushootdown=taushootdefault-0.2
taushootup=taushootdefault+0.2
taushootprec=0.02
;
; -a(1) non-conservative jump expshoot_alternativeempirical.pro
gammaexpshootdefault=$
[-0.384,-0.537,-0.603,-0.605,-0.01025,-0.551,-0.652,-0.584,-0.439]
gammaexpshootdown=gammaexpshootdefault-0.15
gammaexpshootup=gammaexpshootdefault+0.15
gammaexpshootprec=0.02
;
;-----------------------------------------------------------------------
; uncomment for FCS calibration ; unlike C200 assume no flux dependence
;                                 in analyse_fcs.pro
;betadefault(*)=0.4
;betacoeffdefault(*)=0.0
;betaexpdefault(*)=0.0
;tauoffsetdefault(*)=0.0
;taudefault(*)=20.0 ; needs to be high since gammaexp=1
;gammaexpdefault(*)=0.0
;betashootdefault(*)=0.0
;betacoeffshootdefault(*)=0.0
;betaexpshootdefault(*)=0.0
;tauoffsetshootdefault(*)=0.0
;taushootdefault(*)=2.0
;gammaexpshootdefault(*)=0.0
;
;-------------------------------------------
; uncomment for temporary changes to parameters in tests as required 
; (eg to resume a solution with more precision or to converge on just 
;  one parameter). Use SETLIMIT to find search range for shooting parameters
; under linear flux dependence as a function of peak source brightness
; To avoid blow up approaching zero illumination the linear dependence
; in time and betashoot increases with increasing illumination, even though
; physically the reverse may occur. This also allows the offset pparameters
; to be given the same search range as the absolution limits set (eg 
; taushortconmin, taushortconmax) in calling scripts.
;
goto, c999 ; allows defaults from above panel without having to comment below
;           ; comment the goto statement for calibration selfcals
;
;betadefault(*)=0.1
;betadefault=betadefault/2.0
;betaup(*)=0.99 
;betadown(*)=0.01
;betaprec=0.01 
;
;betacoeffdefault(*)=0.0
;betacoeffdefault=betacoeffdefault/2.0
;betacoeffdown(*)=-0.1
;betacoeffup(*)=0.0
;betacoeffprec=0.0005
;
;betaexpdefault(*)=0.0
;betaexpdown(*)=0.0
;betaexpup(*)=1.5
;betaexpprec=0.1
;
;tauoffsetdefault(*)=20.0
;tauoffsetdefault=tauoffsetdefault/2.0
;tauoffsetdown(*)=3.0
;tauoffsetup(*)=30.0
;tauoffsetprec=0.5
;
;taudefault(*)=0.0
;taudefault=taudefault/2.0
;taudown(*)=3.0
;tauup(*)=30.0
;tauprec=0.5
;
;gammaexpdefault(*)=0.0 
;gammaexpup(*)=2.0
;gammaexpdown(*)=0.01
;gammaexpprec=0.05
;
;betashootdefault(*)=0.0 ; to turn off shoot *****
betashootdefault(*)=0.25
betashootup(*)=1.0
betashootdown(*)=-0.25 ; assume betashoot more likely to be positive 
betashootprec=0.02
;
betacoeffshootdefault(*)=0.00 ; to turn off shoot set to 0 *****
;betacoeffshootdefault(*)=0.02
betacoeffshootdown(*)=-0.2
betacoeffshootup(*)=0.2
betacoeffshootprec=0.002
;
betaexpshootdefault(*)=1.0 ; for optimisation assuming linear model *****
;betaexpshootdown(*)=-1.5
;betaexpshootup(*)=1.5
;betaexpshootprec=0.05
;
;tauoffsetshootdefault(*)=0.02 ; to switch off shoot ***** (always positive 
;                                                           and short)
tauoffsetshootdefault(*)=2.0
tauoffsetshootdown(*)=0.0
tauoffsetshootdown(*)=-1.0
tauoffsetshootup(*)=4.0
tauoffsetshootprec=0.01
;
;taushootdefault(*)=0.0 ; to switch off shoot *****
taushootdefault(*)=0.0
taushootup(*)=0.0
taushootup(*)=0.25 ; allow for time constants increasing with flux
                   ; (eg to compensate for effect of long time constants 
                   ; decreasing with flux
taushootdown(*)=-0.25
taushootprec=0.001
;
gammaexpshootdefault(*)=-1.0 ; ***** linear model
;gammaexpshootup(*)=0.0
;gammaexpshootdown(*)=-2.0
;gammaexpshootprec=0.05
;
for ipix=0,8 do begin
model3searchrange,ipix ; fix search range for shooting coefficients for all 
;                         C100 pixels. Search precision will be set according
;                         to input for pixel 8.
endfor ; ipix
;
;taushootup(*)=0.0 ; only search for solutions with time constants 
;                   decreasing with illumination. RJT 2700 actually this
;                   makes solutions worse.
;taushootprec=(taushootup(0)-taushootdown(0))/30.0
;
endif ; array eq 'c100'
;
if(array eq 'c200')then begin
;
; a(0)
betadefault=[0.94,0.98,0.86,1.01]
betadown=betadefault-0.2
betaup=betadefault+0.2
betaprec=0.02
;
; a(2)
betacoeffdefault=[-0.12,-0.16,-0.10,-0.14]
betacoeffdown=betacoeffdefault-0.1
betacoeffup=betacoeffdefault+0.1
betacoeffprec=0.01
;
; +a(1)
betaexpdefault=[0.23,0.20,0.22,0.27]
betaexpdown=betaexpdefault-0.05
betaexpup=betaexpdefault+0.05
betaexpprec=0.005
;
;a(0)
;tauoffsetdefault=[5.35,4.53,3.77,6.33] ; 1999
tauoffsetdefault=[5.92,4.53,3.77,4.92] ; JUN00
tauoffsetdown=tauoffsetdefault-2.0
tauoffsetup=tauoffsetdefault+2.0
tauoffsetprec=0.2
;
;a(2)
;taudefault=[7.71,6.68,5.34,7.26] ; 1999
taudefault=[4.65,6.68,5.34,5.46] ; JUN00
taudown=taudefault-1.0
tauup=taudefault+1.0
tauprec=0.1
;
;-a(1)
;gammaexpdefault=[0.75,0.49,0.52,1.85] ; 1999
gammaexpdefault=[0.60,0.49,0.52,0.57] ; JUN00
gammaexpdown=gammaexpdefault-0.2
gammaexpup=gammaexpdefault+0.2
gammaexpprec=0.02
;
; self CAL results for fast parameters
;
;a(0)
betashootdefault=[-0.298,-0.0879,-0.143,-0.0269]
betashootdown=betashootdefault-0.15
betashootup=betashootdefault+0.15
betashootprec=0.01
;
;a(2)
betacoeffshootdefault=[0.44,0.245,0.342,0.200]
betacoeffshootdown=betacoeffshootdefault-0.1
betacoeffshootup=betacoeffshootdefault+0.1
betacoeffshootprec=0.01
;
;+a(1)
betaexpshootdefault=[0.0088,-0.190,-0.075,-0.0241]
betaexpshootdown=betaexpshootdefault-0.05
betaexpshootup=betaexpshootdefault+0.05
betaexpshootprec=0.005
;
;a(0)
tauoffsetshootdefault=[-4.90,-4.87,-4.88,-4.95]
tauoffsetshootdown=tauoffsetshootdefault-1.0
tauoffsetshootup=tauoffsetshootdefault+1.0
tauoffsetshootprec=0.02
;
;a(2)
taushootdefault=[5.14,5.20,5.20,5.14]  
taushootdown=taushootdefault-0.2
taushootup=taushootdefault+0.2
taushootprec=0.001
;
;-a(1)
gammaexpshootdefault=[0.00313,0.00439,0.00167,0.00249]
gammaexpshootdown=gammaexpshootdefault-0.0015
gammaexpshootup=gammaexpshootdefault+0.0015
gammaexpshootprec=0.0002
;
;-----------------------------------------------------------------------
; uncomment for FCS calibration
;
;betadefault(*)=0.9
;betacoeffdefault(*)=0.0
;betaexpdefault(*)=0.0
;tauoffsetdefault(*)=0.0
;taudefault(*)=20.0
;gammaexpdefault(*)=1.0 ; *** AS ASSUMED IN ANALYSE_FCS
;betashootdefault=1.0-betadefault
;betacoeffshootdefault(*)=0.0
;betaexpshootdefault(*)=0.0
;tauoffsetshootdefault(*)=0.0
;taushootdefault(*)=2.0
;gammaexpshootdefault(*)=1.0
;
;-------------------------------------------
; uncomment for temporary changes to parameters in tests as required 
; (eg to resume a solution with more precision or to converge on just 
;  one parameter). Use SETLIMIT to find search range for shooting parameters
; under linear flux dependence as a function of peak source brightness
;
goto, c999 ; allows defaults from above panel without having to comment below
;           ; comment the goto statement for calibration selfcals
;
;betadefault(*)=0.99
;betaup(*)=0.99 
;betadown(*)=0.5 
;betaprec=0.01 
;
;betacoeffdefault(*)=0.0
;betacoeffdown(*)=-0.1
;betacoeffup(*)=0.0
;betacoeffprec=0.0005
;
;betaexpdefault(*)=1.0
;betaexpdown(*)=0.0
;betaexpup(*)=1.5
;betaexpprec=0.1
;
;tauoffsetdefault(*)=5.0
;tauoffsetdown(*)=3.0
;tauoffsetup(*)=30.0
;tauoffsetprec=0.5
;
;taudefault(*)=5.0
;taudown(*)=3.0
;tauup(*)=30.0
;tauprec=0.5
;
;gammaexpdefault(*)=-1.0 
;gammaexpup(*)=2.0
;gammaexpdown(*)=0.01
;gammaexpprec=0.05
;
;betashootdefault(*)=0.0 ; to turn off shoot *****
betashootdefault(*)=0.1
betashootup(*)=0.5
betashootdown(*)=0.0 ; assume betashoot positive 
betashootprec=0.02
;
betacoeffshootdefault(*)=0.0 ; to turn off shoot *****
;betacoeffshootdefault(*)=0.02
betacoeffshootdown(*)=-0.1
betacoeffshootup(*)=0.1
betacoeffshootprec=0.002
;
betaexpshootdefault(*)=1.0 ; for optimisation assuming linear model *****
;betaexpshootdown(*)=-1.5
;betaexpshootup(*)=1.5
;betaexpshootprec=0.05
;
;tauoffsetshootdefault(*)=0.02 ; to switch off shoot ***** (always positive 
;                                                           and short)
tauoffsetshootdefault(*)=0.5
tauoffsetshootdown(*)=0.0
tauoffsetshootup(*)=2.0
tauoffsetshootprec=0.02
;
;taushootdefault(*)=0.0 ; to switch off shoot *****
taushootdefault(*)=0.0
taushootup(*)=0.0
taushootdown(*)=-0.5
taushootprec=0.001
;
gammaexpshootdefault(*)=-1.0 ; ***** linear model
;gammaexpshootup(*)=0.0
;gammaexpshootdown(*)=-2.0
;gammaexpshootprec=0.05
;
for ipix=0,3 do begin
;;;;model3searchrange,ipix ; fix search range for shooting coefficients for all 
;                         C200 pixels. Search precision will be set according
;                         to input for pixel 3.
endfor ; ipix
;
endif ; array eq 'c200'
;
c999:
;
return
end





