pro p32simpleflat
;
; simple flat fielding for PHT32, by scaling maps made with different
; combinations of detector pixels by a + b * flux. Data in common
; SIGNAL is updated by a call to APPLYROFF and the old data is
; written to snoflat, glitchnoflat and rmsnoflat in common block FLAT,
; if these arrays have no yet been written
;
; this can be run after the drift analysis (only for individual pixels for
; short term drifts) 
; after the Tuffs/Niklas routine (which only runs on individual pixels
; for long term drifts)
;
; if o/s is 1 or more all pixels are simultaneously flat fielded
; if o/s is < 1 we flat field in pixel rows, followed by scaling to a
;               common mean for each average from rows 
;
; result is sent to flatrow=dblarr(2,nrow,npixrow) for offset and scaling
; (additive and multiplicative factors for data, noise etc) in common
; block FLAT
;
; to do:
;
; *** check makemap does really give zeros where there is no data. If not
;     put in this option
;
; *** speed up makemap
;
; *** Then either (better for high s/n extended maps) find histogram of flux 
;    values over a range of data values, plot against each other
;    for row maps and scale mx + c until shapes fit. Avoid noise bias of fit.
;   Have additional option of adding constants outside the source (baseline fit)
;   and doing linear interpolation
;*** future option plait
;*** maybe just constrain to a gradent and fit offsets from map boundaries?
;    (otherwise differing noise gets differing slopes) - parameter to combine
;    and zcombine ioffset
;
;    or just in combine, zcombine fit small number of brightness bins
;
;    or (best) for os/>=1 and nz> 2 or 3 as appropriate simple fit using 
;    common positions and y=mx+c
;
;    otherwise y=mx + c for scans but between scans only fix gradient. Then
;    look at scan ends to fix the offsets
;
;common steerin,array,nptin,npt,ninramp,imeas,osamp
;common mapper,sgridy,sgridz,nygrid,nzgrid,ygrid,zgrid,errflag
;common flat,nflat,nrow,npixrow,ratioinrow,ratiobetweenrow,fmappix,flatrow,$
;snoflat,glitchnoflat,rmsnoflat
;
@common_steerin
@common_mapper
@common_flat
;
print,'P32SIMPLEFLAT:'
;
; case o/s < 1
;
if (osamp lt 1.0) then begin
if (array eq 'c100') then begin
nallpix=9
;allpix=lonarray(nallpix)
allpix=lindgen(nallpix)
nrow=3
npixrow=3
fmappix=lonarr(nrow,npixrow)
fmappix(0,*)=[0,3,6]
fmappix(1,*)=[1,4,7]
fmappix(2,*)=[2,5,8]
endif ; array eq 'c100'
if (array eq 'c200') then begin
nallpix=4
allpix=lindgen(nallpix)
nrow=2
npixrow=2
fmappix=lonarr(nrow,npixrow)
fmappix(0,*)=[1,0]
fmappix(1,*)=[2,3]
endif ; array eq 'c200'
; find factors between pixels in each row of detector
ratioinrow=dblarr(2,nrow,npixrow)
ratiobetweenrow=dblarr(2,nrow)
flatrow=dblarr(2,nrow,npixrow) ; for offset and linear scaling
maprow=dblarr(nrow,nygrid,nzgrid)
maprown=maprow
mapall=dblarr(nrow,npixrow,nygrid,nzgrid)
mapalln=mapall
dmap=dblarr(nygrid,nzgrid)
dmapn=dmap
makemap,nallpix,allpix,$
mapallpix,maprms,mapd,mapy,mapx,mapallpixn,0,1
;
for irow=0,nrow-1 do begin
;
mappix=lonarr(npixrow)
mappix(*)=fmappix(irow,*)
makemap,npixrow,mappix,mapb,maprms,mapd,mapy,mapx,mapn,0,1
maprow(irow,*,*)=mapb(*,*)
maprown(irow,*,*)=mapn(*,*)
dmap(*,*)=maprow(irow,*,*)
dmapn(*,*)=maprown(irow,*,*)
;
for ipix=0,npixrow-1 do begin
;
iipix=fmappix(irow,ipix)
mappix=lonarr(1)
mappix=iipix
makemap,1,mappix,mapb,maprms,mapd,mapy,mapx,mapn,0,1
mapall(irow,ipix,*,*)=mapb(*,*)
mapalln(irow,ipix,*,*)=mapn(*,*)
compare,mapb,mapn,dmap,dmapn,const,slope
ratioinrow(0,irow,ipix)=const
ratioinrow(1,irow,ipix)=slope
;
endfor ; ipix
;
sumr=total(ratioinrow(0,irow,*))
ratioinrow(0,irow,*)=ratioinrow(0,irow,*)-sumr ; sum of offsets is zero
; z flats
zcompare,dmap,dmapn,mapallpix,mapallpixn,const,slope
ratiobetweenrow(0,irow)=const
ratiobetweenrow(1,irow)=slope
;
endfor ; irow
;
; normalise ratiobetweenrow and find final solutions into FLATROW
;
sumr=total(ratiobetweenrow(0,*))
for irow=0,nrow-1 do begin
ratiobetweenrow(0,irow)=ratiobetweenrow(0,irow) - sumr
flatrow(0,irow,*)=ratioinrow(0,irow,*) + ratiobetweenrow(0,irow)
flatrow(1,irow,*)=ratioinrow(1,irow,*) * ratiobetweenrow(1,irow)
;
endfor ; irow
;
avflatrow=total(flatrow(1,*,*))/float(nrow*npixrow)
av0flatrow=total(flatrow(0,*,*))/float(nrow*npixrow)
;
for irow=0,nrow-1 do begin
flatrow(1,irow,*)=flatrow(1,irow,*)/avflatrow
flatrow(0,irow,*)=flatrow(0,irow,*) - av0flatrow
print,'irow,flatrow(0,irow,*) = ',irow,flatrow(0,irow,*)
print,'irow,flatrow(1,irow,*) = ',irow,flatrow(1,irow,*)
endfor ;irow
;
endif ; osamp lt 1.0
;
applyroff ; apply flatrow to data
;
;*** still to do:
;*** add o/s< 1 and nz < *** section
;*** routine for examining effects of basecorr etc and saving these
;*** add option for no offset
;
return
end
