;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PIA P32 Processing Tools Software.              !
;! Designed by: Nanyao Lu at IPAC (lu@ipac.caltech.edu)                        !
;!              Bernhard Schulz at Vilspa (bschulz@iso.vilspa.esa.es)          !
;! Developed by: Iffat Khan at IPAC (irk@ipac.caltech.edu)                     !
;!                                                                             !
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_CUST_DRIFT_PROC
;
; PURPOSE:
;       This routine starts a graphical user interface to define and initiate 
;       the batch processing for drift fitting.
;
; DESCRIPTION:
;       The GUI consists of the following major sections.
;
;       1. Action Buttons:                       
;          Start: checks the validity of input data and starts the batch
;                 processing of drift calcualtions.
;
;          Quit  : menu button having 2 children.                     
;                  Save and Quit: saves the input data into an ASCII file
;                  and exit
;                  Quit: exit without saving
;
;          Help: help on the processing 
;
;       2. Main Text Window:                     
;          Text widget to enter the input lines. Each input line 
;          consists of the pixel #, starting raster point, and 
;          the ending raster point.
;
; CATEGORY:
;       PIA - P32     
;
; CALLING SEQUENCE:
;       pia_cust_drift_proc, pid, GROUP=group
;
; INPUTS:
;       pid:      pointer variable to global parameters structure
;
; OPTIONAL INPUTS:
;       None.
;
; OUTPUTS:
;       None.
;
; KEYWORDS:
;       GROUP : The group leader of the newly created widget. 
;               If none defined then PIA top widget is taken as the
;               group leader.
;
; CALLED ROUTINES:
;       Internal Procedures:
;         PIA_CUST_DRIFT_PROC_EVENT
;         DO_DRIFT 
;       External Procedures:
;         DRIFT32
;         ERD2MAP_MSG
;         PIA_PICKFILE
;         STARTENDPOINT
;         W3NET
;
; CALLED FROM:    
;       PIA_CUST_DRIFT_PROC   
;
; COMMON BLOCKS:
;       e2m_map_locids
;
; PROCEDURE:
;       @common_all    
;       @common_steerin
;       @common_names  
;
; SIDE EFFECTS:
;       None.
;
; RESTRICTIONS:
;
;
; MODIFICATION HISTORY:
;	original design,             IRK        Aug 17, 2001
;-
;-----------------------------------------------------------------------
;
PRO DO_DRIFT, inptxt, pid, mid
@common_all


; get general not changing values
   debug = 0
   wptr = (*pid).dr_wps
   vars = (*wptr).vars
   pars = (*wptr).flags
   restore_params, vars, pars     
   IF debug THEN print,'drift vars',vars
   dr_param = intarr(12)
   IF debug THEN print,'param',dr_param
   speedfactor = 2.
   zerobias = 0.
   istartnewsol = 1
   ndetinit = (*pid).ndetinit
   niter = (*pid).niter
   inegmethod = (*pid).inegmethod
   backpred = (*pid).backpred
   irmscorr = (*pid).irmscorr
   e2map_str = *dptr
   IF debug THEN help,e2map_str,/str
   time = e2map_str.time
   ytrue = e2map_str.ytrue
   ztrue = e2map_str.ztrue
   s = e2map_str.s
   rms = e2map_str.rms
   bad = e2map_str.bad
   bad_in = bad
   IF debug THEN help,s,rms,bad
   idefcal = 1
   islewmethod = (*pid).slew
   PRINT, 'ATTENTION, ATTENTION: using islewmethod: ',islewmethod
   tplatback = 0. & tplatforward = 0.
   icompositecorr = 0
   nlookback = 1
   iverbose = 0

   imodel = (*pid).drift_model
   icalmethod = 4

; implement solution?
   implementdrift = 1

  pno = 0 & n1=0 & n2=0
  ninp = n_elements(inptxt)   
  FOR i = 0, ninp-1 DO BEGIN
      reads, inptxt(i), pno, n1,n2  
      txtstr = ' Processing   ' + inptxt(i)
      WIDGET_CONTROL, mid, set_value = txtstr
     
      npixl  = pno - 1
      pixarray = npixl 
; processing from where to where
      processfrom = n1  - 1
      processto = n2 - 1
      ical1 = processfrom
      ical2 = ical1
      isolveselfcal = dr_param
      IF islewmethod EQ 0 THEN BEGIN
         processfrom = lindgen(to-from+1)+from
         processto = processfrom
      ENDIF
      IF debug THEN help, processfrom, processto
      IF debug THEN help,s

      from = n1 - 1
      to = n2 - 1

;retrieve erd2map data for this pixel within desired range
      startendpoint,from, to,     $
      irasterstart,irasterstop,istartnoe,istopnoe,$
      irasterstarte,irasterstope,istarte,istope


      time(istartnoe:istopnoe) = time(istartnoe:istopnoe)
      ytrue(istartnoe:istopnoe) =ytrue(istartnoe:istopnoe)
      ztrue(istartnoe:istopnoe) =ztrue(istartnoe:istopnoe)
      s(npixl,istartnoe:istopnoe) = s(npixl, istartnoe:istopnoe)
      rms(npixl,istartnoe:istopnoe)= rms(npixl, istartnoe:istopnoe)
      bind = where(bad(npixl,*) EQ 0, gcnt)
      IF debug THEN print,'good bad=', gcnt, bcnt
      IF gcnt GT 0 THEN BEGIN
         illcon1 = MIN(s(npixl, bind))
         illcon2 = MAX(s(npixl, bind))
      ENDIF
      IF illcon1 LE 0. THEN illcon1 = 0.5
      IF illcon2 LE 0. THEN illcon2 = 20.0

      IF debug THEN print,'dr_init', (*pid).dr_init
; Process finally
      drift32,processfrom,processto,idefcal,$
              iverbose,pixarray,niter,$
              icalmethod,tplatback,tplatforward,nlookback,ical1,ical2, $
              isolveselfcal,irmscorr,implementdrift,istartnewsol, $
              ndetinit,icompositecorr, /use_buffer, dr_init=(*pid).dr_init
        bad = bad_in
        (*pid).drift_cor=1
        (*pid).dr_init = 0
        IF debug THEN print,'dr_init', (*pid).dr_init

 ENDFOR   

END
PRO PIA_cust_drift_proc_EVENT,event

@common_steerin
@common_names  
COMMON e2m_map_locids, lid

	WIDGET_CONTROL, event.id, GET_UVALUE=action
	WIDGET_CONTROL, event.top, GET_UVALUE=pid
	
        debug = 0
        IF debug THEN help,action,event,/str
        IF debug THEN print, STRMID(action, 0, 4)
	CASE STRMID(action, 0, 4) of 
	

	 "CLOS": BEGIN
                 WIDGET_CONTROL, event.top, /DESTROY
         END

	 "SAVQ": BEGIN
                 text="_PROC" 
                 is = STRTRIM((*pid).meas, 2)
                 if(lid.nodet eq 9) then tfile= 'C1_'+tdtnam+'_'+is+text+'.inp'
                 if(lid.nodet eq 4) then tfile ='C2_'+tdtnam+'_'+is+text+'.inp'
                 filter = '*'
                 name = PIA_pickfile(file=tfile, filter=filter, path=!INTDIR, /overwrite)
                 IF name EQ  '' THEN BEGIN
                   MESSAGE, /INFO, 'No file chosen'
                   RETURN
                 ENDIF

                 openw, unit, name, /GET_LUN 
                 WIDGET_CONTROL, lid.txtid, GET_VALUE=txtinp
                 inpid = WHERE(txtinp NE '', ninp)
                 inptxt = txtinp(inpid)
                 tit =  'P      N1     N2'
                 tit1 = '-      --     --'
                 printf, unit, tit 
                 printf, unit, tit1 
                 FOR i = 0, ninp - 1 DO $
                    printf, unit, inptxt(i)

                 CLOSE, /all

                 WIDGET_CONTROL, event.top, /DESTROY
         END
	 "QUIT": BEGIN
                 WIDGET_CONTROL, event.top, /DESTROY
         END

	 "RESE": BEGIN
                  WIDGET_CONTROL, lid.txtid, SET_VALUE=lid.pinit       
         END

	 "STAR": BEGIN
                  WIDGET_CONTROL, lid.txtid, GET_VALUE=txtinp
                  inpid = WHERE(txtinp NE ' ' and strlen(txtinp) GT 0, ninp)
                  print, ninp
                  inptxt = txtinp(inpid)

                 pno = 0 & n1=0 & n2=0
                 FOR i = 0, ninp-1 DO BEGIN
                  reads, inptxt(i), pno, n1,n2  
                  pixstr = STRTRIM(pno,2)
                  msgstr = ''
                  print,pno,n1,n2
                  IF pno GT lid.nodet OR pno LT 1 THEN $
                    msgstr = [msgstr,  $
                             'Illegal entry for pixel ' + pixstr]

                  IF n1 LE 0 THEN  $
                    msgstr = [msgstr,  $
                             'Starting raster point is negative or zero for pixel ' + pixstr]
    
                 IF n2 LE 0 THEN  $
                   msgstr = [msgstr, 'Ending raster point is negative or zero for pixel '  $
                              + pixstr]

                 IF n1 GT n2  THEN $
                   msgstr = [msgstr, 'Starting raster point exceeds Ending raster point for pixel '  $
                              + pixstr]

                 IF n1 GT lid.rsiz THEN $
                   msgstr = [msgstr,  $
                             'Starting raster point exceeds the total numberof raster points for pixel '  $
                             + pixstr]
                 IF n2 GT lid.rsiz THEN $
                   msgstr = [msgstr,  $
                             'Ending raster point exceeds the total numberof raster points for pixel '  $
                             + pixstr]
                  print,msgstr
                   help,msgstr
                 IF n_elements(SIZE(msgstr)) GT 3 THEN BEGIN
                    msgstr = msgstr(1:*)
                    erd2map_msg, msgstr, GROUP=event.top, title = "ERROR"
                    RETURN
                 ENDIF
             ENDFOR
	     WIDGET_CONTROL, event.top, /hourglass
             do_drift, inptxt, pid, lid.msgid
             msgstr= 'Drift processing has been completed successfully'
             WIDGET_CONTROL, lid.msgid, SET_VALUE=msgstr
            ; erd2map_msg, msgstr, GROUP=event.top
         END

         "HELP": BEGIN
           IF !VERSION.OS NE 'vms' THEN $
              spawn, "$w3net -remote 'openURL('$PIA_ERD2MAP_HTML'/p32_cust.html)' &"  $
           ELSE $
              spawn, "w3net -remote 'openURL('$PIA_ERD2MAP_HTML'/p32_cust.html)'",/nowait
         END


	 ELSE:

	ENDCASE

 	RETURN
	END
	

	
PRO PIA_cust_drift_proc, pid, GROUP=group

@common_steerin
COMMON e2m_map_locids, lid


        debug = 0
        if array EQ 'c100' then begin
          npx = 9
        ENDIF ELSE IF array EQ 'c200' THEN BEGIN
          npx = 4
        ENDIF
        nsval = 0
        neval = 0
        rtmp = (*pid).dr_to 
        rend = rtmp 
        nent = rtmp * npx 
        rmid = FLOAT(rtmp) / 2.0
        IF debug THEN print,rmid, rtmp, (*pid).dr_to
        IF (rmid - FIX(rmid) NE 0.) THEN rmid = FIX(rmid) + 1 $
        ELSE rmid = FIX(rmid)
        IF debug THEN print,'raster',rmid,rend
        ndisp = 2 * npx
        pixval = 0
        FOR i = 0, npx - 1 DO BEGIN
          pixval = [pixval, i + 1, i + 1]
          nsval = [nsval, 1, rmid]
          neval = [neval, rmid + 1, rend]
        ENDFOR
        pixval = pixval(1:*)
        nsval = nsval(1:*)
        neval = neval(1:*)
        help, pixval, nsval,neval
        IF debug THEN print,pixval, nsval,neval 


	IF not KEYWORD_SET(group) THEN group=!PIA_TOP_WID
	id_base= WIDGET_BASE(TITLE="Custom Processing", Xsize=250, $
                             /MODAL,  /COLUMN, GROUP=group)
	
	id_0 = WIDGET_BASE(id_base, /COL, /ALIGN_CENTER)
	id_1 = WIDGET_BASE(id_0, /ROW)
	junk = WIDGET_BUTTON( id_1, VAL=" Start  ", UV="START" )
	id_2 = WIDGET_BUTTON( id_1, VAL="  Quit    ",  /menu )
	junk = WIDGET_BUTTON( id_2, VAL="  Save and Quit   ", UV="SAVQUIT" )
	junk = WIDGET_BUTTON( id_2, VAL="  Quit   ", UV="QUIT")
	junk = WIDGET_BUTTON( id_1, VAL="  Help ", UV="HELP" )

;       labstr=['Please enter desired pixel #, the starting raster point,', $
;               'and the ending raster point on each line']  
;       lab = WIDGET_TEXT(id_base,  VAL=labstr, ysiz=2,  $
;              FONT='-adobe-courier-bold-r-normal--12-120-75-75-m-70-iso8859-1')

        IF debug THEN print,'entries=',nent

        col1 = WIDGET_BASE(id_0, /COL, /ALIGN_CENTER)
        lab = WIDGET_LABEL(col1, VAL='Pixel N(Start) N(End) ', /ALIGN_CENTER, $
                           FONT='-adobe-courier-bold-r-normal--12-120-75-75-m-70-iso8859-1')
        pval = strarr(nent)
        FOR i = 0, ndisp-1, 2 DO BEGIN
          pval(i) = STRING(pixval(i), FORMAT='(I1)') +  ' ' $
                    + STRING(nsval(i),FORMAT='(I6)') + ' ' + STRING(nsval(i+1), FORMAT='(I6)')
          pval(i+1) = STRING(pixval(i), FORMAT='(I1)') +  ' ' $
                    + STRING(neval(i),FORMAT='(I6)') + ' ' + STRING(neval(i+1), FORMAT='(I6)')
        ENDFOR

        txtid = WIDGET_TEXT(col1, VAL=pval,  UVAL="JUNK", /editable, /scroll, xsize=15, ysiz=ndisp)


	id_0 = WIDGET_BASE(id_base, /ROW, /ALIGN_CENTER)
	id_1 = WIDGET_BUTTON( id_0, VAL=" Reset ", UV="RESET" )

        msgid = WIDGET_TEXT(id_base, VAL='         ' ,  UVAL="JUNK", /editable, xsiz=30, ysiz=2, /scroll)
	
 	lid ={txtid:txtid,  msgid:msgid, pinit: pval, rsiz:(*pid).dr_to, nodet:npx}

	WIDGET_CONTROL, id_base, /realize, set_UVALUE=pid	
	Xmanager, /NO_BLOCK, "PIA_CUST_DRIFT_PROC", id_base, GROUP=group

	RETURN
	END
	
	
