;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the ERD2MAP Interface Software.                     !
;! Designed by: Nanyao Lu at IPAC (lu@ipac.caltech.edu)                        !
;!              Bernhard Schulz at Vilspa (bschulz@iso.vilspa.esa.es)          !
;! Developed by: Iffat Khan at IPAC (irk@ipac.caltech.edu)                     !
;!                                                                             !
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_ERD2MAP
;
; PURPOSE:
;       This is the lowest level routine called from IDL command line
;       to start the P32 processing tools.                         
;    
;
; DESCRIPTION:
;
;       This routine starts a graphical user interface to select a 
;       sky measurement,  initialize certain parameters associated with its type
;       (C1 or C2) and starts P32 data initialization graphical user interface. 
;
;       All the parameters and variables needed to do the processing are
;       defined and initialized in a structure in this routine. The pointer 'pid'
;       to this structure is then passed through the subroutine or function 
;       arguments to make these parameters/variables global to the whole software.
;
; CATEGORY:
;       
;
; CALLING SEQUENCE:
;       pia_erd2map
;
; INPUTS:
;       None.
;
; OPTIONAL INPUTS:
;       None.
;
; OUTPUTS:
;       None.
;
; KEYWORDS:
; 
;
; CALLED ROUTINES:
;       GIVE_CS
;       PIA_PICKMEAS
;       PIA_ERD2MAP_INIT
;
; CALLED FROM:    
;       IDL command line
;
; COMMON BLOCKS:
;       PIX_PTR   
;
; PROCEDURE:
;       @common_all
;
; SIDE EFFECTS:
;       None.
;
; RESTRICTIONS:
;
;
; MODIFICATION HISTORY:
;	original design, IRK                    January, 2001
;-

;-----------------------------------------------------------------------
;
PRO pia_erd2map

@common_all
common pixptr, map_all, map_pix

	IF Xregistered("PIA_ERD2MAP") THEN BEGIN
		MESSAGE, /INFO, 'Already running, only one instance allowed'
		RETURN
	ENDIF
	
; initialize some common blocks
	drift_model = 3
        dgparms = {fracb:5., tglch:1., thres1:50., thres2:50., irep:0}
	
	ids = { pix:0L, n1:0L, n2:0L, admn:' ', plid:' ', aotn:0L, object:' ',  $
		det:' ', raster:' ', filter:' ', meas:0,       $
		inderd:0, hdr:ptr_new(-1), cs:ptr_new(-1), roll:-99., drift:0L,  $
		map_unit:0, res_int_cor:1, otf:1, ffc:1, darks:1, slin:0, bright:0, cal:0, $
		map_slew:1, self_cal:0, impl_drft:2, dr_fr:1, dr_to:1024, $
		ndetinit:2, irmscorr:1, backpred:1, pixarray:ptr_new(-1),    $
		niter:2, inegmethod:0,  drift_model:drift_model, imple:0,   $
		dr_fr_sin:0, dr_to_sin:1024, dr_wps:ptr_new(), dr_tps:ptr_new(), dr_param:intarr(12), $
		dr_allpix:0, dr_pix:1, calib:0L, proc_fcs:0, cust:0L, proc:0L, $
		meas2pia:0L, lin_volt:1, drift_cor:0L, map_can:0L, $
                erd2map_ff:1, dr_init:1, cal_type:1, slew:0, lin_sig:1 , fcs1:'', fcs2:'', $
                dgq:dgparms}   
	
		
	vers = 'V2.0'
	defsysv, '!P32TOOLS_VERSION', vers
	pid = ptr_new(ids)
        dptr = ptr_new() 
        debug = 0
            
 	meas = pickmeas(FTYPE="ERD", posi=posi)
        IF debug THEN print,'meas=',meas 
        IF meas EQ '' THEN BEGIN
          print,'No measurement selected'
          RETURN
        ENDIF
        logfile = !INTDIR + meas + '_log'
        journal, logfile
        ind = WHERE(phterd.admn EQ meas)
        ind=ind(posi(0))
        IF debug THEN print,'meas',meas
	IF STRMID(meas,0,1) NE "C" THEN RETURN 
        sky = FIX(STRMID(meas, 2, 2)) + 1
        sky_meas = [2, 5, 8, 11, 14]
        tmpind = where(sky eq sky_meas, scnt)
        if scnt eq 0 then  BEGIN
           XDISPLAYFILE, '',height=3, $
           Text= ['Error: Selected measurement is not a sky measurement']
           return
        endif
        indx= FIX(STRMID(meas, 2, 2))
        ind1 = STRING(indx - 1, format='(i2.2)')
        ind2 = STRING(indx + 1, format='(i2.2)')
        IF debug THEN print,'indices',ind1,ind2
        fcs1 = meas & fcs2 = meas
        strput,fcs1,ind1, 2 
        strput,fcs2,ind2 , 2
        (*pid).fcs1 = fcs1
        (*pid).fcs2 = fcs2
        IF debug THEN print, (*pid).fcs1, (*pid).fcs2             
        
	(*pid).inderd = ind
	handle_value, phterd(ind).hdr, hdr
        (*pid).hdr = ptr_new(hdr)
        IF debug THEN help,hdr
        IF debug THEN help, (*pid).hdr
        (*pid).n1=0
        (*pid).n2 = phterd(ind).dims - 1
        IF phterd(ind).det EQ 'C1' THEN BEGIN
           npix = 9
           pix='5' 
           slew = 1
           (*pid).ndetinit = 1
           (*pid).niter = 1
           vars = fltarr(12,9)
           dr_param = intarr(12,9)
        ENDIF ELSE BEGIN
           npix = 4
           pix='2'
           slew = 2
           vars = fltarr(12,4)
           dr_param = intarr(12,4)
        ENDELSE

         IF debug THEN help,pix,npix,map_pix
        (*pid).slew = slew  
        (*pid).pix  = pix   
        map_all = 1
        map_pix = intarr(npix)
        (*pid).admn = dec_admn(meas)
        (*pid).meas = FIX(STRMID(meas, 2, 2)) + 1
         IF debug THEN print,'out',(*pid).meas
         backpred = (*pid).backpred
				
	object     = FXPAR( hdr,"OBJECT"  , COUNT=count )
	IF count LE 0 THEN $
        	MESSAGE, /INFO, 'Warning: missing keyword '+keyword $
        ELSE (*pid).object = object

	IF N_ELEMENTS(c1filters) EQ 0 THEN phtfilter_init

	give_cs, phterd(ind), cst, rec, conv_cst
	filt_id = conv_cst.c2ps(rec)

; put cfilter into names CB
	IF STRMID(filt_id,5,1) EQ '1' OR $
	   STRMID(filt_id,5,1) EQ '2' THEN $
	   cfilter=FIX(STRMID(filt_id,5,3)) ELSE $
	   cfilter=FIX(STRMID(filt_id,5,2))
		
        (*pid).filter = filt_id 
	keyword = "EOHAPLID"
	plid     = FXPAR( hdr, keyword, COUNT=count )
	IF count LE 0 THEN $
        	MESSAGE, /INFO, 'Warning: missing keyword '+keyword 
        (*pid).plid = plid
		
	keyword = "EOHAAOTN"
	aotn = FXPAR( hdr, keyword, COUNT=count)
	IF count LE 0 THEN $
		MESSAGE, /INFO, 'Warning: missing keyword '+keyword

	det = STRMID(meas,0,2)+ '00'
        IF debug THEN help,meas, det
        (*pid).det = det
		
	keyword = "ATTRNLNS"
	nlns = FXPAR( hdr, keyword, COUNT=count )

	keyword = "ATTRNPTS"
	npts = FXPAR( hdr, keyword, COUNT=count )

	raster = STRTRIM(npts,2) + " x " + STRTRIM(nlns,2) 
        (*pid).raster = raster
		
	(*pid).dr_to = npts * nlns

        array = STRLOWCASE(STRMID(phterd(ind).admn,0,2)) + '00'
        drift_model = 3
        detdefaultsetup, 1, drift_model

        pia_set_wps, vars
        (*pid).dr_wps = ptr_new({vars:vars, flags:dr_param})
        IF debug THEN help, vars
        pia_erd2map_init, pid

	
RETURN
END
	
