;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_ERD2MAP_MAPDRAW
;
; PURPOSE:
;	Draw a 2-dimensional map of the sky in gnomonic coordinates
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_ERD2MAP_MAPDRAW, map, trans, pixsize
;
; INPUTS:
;	MAP		The two dimensional map of the image to be drawn
;
;	TRANS		The transformation structure as provided by PIA_MKTRANS
;
;	PIXSIZE		Pixel size [x,y] of a map pixels in arcsec
;
; KEYWORD PARAMETERS:
;	TITLE		The widget title
;
;	GROUP		The widget group leader
;
;	HEADLINE	The headline (plot title)
;
;	NO_ROT		Rotation menu disabled
;
;	NO_DECONV	Deconvolution menu disabled
;
; OUTPUTS:
;	(none)
;
; PROCEDURES USED:
;	PIA Procedure(s):
;		pia_mapgrid
;		pia_prtdef
;		pia_source_search
;		pia_xy2rd
;		write_map
;	Astronomical Library:
;		avg
;		radec
;		sigma
;	Internal:
;		pia_mapdraw_cust_event
;		pia_mapdraw_cust
;		pia_mapdraw_draw
;		pia_mapdraw_cleanup
;		pia_mapdraw_drev
;		pia_mapdraw_event
;
; COMMON BLOCKS:
;	PIA_PRINT
;
; MODIFICATION HISTORY:
;	Written by:		D. Skaley, MPIK/Heidelberg	March 1995
;	Modified (last) by:	C. Gabriel, ESA/VILSPA		November 1996
;	V5.x
;	Plot profiles better handled - CG			March 1997
;	V6.1
;	Continuous zooming disabled by default (CG)		October 1997
;	V6.5
;	Reserving last color for white (CG)			April 1998
;	V7.1
;	Message for "one-dimensional" map added (CG)		May 1998
;	V7.1.1
;	Map deconvolution menu added (CG)			May 1998
;	Profiles extracted linearly (CG)			May 1998
;	V7.2
;	Headline configurable now - zooming fixed (CG)		August 1998
;	V7.3
;	pia_pickfile1 replaced (CG)				February 1999
;	V7.4
;	Map noise calculated "intrinsically" if not derived
;	+ aspect ratio added to customize (CG)			August 1999
;	V8.0
;	
;-

; ****************************************************************************
; PIA_ERD2MAP_MAPDRAW_CUST_EVENT  -  customization
; ****************************************************************************

PRO PIA_ERD2MAP_MAPDRAW_CUST_EVENT, event

	WIDGET_CONTROL, event.id, GET_UVALUE=action
	WIDGET_CONTROL, event.top, GET_UVALUE=hcust
	HANDLE_VALUE, hcust, scust

	CASE action OF

	'OK':	BEGIN
		HANDLE_VALUE, scust.hid, id
		HANDLE_VALUE, scust.htmp, par, /NO_COPY

		WIDGET_CONTROL, id.title, GET_VALUE=val
		par.headline = val(0)

		WIDGET_CONTROL, id.aspect, GET_VALUE=val
		par.aspectratio = val(0)

;		mappar.admn_decoded = par.headline
;	        HANDLE_VALUE, save.hmappar, mappar, /SET
		
		WIDGET_CONTROL, id.chsize, GET_VALUE=val
		!P.charsize = FLOAT(val(0))
		WIDGET_CONTROL, id.ngrid, GET_VALUE=val
		par.ngrid = val(0)
		WIDGET_CONTROL, id.lcval, GET_VALUE=val
		par.lcval = val(0)
		WIDGET_CONTROL, id.hcval, GET_VALUE=val
		par.hcval = val(0)
		WIDGET_CONTROL, id.conval, GET_VALUE=val
		par.contlvls = FIX(val(0))
		WIDGET_CONTROL, id.contthic, GET_VALUE=val
		par.contthic = val(0)
		HANDLE_VALUE, scust.hpar, par, /SET, /NO_COPY
		WIDGET_CONTROL, event.top, /DESTROY
		END

	'CANC':	BEGIN
		; delete handle to signal CANCLE to the main routine
		HANDLE_FREE, hcust
		WIDGET_CONTROL, event.top, /DESTROY
		END

	'GRID':	BEGIN
		HANDLE_VALUE, scust.htmp, par, /NO_COPY
		par.grid = event.select
		HANDLE_VALUE, scust.htmp, par, /SET, /NO_COPY
		END

	'INTP':	BEGIN
		HANDLE_VALUE, scust.htmp, par, /NO_COPY
		par.interp = event.select
		HANDLE_VALUE, scust.htmp, par, /SET, /NO_COPY
		END

	'ZOOC':	BEGIN
		HANDLE_VALUE, scust.htmp, par, /NO_COPY
		par.zoomcont = event.select
		HANDLE_VALUE, scust.htmp, par, /SET, /NO_COPY
		END

	'LCN':	BEGIN
		HANDLE_VALUE, scust.hid, id
		HANDLE_VALUE, scust.htmp, par, /NO_COPY
		par.lcut = 0
		WIDGET_CONTROL, id.lcval, SENSITIVE=0
		HANDLE_VALUE, scust.htmp, par, /SET, /NO_COPY
		END

	'LCA':	BEGIN
		HANDLE_VALUE, scust.hid, id
		HANDLE_VALUE, scust.htmp, par, /NO_COPY
		par.lcut = 1
		WIDGET_CONTROL, id.lcval, SENSITIVE=0
		HANDLE_VALUE, scust.htmp, par, /SET, /NO_COPY
		END

	'LCU':	BEGIN
		HANDLE_VALUE, scust.hid, id
		HANDLE_VALUE, scust.htmp, par, /NO_COPY
		par.lcut = 2
		WIDGET_CONTROL, id.lcval, SENSITIVE=1
		HANDLE_VALUE, scust.htmp, par, /SET, /NO_COPY
		END

	'HCN':	BEGIN
		HANDLE_VALUE, scust.hid, id
		HANDLE_VALUE, scust.htmp, par, /NO_COPY
		par.hcut = 0
		WIDGET_CONTROL, id.hcval, SENSITIVE=0
		HANDLE_VALUE, scust.htmp, par, /SET, /NO_COPY
		END

	'HCA':	BEGIN
		HANDLE_VALUE, scust.hid, id
		HANDLE_VALUE, scust.htmp, par, /NO_COPY
		par.hcut = 1
		WIDGET_CONTROL, id.hcval, SENSITIVE=0
		HANDLE_VALUE, scust.htmp, par, /SET, /NO_COPY
		END

	'HCU':	BEGIN
		HANDLE_VALUE, scust.hid, id
		HANDLE_VALUE, scust.htmp, par, /NO_COPY
		par.hcut = 2
		WIDGET_CONTROL, id.hcval, SENSITIVE=1
		HANDLE_VALUE, scust.htmp, par, /SET, /NO_COPY
		END

	'NOCONT': BEGIN
		HANDLE_VALUE, scust.hid, id
		HANDLE_VALUE, scust.htmp, par, /NO_COPY
		par.contour = 0
		par.overcont = 0 
		HANDLE_VALUE, scust.htmp, par, /SET, /NO_COPY
		END
	'CONTOUR': BEGIN
		HANDLE_VALUE, scust.hid, id
		HANDLE_VALUE, scust.htmp, par, /NO_COPY
		par.contour = 1
		par.overcont = 0 
		HANDLE_VALUE, scust.htmp, par, /SET, /NO_COPY
		END
	'OVERCONT': BEGIN
		HANDLE_VALUE, scust.hid, id
		HANDLE_VALUE, scust.htmp, par, /NO_COPY
		par.contour = 0
		par.overcont = 1 
		HANDLE_VALUE, scust.htmp, par, /SET, /NO_COPY
		END
	ELSE:
	ENDCASE

	RETURN
	END

; ****************************************************************************
; PIA_ERD2MAP_MAPDRAW_CUST  -  customization dialog window
; ****************************************************************************

PRO PIA_ERD2MAP_MAPDRAW_CUST, hsave, GROUP=group, REDRAW=redraw

	HANDLE_VALUE, hsave, save
	HANDLE_VALUE, save.hpar, par

; parameters for this instance

	id = { ngrid:0L, lcval:0L, hcval:0L, conval:0L, $
		contthic:0L, title:0L, chsize:0L, aspect:0L }

; set up dialog widgets

	id_base = WIDGET_BASE( TITLE="Set Image Parameters", /COLUMN, $
			/modal, group=group )

	id_0 = WIDGET_BASE( id_base, /ROW )
	id_1 = WIDGET_BUTTON( id_0, VAL="     OK     ", UVA="OK" )
	id_1 = WIDGET_BUTTON( id_0, VAL="  Cancel  ", UVA="CANC" )

	id_0 = WIDGET_BASE( id_base, /COLUMN , /FRAME)
	id_1 = WIDGET_LABEL(id_0, VAL="Image Headline:")
	id.title = WIDGET_TEXT(id_0, /EDITABLE, XSIZE=40, VAL=par.headline, $
			UVAL="TITLE")
	id_1 = WIDGET_BASE( id_0, /ROW)
	id_2 = WIDGET_LABEL(id_1, VAL="Character size (0=1):")
	id.chsize = WIDGET_TEXT(id_1, /EDITABLE, $
		VAL=STRTRIM(!P.charsize,2), UVA="chsiz")
	
	id_0 = WIDGET_BASE( id_base, /COLUMN, /FRAME )
	id_1 = WIDGET_BASE( id_0, /NONEXCLUSIVE )
	id_grid = WIDGET_BUTTON( id_1, VAL="Draw grid lines", UVA="GRID" )
	id_1 = WIDGET_BASE( id_0, /ROW )
	id_2 = WIDGET_LABEL( id_1, VAL="Maximum number of grid lines:" )
	id.ngrid = WIDGET_TEXT( id_1, XSIZE=10, /EDITABLE, UVA='NGRD' )

	id_0 = WIDGET_BASE( id_base, /COLUMN, /FRAME )
	id_1 = WIDGET_BASE( id_0, /NONEXCLUSIVE )
	id_interp = WIDGET_BUTTON( id_1, VAL="Interpolate image pixels", $
				UVA="INTP" )

	id_0 = WIDGET_BASE( id_base, /COLUMN, /FRAME )
	id_1 = WIDGET_BASE( id_0, /NONEXCLUSIVE )
	id_zoomcont = WIDGET_BUTTON( id_1, VAL="Continuous zoom", $
				UVA="ZOOC" )

	id_0 = WIDGET_BASE( id_base, /COLUMN, /FRAME )
	id_1 = WIDGET_BASE( id_0, /ROW )
	id_lab = WIDGET_LABEL( id_1, VAL="Aspect ratio:")
	id.aspect = WIDGET_TEXT( id_1, $
		VAL=STRING(par.aspectratio,FORMAT="(D4.2)"), $
				UVA="ASPECT", XSIZE=5, /EDITABLE )
	id_lab = WIDGET_LABEL( id_1, VAL="x/y pixsize - 0=not active") 
				
	id_0 = WIDGET_BASE( id_base, /COLUMN, /FRAME )
	id_1 = WIDGET_LABEL( id_0, VALUE="Set cut values" )
	id_1 = WIDGET_BASE( id_0, /ROW )

	id_2 = WIDGET_BASE( id_1, /COLUMN )
	id_3 = WIDGET_LABEL( id_2, VALUE="Low cut value:" )
	id_3 = WIDGET_BASE( id_2, /EXCLUSIVE )
	id_lcnone = WIDGET_BUTTON( id_3, VAL="None", UVA="LCN", /NO_RELEASE )
	id_lcauto = WIDGET_BUTTON( id_3, VAL="Automatic", UVA="LCA", $
						/NO_RELEASE )
	id_lcuser = WIDGET_BUTTON( id_3, VAL="User supplied", UVA="LCU", $
						/NO_RELEASE )
	id.lcval = WIDGET_TEXT( id_2, XSIZE=12, UVA="LCV", /EDITABLE )

	id_2 = WIDGET_LABEL( id_1, VALUE="   " )

	id_2 = WIDGET_BASE( id_1, /COLUMN )
	id_3 = WIDGET_LABEL( id_2, VALUE="High cut value:" )
	id_3 = WIDGET_BASE( id_2, /EXCLUSIVE )
	id_hcnone = WIDGET_BUTTON( id_3, VAL="None", UVA="HCN", /NO_RELEASE )
	id_hcauto = WIDGET_BUTTON( id_3, VAL="Automatic", UVA="HCA", $
						/NO_RELEASE )
	id_hcuser = WIDGET_BUTTON( id_3, VAL="User supplied", UVA="HCU", $
						/NO_RELEASE )
	id.hcval = WIDGET_TEXT( id_2, XSIZE=12, UVA="HCV", /EDITABLE )

; Contours definitions

	id_0 = WIDGET_BASE( id_base, /COLUMN, /FRAME )
	id_1 = WIDGET_LABEL( id_0, VALUE="Set contours " )
	id_1 = WIDGET_BASE( id_0, /EXCLUSIVE )
	id_connot = WIDGET_BUTTON( id_1, VAL="No contours", $
			UVA="NOCONT", /NO_RELEASE )
	id_conyes = WIDGET_BUTTON( id_1, VAL="Contours instead of maps", $
			UVA="CONTOUR", /NO_RELEASE )
	id_conover = WIDGET_BUTTON( id_1, VAL="Overplot contours", $
		UVA="OVERCONT", /NO_RELEASE )
	id_1 = WIDGET_BASE( id_0, /ROW )
	id_2 = WIDGET_LABEL( id_1, VALUE="Number of contour levels: ")
	id.conval = WIDGET_TEXT( id_1, XSIZE=6, $
			VALUE=STRTRIM(par.contlvls,2),$
			UVA="NLEVEL", /EDITABLE )
	id_1 = WIDGET_BASE( id_0, /ROW )
	id_2 = WIDGET_LABEL( id_1, VALUE="Thickness of contours: ")
	id.contthic = WIDGET_TEXT( id_1, XSIZE=6, $
			VALUE=STRING(FORMAT="(F5.2)",par.contthic),$
			UVA="NTHIC", /EDITABLE )


; save paramaters for this instance

	hcust = HANDLE_CREATE()
	hid = HANDLE_CREATE( hcust, VALUE=id )
	htmp = HANDLE_CREATE( hcust, VALUE=par )
	scust = { hid:hid, htmp:htmp, hpar:save.hpar }
	HANDLE_VALUE, hcust, scust, /SET
	WIDGET_CONTROL, id_base, /REALIZE, SET_UVALUE=hcust

; initialize widget states
	WIDGET_CONTROL, id_conyes, SET_BUTTON=par.contour
	WIDGET_CONTROL, id_conover, SET_BUTTON=par.overcont
	IF par.contour OR par.overcont THEN $
		WIDGET_CONTROL, id_connot, SET_BUTTON=0 ELSE $
		WIDGET_CONTROL, id_connot, SET_BUTTON=1

	WIDGET_CONTROL, id_grid, SET_BUTTON=par.grid
	WIDGET_CONTROL, id.ngrid, SET_VALUE=STRING(par.ngrid)
	WIDGET_CONTROL, id_interp, SET_BUTTON=par.interp
	WIDGET_CONTROL, id_zoomcont, SET_BUTTON=par.zoomcont
	CASE par.lcut OF
	0:	BEGIN
		WIDGET_CONTROL, id_lcnone, /SET_BUTTON
		WIDGET_CONTROL, id.lcval, SENSITIVE=0
		END
	1:	BEGIN
		WIDGET_CONTROL, id_lcauto, /SET_BUTTON
		WIDGET_CONTROL, id.lcval, SENSITIVE=0
		END
	ELSE:	BEGIN
		WIDGET_CONTROL, id_lcuser, /SET_BUTTON
		WIDGET_CONTROL, id.lcval, SENSITIVE=1
		END
	ENDCASE
	WIDGET_CONTROL, id.lcval, SET_VALUE=STRING(par.lcval)
	CASE par.hcut OF
	0:	BEGIN
		WIDGET_CONTROL, id_hcnone, /SET_BUTTON
		WIDGET_CONTROL, id.hcval, SENSITIVE=0
		END
	1:	BEGIN
		WIDGET_CONTROL, id_hcauto, /SET_BUTTON
		WIDGET_CONTROL, id.hcval, SENSITIVE=0
		END
	ELSE:	BEGIN
		WIDGET_CONTROL, id_hcuser, /SET_BUTTON
		WIDGET_CONTROL, id.hcval, SENSITIVE=1
		END
	ENDCASE
	WIDGET_CONTROL, id.hcval, SET_VALUE=STRING(par.hcval)

; manage

	xMANAGER,No_BLOCK=1, "PIA_ERD2MAP_MAPDRAW_CUST", id_base, GROUP=group
	IF HANDLE_INFO( hcust, /VALID ) THEN BEGIN	; OK button was pressed
		HANDLE_FREE, hcust
		redraw = 1
	ENDIF ELSE BEGIN				; CANCEL was pressed
		redraw = 0
	ENDELSE

	RETURN
	END

; ****************************************************************************
; PIA_ERD2MAP_MAPDRAW_DRAW  -  drawing the map
; ****************************************************************************

PRO PIA_ERD2MAP_MAPDRAW_DRAW, hsave, overl_str=overl_str
COMMON PIA_MAPDR_AREAS, wsize, area 
COMMON pia_overlay_str, overlay_str, overl_str_flag
@colour_indices

	HANDLE_VALUE, hsave, save
	HANDLE_VALUE, save.hpar, par, /NO_COPY
	HANDLE_VALUE, save.hmap, map, /NO_COPY
	HANDLE_VALUE, save.hmappar, mappar, /NO_COPY

        wsize = par.wsize
	
; PostScript: scaling positions with 24 seems to be o.k.
; also setting a maximum of 128 for n_colors to avoid problem with 
; printers  (CG)

	IF !D.NAME EQ "PS" THEN BEGIN
	   pscale=32 
	   n_colors = min([!D.N_COLORS-12,116])
	ENDIF ELSE BEGIN
	   pscale = 1
	   n_colors = !D.N_COLORS-12
	ENDELSE
; focus to draw window and erase only if window device

	IF (!D.FLAGS AND 256) NE 0 THEN BEGIN
		WSET, par.window
		ERASE
	ENDIF

; define the drawing area

	; lower left corner
	par.area(0:1) = [ 80, 50 ]
	; preliminary max display size
	dsize_max = par.wsize - par.area(0:1) - [ 130, 50 ]
	IF MIN(dsize_max) LE 0 THEN MESSAGE, "Wrong window dimensions"

; calculate the scaling factor to fit the map into the display area

	IF par.aspectratio NE 0. THEN aspect_ratio=par.aspectratio ELSE $
	 aspect_ratio = par.pixsize(0)/par.pixsize(1)
	IF aspect_ratio GE 1. THEN aspect = [ aspect_ratio, 1. ] $
	                      ELSE aspect = [ 1., 1./aspect_ratio ]
	par.scale = aspect * MIN(dsize_max/(par.msize*aspect))
	imagedim = FIX( par.scale * par.msize )

; avoid strange appearance
	IF imagedim(1) LT imagedim(0)/2 AND par.aspectratio EQ 0. THEN BEGIN
	  factor = imagedim(0)/2. / imagedim(1)
	  par.scale(1) = par.scale(1)*factor
	  imagedim(1) = FIX(imagedim(1)*factor)
	ENDIF

; the actual drawing area

	par.area(2:3) = par.area(0:1) + imagedim
	area = par.area*pscale

; print the headline

	xpos = (area(0)+area(2))/2.
	ypos = (par.wsize(1)-20)*pscale

	chars = !P.charsize*1.5
	IF chars EQ 0. THEN chars = 1.5
	XYOUTS, xpos, ypos, /DEVICE, par.headline, ALIGNMENT=0.5, $
	 charsize=chars

; some map statistics

	mapmin = MIN( map )
	mapmax = MAX( map )
	mapavg = AVG( map )
	mapstd = SIGMA( map )

	ind= where(map NE -1.,nok)
	IF nok GT 0 THEN BEGIN
	  realmin = MIN(map(ind)) 
	  rmin = realmin - 0.3*(max(map)-realmin)
	ENDIF ELSE rmin=-1.
	
; transform map to bytes scaled to cut-values

	CASE par.lcut OF
;	0:	par.cutmin = mapmin
;	1:	BEGIN
;		par.cutmin = mapmin
;		END
	0:	par.cutmin = rmin
	1:	BEGIN
		par.cutmin = rmin
		END
	ELSE:	par.cutmin = par.lcval
	ENDCASE
	CASE par.hcut OF
	0:	par.cutmax = mapmax
	1:	BEGIN
;		par.cutmax = mapavg + 2*mapstd < mapmax
                par.cutmax = mapmax
		END
	ELSE:	par.cutmax = par.hcval
	ENDCASE
	
	IF par.cutmin EQ par.cutmax THEN BEGIN
		par.cutmin=par.cutmin - 0.1*par.cutmin
		par.cutmax=par.cutmax + 0.1*par.cutmax
	ENDIF

	image = BYTSCL(map, MIN=par.cutmin, MAX=par.cutmax, TOP=N_COLORS-1) + 1

; scale the map in x/y-direction to new dimensions
; This is because of problems with pipeline maps:
IF 1L*imagedim(0)*imagedim(1) LT 0 THEN $
    PRINT, 'Problems with image dimensions'
IF imagedim(0) LT 0 THEN imagedim(0) = -imagedim(0)
IF imagedim(1) LT 0 THEN imagedim(1) = -imagedim(1)

	image = CONGRID(image,imagedim(0),imagedim(1),INTERP=par.interp,$
			MINUS_ONE=par.interp)

; draw the image

	IF not par.contour THEN $
	TV, image, area(0), area(1), $
		XSIZE=area(2)-area(0), YSIZE=area(3)-area(1)
		
	IF par.contour OR par.overcont THEN BEGIN
;	  levels = par.cutmin+findgen(par.contlvls)* $
;	  	(par.cutmax-par.cutmin)/par.contlvls
	  contmin = par.cutmin > realmin
	  contmin = par.cutmin
	  levels = contmin+findgen(par.contlvls)* $
	  	(par.cutmax-contmin)/par.contlvls

	  contour, map, /noerase, xstyle=1, ystyle=1, /follow,   $
	  	LEVELS=levels, C_LABELS=INTARR(par.contlvls)+1, $
	  	C_LINESTYLE=[1,0], C_THICK=par.contthic,$
	  	XTICKS=1, YTICKS=1, XTICKN=[' ',' '], YTICKN=[' ',' '],$
	  	POSITION=[area(0),area(1),area(2),area(3)] , /device
	ENDIF

	IF KEYWORD_SET(overl_str) THEN BEGIN
	  contmin = min(overl_str.map)
	  contmax = max(overl_str.map)
	  levels = contmin+findgen(par.contlvls)* $
	  	(contmax-contmin)/par.contlvls
	  IF par.contour OR par.overcont THEN cont_color=red ELSE $
	       cont_color=white 
	  contour, overl_str.map, /noerase, xstyle=1, ystyle=1, /follow,   $
	  	LEVELS=levels, C_LABELS=INTARR(par.contlvls), $
	  	C_LINESTYLE=[0,1], C_THICK=par.contthic, $
	  	XTICKS=1, YTICKS=1, XTICKN=[' ',' '], YTICKN=[' ',' '],$
	  	POSITION=[area(0),area(1),area(2),area(3)] , /device, $
		c_colors=[cont_color]

	ENDIF
	   
	
; the image transformation parameters

	itrans = par.trans
	itrans.crpix = (par.trans.crpix+0.5)*par.scale*pscale
	invscl = 1./(par.scale*pscale)
	itrans.cd = par.trans.cd # [[invscl(0),0],[0,invscl(1)]]
	itrans.dc = INVERT(itrans.cd)

; draw the gridlines 
	IF par.grid THEN PIA_MAPGRID, itrans, area, par.ngrid, $
	   simple=par.simple

; draw the color bar

	csize = [ 30, N_COLORS ]
	cbar = REPLICATE(1,FIX(csize(0))) # BINDGEN(LONG(csize(1)))
	carea = FINDGEN(4)
;	carea(0) = par.wsize(0) - 100		; 100 from right window border
	carea(0) = par.area(2) + 30		; 30 from right map border
	carea(1) = par.area(1) + 60		; 60 above lower display area
	carea(2:3) = carea(0:1) + csize

	carea = carea*pscale
	csize = csize*pscale

	IF not par.contour THEN BEGIN 
	 TV, cbar, carea(0), carea(1), XSIZE=csize(0), YSIZE=csize(1)
	 yrange = [par.cutmin,par.cutmax]
	 IF yrange(1) EQ yrange(0) THEN yrange(1)=yrange(1)+1
	 PLOT, [0], [0], /NODATA, /NOERASE, POSITION=carea, /DEVICE, $
		XRANGE=[0.,1.], YRANGE=yrange, XSTYLE=4, YSTYLE=5
	 AXIS, YAXIS=1, YTICKLEN=-0.02, YSTYLE=1
	ENDIF

; annotate unit
        print, mappar.datatype, par.map_type
	IF par.map_type EQ 2 THEN dunit = "[sec]" ELSE BEGIN

		IF mappar.datatype GE 4 THEN dunit = "[Jy/beam]" ELSE $
		dunit = "[MJy/sr]"
	ENDELSE
	IF par.map_type EQ -1 THEN dunit="[Arb.unit]"
	IF par.map_type EQ -2 THEN dunit="[V/s]"
		
	IF !P.charsize EQ 0. THEN chsiz = 1.3 ELSE chsiz = !P.charsize*1.3
	XYOUTS, carea(0)-10*pscale, carea(3)+80*pscale, /DEVICE, $
		dunit, CHARSIZE=1.3

; annotate overlay info

	IF KEYWORD_SET(overl_str) THEN BEGIN 
	 IF !D.NAME NE "PS" THEN BEGIN
	  PIA_write_anything, 'Text inclusion', strout, proposal='Overlay:'
	  IF strout(0) EQ '' THEN strout='Overlay: '+ overl_str.name
	  XYOUTS, carea(0)/2 +20*pscale, 10*pscale, /DEVICE, $
		strout(0), $
		CHARSIZE=1.3
	  overl_str.text = strout(0)
	 ENDIF ELSE BEGIN  
	  XYOUTS, carea(0)/2 +20*pscale, 10*pscale, /DEVICE, $
		overl_str.text, $
		CHARSIZE=1.3
	 ENDELSE
	ENDIF  
	overl_str_flag=0


; annotate min/max and low-/high-cut values

	XYOUTS, carea(0)-10*pscale, carea(1)-40*pscale, /DEVICE, $
		STRCOMPRESS('min='+STRING(realmin, FORMAT="(E10.3)")), $
		CHARSIZE=!P.CHARSIZE
	XYOUTS, carea(0)-10*pscale, carea(3)+40*pscale, /DEVICE, $
		STRCOMPRESS('max='+STRING(mapmax, FORMAT="(E10.3)")), $
		CHARSIZE=!P.CHARSIZE
	XYOUTS, carea(0)-10*pscale, carea(1)-20*pscale, /DEVICE, $
		STRCOMPRESS('lowcut='+STRING(par.cutmin, FORMAT="(E10.3)")), $
		CHARSIZE=!P.CHARSIZE
	XYOUTS, carea(0)-10*pscale, carea(3)+20*pscale, /DEVICE, $
		STRCOMPRESS('highcut='+STRING(par.cutmax, FORMAT="(E10.3)")), $
		CHARSIZE=!P.CHARSIZE


	reg = "PHT-Interactive Analysis Display System"
	XYOUTS, 10, 10, /DEVICE, reg, ALIGNMENT=0., charsize=!P.CHARSIZE
; move par and map  back to handles

	HANDLE_VALUE, save.hpar, par, /SET, /NO_COPY
	HANDLE_VALUE, save.hmap, map, /SET, /NO_COPY
	HANDLE_VALUE, save.hmappar, mappar, /SET, /NO_COPY

	RETURN
	END

; ****************************************************************************
; PIA_ERD2MAP_MAPDRAW_CLEANUP  -  cleanup routine for PIA_MAPDRAW
; ****************************************************************************

PRO PIA_ERD2MAP_MAPDRAW_CLEANUP, id_top

	WIDGET_CONTROL, id_top, GET_UVALUE=hsave
	HANDLE_FREE, hsave
	RETURN
	END

; ****************************************************************************
; PIA_ERD2MAP_MAPDRAW_DREV  -  event handling routine for draw window events
; ****************************************************************************

PRO PIA_ERD2MAP_MAPDRAW_DREV, event

COMMON pia_mapdraw_scan, scandir
@colour_indices
COMMON zoom_discareas, disc_area, all_disc_areas
	
	IF event.type EQ 1 THEN RETURN

	IF N_ELEMENTS(scandir) EQ 0 THEN scandir = 0
	
	WIDGET_CONTROL, event.top, GET_UVALUE=hsave
	HANDLE_VALUE, hsave, save
	HANDLE_VALUE, save.hid, id
	HANDLE_VALUE, save.hpar, par
	HANDLE_VALUE, save.hmappar, mappar

	x = FIX((event.x-par.area(0))/par.scale(0))
	y = FIX((event.y-par.area(1))/par.scale(1))
	IF x GE 0 AND x LT par.msize(0) AND $
	   y GE 0 AND y LT par.msize(1) THEN BEGIN
		PIA_XY2RD, x, y, par.trans, ra, dec

		RADEC, ra, dec, rh, rm, rs, dd, dm, ds
		IF dec LT 0 THEN BEGIN
			dd = -ABS(dd)
			dm = ABS(dm)
			ds = ABS(ds)
		ENDIF
		sra = STRING(rh,rm,rs,FORMAT="(I2,'h ',I2,'m ',I2,'s')")
		sdec = STRING(dd,dm,ds,FORMAT="(I3,'d ',I2,'m ',I2,'s')")
		WIDGET_CONTROL, id.ra, SET_VALUE=sra
		WIDGET_CONTROL, id.dec, SET_VALUE=sdec
		HANDLE_VALUE, save.hmap, map, /NO_COPY
		HANDLE_VALUE, save.hmapunc, mapunc
		WIDGET_CONTROL, id.value, SET_VALUE=STRING(map(x,y))
		IF id.plprof_val GT 0 AND id.plprof_val LE 4 THEN BEGIN

			IF scandir EQ 0 THEN BEGIN
			 scan = map(*,y)
			 indscan = WHERE(scan NE 0.,nscan)
			 IF nscan EQ 0 THEN RETURN

			 PIA_XY2RD, indscan(0), y, par.trans, ra0, dec0
			 PIA_XY2RD, par.msize(0)-1, y, par.trans, ra1, dec1
;			 PIA_XY2RD, max(indscan), y, par.trans, ra1, dec1
			ENDIF ELSE BEGIN
			 scan = map(x,*)
			 indscan = WHERE(scan NE 0.,nscan)
			 IF nscan EQ 0 THEN RETURN

			 PIA_XY2RD, x, indscan(0), par.trans, ra0, dec0
			 PIA_XY2RD, x, par.msize(1)-1, par.trans, ra1, dec1
;			 PIA_XY2RD, x, max(indscan), par.trans, ra1, dec1
			ENDELSE	

; take only points with signal:
			scan = scan(indscan)
			xind = N_ELEMENTS(scan)
			shifting = 0
			  
			IF id.plprof_val EQ 2 OR id.plprof_val EQ 4 THEN BEGIN
;			   indbck = WHERE(scan NE 0., nbck)
;			   IF nbck GT 8 THEN BEGIN
;			    scanbck = [scan(indbck(0:3)), $
;			    		scan(max(indbck)-3:max(indbck))]
;			    bckgr = median(scanbck)
;			    shifting = 1
;			   ENDIF ELSE BEGIN
;			    PRINT, 'Not enough points to compute background'
;			    bckgr = 0.
;			    shifting = 0
;			   ENDELSE
			   allval = WHERE(map NE 0., ncount)
			   allmed = median(map(allval))
			   indbel = WHERE(map(allval) LT allmed)
			   bckgr = median(map(allval(indbel))) 
			   shifting = 1			   
			ENDIF ELSE bckgr = 0.
			
;			scan = scan - bckgr
;			scan = scan / max(scan)
			
			xele = indgen(xind) * (ra1*1.D0-ra0*1.D0)/(xind-1) + ra0
;			xele = indgen(xind)
			xtitle = ' RA map-projection '
			ytitle = ' Brightness Value   [MJy/sr]' 
			IF shifting THEN BEGIN
			 difra = max([ra1 - ra0,ra0 - ra1])
			 difdec = max([dec1 - dec0, dec0 - dec1])
			 
			 radec, difra, difdec, hr, hm, hs, dr, dm, ds
			 difra = abs(hm*60.)+ abs(hs) 
			 difdec = abs(dm*60.) + abs(ds) 
			 
			 difra = difra/(xind-1) * 15. * $
			          cos((dec1+dec0) * !PI / 360.)  ; /2 *2
			 difdec = difdec / (xind-1)

			 difarcs = SQRT(difra^2.+difdec^2.) 

			 ind = where(scan EQ max(scan))

			 xele = (indgen(xind) - ind(0)) * difarcs
			 xtitle = ' Offset  [arcsec] '
			 ytitle = ' Normalized brightness '
			ENDIF

			handle_value, save.hmappar, imappar
			title = 'Row '+STRTRIM(STRING(y),2)+ ' profile:'+ $
				imappar.admn_decoded 
			legend = imappar.admn_decoded
			IF id.plprof_val LE 2 THEN BEGIN
		         PIA_XPLOT, xele, scan, TITLE=title, $
		         	annotation=title, linestyle=0, thick=2.5,$
				xtitle=xtitle, $
				ytitle=ytitle, $
				legend = legend 
			ENDIF ELSE BEGIN		        
			 PIA_XPLOT, xele, scan, annotation=title, $
				 linestyle=2, thick=3.,$
				 color=red, /overplot, legend=legend 
			ENDELSE
		ENDIF ELSE IF id.plprof_val GE 5 AND $
			id.plprof_val LT 20 THEN BEGIN
;		   PRINT, 'RA, DEC', RA, DEC

		   IF id.plprof_val EQ 11 THEN BEGIN
; get filter	
			  IF mappar.pixsize(0) NE 24. AND mappar.pixsize(1) NE 24. $
			   THEN BEGIN
			     MESSAGE, /INFO, 'This works only with pixsize=[24.,24.]'
			     GOTO, out_here
			  ENDIF
			  srd_admn = mappar.admn
			  STRPUT, srd_admn, 'L', 1
			  find_meas, srd_admn, 'SRD', posisrd, tmp=tmpsrd, error=error
			  IF error THEN BEGIN
			     MESSAGE, /INFO, 'SRD Measurement not found, returning'
			     GOTO, out_here
			  ENDIF
			  
			  indpix = WHERE(mappar.pixselect GT 0, n)
			  
			  IF mappar.detector EQ 'SL' THEN addpix=64 ELSE addpix=0
			  find_meas, mappar.admn, 'AAP', posi, tmp=tmp, error=error
			  IF error THEN BEGIN
			     MESSAGE, /INFO, 'AAP Measurement not found, returning'
			     GOTO, out_here
			  ENDIF

			  rpymax = max(tmp.rpid(0,*))
			  rpxmax = max(tmp.rpid(1,*))
			  rpx = rpxmax - x 
			  rpy = y + 1
			  FOR ipix=0,n-1 DO BEGIN
			    pixel = mappar.pixselect(indpix(ipix)) + addpix
			    ind = WHERE(tmpsrd.rpid(0,*) EQ rpy AND $
			    		tmpsrd.rpid(1,*) EQ rpx, ncount)
			    IF ncount GT 0 THEN BEGIN
			     title="RPID [" + STRTRIM(rpy,2) + "," + $
			     			STRTRIM(rpx,2) +"]"
			     xtitle = "Time within measurement"
			     ytitle = "Signal pixel " + STRTRIM(pixel+1,2)
			     get_sigdisc, tmpsrd, sigdisc
			     pia_xplot, tmpsrd.stim(ind), $
			     		flagged=sigdisc(pixel,ind), $
			     		tmpsrd.slop(pixel,ind), $
			     		tmpsrd.slun(pixel,ind), psym=4, /disc_area, $
					title=title, xtitle=xtitle, ytitle=ytitle
;			     indfl = WHERE(tmpsrd.flag(pixel,ind) GE 2, nfl)
;			     IF nfl GT 0 THEN $
;			      pia_xplot, tmpsrd.stim(ind(indfl)), $
;			      		 tmpsrd.slop(pixel,ind(indfl)), $
;			     		 psym=7, color=red, /overplot
			
				siz= size(all_disc_areas)
				IF siz(0) NE 0 THEN BEGIN 
				
				 FOR I=0,N_ELEMENTS(all_disc_areas)-1 DO BEGIN
				  p1 = all_disc_areas(i).pos1
				  p2 = all_disc_areas(i).pos2
				  IF p1(1) NE 0. or p2(1) NE 0. THEN BEGIN
				     indbad = WHERE(tmpsrd.slop(pixel,ind) GE $
				     	p1(1) AND $
			     		tmpsrd.slop(pixel,ind) LE p2(1) AND $
					tmpsrd.stim(ind) GE p1(0) AND $
					tmpsrd.stim(ind) LE p2(0), ndisc)
				     IF ndisc GT 0 THEN BEGIN
				       tmpsrd.flag(pixel,ind(indbad)) = 4
				     ENDIF
				  ENDIF
				 ENDFOR

				 fill_srd, tmpsrd, replace=posisrd(0) 

				ENDIF				 
			    ENDIF ELSE print, "Nothing in pixel "+ STRTRIM(pixel+1,2)
			  ENDFOR
			  
		   ENDIF ELSE BEGIN   
			  
			
			find_meas, mappar.admn, 'AAP', posi, tmp=tmp, error=error
			IF ERROR THEN RETURN
			difra = ABS(tmp.ra - RA)
			difdec = ABS(tmp.dec - DEC)
			avgnra = avg(difra) / par.msize(0) *2.
			avgndec = avg(difdec) / par.msize(1)*2.
			ind = WHERE(difra LT avgnra AND difdec LT avgndec, n)

			IF n GT 1 THEN BEGIN
			 MESSAGE, /INFO, $
			  ' Confuse case, found '+STRTRIM(n,2) + ' positions'
			 MESSAGE, /INFO, $
			  ' taking medians ... '
			ENDIF
			IF n EQ 0 THEN BEGIN
			PRINT, 'RA, DEC', RA, DEC
			 MESSAGE, /INFO, $
			  ' Confuse case, no points found within the area '
			 MESSAGE, /INFO, $
			  ' Returning '
			 GOTO, out_here
			ENDIF
	
			IF STRMID(mappar.admn,0,2) EQ 'SS' THEN BEGIN
			  wtype = 0
			  admn2='SL'+STRMID(mappar.admn,2,10)
			ENDIF ELSE BEGIN
			  wtype = 1
			  admn2='SS'+STRMID(mappar.admn,2,10)
			ENDELSE
			find_meas, admn2, 'AAP', posi, tmp=tmp2, $
			    error=error
			
			IF id.plprof_val GE 5 AND id.plprof_val LE 8 THEN $
			   case_id=1 $
			ELSE IF id.plprof_val GE 9 AND id.plprof_val LE 10 THEN $
			   case_id=2 ELSE case_id=0
			

			CASE case_id of 
			 1: BEGIN
			 	flux = tmp.mnfl(*,ind)
				unc = tmp.mnfu(*,ind)
			 	flux3 = tmp.mdfl(*,ind)
				flag = tmp.flag(*,ind)
				overplot=0
				IF id.plprof_val EQ 6 or id.plprof_val EQ 8 $
					THEN overplot=99
				type=0
				IF not ERROR THEN BEGIN
				  flux2 = tmp2.mnfl(*,ind)
				  flux4 = tmp2.mdfl(*,ind)
				  unc2 = tmp2.mnfu(*,ind)
				  flag2 = tmp2.flag(*,ind)
				ENDIF
			    END
			 2: BEGIN
			 	flux = tmp.mnbr(*,ind)
			 	flux3 = tmp.mdbr(*,ind)
				flag = tmp.flag(*,ind)
				unc = tmp.mnbu(*,ind)
				overplot=0
				IF id.plprof_val EQ 10  $
					THEN overplot=99
				type=2
				IF not ERROR THEN BEGIN
				  flux2 = tmp2.mnbr(*,ind)
				  flux4 = tmp2.mdbr(*,ind)
				  flag2 = tmp2.flag(*,ind)
				  unc2 = tmp2.mnbr(*,ind)
				ENDIF
			    END
			  
			 ELSE: GOTO, out_here
		 	ENDCASE

			IF N_ELEMENTS(flux(0,*)) GT 1 THEN BEGIN
			 FOR i=0,63 DO BEGIN
			  indok = WHERE(flag(i,*) LE 1, nok)
			  IF nok GT 0 THEN BEGIN
			   flux(i,0) = median([flux(i,indok)])
			   flux3(i,0) = median([flux3(i,indok)])
			   unc(i,0) = SIGMA([unc(i,indok)])
			   flag(i,0) = 0
			  ENDIF ELSE BEGIN
			   flux(i,0) = median([flux(i,*)])
			   flux3(i,0) = median([flux3(i,*)])
			   unc(i,0) = SIGMA([unc(i,*)])
			   flag(i,0) = 2
			  ENDELSE
			 ENDFOR
			 flux=flux(*,0)
			 flux3=flux3(*,0)
			 unc=unc(*,0)
			 flag = flag(*,0)
			ENDIF

			IF not ERROR and N_ELEMENTS(flux2(0,*)) GT 1 THEN BEGIN
			 FOR i=0,63 DO BEGIN
			  indok = WHERE(flag2(i,*) LE 1, nok)
			  IF nok GT 0 THEN BEGIN
			   flux2(i,0) = median([flux2(i,indok)])
			   flux4(i,0) = median([flux4(i,indok)])
			   unc2(i,0) = SIGMA([unc2(i,indok)])
			   flag2(i,0) = 0
			  ENDIF ELSE BEGIN
			   flux2(i,0) = median([flux2(i,*)])
			   flux4(i,0) = median([flux4(i,*)])
			   unc2(i,0) = SIGMA([unc2(i,*)])
			   flag2(i,0) = 2
			  ENDELSE
			 ENDFOR
			 flux2=flux2(*,0)
			 flux4=flux4(*,0)
			 unc2=unc2(*,0)
			 flag2 = flag2(*,0)
			ENDIF
			
			flagged=flag
			flagged2=flag2 
			PIA_plot_spectra, flux, unc, flagged = flagged, $
			      type=type, wtype=wtype, ra=ra, dec=dec, $
			      overplot=overplot

			IF not ERROR THEN $
			   PIA_plot_spectra, flux2, unc2, flagged = flagged2, $
			      type=type, wtype=ABS(wtype-1), ra=ra, dec=dec, $
			      overplot=overplot

			flagged=flag
			flagged2=flag2 

			PIA_plot_spectra, flux3, unc, flagged=flagged, $
			      type=type+3, wtype=wtype, ra=ra, dec=dec, $
			      overplot=0

			IF not ERROR THEN $
			   PIA_plot_spectra, flux4, unc2, flagged=flagged2, $
			      type=type+3, wtype=ABS(wtype-1), ra=ra, dec=dec,$ 
			      overplot=0
		   ENDELSE
		   		
		ENDIF ELSE IF id.plprof_val EQ 20 THEN BEGIN
		   siz = size(map)
		   admndec = mappar.admn_decoded
		   pos = strpos(admndec, '!4l!3m')
		   IF pos NE -1 THEN STRPUT, admndec, 'micron', pos
		   
		   IF x EQ 0 or y EQ 0 or x GE (siz(1)-1) or y GE (siz(2)-1) $
		      THEN BEGIN
		      		MESSAGE, /INFO, $
				 'Extraction from edge not possible, returning'
				id.plprof_val = 0
				GOTO, out_here
		   ENDIF
		    
		   mappi = map(x-1:x+1, y-1:y+1)
		   mappiunc = mapunc(x-1:x+1, y-1:y+1)
		   
		   IF mappar.datatype LT 4 THEN brtype=1 ELSE brtype=0
		   minimap_extr, mappi, mappar, 0, flux, flun, bckfl, bcksig,$
		   	bright=brtype, error=error, mapunc=mappiunc
		   Text = " "
		   IF not ERROR THEN BEGIN
		    Text=[Text, $
		    	  " Results of flux extraction from "+admndec,$
		    	  " ", "Position: RA-" + sra + "   DEC-" + sdec,$
			  " ", $
	"    Using simple extraction - flux in one pixel (only central fpsf) ", $
	"","Flux   : " + STRTRIM(flux,2) + "+/-" + STRTRIM(flun,2)+ " Jy", " ", $
			  "Background: " + STRTRIM(bckfl,2) + " Jy/beam" + $
	"  - Bck. fluctuation (simple sigma): " + STRTRIM(bcksig,2) + " Jy/beam"]
		   ENDIF
		   minimap_extr, mappi, mappar, 1, flux, flun, bckfl, bcksig,$
		   	bright=brtype, error=error1, mapunc=mappiunc
		   IF not ERROR1 THEN BEGIN
		    Text=[Text, $
			  " ", " ", $
	"    Using also psf factors for lateral and diagonal pixels ", $
	"","Flux   : " + STRTRIM(flux,2) + "+/-" + STRTRIM(flun,2)+ " Jy", " ", $
			  "Background: " + STRTRIM(bckfl,2) + " Jy/beam" + $
	"  - Bck. fluctuation (robust sigma): " + STRTRIM(bcksig,2) + " Jy/beam"]
		   ENDIF
		   
		   IF error+error1 LE 1 THEN $
		     PIA_DISP_PRINT_FILE, "", TITLE='Flux extraction', text=text
		     
		     
		   id.plprof_val = 0
		   HANDLE_VALUE, save.hid, id, /set
		   
		ENDIF   
out_here:			
		HANDLE_VALUE, save.hmap, map, /SET, /NO_COPY
		HANDLE_VALUE, save.hmappar, mappar, /SET, /NO_COPY
	ENDIF



	RETURN
	END

; ****************************************************************************
; PIA_ERD2MAP_MAPDRAW_EVENT  -  general event handling routine for PIA_MAPDRAW
; ****************************************************************************

PRO PIA_ERD2MAP_MAPDRAW_EVENT, event

COMMON PIA_PRINT, prt
COMMON pia_mapdraw_scan, scandir
COMMON pia_overlay_str, overlay_str, overl_str_flag

	WIDGET_CONTROL, event.id, GET_UVALUE=action
	WIDGET_CONTROL, event.top, GET_UVALUE=hsave
	HANDLE_VALUE, hsave, save

	CASE action OF

; NaNs  
	'NAN0': BEGIN
	    handle_value, save.hmap, testmap
	    ind = WHERE(finite(testmap) NE 1, nind)
	    IF nind GT 0 THEN BEGIN
	      mapt = testmap
	      mapt(ind) = -1.
	      handle_value, save.hmap, mapt, /set
	      handle_value, hsave, save, /set
	      PIA_ERD2MAP_MAPDRAW_DRAW, hsave
	    ENDIF
	 END
	      
	    


; color table stuff

	'CTAB':	XLOADCT, ncolors=!D.N_COLORS-12, bottom=1
	'CPAL':	XPALETTE
	'CPEN':	XPCOLOR
	'CADJ':	ADJCT
	'CHEQ':	BEGIN
		HANDLE_VALUE, save.hpar, par
		HANDLE_VALUE, save.hmap, map, /NO_COPY
		image = BYTSCL(map, MIN=par.cutmin, MAX=par.cutmax, $
					TOP=!D.N_COLORS-12)
		HANDLE_VALUE, save.hmap, map, /SET, /NO_COPY
		H_EQ_INT, image
		END

; printer definition

	'PDEF':	PIA_PRTDEF, GROUP=event.top

; print plot

	'PPRT_OVERL':	BEGIN
		overl_str = overlay_str
		GOTO, print_plot
	END
; print plot

	'PPRT':	BEGIN
		overl_str = 0
print_plot:
		WIDGET_CONTROL, event.top, /HOURGLASS

		; ask for printer device if necessary
		IF N_ELEMENTS(prt) EQ 0 THEN PIA_PRTDEF
		IF N_ELEMENTS(prt) EQ 0 THEN RETURN
		IF prt.device EQ "" THEN PIA_PRTDEF
		IF prt.device EQ "" THEN RETURN

		; save present device before changing
		this_device = !D.NAME
		SET_PLOT, prt.device, COPY=prt.copy, INTERPOL=prt.interpolate
		; put together the device command
		cmd = "DEVICE"
		IF prt.filename NE "" THEN BEGIN
			filename = prt.filename
			cmd = cmd + ", FILENAME=" + "'"+ filename + "'"
		ENDIF ELSE BEGIN
			filename = STRLOWCASE("idl."+!D.NAME)
		ENDELSE
		IF prt.keys NE "" THEN cmd = cmd + prt.keys
		IF cmd NE "DEVICE" THEN BEGIN
		   IF NOT EXECUTE(cmd) THEN BEGIN
		      MESSAGE, /INFO, "Could not set-up device: check keywords"
		      RETURN
		   ENDIF
		ENDIF

		; smaller character size for printout than on screen
		IF !P.CHARSIZE EQ 0. THEN !P.charsize = 1.
		orig_charsize = !P.CHARSIZE
		!P.CHARSIZE = !P.CHARSIZE * 0.8

		; generate image
		PIA_ERD2MAP_MAPDRAW_DRAW, hsave, overl_str=overl_str
       		plot_id

		; reset character size
		!P.CHARSIZE = orig_charsize

		; close plot and reset device
		DEVICE, /CLOSE
		SET_PLOT, this_device

		; send printfile to printer
		IF prt.print AND prt.command NE "" THEN BEGIN
			cmd = prt.command + " " + filename
			SPAWN, cmd
		ENDIF
		END

	'PPRT_SIMPLE':	BEGIN
		WIDGET_CONTROL, event.top, /HOURGLASS

		; ask for printer device if necessary
		IF N_ELEMENTS(prt) EQ 0 THEN PIA_PRTDEF
		IF N_ELEMENTS(prt) EQ 0 THEN RETURN
		IF prt.device EQ "" THEN PIA_PRTDEF
		IF prt.device EQ "" THEN RETURN

		; save present device before changing
		this_device = !D.NAME
		
		; take image from DISPLAY - change white in black and vv
		TVim = TVRD()
		indb = WHERE(tvim EQ 0, nb)
		indw = WHERE(tvim EQ (!D.n_colors - 1), nw)
		IF nb GT 0 THEN TVim(indb) = !D.n_colors - 1 
		IF nw GT 0 THEN TVim(indw) = 0
		
		
		SET_PLOT, prt.device, COPY=prt.copy, INTERPOL=prt.interpolate
		; put together the device command
		cmd = "DEVICE"
		IF prt.filename NE "" THEN BEGIN
			filename = prt.filename
			cmd = cmd + ", FILENAME=" + "'"+ filename + "'"
		ENDIF ELSE BEGIN
			filename = STRLOWCASE("idl."+!D.NAME)
		ENDELSE
		IF prt.keys NE "" THEN cmd = cmd + prt.keys
		IF cmd NE "DEVICE" THEN BEGIN
		   IF NOT EXECUTE(cmd) THEN BEGIN
		      MESSAGE, /INFO, "Could not set-up device: check keywords"
		      RETURN
		   ENDIF
		ENDIF

		; smaller character size for printout than on screen
		IF !P.CHARSIZE EQ 0. THEN !P.charsize = 1.
		orig_charsize = !P.CHARSIZE
		!P.CHARSIZE = !P.CHARSIZE * 0.8


		TV, TVim
       		plot_id

		; reset character size
		!P.CHARSIZE = orig_charsize

		; close plot and reset device
		DEVICE, /CLOSE
		SET_PLOT, this_device

		; send printfile to printer
		IF prt.print AND prt.command NE "" THEN BEGIN
			cmd = prt.command + " " + filename
			SPAWN, cmd
		ENDIF
		END

; save file stuff, WMT
	'SFIT': BEGIN
		handle_value, save.hmappar, tmappar
		handle_value, save.hmap, tmap
		handle_value, save.hpar, tpar
		tfile = tmappar.admn + 'M.FITS'
		filename = pia_pickfile(path=!intdir, file=tfile, $
		  group=event.top, $
		  filter='*M.FITS', get_path = newpath, /write, /overwrite)
		if filename NE '' then begin
		  write_map, filename, tmap, tpar.hdr, tmappar
		endif
		;save path name
		!INTDIR = newpath
		END

; save file stuff, WMT
	'SINT': BEGIN
		handle_value, save.hmappar, imappar
		handle_value, save.hmap, imap
		handle_value, save.hmapunc, imapunc
		handle_value, save.hpar, tpar
		imaphdr = tpar.hdr
		imap_type = tpar.map_type
        	CASE imap_type of
            	  0: begin
			tfile=imappar.admn+'.IMAP'
			filter = '*.IMAP'
		     end
          	  1: begin
			tfile=imappar.admn+'.IMAP_UNC'
			filter = '*.IMAP_UNC'
		     end
          	  2: begin
			tfile=imappar.admn+'.IMAP_EXP'
			filter = '*.IMAP_EXP'
		     end
        	  ELSE:
        	ENDCASE

		filename = pia_pickfile(path=!intdir, file=tfile, $
		  group=event.top, $
		  filter=filter, get_path = pathvar, /write, /overwrite)
		if filename NE '' then begin
;		  if pathvar NE '' then filename = pathvar + filename
		   SAVE, imap, imappar , imaphdr, imap_type, $
                     FILENAME=filename, /XDR
		IF imap_type EQ 0 THEN $
		  IF N_ELEMENTS(imapunc) NE 0 THEN BEGIN
		    imap = imapunc
		    imap_type = 1
		    SAVE, imap, imappar , imaphdr, imap_type, $
                     FILENAME=filename+"_UNC", /XDR
		    MESSAGE, /INFO, $
		     'Uncertainty map saved under ' + filename+"_UNC"
		   ENDIF
		    
		   !INTDIR = pathvar
		endif
		END

; save file stuff, WMT
	'SGIF': BEGIN
		handle_value, save.hpar, tpar
		WSET, tpar.window
		handle_value, save.hmappar, tmppar
		tfile = tmppar.admn + '.GIF'
		filename = pia_pickfile(path=!intdir, file=tfile, $
		  group=event.top, $
		  filter='*.GIF', get_path = pathvar, /write, /overwrite)
		if filename NE '' then begin
;		  if pathvar NE '' then filename = pathvar + filename
		  TVLCT, rrr, ggg, vvv, /GET
		  tv_image = tvrd()
		  write_gif, filename, tv_image, rrr,ggg,vvv
		  !INTDIR = pathvar
		endif
		END

; customization

	'CUST':	BEGIN
		PIA_ERD2MAP_MAPDRAW_CUST, hsave, GROUP=event.top, REDRAW=redraw
		IF redraw THEN PIA_ERD2MAP_MAPDRAW_DRAW, hsave
		END

; redraw map

	'RDRW':	BEGIN
		WIDGET_CONTROL, event.top, /HOURGLASS
		PIA_ERD2MAP_MAPDRAW_DRAW, hsave
		END
; smooth map

	'SMOOTH': BEGIN
		handle_value, save.hmappar, imappar
		handle_value, save.hmap, imap
		handle_value, save.hpar, tpar
		imaphdr = tpar.hdr
		smap = smooth(imap, 3, /edge_truncate)
		FXADDPAR, imaphdr, 'PRM_SMOO', 1, $
		  ' Original map smoothed - win=3 - edge_trunc', $
		  BEFORE='XTENSION'
		PIA_ERD2MAP_MAPDRAW, smap, imappar.trans, imappar, imaphdr, 0, $
		  TITLE='Smoothed map - '+imappar.admn_decoded, $
		  HEADLINE= 'Smoothed map - '+imappar.admn_decoded
		END

; deconvolve map 
	'DECONV': BEGIN
		handle_value, save.hmappar, imappar
		handle_value, save.hmap, imap
		handle_value, save.hpar, tpar
		imaphdr = tpar.hdr
		PIA_DECONV, imap, imappar, imaphdr, dec_imap
		END		

; convolve map 
	'CONV': BEGIN
		handle_value, save.hmappar, imappar
		handle_value, save.hmap, imap
		handle_value, save.hpar, tpar
		imaphdr = tpar.hdr
		PIA_CONVOLVE, imap, imappar, imaphdr
		END		

; convolve map 
	'CONV_SCAN': BEGIN
		handle_value, save.hmappar, imappar
		handle_value, save.hmap, imap
		handle_value, save.hpar, tpar
		imaphdr = tpar.hdr
		PIA_CONVOLVE, imap, imappar, imaphdr, /scan
		END		

; rotate map 
	'ROTATE': BEGIN
		handle_value, save.hmappar, imappar
		handle_value, save.hmap, imap
		handle_value, save.hpar, tpar
		imaphdr = tpar.hdr
		PIA_MAP_ROTATE, imap, imappar, imaphdr
		END		

; overlay image
	'OVERLAY': BEGIN
		handle_value, save.hpar, act_par
		handle_value, save.hmappar, act_imappar
		handle_value, save.hmap, act_imap
        	filename = pia_pickfile(path=!xdrdir, filter="*.IMAP*", $
        	  /read, /must_exist, get_path = newpath, group=event.top)
		IF filename NE '' THEN BEGIN
		 restore, filename
		
		 IF ABS(imappar.rota-act_imappar.rota) GT 0.001 THEN BEGIN
;print, imappar.rota, act_imappar.rota
		  MESSAGE, /INFO, 'Overlay map has a different roll angle as the displayed map'
		  MESSAGE, /INFO, ' Rotating the overlay map using default values'

		  rot_ang = act_imappar.rota
		  sz = size(imap)
		  nx = sz(1)
		  ny = sz(2)
		  pixadd = max([nx,ny]) / 5 > 4

		  newmap = fltarr(nx+2*pixadd,ny+2*pixadd)
		  newmap(pixadd:nx+pixadd-1,pixadd:ny+pixadd-1) = imap
		  imap = newmap
		  imappar.trans.crpix = imappar.trans.crpix + [pixadd,pixadd]
		  trans = PIA_MKTRANS([imappar.trans_ra, imappar.trans_dec], $
			imappar.trans.crpix,  imappar.pixsize, rot_ang)
		  newmap = rot(imap, -imappar.rota + rot_ang, 1., $
                	trans.crpix(0),trans.crpix(1),/pivot, $
                	interp=1)
		  imappar.trans = trans
		  imappar.rota = rot_ang
		  imap = newmap

;		  pia_xy2rd, trans.crpix(0), trans.crpix(1), $
;		     trans, lon, lat
;		  pia_xy2rd, trans.crpix(0)+1, trans.crpix(1), $
;		     trans, lon1, lat1
;	  	  pia_xy2rd, trans.crpix(0), trans.crpix(1)+1, $
;		     trans, lon2, lat2
;		   
;		  radec, ABS(lon-lon1), ABS(lat-lat1), hr,hm,hs,dr,dm,ds
;		  difh = hm* 60. + hs
;		  difd = dm* 60. + ds
;		  difx = SQRT((difh*15.*cos(lat*2*!PI/360.)) ^2 + difd^2)
;		  radec, ABS(lon-lon2), ABS(lat-lat2), hr,hm,hs,dr,dm,ds
;		  difh = hm* 60. + hs
;		  difd = dm* 60. + ds
;		  dify = SQRT((difh*15.*cos(lat*2*!PI/360.)) ^2 + difd^2)
;		  
;		  print, difx, dify
;		  imappar.pixsize = [difx,dify]

		 ENDIF
		
		act_size = size(act_imap)
		o_size = size(imap)
		
		pix_act = act_imappar.pixsize
		pix_o = imappar.pixsize 
 		factor = pix_o / pix_act
		nsize = ROUND(o_size(1:2) * factor)
		
		new_map = congrid(imap, nsize(0), nsize(1))
		
		cpix = ROUND(fix(imappar.trans.crpix + 0.5) * factor)

		PIA_RD2XY, imappar.trans_ra, imappar.trans_dec, act_imappar.trans, xx, yy
		xx = round(xx)   & yy = round(yy)
;		xx = FIX(xx)   & yy = FIX(yy)
		
;	        IF xx GE 0 AND xx LT act_size(1) AND $
;	   	   yy GE 0 AND yy LT act_size(2) THEN BEGIN

		  difer = [xx,yy] - cpix 
		  
		  trans_map = act_imap * 0.
		  
		  beg_map = difer > [0,0]
		  end_map = difer + (nsize -1) < (act_size(1:2) - 1)
		  
		  all_x = indgen(nsize(0)) + difer(0)
		  all_y = indgen(nsize(1)) + difer(1)
		  
		  x_ind = WHERE(all_x GE 0 AND all_x LE end_map(0), n_indx)
		  y_ind = WHERE(all_y GE 0 AND all_y LE end_map(1), n_indy)

		  IF n_indx GT 0 AND n_indy GT 0 THEN BEGIN
		    
		    max_x_ind = max(x_ind)
		  
		    trans_map(beg_map(0):end_map(0),beg_map(1):end_map(1)) = $
		      new_map(x_ind(0):max(x_ind), y_ind(0):max(y_ind)) 
		
		    overl_str = {name:dec_admn(imappar.admn), map:trans_map, $
		    		text:''}
		    PIA_ERD2MAP_MAPDRAW_DRAW, hsave, overl_str=overl_str
		    overl_str_flag = 1
		    overlay_str = overl_str
		    
		  ENDIF ELSE PRINT, 'Impossible - overlay image fully outside the map '
		 ENDIF
		END  
		  
; zoom part of the image

	'ZOOM':	BEGIN
		HANDLE_VALUE, save.hpar, par
		wset, par.window
		ZOOM, CONTINUOUS=par.zoomcont
		END

; 3D-Surface map

	'SURFACE':BEGIN
		HANDLE_VALUE, save.hpar, par
		HANDLE_VALUE, save.hmap, map
		IF par.contour or par.overcont THEN BEGIN
	  	  levels = par.cutmin+findgen(par.contlvls)* $
	  		(par.cutmax-par.cutmin)/par.contlvls 
	  	  contours=1
	  	ENDIF ELSE BEGIN
		  contours=0
	  	  levels=-1.
	  	ENDELSE
			 
		PIA_XSURFACE, map, title=par.headline, contours=contours, $
			clevels=levels
		END

	'SURLEGO':BEGIN
		HANDLE_VALUE, save.hpar, par
		HANDLE_VALUE, save.hmap, map
		IF par.contour or par.overcont THEN BEGIN
	  	  levels = par.cutmin+findgen(par.contlvls)* $
	  		(par.cutmax-par.cutmin)/par.contlvls 
	  	  contours=1
	  	ENDIF ELSE BEGIN
		  contours=0
	  	  levels=-1.
	  	ENDELSE
			 
		PIA_XSURFACE, map, title=par.headline, contours=contours, $
			clevels=levels, /wlego
		END
; find point sources

	'FIND':	BEGIN
		HANDLE_VALUE, save.hpar, par
		HANDLE_VALUE, save.hmap, map
		PIA_source_search, map, par.trans, xout, yout, findflag, $
			measname=par.headline
		END

; draw profiles of image

	'PROF':	BEGIN
;		PIA_DISP_PRINT_FILE, '', width=40, height=15,$
		xdisplayfile, '', width=40, height=15,$
		  TITLE='PIA informing', $
		  TEXT=['The profiles facility draws row',$
		        'or column profiles interactively', $
			'in a separate window. ', 'Use: ', $
			'Left mouse button to toggle ',$
			'between rows and columns. ',$
			'Right mouse button to Exit.',$
			' ', $
			'To get static profile plots which',$
			'can be saved, sent to the printer,',$
			'overplotted, etc, please make use', $
			'of the bottom right menu in the',$
			'composed maps drawing window']  
	
		HANDLE_VALUE, save.hpar, par
		HANDLE_VALUE, save.hmap, map, /NO_COPY
		image = CONGRID( map, par.area(2)-par.area(0), $
				par.area(3)-par.area(1), INTERP=par.interp )
		HANDLE_VALUE, save.hmap, map, /SET, /NO_COPY
		PROFILES, image, SX=par.area(0), SY=par.area(1)
		END

; Show the fits header
	'SHDR': BEGIN
		HANDLE_VALUE, save.hpar, par
		admn = fxpar(par.hdr, 'FILENAME')
		PIA_DISP_HDR, par.hdr, admn, 'MAP'
		END

; Show the parameters
	'SHPAR': BEGIN
		HANDLE_VALUE, save.hmappar, mappar
		parnames = tag_names(mappar)
		text=''
		FOR i=0,N_ELEMENTS(parnames)-1 DO BEGIN
		 siz = size(mappar.(i))
		 IF siz(2) NE 8 THEN $
		  text= [text, parnames(i) + ':     ' + STRTRIM(mappar.(i),2)]
		ENDFOR
		PIA_DISP_PRINT_FILE, '',$
		 TITLE='Map parameters', text=text
	        END

; Set no profile plotting
	'NOPLPROF': BEGIN
		HANDLE_VALUE, save.hid, id
		WIDGET_CONTROL, id.plprof, SET_VALUE='Plot profile disabled'
		id.plprof_val = 0
		HANDLE_VALUE, save.hid, id, /set
		HANDLE_VALUE, hsave, save, /SET
	END

; Set profile plotting
	'PLPROF': BEGIN
		scandir = 0
		HANDLE_VALUE, save.hid, id
		WIDGET_CONTROL, id.plprof, SET_VALUE='  Plot x-profile     '
		id.plprof_val = 1
		HANDLE_VALUE, save.hid, id, /set
		HANDLE_VALUE, hsave, save, /SET
		
	END

; Set profile overplotting
	'OPLPROF': BEGIN
		scandir = 0
		HANDLE_VALUE, save.hid, id
		WIDGET_CONTROL, id.plprof, SET_VALUE=' OverPlot x-profile  '
		id.plprof_val = 3
		HANDLE_VALUE, save.hid, id, /set
		HANDLE_VALUE, hsave, save, /SET
	END
; Set profile plotting
	'B_PLPROF': BEGIN
		scandir = 0
		HANDLE_VALUE, save.hid, id
		WIDGET_CONTROL, id.plprof, SET_VALUE='Norm(prof. - bckgr) x'
		id.plprof_val = 2
		HANDLE_VALUE, save.hid, id, /set
		HANDLE_VALUE, hsave, save, /SET
		
	END

; Set profile overplotting
	'B_OPLPROF': BEGIN
		scandir = 0
		HANDLE_VALUE, save.hid, id
		WIDGET_CONTROL, id.plprof, SET_VALUE='Oplot Norm(pr-bck)  x'
		id.plprof_val = 4
		HANDLE_VALUE, save.hid, id, /set
		HANDLE_VALUE, hsave, save, /SET
	END
; Set profile plotting
	'YPLPROF': BEGIN
		scandir = 1
		HANDLE_VALUE, save.hid, id
		WIDGET_CONTROL, id.plprof, SET_VALUE='  Plot y-profile     '
		id.plprof_val = 1
		HANDLE_VALUE, save.hid, id, /set
		HANDLE_VALUE, hsave, save, /SET
		
	END

; Set profile overplotting
	'YOPLPROF': BEGIN
		scandir = 1
		HANDLE_VALUE, save.hid, id
		WIDGET_CONTROL, id.plprof, SET_VALUE=' OverPlot y-profile  '
		id.plprof_val = 3
		HANDLE_VALUE, save.hid, id, /set
		HANDLE_VALUE, hsave, save, /SET
	END
; Set profile plotting
	'YB_PLPROF': BEGIN
		scandir = 1
		HANDLE_VALUE, save.hid, id
		WIDGET_CONTROL, id.plprof, SET_VALUE='Norm(prof. - bckgr) y'
		id.plprof_val = 2
		HANDLE_VALUE, save.hid, id, /set
		HANDLE_VALUE, hsave, save, /SET
		
	END

; Set profile overplotting
	'YB_OPLPROF': BEGIN
		scandir = 1
		HANDLE_VALUE, save.hid, id
		WIDGET_CONTROL, id.plprof, SET_VALUE='Oplot Norm(pr-bck)  y'
		id.plprof_val = 4
		HANDLE_VALUE, save.hid, id, /set
		HANDLE_VALUE, hsave, save, /SET
	END
; Set signals plotting
	'B_PLSSIG': BEGIN
		HANDLE_VALUE, save.hid, id
		WIDGET_CONTROL, id.plprof, SET_VALUE='Plot SRD signals'
		id.plprof_val = 11
		HANDLE_VALUE, save.hid, id, /set
		HANDLE_VALUE, hsave, save, /SET
	END
; Set spectrum plotting
	'B_PLSPEC': BEGIN
		HANDLE_VALUE, save.hid, id
		WIDGET_CONTROL, id.plprof, SET_VALUE='Plot F_nu'
		id.plprof_val = 5
		HANDLE_VALUE, save.hid, id, /set
		HANDLE_VALUE, hsave, save, /SET
	END
; Set spectrum overplotting
	'B_OPLSPEC': BEGIN
		HANDLE_VALUE, save.hid, id
		WIDGET_CONTROL, id.plprof, SET_VALUE='OverPlot F_nu'
		id.plprof_val = 6
		HANDLE_VALUE, save.hid, id, /set
		HANDLE_VALUE, hsave, save, /SET
	END
; Set spectrum plotting
	'B_PLFSPEC': BEGIN
		HANDLE_VALUE, save.hid, id
		WIDGET_CONTROL, id.plprof, SET_VALUE='Plot F_lambda'
		id.plprof_val = 7
		HANDLE_VALUE, save.hid, id, /set
		HANDLE_VALUE, hsave, save, /SET
	END
; Set spectrum overplotting
	'B_OPLFSPEC': BEGIN
		HANDLE_VALUE, save.hid, id
		WIDGET_CONTROL, id.plprof, SET_VALUE='OverPlot F_lambda'
		id.plprof_val = 8
		HANDLE_VALUE, save.hid, id, /set
		HANDLE_VALUE, hsave, save, /SET
	END
; Set spectrum plotting
	'B_PLBRIG': BEGIN
		HANDLE_VALUE, save.hid, id
		WIDGET_CONTROL, id.plprof, SET_VALUE='Plot Surf.Bright.'
		id.plprof_val = 9
		HANDLE_VALUE, save.hid, id, /set
		HANDLE_VALUE, hsave, save, /SET
	END
; Set spectrum overplotting
	'B_PLOBRIG': BEGIN
		HANDLE_VALUE, save.hid, id
		WIDGET_CONTROL, id.plprof, SET_VALUE='OverPlot Surf.Br.'
		id.plprof_val = 10
		HANDLE_VALUE, save.hid, id, /set
		HANDLE_VALUE, hsave, save, /SET
	END
	
	'EXT_FLUX': BEGIN
		HANDLE_VALUE, save.hid, id
		id.plprof_val = 20
		PRINT, 'Press left mouse button	on desired position'	
		HANDLE_VALUE, save.hid, id, /set
		HANDLE_VALUE, hsave, save, /SET
	END				


; quit application

	'QUIT':	WIDGET_CONTROL, event.top, /DESTROY

	ELSE:
	ENDCASE

	RETURN
	END

; ****************************************************************************
; PIA_ERD2MAP_MAPDRAW  -  main routine
; ****************************************************************************

PRO PIA_ERD2MAP_MAPDRAW, map, trans, mappar, header, map_type, TITLE=title, GROUP=group, $
		HEADLINE=headline, NO_ROT=no_rot, NO_DECONV=no_DECONV, $
		SIMPLE = simple, NO_GRID=no_grid, NO_print=no_print, $
		MAPUNC=mapunc

COMMON pia_overlay_str, overlay_str, overl_str_flag


; check arguments
	overl_str_flag = 0
	nelem_map = N_ELEMENTS(map)
	IF nelem_map EQ 0 THEN GOTO, err_input
	size_map = SIZE(map)
	IF size_map(0) EQ 1 THEN BEGIN
	 MESSAGE, /INFO, $
	   'Redefine the image pixel size for obtaining two dimensions, please. '
	 MESSAGE, /INFO, $
	   'For instance dividing the pixel size by two. Returning ...'
	 RETURN
	ENDIF
	
	IF size_map(0) NE 2 THEN GOTO, err_input
	IF N_ELEMENTS(trans) EQ 0 THEN GOTO, err_input
;	IF N_ELEMENTS(pixsize) NE 2 THEN GOTO, err_input
	IF KEYWORD_SET(simple) THEN simple=1 ELSE simple=0
	IF KEYWORD_SET(no_grid) THEN grid=0 ELSE grid=1


; get map uncertainty if not as input keyword
	IF map_type EQ 0 THEN BEGIN
	  IF not KEYWORD_SET(mapunc) THEN BEGIN
	  	int_noise = get_map_noise(map)
		mapunc = map * 0. + int_noise
		MESSAGE, /INFO, $
		 'Warning: Map uncertainties calculated from "intrinsic noise"'
	  ENDIF 
	ENDIF ELSE mapunc = map*0.  

; define and initialize program parameters

	id = { ra:0L, dec:0L, value:0L, plprof:0L, plprof_val:0 }

	par = { $
		hdr: header, $			; aap fits header
		map_type: map_type, $		; map type, {0, 1, 2}
		; for brightness, uncertainty and exposure
		trans:trans, $			; transformation parameters
		pixsize:[0.,0.], $		; map pixel size in arcsec
		msize:[0,0], $			; map size (# pixels)
		wsize:[600,500], $		; total window size
		area:[0,0,0,0], $		; actual drawing area
		scale:[0.,0.], $		; scale factor
		grid:grid, $			; drawing grid flag
		ngrid:6, $			; approx # grid lines
		interp:0, $			; interpolation flag
		zoomcont:0, $			; continuous zoom flag
		lcut:1, $			; low cut action
		hcut:1, $			; high cut action
		lcval:0., $			; user low cut value
		hcval:0., $			; user high cut value
		cutmin:0., $			; actual low cut value
		cutmax:0., $			; actual high cut value
		window:0L, $			; draw window number
		headline:'', $			; the headline (plot title)
		contour:0, $			; contour instead of map
		overcont:0, $			; map + contour
		contlvls:0, $			; number of contour levels
		contthic:0., $			; thickness  of contour
		surfcont:0, $			; surface + contour
		aspectratio:0., $		; aspect ratio
		simple:simple $			; simple map flag
	}
	par.msize = size_map(1:2)
	par.pixsize = mappar.pixsize
	par.contlvls = 10
	par.contthic = 1.

; check for the existence of a hdr file and use its contents
	IF is_file_exist(!INTDIR+'parhdr.txt') THEN BEGIN
	 junk = read_ascii(!INTDIR+"parhdr.txt", data_start=15,header=parhdr)
	 res = FXPAR(parhdr,"INTERP", count=count)
	 IF count GT 0 THEN par.interp = res
	 res = FXPAR(parhdr,"LCUT", count=count)
	 IF count GT 0 THEN par.lcut = res
	 res = FXPAR(parhdr,"HCUT", count=count)
	 IF count GT 0 THEN par.hcut = res
	 res = FXPAR(parhdr,"LCVAL", count=count)
	 IF count GT 0 THEN par.lcval = res
	 res = FXPAR(parhdr,"HCVAL", count=count)
	 IF count GT 0 THEN par.hcval = res
	 res = FXPAR(parhdr,"CONTOUR", count=count)
	 IF count GT 0 THEN par.contour = res
	 res = FXPAR(parhdr,"OVERCONT", count=count)
	 IF count GT 0 THEN par.overcont = res
	 res = FXPAR(parhdr,"CONTLVLS", count=count)
	 IF count GT 0 THEN par.contlvls = res
	 res = FXPAR(parhdr,"CONTTHIC", count=count)
	 IF count GT 0 THEN par.contthic = res
	 res = FXPAR(parhdr,"GRID", count=count)
	 IF count GT 0 THEN par.grid = res
	 res = FXPAR(parhdr,"NGRID", count=count)
	 IF count GT 0 THEN par.ngrid = res
	ENDIF 

	IF N_ELEMENTS(title) EQ 0 THEN title="Map"
	IF N_ELEMENTS(headline) EQ 0 THEN par.headline = '' $
	ELSE par.headline = headline

; set up widget hierarchy

	id_base = WIDGET_BASE( TITLE=title, /ROW )

	id_left = WIDGET_BASE( id_base, /COLUMN )

	id_0 = WIDGET_BUTTON( id_left, VAL="   Colours...     ", /MENU )
	id_1 = WIDGET_BUTTON( id_0, VAL="Load Color Table...", UVA="CTAB" )
	id_1 = WIDGET_BUTTON( id_0, VAL="Define Color Palette...", UVA="CPAL" )
	id_1 = WIDGET_BUTTON( id_0, VAL="Define Plot Color...", UVA="CPEN" )
	id_1 = WIDGET_BUTTON( id_0, VAL="Adjust Color Table...", UVA="CADJ" )
	id_1 = WIDGET_BUTTON( id_0, VAL="Hist Eq Color Table...", UVA="CTAB" )

	id_0 = WIDGET_BUTTON( id_left, VAL="   Printer...     ", /MENU )
	id_1 = WIDGET_BUTTON( id_0, VAL="Define printer", UVA="PDEF" )
	id_1 = WIDGET_BUTTON( id_0, VAL="Print image", UVA="PPRT" )
	IF KEYWORD_SET(NO_PRINT) THEN WIDGET_CONTROL, id_1, sensitive=0
	id_1 = WIDGET_BUTTON( id_0, VAL="... + overlay", UVA="PPRT_OVERL" )
	IF KEYWORD_SET(NO_PRINT) THEN WIDGET_CONTROL, id_1, sensitive=0
	id_1 = WIDGET_BUTTON( id_0, VAL="Simple print display", $
			UVA="PPRT_SIMPLE" )

	id_0 = WIDGET_BUTTON( id_left, VAL="   Save Map...    ", /MENU )
	id_1 = WIDGET_BUTTON( id_0, VAL="To Internal file", UVA="SINT" )
	id_1 = WIDGET_BUTTON( id_0, VAL="To FITS file", UVA="SFIT" )
	id_1 = WIDGET_BUTTON( id_0, VAL="To GIF file", UVA="SGIF" )

	id_0 = WIDGET_BUTTON( id_left, VAL="Custom", UVA="CUST" )
	id_0 = WIDGET_BUTTON( id_left, VAL="Redraw", UVA="RDRW" )
	id_0 = WIDGET_BUTTON( id_left, VAL="Smooth map", UVA="SMOOTH")
	id_0 = WIDGET_BUTTON( id_left, VAL="Deconvolve", UVA="DECONV") 
	IF KEYWORD_SET(no_deconv) THEN WIDGET_CONTROL, id_0, SENSITIVE=0
	id_0 = WIDGET_BUTTON( id_left, VAL="   Convolve...    ", /MENU) 
	id_1 = WIDGET_BUTTON( id_0, VAL=" full map ",UVA="CONV" )
	id_1 = WIDGET_BUTTON( id_0, VAL="   scan   ",UVA="CONV_SCAN" )
	id_0 = WIDGET_BUTTON( id_left, VAL="Rotate", UVA="ROTATE") 
	IF KEYWORD_SET(no_rot) THEN WIDGET_CONTROL, id_0, SENSITIVE=0
	id_0 = WIDGET_BUTTON( id_left, VAL="Overlay", UVA="OVERLAY") 
	id_0 = WIDGET_BUTTON( id_left, VAL="Zoom", UVA="ZOOM" )
	id_0 = WIDGET_BUTTON( id_left, VAL="Surface", UVA="SURFACE" )
	id_0 = WIDGET_BUTTON( id_left, VAL="Surface (lego)", UVA="SURLEGO" )
;	id_0 = WIDGET_BUTTON( id_left, VAL="Find Point Sources", UVA="FIND" )
	id_0 = WIDGET_BUTTON( id_left, VAL="Profiles", UVA="PROF" )
	id_0 = WIDGET_BUTTON( id_left, VAL="Show Header", UVA="SHDR" )
	id_0 = WIDGET_BUTTON( id_left, VAL="Map Parameters", UVA="SHPAR" )
	id_0 = WIDGET_BUTTON( id_left, VAL="NaN's -> 0.", UVA="NAN0" )
	id_0 = WIDGET_BUTTON( id_left, VAL="Extract flux", UVA="EXT_FLUX")
	IF map_type NE 0 THEN WIDGET_CONTROL, id_0, sensitive=0
	id_0 = WIDGET_BUTTON( id_left, VAL="Quit", UVA="QUIT" )

	id_right = WIDGET_BASE( id_base, /COLUMN )
; add retain = 2 for IDL to handle its own backing store.
	id_draw = WIDGET_DRAW( id_right, $
			XSIZE=par.wsize(0), YSIZE=par.wsize(1), $
			/BUTTON_EVENTS, EVENT_PRO="PIA_ERD2MAP_MAPDRAW_DREV" ,$
			retain = 2)

	id_0 = WIDGET_BASE( id_right, /ROW )
	id_1 = WIDGET_LABEL( id_0, VAL="RA:" )
	id.ra = WIDGET_TEXT( id_0, XSIZE=14 )
	id_1 = WIDGET_LABEL( id_0, VAL="DEC:" )
	id.dec = WIDGET_TEXT( id_0, XSIZE=14 )
	id_1 = WIDGET_LABEL( id_0, VAL="VAL:" )
	id.value = WIDGET_TEXT( id_0, XSIZE=14 )
	id_1 = WIDGET_LABEL( id_0, VAL="  " )
	id.plprof = WIDGET_BUTTON(id_0, VAL='Plot profile disabled', /MENU)
	id.plprof_val = 0
	id_2 = WIDGET_BUTTON(id.plprof,VAL='Plot profile disabled', $
			UVAL='NOPLPROF')
	id_2 = WIDGET_BUTTON(id.plprof,VAL='Plot profile - xscan ', /MENU)
	id_3 = WIDGET_BUTTON(id_2,VAL='  Plot x-profile     ', UVAL='PLPROF')
	id_3 = WIDGET_BUTTON(id_2,VAL=' OverPlot x-profile  ', UVAL='OPLPROF')
	id_3 = WIDGET_BUTTON(id_2,VAL='Norm(prof. - bckgr) x', UVAL='B_PLPROF')
	id_3 = WIDGET_BUTTON(id_2,VAL='Oplot Norm(pr-bck)  x', UVAL='B_OPLPROF')
	id_2 = WIDGET_BUTTON(id.plprof,VAL='Plot profile - yscan ', /MENU)
	id_3 = WIDGET_BUTTON(id_2,VAL='  Plot y-profile     ', UVAL='YPLPROF')
	id_3 = WIDGET_BUTTON(id_2,VAL=' OverPlot y-profile  ', UVAL='YOPLPROF')
	id_3 = WIDGET_BUTTON(id_2,VAL='Norm(prof. - bckgr) y', UVAL='YB_PLPROF')
	id_3 = WIDGET_BUTTON(id_2,VAL='Oplot Norm(pr-bck)  y', UVAL='YB_OPLPROF')
	id_2 = WIDGET_BUTTON(id.plprof,VAL='    PHT-S Spectra    ', /MENU)
	id_3 = WIDGET_BUTTON(id_2,     VAL='Plot underlying signals ', $
					UVAL='B_PLSSIG')
	id_3 = WIDGET_BUTTON(id_2,     VAL='Plot F_nu FluxDensity ', UVAL='B_PLSPEC')
	id_3 = WIDGET_BUTTON(id_2,     VAL='OverPlot F_nu Flux    ', UVAL='B_OPLSPEC')
	id_3 = WIDGET_BUTTON(id_2,     VAL=' Plot F_lambda Flux   ', UVAL='B_PLFSPEC')
	id_3 = WIDGET_BUTTON(id_2,     VAL='OverPlot F_lambda Flux', UVAL='B_OPLFSPEC')
	id_3 = WIDGET_BUTTON(id_2,     VAL=' Plot Brightness Surf.', UVAL='B_PLBRIG')
	id_3 = WIDGET_BUTTON(id_2,     VAL='OverPlot Brightness S.', UVAL='B_OPLBRIG')
	IF STRMID(mappar.admn,0,1) NE 'S' THEN WIDGET_CONTROL, id_2, sensitive=0

; realize widget

	WIDGET_CONTROL, id_base, /REALIZE
	WIDGET_CONTROL, id_draw, GET_VALUE=window
	par.window = window				; the window number

; save program parameters

	hsave = HANDLE_CREATE()
	hid = HANDLE_CREATE( hsave, VALUE=id )
	hpar = HANDLE_CREATE( hsave, VALUE=par )
	hmap = HANDLE_CREATE( hsave, VALUE=map )	; keep an own copy
	hmapunc = HANDLE_CREATE( hsave, VALUE=mapunc )	; keep an own copy
; added by WMT for the file output
	hmappar = HANDLE_CREATE( hsave, VALUE=mappar )	; keep an own copy
	save = { hid:hid, hpar:hpar, hmap:hmap, hmappar:hmappar, $
		hmapunc:hmapunc}
	HANDLE_VALUE, hsave, save, /SET, /NO_COPY
	WIDGET_CONTROL, id_base, SET_UVALUE=hsave

; draw the map before managing

	PIA_ERD2MAP_MAPDRAW_DRAW, hsave

; now manage widget

	xMANAGER,No_BLOCK=1, "PIA_ERD2MAP_MAPDRAW", id_base, GROUP=group, $
			CLEANUP="PIA_ERD2MAP_MAPDRAW_CLEANUP"

	RETURN	

err_input:
	MESSAGE, /INFO, "missing argument"
	RETURN

	END
