;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PIA P32 Processing Tools Software.              !
;! Designed by: Nanyao Lu at IPAC (lu@ipac.caltech.edu)                        !
;!              Bernhard Schulz at Vilspa (bschulz@iso.vilspa.esa.es)          !
;! Developed by: Iffat Khan at IPAC (irk@ipac.caltech.edu)                     !
;!                                                                             !
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_SET_PARS      
;
; PURPOSE:
;       This routine translates the values of current drift fitting parameters 
;       and flags into 4x6 matrix shown on 'INSPECT_SINGLE_PIXELS' GUI.
;
; DESCRIPTION:
;       The routine gets the values of 12 detector parameters from the current
;       working set and obtains the 'A', 'B', 'C' values for beta1, tau1, 
;       beta2, and tau2. it also sets the flag status for these parameters.
;       The output arrays are then written into text widget buttons on
;       'Inspect signals per pixel' GUI.
;
; CATEGORY:
;       PIA - P32     
;
; CALLING SEQUENCE:
;       pia_set_pars, pix, vars, flags, aval, bval, cval, afl, bfl, cfl
;
; INPUTS:
;       pix: IDL convention for selected pixel i.e pixel # - 1   
;       vars(12, npix): current values of drift fitting parameters
;       flags(12, npix): current values of drift fitting parameters flags, 
;                        Free or Fix.
;
; OPTIONAL INPUTS:
;       None.
;
; OUTPUTS:
;          
;       aval(4): 'A' coefficients for parameters beta1, tau1, beta2, tau2
;       bval(4): 'B' coefficients for parameters beta1, tau1, beta2, tau2
;       cval(4): 'C' coefficients for parameters beta1, tau1, beta2, tau2
;       afl (4): Free/fix flags for 'A' coefficients 
;       bfl (4): Free/fix flags for 'B' coefficients 
;       cfl (4): Free/fix flags for 'C' coefficients 
;
; KEYWORDS:
;       None.
;
; CALLED ROUTINES:
;
; CALLED FROM:    
;       PIA_ERD2MAP_SPIX      
;
; COMMON BLOCKS:
;
; PROCEDURE:
;       None.
;
; SIDE EFFECTS:
;       None.
;
; RESTRICTIONS:
;
;
; MODIFICATION HISTORY:
;	original design, Version 1.1 IRK        Jan 08, 2001
;-
;-----------------------------------------------------------------------
;
PRO PIA_set_pars, pix, vars, flags, aval, bval, cval, afl, bfl, cfl
        
          aval(0) = STRTRIM(vars(0, pix),2)
          bval(0) = STRTRIM(vars(1, pix),2)
          cval(0) = STRTRIM(vars(2, pix),2)

          aval(1) = STRTRIM(vars(3, pix),2)
          bval(1) = STRTRIM(vars(4, pix),2)
          cval(1) = STRTRIM(vars(5, pix),2)
         
          aval(2) = STRTRIM(vars(6, pix),2)
          bval(2) = STRTRIM(vars(7, pix),2)
          cval(2) = STRTRIM(vars(8, pix),2)
          
          aval(3) = STRTRIM(vars(9, pix),2)
          bval(3) = STRTRIM(vars(10, pix),2)
          cval(3) = STRTRIM(vars(11, pix),2)

        afl  = [flags(0,pix), flags(3,pix), flags(6,pix), flags(9,pix)]
        bfl  = [flags(1,pix), flags(4,pix), flags(7,pix), flags(10,pix)]
        cfl  = [flags(2,pix), flags(5,pix), flags(8,pix), flags(11,pix)]

RETURN
END

