pro point,iiph,ics,hdr,rpid,tkey,chop,step,ny,nz,precotf,$
ra,dec,racen,deccen,rarel,decrel,yrel,zrel,$
rpidcen,yzrpidcen,ytrue,ztrue,otfstart,otfstop,ichopcheck, CST=cst, MROLL=mroll
;
; Pointing reconstruction with erd time resolution
;
; find ra and dec and convert pointing to arcsec offsets in RA, DEC from 
; median of ra, dec on central point in raster (arrays rarel,decrel) and in 
; Y, Z (arrays yrel, zrel)
;
; Edition History:
;
; modified by CG ONLY adding CST as input keyword to NOV.99 routine
; modified by B.Schulz to merge independent changes by RJT an CG
;
;
; input:
;      NPTIN (common, long) number of time samples in erd
;      NPIX  (common, long) number of pixels
;      IIPH stem of name of .fits iiph data set (string)
;      ICS  stem of name of .ics ics data set (string)
;      HDR  header of erd fits file (string)
;      RPID raster position (BYTE dim 2,nptin)
;      TKEY internal clock (LONG dim nptin)
;      NCHOP number of chopper positions
;      CHOP chopper offset in Y in arcsec (float, ndim)
;      STEP chopper offset identifier (long, ndim)
;      NY,NZ number of raster points
;      PRECOTF tolerance in ra, dec (arcsec) s.t. otf can be considered on 
;      BAD,BADIN (common signal) needed to mask points where chopper is out 
;                of sync
;      ICHOPCHECK=1 to mask bad points suspected of having false or 
;            ambiguouss chopper positions in the housekeeping data
;
; output: 
;      RA,DEC (double, dim nptin) spacecraft ra, dec in degrees of erd sample
;      RACEN, DECCEN (double) true map centre (degrees), calculated as median
;                     of pointings on central raster position within
;                     tolerance precotf. For even number of raster points
;                     the position between the two central pointings is taken.
;      RACENC, DECCENC same for common block POINTCEN 
;      PAPOINTINY (common POINTCEN) is PA in degrees of positive spacecraft Y,
;                                   East from North
;      RAREL,DECREL (double, nptin) ra, dec offsets from map centre in arcsec
;      YREL,ZREL (double, nptin) offsets in Y, Z from map centre in arcsec
;      RPIDCEN (double, 2,ny,nz) spacecraft centre in ra, dec in arcsec 
;               relative to map centre for each fine pointing
;      YZRPIDCEN (double, 2,ny,nz) spacecraft centre in y, z in arcsec 
;               relative to map centre for each fine pointing
;      YTRUE,ZTRUE true pointing (double, npix, nptin) in arcsec of each pixel
;                   in y, z taking chopper and pixel offset into account
;      RATRUE,DECTRUE(npix,nptin) corresponding offsets in RA, DEC 
;                                 from map centre
;      OTFSTART,OTFSTOP long (ny,nz) integer identifiers of reads corresponding
;               to range where pointing is within precotf of rpidcen (single
;               valued - jitter removed). In finding otfstart otfstop we do not
;               RPID or OTF flags as these may change before precotf is 
;               violated.
;      WRPTY(0:nptin) = raster point identifier in Y IY (range 1:NY) 
;                       if point is on a fine pointing (sampled in range 
;                       OTFSTART:OTFSTOP) At present internal parameter
;                     = 0 otherwise 
;      WRPTZ(0:nptin) = same for Z
;      FPT(0:nptin-1) = 1 on fine pointing =0 otherwise
;     
;
;      also output is common block MAPPER
;
;        COMMON PHTERD, PHTERD, PHTERD_REC
;common signal,rs,cs,nch,s_in,s,badin,bad,rel,rms,glitch,jf,njf,ninchmax,rd,$
;nkf,kf,nkfmax,irelstart,nchopmed,gbad,npolyrms,nrmsmed,sigmaxfract
@common_signal
;common steerin,array,nptin,npt,ninramp,imeas,osamp
;common steer1,npix,pixsize,pixpitch,pixoff,nchop,dcy,dry,drz
;common mapper,sgridy,sgridz,nygrid,nzgrid,ygrid,zgrid,errflag
;common pinfo,fpt
;common const,pie
;common timer,time,dtime,complete
;
@common_timer ; BUGFIX FEB01 repeated scans
;
@common_pointcen
;common pointcen,ratrue,dectrue,racenc,deccenc,papointiny
@common_steerin
@common_steer1
@common_mapper
@common_pinfo
@common_const
;
;print,' '
IF not KEYWORD_SET(CST) THEN cst=0
iiph_erd,iiph,ics,hdr,tkey,ra,dec, cst=cst, MROLL=mroll
;print,hdr
;print,'POINT: ra, dec range (deg) = ',min(ra),max(ra),min(dec),max(dec)
;
; find RACEN DECCEN in degrees
;
ncenprec=10 ; for 2*ncenprec percentage of points used with RPID set
            ; (all cannot be used because RPID not reset after microslew
            ;  starts to go to the next find pointing). 
sumr=0.0D
sumd=0.0D
findradecpos,ra,dec,rpid,ncenprec,1,1,rac0,decc0
for iy=1,ny do begin ; rpid runs from 1 to ny or nz, not from 0
for iz=1,nz do begin
findradecpos,ra,dec,rpid,ncenprec,iy,iz,rac,decc
sumr=sumr+(rac-rac0)
sumd=sumd+(decc-decc0)
endfor ; iz
endfor ; iy
racen=rac0+sumr/double(ny*nz)
racenc=racen				; BUGFIX FEB01 
deccen=decc0+sumd/double(ny*nz)
deccenc=deccen				; BUGFIX FEB01 
;
rahr=long((racen/360.0)*24.0)
ramin=long((racen/15.0-rahr)*60.0)
rasec=((racen/15.0-rahr)*60.0-ramin)*60.0
print,'POINT: RA  map centre (J2000):',rahr,ramin,rasec
ddec=abs(deccen)
deg=long(ddec)
dmin=long((ddec-deg)*60.0)
dsec=((ddec-deg)*60.0-dmin)*60.0
if(deccen lt 0.0)then deg=0L-deg
print,'POINT: DEC map centre (J2000):',deg,dmin,dsec
;
;help,racen
;help,deccen
deccenrad=deccen*double(pie/180.0)
;rarel=(ra-racen)*double(3600.0)/cos(deccenrad) ; wrong!!
rarel=(ra-racen)*double(3600.0)*cos(deccenrad)
;plot,rarel
;help,rarel
decrel=(dec-deccen)*double(3600.0)
;plot,decrel
;help,decrel
;
; create arrays otfstart otfstop of starting and finishing points for each 
; pointing defined as range of values where pointing is within precotf of 
; median pointing where otf is set 
; In finding otfstart otfstop we do not use prid or otf as criteria as these 
; may change before precotf is violated.
;
; first find array of ra dec values relative to map centre rpidcen
; for each spaceraft pointing within precotf of the nominal position
;
rpidcen=dblarr(2,ny,nz) ; centre in ra, dec in arcsec relative to map centre
for i=0L,ny-1 do begin
for j=0L,nz-1 do begin
ic=where(rpid(0,*) eq i+1 and rpid(1,*) eq j+1, ncen)
;print,'POINT: i,j,ncen,ic(0):',i,j,ncen,ic(0)
radum=rarel(ic)-double(rarel(ic(0))) ; truncate to increase precision
decdum=decrel(ic)-double(decrel(ic(0)))
irs=sort(radum)
ird=sort(decdum)
radum=radum(irs)
decdum=decdum(ird)
dii=ncen/ncenprec ; for central 2*ncenprec percent of points to be used
ii=(ncen/2)-dii
iii=(ncen/2)+dii
xni=double(iii-ii+1)
;ii=ncen/4
;iii=ncen-ii-1
;xni=float(iii-ii+1)
;xni=double(xni)
rpidcen(0,i,j)=median(radum(ii:iii))+double(rarel(ic(0)))
rpidcen(1,i,j)=median(decdum(ii:iii))+double(decrel(ic(0)))
;rpidcen(0,i,j)=double(total(radum(ii:iii)))/xni+double(rarel(ic(0)))
;rpidcen(1,i,j)=double(total(decdum(ii:iii)))/xni+double(decrel(ic(0)))
;print,'POINT: i,j,rpidcen(0,i,j),rpidcen(1,i,j):',i,j,rpidcen(0,i,j),rpidcen(1,i,j)
endfor
endfor
; now find range of values otfstart otfstop where pointing is within precotf 
; of median pointing and fpt(0:nptin-1) (flag = 1 where fine pointing is 
; applying = 0 elsewhere). Note: whereas otfstart otfstop are bounded by
; the first and last points in time on the rpid which get within precotf
; fpt is strictly defined according to the precotf definition (ie can oscillate
; in and out within the otfstart otfstop range).
;
fpt=lonarr(nptin) ; ie all zero
otfstart=lonarr(ny,nz)
otfstop=lonarr(ny,nz)
;
; BUGFIX FEB01 repeated scans
;
if(osamp lt 0 and nz ne 2)then begin
print,'POINT: WARNING ******************************************'
print,'POINT: osamp indicates repeated scans but NZ not 2'
print,'POINT: osamp,nz = ',osamp,nz
print,'POINT: WARNING ******************************************'
endif ;
thalf=0.0
if(osamp lt 0)then thalf=time(n_elements(rarel)/2)
;
; end BUGFIX FEB01
;
for iy=0L,ny-1 do begin
for iz=0L,nz-1 do begin
i=where(abs(rarel(*)-rpidcen(0,iy,iz)) lt precotf and $
abs(decrel(*)-rpidcen(1,iy,iz)) lt precotf)
;
; BUGFIX FEB01 repeated scans
;
; iz=1 in rpidcen array is second scan leg
if(osamp lt 0 and iz eq 1)then begin 
i=where(abs(rarel(*)-rpidcen(0,iy,iz)) lt precotf and $
abs(decrel(*)-rpidcen(1,iy,iz)) lt precotf and time gt thalf)
endif ; osamp lt 0 and iz eq 1
; iz=1 in rpidcen aray is first scan leg
if(osamp lt 0 and iz eq 0)then begin 
i=where(abs(rarel(*)-rpidcen(0,iy,iz)) lt precotf and $
abs(decrel(*)-rpidcen(1,iy,iz)) lt precotf and time le thalf)
endif ; osamp lt 0 and iz eq 1
;
; end BUGFIX FEB01
;
;print,'POINT: iy,iz,max(i),min(i)',iy,iz,max(i),min(i)
fpt(i)=1L
otfstart(iy,iz)=min(i)
otfstop(iy,iz)=max(i)
endfor
endfor
;print,'POINT: otfstart = ',otfstart ; diagnostic
;print,'POINT: otfstart = ',otfstop
;
; orientation from first leg (starts at lowest Y, highest Z)
;
x=rpidcen(1,ny-1,0)-rpidcen(1,0,0) ; difference in declination
y=0.0-(rpidcen(0,ny-1,0)-rpidcen(0,0,0)) ; diff in -RA (positive to right)
;
;y=0.0-y ; rjt 04/00 diff in RA (positive to left) - gives usual convention
;         of PA positive E from North. But this sets off the program wrong
ytoprint=0.0-y			;BUGFIX FEB01
;
thetrad=atan(y,x)
thetradtoprint=atan(ytoprint,x)			;BUGFIX FEB01
thet=thetrad*double(180.0/pie)
thettoprint=thetradtoprint*double(180.0/pie)	;BUGFIX FEB01
if(thet lt 0.0)then begin
thetrad=thetrad+double(2.0*pie)
thet=thet+double(360.0)
endif
;
; 	BUGFIX FEB01 start
;
if(thettoprint lt 0.0)then begin
thetradtoprint=thetradtoprint+double(2.0*pie)
thettoprint=thettoprint+double(360.0)
endif
;print,'POINT: y,x,thetrad,thet',y,x,thetrad,thet
print,'POINT: position angle of positive Y (deg): ',thettoprint
papointiny=thettoprint
;
; 	BUGFIX FEB01 end
;
;
; convert rarel decrel to Y Z coordinates YREL ZREL and rpidcen to Y Z 
; as yzrpidcen
;
yrel=decrel*cos(thetrad) - rarel*sin(thetrad)
zrel=decrel*sin(thetrad) + rarel*cos(thetrad)
zrel=0.0-zrel ; raster starts at positive z
;
yzrpidcen=rpidcen
for i=0L,ny-1 do begin 
for j=0L,nz-1 do begin 
yzrpidcen(0,i,j)=rpidcen(1,i,j)*cos(thetrad) - rpidcen(0,i,j)*sin(thetrad)
yzrpidcen(1,i,j)=rpidcen(1,i,j)*sin(thetrad) + rpidcen(0,i,j)*cos(thetrad)
yzrpidcen(1,i,j)=0.0-yzrpidcen(1,i,j) ; as for zrel
;print,'POINT: raster id, Y, Z: ',i,j,yzrpidcen(0,i,j),yzrpidcen(1,i,j)
endfor
endfor
;
; For rasters overwrite DRY DRZ (spacecraft raster interval in arcsec, 
; assigned in INIT1 to commanded values) to actual values.
;
if(ny gt 1)then begin ; find DRY
DUM1=total(yzrpidcen(0,0,*))/double(nz)
DUM2=total(yzrpidcen(0,ny-1,*))/double(nz)
DRY=(DUM2-DUM1)/double(ny-1)
DRY=ABS(DRY)
endif ; dry
if(nz gt 1)then begin ; find DRZ
DUM1=total(yzrpidcen(1,*,0))/double(ny)
DUM2=total(yzrpidcen(1,*,nz-1))/double(ny)
DRZ=(DUM2-DUM1)/double(nz-1)
DRZ=ABS(DRZ)
; Added RJT JUL00
if(osamp lt 0)then DRZ=0.0 ; case repetition of scan
endif ; drz
print,'POINT: s/c raster increments in Y, Z = ',dry,drz
;
; find true pointing YTRUE, ZTRUE of each pixel taking chopper into account
;
ytrue=dblarr(npix,nptin)
ztrue=ytrue
;help,ytrue
;print,pixoff(0,0)
;help,pixoff
for ipix=0L,npix-1 do begin
ytrue(ipix,*)=yrel(*)+pixoff(0,ipix)+chop(*)
;if(ipix eq 0)then begin
;print,'POINT: yrel(0),pixoff(0,0),pixpitch,chop(0),ytrue(0,0)',$
;yrel(0),pixoff(0,0),pixpitch,chop(0),ytrue(0,0)
;print,'POINT: max min ytrue(0,*) = ',max(ytrue(0,*)),min(ytrue(0,*))
;endif
ztrue(ipix,*)=zrel(*)+pixoff(1,ipix)
endfor
;print,ytrue(0,4400:4450)
;
;      set up
;      WRPTY(0:nptin) = raster point identifier in Y IY (range 1:NY) if point is
;                       on a fine pointing (sampled in range (OTFSTART,OTFSTOP))
;                     = 0 otherwise 
;
wrpty=lonarr(nptin)
wrptz=wrpty
for iy=0,ny-1 do begin
for iz=0,nz-1 do begin
i1=otfstart(iy,iz)
i2=otfstop(iy,iz)
wrpty(i1:i2)=iy+1
wrptz(i1:i2)=iz+1
endfor ; iz
endfor ; iy
;
; find true mean chopper increment and overwrite DCY. Then set points
; with chopper+spacecraft Y position out of +- precotf range with fpt=0
; 
; Note added oct99 rjt: It is sstrictly speaking the only correct thing to
; do to correct the pointing where this can be proved. However, this
; breaks the fine pointing sequence, which can under unfavourable circumstances
; make the drift correction in DRIFT32 unstable. Hence, rather than setting
; fpt=0 we set BAD and BADIN=0 for all pixels
;
;
cposmed=dblarr(nchop)
;help,step
;help,chop
;print,max(step),min(step)
;print,max(chop),min(chop)
for ichop=0,nchop-1 do begin
ii=where(step eq ichop+1,nii)
;if(nii le 0)then begin
;print,'ichop+1 = ',ichop+1
;help,step
;print,step(0:1000)
;endif
cposmed(ichop)=median(chop(ii))
endfor ; ichop
dcy=(cposmed(nchop-1)-cposmed(0))/double(nchop-1)
print,'POINT: setting DCY to ',dcy
;
test1=yrel+chop ; actual pos. in arcs wrt natural map cen in Y of foc pl. im
evenodd,ny,iyodd
if(iyodd eq 0)then ycen=0.5+double(ny/2) ; NY even ; ycen=2.5 for ny=4
if(iyodd ne 0)then ycen=1.0+double(ny/2) ; NY odd ; ycen=3 for ny=5
test2=(double(wrpty)-ycen)*dry ;  predicted Y position of focal plane image
test2=test2+dcy*double(step-1-nchop/2) ; predicted Y position of focal plane image wrt 
                             ; map centre of natural map (assumes nchop always
;                                                           odd)
test1=abs(test1-test2)
ii=where(fpt eq 1,nii) ; select points where on a fine pointing
id=lindgen(nptin)
id=id(ii)
test=test1(ii)
iii=where(test gt precotf,niii)
if(niii gt 0)then begin
id=id(iii) ; identifiers of points on a fine pointing position but chopper-
           ; translated image position outside fine pointing tolerance precotf
; rjt oct99 fpt(id)=0
if(ichopcheck eq 1)then begin ; rjt oct99
for ipix=0,npix-1 do begin  ; rjt oct99
bad(ipix,id)=1
badin(ipix,id)=1
endfor ; ipix
endif ; ichopcheck eq 1
;
endif ; niii
if(niii le 0)then niii=0
print,'POINT: number of positions translated out of fine pointing tolerance',$
'due to abnormal chopper amplitude = ',niii
;
idum=where(fpt eq 1,nidum)
print,'number of points with pointing within precotf = ',nidum
;
; now correct range of values otfstart otfstop where pointing is within 
; precotf such that chopper oscillation points are do not cause short blips 
; onto the fine pointing. We define that a fine pointing of less than 
; nfinmin=4 points should be classified as a slew.
;
; rjt oct99 we bypass this as we need a robust definition of the fine pointing
; range
;
goto,c297 ; rjt oct99
;
nfinmin=4
;
for iy=0L,ny-1 do begin
for iz=0L,nz-1 do begin
;
otf1=otfstart(iy,iz)
otf2=otfstop(iy,iz)
itest=otf1+lindgen(otf2-otf1+1)
iout=where(fpt(itest) eq 0,niout)
if(niout gt 0)then begin
i1=otf1-1 ; last point before fine pointing
for i=0,niout-1 do begin
i2=itest(iout(i))
if(i2-i1 lt nfinmin)then fpt(i1:i2)=0
i1=i2
endfor ; i=0,niout-1
ifin=where(fpt(itest) eq 1,nifin)
otfstart(iy,iz)=min(itest(ifin))
otfstop(iy,iz)=max(itest(ifin))
endif ; niout gt 0
endfor ; iz
endfor ; iy
;
c297:
;
; *** added rjt JUL00
;
findp32grid,ny,nz ; common MAPPER needed by simul32 and other routines
assigngrid
;
; now make sure we start and end fine pointing at start of a chopper plateau,
; to avoid short plateaus in the drift reconstruction. Make FPT and OTFSTART
; OTFSTOP consistent with this definition. The arrays IDY and IDZ set up in
; the call to ASSIGNGRID aabove are not checked for consistency, but should
; be OK as the oscillatory motion of the satellite after first getting to
; within 2 arcsec of the fine pointing position never gives an overshoot of
; more than half the C100 natural grid pixel size (ca. 15/2 arcsec).
;
for iy=0L,ny-1 do begin
for iz=0L,nz-1 do begin
;
otf1=otfstart(iy,iz)
if(otf1 gt 0)then begin ; we are not at start of observation
i=otf1-1
c670:
i=i+1
if(step(i) ne step(i-1))then begin ; 1st pt of next chopper plateau reached 
otfstart(iy,iz)=i
goto,c666
endif ; step(i) ne step(i-1)
fpt(i)=0
goto,c670
c666:
endif ; otf1 gt 0
;
otf2=otfstop(iy,iz)
if(otf2 lt n_elements(step)-1)then begin ; don't change end of observation
i=otf2+1
c770:
i=i-1
if(step(i) ne step(i+1))then begin ; last pt of preceding chopper plat reached
otfstop(iy,iz)=i
goto,c766
endif ; step(i) ne step(i+1)
fpt(i)=0
goto,c770
c766:
endif ; otf2 lt n_elements(step)-1
;
endfor ; iz
endfor ; iy
;
; *** end add rjt JUL00
;
; added JAN01
;
ratrue=ztrue*cos(thetrad) + ytrue*sin(thetrad)
dectrue=ztrue*sin(thetrad) - ytrue*cos(thetrad)
;
return
end





