;+
; NAME:
;	pr_close
; PURPOSE:
;	closes the device which has been opened by pr_open
;	and spawn a VMS 'print' command
; CATEGORY:
;	PRINTER
; CALLING SEQUENCE:
;	pr_close, /cancel
; ARGUMENTS:
;	-
; KEYWORDS:
;	cancel		(input, optional)
;			do not print the output which has been collected since
;			last pr_open call, but delete the print file.
; RESTRICTIONS:
;	The routine is restricted to VMS on the following reasons:
;	- The VMS 'print' and 'delete' commands are used.
;	  Extension to other operating systems is straight forward.
; CALLED ROUTINES:
;	-
; COMMON BLOCKS:
;	common printer
; REVISION HISTORY:
;	16-feb-94 ds	created: D. Skaley, MPIK Heidelberg
;-

pro pr_close, cancel=cancel

	on_error, 2

	common printer, pstatus, pformats, pqueues

	if n_elements(pstatus) eq 0 then p_active = 0 $
		else p_active = pstatus.active
	if not p_active then begin
		message,/info,'printing was not active.'
		return
	endif

	device, /close_file
	set_plot, pstatus.prev_device

	if keyword_set(cancel) then begin
		case !version.os of
		'vms':	cmd = 'delete '+pstatus.filename+';'
		else:	message,"Don't know how to delete a file."
		endcase
		spawn, cmd
		message,/info,'printing canceled.'
	endif else begin
		if not pstatus.fileselect then begin
			case !version.os of
			'vms':	cmd = 'print/notify ' + pstatus.filename + $
					'/delete /queue=' + pstatus.queue
			else:	message,"Don't know how to print a file."
			endcase
			spawn, cmd
		endif
	endelse

	pstatus.active=0
	return
	end
