pro preglitch2,kp,i1scp,i2scp,glscp,thresherd,iusefine,iviguse,itwomethod,$
ipix,x,g,xminus,xplus,spt,igood,nigood,badprev,badpost,kprev,kpost,nrel
;
; uses SCPBLOCK common block data-dependent arrays to precondition prior
; to deglitching the SCP plateaus within a range of plateaus i1scp to i2scp 
; for detector pixel IPIX and sky pointing direction KP. If IUSEFINE is 1 only 
; Fine pointing data is used. In any case, only good data are
; passed back. Having selected good data, the signals are normailised by the 
; RMS the median value is subtracted for each sequence corresponding to the 
; pointing direction KP on each s/c pointing direction, and a modulus is taken.
; If there are only two points per pointing direction and s/c pointing there 
; is a difficulty in deciding which point of the two is bad, if there is a 
; substantial gap. In this case, if ITWOMETHOD is 0, PREGLITCH2 subtracts the 
; average before applying the modulus. If ITWOMETHOD is 1, a subtraction is 
; made such that point with the lower absolute signal is set to zero, before 
; taking the modulus. In the calling program to PREGLITCH2, statistics are 
; taken from the whole dataset from i1scp ti i2scp to make the level of the 
; points statistically independent of the number of plateaus from which the 
; relativisation on each s/c pointing was done. Also, statistics are done on
; the level as a function of preceding brightnesses. The net result should be 
; an unbiased array which can be clipped by the calling program either over the
; whole dataset (if drift artifacts can be ignored) or for individual 
; pointings. The output arrays can be cocatenated togeher by the calling 
; program.
;
; Note added JUL00 (RJT) now no longer dividing by rms.
;
; If IVIGUSE is 1 the signal and rms arrays are corrected for the vignetting
;
; input from SCP level from common SCPBLOCK:
;     KPT_SCP(npix,nplat_scp)pointing direction on P32 natural grid of 
;                            fine pointing direction. For a slew it is the
;                            most common pointing direction of the good points
;                            on the plateau
;     VIG_SCP(nplat_scp)     vignetting factors for each chopper plateau
;     SPT_SCP(nplat_scp)     s/c pointing identifyer (in time order). For a 
;                            slew it is set to -1
;     FPT_SCP(nplat_scp)     =1 if all good or bad points on the plat are on a
;                            fine pointing, =0 otherwise
;     FROM_SCP(nplat_scp)    ERD ident of 1st point of plateau (even if bad)
;     TO_SCP(nplat_scp)      ERD ident of last point of plateau (even if bad)
;     TIME_SCP(nplat_scp)    Time of first sample in each plateau 
;                            (for simplicity) 
;     NPLAT_SCP              Number of chopper plateaus in the SCPBLOCK arrays
;
;     S_SCP(npix,nplat_scp)  = mean of all good points on plateau
;                            derived from input S array  
;     RMS_SCP(npix,nplat_scp)= error in mean of all good points on plateau
;                            derived from input RMS array  
;     BAD_SCP(npix,nplat_scp)=0 if at least one input ERD sample on plateau is
;                            good =1 otherwise
;     N_SCP(npix,nplat_scp)  number of good elementary ERD samples contributing
;                            to plateau
;  input from call:
;     GLSCP(nplat_scp)       average amplitude of proton hits including
;                            tails from the ERD glitch DG1. This is used to
;                            determine which of a discrepent pair of points
;                            for a given s/c pointing and sky direction is
;                            more likely to be the glitch, when running with
;                            ITWOMETHOD=2. Positive quantity on input.
;     THRESHERD              points with GLSCP > THRESHERD are excluded from
;                            the median determination
; output:
;     X                      array containing good quantity derived from 
;                            SCP signals. X is not the signal so cannot be
;                            compared with XMINUS, XPLUS (below).
;     IGOOD                  original scp plateau indices for X
;     NIGOOD                 number of good points in X (can be zero)
;     G                      value of ERD proton tails corresponding to X
;                            (averaged over plateaus IGOOD)
;     SPT                    s/c pointing for X
;     XMINUS                 value of signal on preceding SCP plateau
;     XPLUS                  value of signal on postceding SCP plateau
;     KPREV                  the (different) pointing direction of preceding 
;                            SCP signal
;     KPOST                  pointing direction of postceding scp signal
;     BADPREV                mask for preceding scp signal
;     BADPOST                mask for postceding scp signal;
;     NREL                   number of SCP plateaus on fine pointing from
;                            which RELSCP performed the relativisation.
;
@common_scpblock
;common scpblock,s_scp,bad_scp,rms_scp,n_scp,kpt_scp,spt_scp,fpt_scp,$
;from_scp,to_scp,time_scp,vig_scp,nplat_scp
;
x=s_scp(ipix,i1scp:i2scp)
v=vig_scp(ipix,i1scp:i2scp)
g=glscp(i1scp:i2scp)
;
if(i1scp eq 0)then begin
xp=fltarr(i2scp-i1scp)
kprev=lonarr(i2scp-i1scp)
badprev=kprev
xp(*)=s_scp(ipix,i1scp:i2scp-1)
xp=[s_scp(ipix,i1scp),xp]
kprev(*)=kpt_scp(ipix,i1scp:i2scp-1)
kprev=[kpt_scp(ipix,i1scp),kprev]
badprev(*)=bad_scp(ipix,i1scp:i2scp-1)
badprev=[bad_scp(ipix,i1scp),badprev]
endif ; i1scp eq 0
if(i1scp gt 0)then begin
xp=fltarr(i2scp-i1scp+1)
kprev=lonarr(i2scp-i1scp+1)
badprev=kprev
xp(*)=s_scp(ipix,i1scp-1:i2scp-1)
kprev(*)=kpt_scp(ipix,i1scp-1:i2scp-1)
badprev(*)=kpt_scp(ipix,i1scp-1:i2scp-1)
endif ; i1scp gt 0
if(i2scp ge nplat_scp-1)then begin
xm=fltarr(i2scp-i1scp)
kpost=lonarr(i2scp-i1scp)
badpost=kpost
xm(*)=s_scp(ipix,i1scp+1:i2scp)
xm=[xm,s_scp(ipix,i2scp)]
kpost(*)=kpt_scp(ipix,i1scp+1:i2scp)
kpost=[kpost,kpt_scp(ipix,i2scp)]
badpost(*)=bad_scp(ipix,i1scp+1:i2scp)
badpost=[badpost,bad_scp(ipix,i2scp)]
endif ; i2scp ge nplat_scp
if(i2scp lt nplat_scp-1)then begin
xm=fltarr(i2scp-i1scp+1)
kpost=lonarr(i2scp-i1scp+1)
badpost=kpost
xm(*)=s_scp(ipix,i1scp+1:i2scp+1)
kpost(*)=kpt_scp(ipix,i1scp+1:i2scp+1)
badpost(*)=bad_scp(ipix,i1scp+1:i2scp+1)
endif ; i2scp lt nplat_scp-1
;
b=lonarr(i2scp-i1scp+1)
b(*)=bad_scp(ipix,i1scp:i2scp)
r=fltarr(i2scp-i1scp+1)
r(*)=rms_scp(ipix,i1scp:i2scp)
k=lonarr(i2scp-i1scp+1)
k(*)=kpt_scp(ipix,i1scp:i2scp)
f=lonarr(i2scp-i1scp+1)
f(*)=fpt_scp(i1scp:i2scp)
spt=lonarr(i2scp-i1scp+1)
spt(*)=spt_scp(i1scp:i2scp)
;
if(iusefine eq 1)then igood=where(b eq 0 and f eq 1 and k eq kp,nigood)
if(iusefine ne 1)then igood=where(b eq 0 and k eq kp,nigood)
if(nigood le 0)then begin
print,'PREGLITCH2: warning - insufficient good data for ipix,kp = ',ipix,kp
goto,c999
endif ; nigood le 0
;
x=x(igood)     ; good scp signal
v=v(igood)
g=g(igood)
xminus=xp(igood)   ; preceding scp signal (can be good or bad)
xplus=xm(igood)    ; postceding scp signal
kprev=kprev(igood) ; the (different) pointing direction of preceding scp signal
kpost=kpost(igood) ; pointing direction of postceding scp signal
badprev=badprev(igood) ; mask for preceding scp signal
badpost=badpost(igood) ; mask for postceding scp signal
r=r(igood)     ; rms
spt=spt(igood) ; s/c pointing
;
;x=x/r
if(iviguse eq 1)then begin
x=x/v
xminus=xminus/v
xplus=xplus/v
r=r/v
endif ; iviguse eq 1
;
; notes - the post and previous SCP plateaus may actually not be on a 
;         fine pointing. However, sincfe the definition of fine pointing is
;         quite conservative, this is expected to have no consequences for the
;         deglitch
;       - XMINUS and XPLUS are passed back as the original signals, as these
;         may be needed for (i) looking at the dependence of statistics of X
;         on the illumination step and (ii) both quantities may be needed
;         when replacing the ERD signal if the first occurance of a direction
;         is found bad. Beware that XMINUS and/or XPLUS may be bad. Then we 
;         should not use the signal(s) in this statistical way or to find the
;         levels for an ERD  patch. The same applies if KPREV is the same as 
;         KPT (we are then at the first datapoint) or if KPOST is the same as 
;         KPT (we are then at the last datapoint).
;
isptmin=min(spt)
isptmax=max(spt)
nrel=long(r)
for ispt=isptmin,isptmax do begin
ii=where(spt eq ispt,nii)
if(nii le 0)then goto,c444
xtest=x(ii)
gtest=g(ii) ; level of erd proton hit averaged over plateau
x2grad=abs( x(ii)-(xminus(ii)+xplus(ii))/2.0 ) ; abs of double gradient
nrel(ii)=nii
;iii=where(gtest eq 0.0,niii) ; ignore ANY point in  tail
iii=where(gtest le thresherd,niii) ; don't use ERD glitched points in median
if(niii ge 1)then xtest=xtest(iii) ; except where all points bad (in which case
mediantrue,xtest,xmed              ; they will be caught by the ERD trap in DG2
;x(ii)=abs((x(ii)-xmed)/r(ii))
if(nii gt 2 or nii eq 1)then x(ii)=abs((x(ii)-xmed))
if(nii eq 2 and itwomethod eq 0)then x(ii)=abs((x(ii)-xmed))
if(nii eq 2 and itwomethod eq 1)then begin
   if(x(ii(0)) ge x(ii(1)))then xoff=x(ii(1))
   if(x(ii(1)) gt x(ii(0)))then xoff=x(ii(0))
   x(ii)=x(ii)-xoff
endif ; nii eq 2 and itwomethod eq 1
if(nii eq 2 and itwomethod eq 2)then begin
   if(max(g(ii)) gt thresherd)then begin ; at least one plateau has an erd glitch
;                                    or part of it's tail
      if(g(ii(0)) ge g(ii(1)))then xoff=x(ii(1))
      if(g(ii(1)) gt g(ii(0)))then xoff=x(ii(0))
      x(ii)=x(ii)-xoff
   endif ; max(g(ii)) gt 0.0
;   if(max(g(ii)) eq 0.0)then begin ; no erd glitch so procede as for 
;                                    itwomethod=1 
;      if(x(ii(0)) ge x(ii(1)))then xoff=x(ii(1))
;      if(x(ii(1)) gt x(ii(0)))then xoff=x(ii(0))
;      x(ii)=x(ii)-xoff
;   endif ; max(g(ii)) eq 0.0
   if(max(g(ii)) le thresherd)then begin ; no erd glitch so take point with 
                                   ; largest double grad as being the worst
      if(x2grad(0) ge x2grad(1))then xoff=x(ii(1))
      if(x2grad(1) gt x2grad(0))then xoff=x(ii(0))
;      if(x(ii(0)) ge x(ii(1)))then xoff=x(ii(1))
;      if(x(ii(1)) gt x(ii(0)))then xoff=x(ii(0))
      x(ii)=x(ii)-xoff
   endif ; max(g(ii)) eq 0.0
endif ; nii eq 2 and itwomethod eq 2
c444:
endfor ; ispt=isptmin,isptmax
;
c999:
;
return
end









