pro rchset,k1,k2
;  
; Create a readout array RS(nptin) (eg containing 1 2 3 4 1 2 3 4 .... for 
; cycles of (eg) 3 non-destructive + 1 destructive reads (common block)
;
; Sets up chop step identifier CS(nptin) - ie readout identifiers when chopper has
; moved (first read after move, should always have rs=1). CS contains
; nch elements (ie there are nch+1 chop movements and nch+2 chop plateaus. (common block)
;
; corrects spurious chop values. (rchset should always be run before
; the pointing reconstruction
;
; k1 and k2 are range for printing of chopper resets
;
;common steerin,array,nptin,npt,ninramp,imeas,osamp
;common steer1,npix,pixsize,pixpitch,pixoff,nchop,dcy,dry,drz
;common signal,rs,cs,nch,s_in,s,badin,bad,rel,rms,glitch,jf,njf,ninchmax,rd,$
;nkf,kf,nkfmax,irelstart,nchopmed,gbad,npolyrms,nrmsmed,sigmaxfract
;common plotter,otfstart,otfstop,rdstat,chop,step,otf,rpid,yrel,zrel,$
;ytrue,ztrue,yzrpidcen,nyraster,nzraster
;
@common_steerin
@common_steer1
@common_signal
@common_plotter
;help,chop
;help,step
;
; 1st remove spurious glitches in chop (this was tested on bright sources)
; NB 1st ndr is sometimes not quite reaching the chopper plateau position
;
kk2=abs(k2) ; printing parameters
kk1=abs(k1)
;
nspur1=0L
nspur2=0L
prch=0.2 ; precision for matching chop to plateau is prch * dcy 
for i=0L,nptin-2 do begin
if(abs(chop(i+1)-chop(i)) gt prch*dcy and rdstat(i) eq 0)then begin
;                                chop moving within readout ramp
; find beginning of read ramp where chopper blip detected
itest=i
c111:
itest=itest-1
if(itest eq 0)then begin ; beginning of ramp is 1st read in dataset
i1=0L
i2=i1+ninramp-1 ; last non-destructive read on ramp 
goto,c112
endif
if(rdstat(itest) eq 1)then begin ; we've reached end of previous ramp
i1=itest+1 ; 1st non-destructive read on ramp where chop blip found
i2=i1+ninramp-1 ; last non-destructive read on ramp
goto,c112
endif
goto,c111
c112:
;
;print,'RCHSET: i1+1,i2',i1+1,i2
if(i2 gt nptin-1)then begin ; avoid setting chop coordinate to chop(i1), which
                            ; is likely to be the first following a chopper 
                            ; motion
i2=nptin-1
rdstat(i1:i2)=1L ; flag all these points bad if chopper has moved just
                 ; prior to the last ramp which is incomplete (rdstat is
                 ; referenced in CREATESIG when creating BADIN, BAD)
chopmed=chop(nptin-1) ; most probable value is furthest in time from transition
endif ; i2 gt nptin-1
;
if(i2 le nptin-1)then chopmed=median(chop(i1+1:i2)) ; as 1st read is often wrong only take last reads  
for ic=i1,i2 do begin
if(abs(chop(ic)-chopmed) gt prch * dcy)then begin
;if(i lt kk2 and i gt kk1 and kk1 gt 0)then begin
;print,'i1,i2,chop(i1:i2):',i1,i2,chop(i1:i2)
;print,'i1-1,i2+1,step(i1:i2)',i1-1,i2+1,step(i1-1:i2+1)
;print,'spurious chopper blip corrected at read, ndr ',ic,ic-i1+1 
;endif ; i lt kk2
chop(ic)=chopmed 
if(ic-i1+1 eq 1)then nspur1=nspur1+1
if(ic-i1+1 gt 1)then nspur2=nspur2+1
endif
endfor
;
endif ; prch * dcy
endfor
;
print,'RCHSET: number of chopper positions corrected (ndr=1) = ',nspur1
print,'RCHSET: number of chopper positions corrected (ndr>1) = ',nspur2
;
; find RS
;
rs=long(rdstat)
for i=0L,nptin-1,ninramp do begin
i1=i
i2=min([i1+ninramp-1,nptin-1])
;print,i1,i2
rs(i1:i2)=lindgen(i2-i1+1)+1
endfor
;if(kk1 gt 0)then print,rs(kk1:kk2)
;
cs=long(rdstat) ; to get array initialised
cs(*)=0L
nch=-1L ; number of changes to chopper
ipchk=3L ; number of consecutive consistent measurements at a new position
      ; to qualify for chopper really having moved.
if(array eq 'c100')then bstep=13
if(array eq 'c200')then bstep=7
;print,'bstep = ',bstep
for i=ipchk,nptin-ipchk do begin
s1=total(step(i:i+ipchk-1))/ipchk
s2=total(step(i-ipchk:i-1))/ipchk
if(abs(abs(s2-s1)-1.0) lt 0.01 or abs(abs(s2-s1)-bstep+1.0) lt 0.01)then begin
;if(i lt kk2 and i gt kk1)then begin
;print,'chop change at:',i
;print,i,s1,s2,abs(abs(s2-s1)-1.0),abs(abs(s2-s1)-bstep+1.0),$
;step(i-ipchk:i+ipchk-1)
;endif
nch=nch+1
cs(nch)=i
if(rs(i) ne 1)then begin ; chop transition must always coincide with 1st read
print,'RCHSET: WARNING: chop transition not at 1st read for readout = ',i
endif
endif
;if(i lt 8100 and i gt 8000)then begin
;endif
endfor
print,'RCHSET: number of chopper plateaus = nch+2 =',nch+2
;print,step(8065:8075)
;
return
end
