pro rmsprop,x,xrms,xmean,xsig,xsigmean,imethod
;
; calculates mean XMEAN and sigma in mean XSIGMEAN for input data array X
; with input RMS XRMS error propagation under various weighting scenarios:
; XSIG is also the error in the mean of X, but is calculated from the 
; dispersion of the data as the sigma in the weighted distribution in X (it is
; output as 0 for an array with only one data point). This is in contrast to 
; XSIGMEAN which is calculated only from the weighted XRMS array. A comparison
; between XSIG and XSIGMEAN is therefore an indication of the extent to
; which the input XRMS are real.
;
; IMETHOD=0 - equal weights for all data
; IMETHOD=1 - data weighted according to (1/RMS)^2
;
;print,xrms
n=n_elements(x)
xn=float(n)
;
xrms2=xrms*xrms
if(imethod eq 1)then w=(1.0/xrms2)
if(imethod eq 0)then w=replicate(1.0,n)
w=w/total(w)
;
xmean=total(w*x)
;
;xsig=total(w*x*x)+xmean*xmean-2.0*xmean*total(x*w)
;xsig=sqrt(xsig) ; estimate of sigma from data X
;
xsig=sqrt(total(w*((x-xmean)^2.))) ; estimate of sigma from data X
xsigmean=sqrt(total(w*xrms2)) ; estimate of sigma from errors XRMS
if(n gt 1)then begin
xsigmean=xsigmean/sqrt(xn-1.)
xsig=xsig/sqrt(xn-1.)
endif ; n gt 1
if(n eq 1)then begin
xsigmean=xsigmean/sqrt(xn)
xsig=xsig/sqrt(xn)
endif ; n eq 1
;
return
end
