pro setjump_model3,sillum,sillump,signalprev,signalshootprev,tlong,tlongprev,$
betalong,betalongprev,betash,betashprev,tshoot,tshootprev,s0,s0shoot
;
; finds s0 and s0shoot for detector model 3 as a function of:
;
; SILLUM           illumination on current plateau
; SILLUMP          illumination on previous plateau
; SIGNALPREV       signal at end of previous plateau
; SIGNALSHOOTPREV  signal at end of previous plateau
; TLONG            long time constant on current plateau
; TLONGPREV        long time constant on previous plateau
; BETALONG         jump factor for long time constant on current plateau
; BETALONGPREV     jump factor for long time constant on previous plateau
; TSHOOT           long time constant on current plateau
; TSHOOTPREV       long time constant on previous plateau
; BETASH           jump factor for shooting time constant on current plateau
; BETASHPREV       jump factor for shooting time constant on previous plateau
;
; note that conservative and non-conservative jump conditions are equivalent
; if the beta and tau constants are independent of illumination
;
; note: changes to this program must be matched with same changes
;       in INVERSEJUMP_MODEL3; otherwise the optimisation of detector
;       detector initial state will go wrong       
;
@common_steerin
; common steerin,array,nptin,npt,ninramp,imeas,osamp
;
; conservative, standard imodel=3 
; (expshoot_standardintegralsubtraction.pro and 
;  expshoot_originalexpaddition.pro)
; s0=betalong*sillum+(tlongprev/tlong)*(signalprev-betalongprev*sillump) 
; s0shoot=betash*sillum+$
; (tshootprev/tshoot)*(signalshootprev-betashprev*sillump)
;
; non conservative, standard imodel=3
; (expshoot_standardintegralsubtraction.pro and 
;  expshoot_originalexpaddition.pro)
; s0=signalprev+(betalong*(sillum-sillump))
; s0shoot=betash*(sillum-sillump)+signalshootprev 
; 
; conservative, alternative empirical imodel=3
; (expshoot_alternativeempirical.pro)
if(array eq 'c200')then begin
  s0=betalong*sillum+(tlongprev/tlong)*(signalprev-betalongprev*sillump) 
  s0shoot=signalshootprev*(tshootprev/tshoot)
endif ; array eq 'c200'
;
; non conservative, alternative empirical imodel=3
; (expshoot_alternativeempirical.pro)
if(array eq 'c100')then begin
  s0=signalprev+(betalong*(sillum-sillump))
  s0shoot=signalshootprev
endif ; array eq 'c100'
;
return
end




