pro setshootbeta_model3,betawk,sillum,betalong,betashort
;
; Finds detector jump constants BETALONG and BETASHORT as a function of 
; illumination SILLUM for imodel=3 (imodel eq 3) 
; This is needed by the routine EXPSHOOT and DETSELFCAL, so should be 
; defined in one place (this routine). SILLUM and
; the output BETALONG BETASHORT can be arrays as needed by SETRANGE. 
; Where called by SOLVEILLUM1, SOLVEBACK2, and all calls to EXPSHOOTEXPSHOOT 
; however, only scalars are input. Hence the trap for betalong (below) only 
; uses betalong(0), to maintain speed.
;
; input:
;       - common MOREPAR with shooting detector parameters and the zero bias
;                BETAWK, the long jump constant called by EXPSHOOT 
;                (not in common)
;       - SILLUM illumination in V/s (single vlue or array)
;
; output:
;       - BETASHORT, the jump constant for shooting; same
;                    dimension as SILLUM
;       - BETALONG,  the jump constant for the long response;
;                    same dimension as SILLUM
;
@common_steerin
;common steerin,array,nptin,npt,ninramp,imeas,osamp
@common_morepar
;common morepar,gammaexp,zerobias,betashoot,taushoot,gammaexpshoot,$
;betacoeffshoot,betaexpshoot,tauoffsetshoot,tauoffset,betaexp,betacoeff
;
betalong=betawk+betacoeff*(sillum^(betaexp))
betashort=betashoot+betacoeffshoot*(sillum^(betaexpshoot))
;
;if(array eq 'c200')then betalong=betalong-betashort 
betalong=betalong-betashort 
                            ; this is needed when the taushort is so
                            ; short that the FCS fit does not "see" the
                            ; short tau at all. The statement thus ensures
                            ; that the liong behaviour of the fcs fit is 
                            ; preserved. This is essential for C200, where
                            ; taushort may be typically a few tens of seconds,
                            ; but marginal for C100 where taushort may be
                            ; a few seconds. Unless this statement is included,
                            ; C200 effectively operates with beta=1.0, which
                            ; clearly violates the FCS fits.
;
;if(betalong(0) gt 1.0)then print,'*** beta > 1.0 - sillum(0),beta(0) = ',$
;sillum(0),betalong(0)
;if(betalong(0) lt 0.0)then print,'*** beta < 0.0 - sillum(0),beta = ',$
;sillum(0),betalong(0)
;
if(betalong(0) gt 1.0)then betalong(0)=1.0
if(betalong(0) lt 0.0)then betalong(0)=0.0
;
return
end







