
pro sigcreate,conp,rdstat,autdr,sus,dt
;
; create data array S_IN in V/s and mask array badin (common block). Use 
; convention that s_in(ipix,i) is conp(ipix,i+1) - conp(ipix,i) 
; where conp is volts. Where i is destructive read on a new integration ramp, 
; badin is set to 1 from 0. DT is the non-destructive read interval in sec.
; Perform reset interval and dark correction.
;
; to add FLAG from ERDTOMAP need to decode the bit
; can be 3 numbers. 
; don't take 1st bit is selection criterior 
; do take selection bit
; do take bit saying wheter or no deglitched automatically
;
; S and S_IN are identical on output, both with corrections for dark and
; reset interval
;
; Edition History:
;
; 26/02/2001 modified by B.Schulz to merge in changes by RJT
;
;
; input (common NAMES):
;    TDTNAM: string denoting name of TDT eg '53801001'
;    ISEQ:   string denoting sequence number of target source map
;            (normally '01' or '03' or '05' for multifilter sequence separated
;             by FCS measurements) 
;    DIRNAM: dstring denoting irectory name for internal PIA files
;            eg '/d13/vlk/rjt/pia/p32p22p25/v7_3/'
; input:
; Dark current is also subtracted and the reset correction applied here:
;    ICALDONE incremented by 1 if S and RMS have been overwritten
;    IDARKDONE incremented by 1 if S has had dark current subtracted.
;    IRESETDONE incremented by 1 if S and RMS have been overwritten
;    CALRESULT FLTARR(npix,nptin) with 
;              multiplitive factors applied to convert V/s to MJy/sterad
;    DARKRESULT FLTARR(NPIX) with applied dark currents
;    RESETRESULT FLTARR(NPIX) with applied multiplitive
;               
;
;common steerin,array,nptin,npt,ninramp,imeas,osamp
;common steer1,npix,pixsize,pixpitch,pixoff,nchop,dcy,dry,drz
;common signal,rs,cs,nch,s_in,s,badin,bad,rel,rms,glitch,jf,njf,ninchmax,rd,$
;nkf,kf,nkfmax,irelstart,nchopmed,gbad,npolyrms,nrmsmed,sigmaxfract
;
@common_names
@common_steerin
@common_steer1
@common_signal
@common_timer
@common_cal
@phterd
;
;common cal,icaldone,idarkdone,iresetdone,calresult,darkresult,resetresult
;  
;
s_in=fltarr(npix,nptin)
badin=lonarr(npix,nptin)
dt=time(1)-time(0)

;********** ADDED FEB01 ***************************************
;
; read ERD FLAGS
;
handle_value,phterd(imeas).flag,flag ; erd flag (FLT dim npix+2,nptin)
;
;*********************************************************************
;
for ipix=0L,npix-1 do begin
s_in(ipix,0:nptin-2)=(conp(ipix,1:nptin-1)-conp(ipix,0:nptin-2))/dt ; in V/sec
; VILSPA set times to time of read as in signal to get flags right
; however expand32 then gives a spurious transition in the plateau
; in the illumination history, which treats the destructive read as good.
;time(0:nptin-2)=time(1:nptin-1)
;time(nptin-1)=time(nptin-2)+dt
;
i=where(rdstat eq 1)
badin(ipix,i)=1L
i1=where(autdr eq -1,ni1)
ii1=i1-1
if(ii1(0) eq -1 and ni1 gt 0)then ii1(0) = 0 ; to prevent problems with
                                             ; first read being bad
if(ni1 gt 0)then begin
if(ipix eq 0)then print,'number of input reads with autdr = -1 is:',ni1
badin(ipix,ii1)=1L
badin(ipix,i1)=1L
endif
i2=where(sus ne 0,ni2)
ii2=i2-1
if(ii2(0) eq -1 and ni2 gt 0)then ii2(0) = 0
if(ni2 gt 0)then begin
if(ipix eq 0)then print,'number of suspicious input reads = ',ni2
badin(ipix,i2)=1L
badin(ipix,ii2)=1L
endif
;
;*********** ADDED FEB01 ********************************
;
; incorporate FLAG (containing user set bad flags from ERD) into BADIN
;
i3=where(flag(ipix,*) ge 32,ni3)
ii3=i3-1
if(ii3(0) eq -1 and ni3 gt 0)then ii3(0) = 0
if(ni3 gt 0)then begin
print,'SIGCREATE: ipix, number of flagged input reads = ',ipix,ni3
badin(ipix,i3)=1L
badin(ipix,ii3)=1L
endif
;
;********************************************************
;
endfor ; ipix
;
;
print,'SIGCREATE: total input bad signals = ',total(badin(0,*))
idum=where(rdstat eq 1,ndestr)
print,'SIGCREATE: total number of destructive reads = ',ndestr
;
s=s_in ; needed by CAL32
rms=s_in
rms(*,*)=0.0 ; initialize - needed by CAL32
;
; initialisation of calibration flags
;

;;;; Taking all this out because calibration performed in main routine
;;;; ERDtoMAP ----

;icaldone=0
;idarkdone=0
;iresetdone=0


;;;print,'SICREATE: correcting for dark current and reset interval correction'
; note that reset correction must be made before dark correction
;cal32,result1,result2,5 ; reset correction
;cal32,result1,result2,3 ; dark correction
;s_in=s ; as s_in is input to relativise

bad=badin ; rjt sep99

;
return
end



