pro skyflat,template,skyin,polydegree,mediandegree,implement,ips
;
; Finds a (pure multiplive)time-dependent P32 flat field independently for each
; detector pixel by comparing simple maps with an array SKYIN, over a subset of
; map pixels for which TEMPLATE is 1. To get an optimum overall scaling,
; SKYFLAT should be run after standard flat routines FLAT_INSCAN 
; FLAT_CROSSSCAN FLAT_INSCAN_TD and FLAT_CROSSSCAN_TD, if TEMPLATE does not 
; specify positions seen by each detector pixel. SKYFLAT can also be
; run prior to FLAT_INSCAN FLAT_CROSSSCAN FLAT_INSCAN_TD and FLAT_CROSSSCAN_TD
; (without implementing the flat) to get the true systematic dispersion in the
; flat field between the detector pixels, which is needed to determine the
; scaling uncertainly in the background brightness and source flux.
;
; The ratio of detector signals from simple maps to sky, scaled to the data,
; is plotted versus time and a polynomial fit of degree POLYDEGREE(IPIX) is 
; applied for detector pixel IPIX. If an element of MEDIANDEGREE(NPIX) is 
; greater than 0, a median filtering of width MEDIANDEGREE(IPIX) for the pixel
; IPIX is applied beforehand. The use of different medians and polynomial
; degrees for different detector pixels is useful
; to filter any source emission or glitches coming into some detector pixels 
; but not others - the graphical display of SKYFLAT allows users to experiment
; with different combinations of POLYDEGREE and MEDIANDEGREE until a solution
; replecting the real long term trends is found for each detector pixel. The 
; polynomial fit for pixels overlapping with the
; background, sampled at the original time resolution (non-expanded) of the 
; data is stored in the array FMULTTD (common FLATTD). Pixels not overlapping
; with the background are scaled to the average solution of the detector
; pixels which are. HMULTTD (common FLATTD) is initialised as 0. If
; IMPLEMENT is 1, implement_td is called to implement the flat into S and RMS.
; 
; output (common FLATTD)
; FMULTTD(npix,nptin) are yet to be applied multiplicative flat field factors
; HMULTTD(npix,nptin) are yet to be applied addititive flat field factors
;
@common_flattd
;common flattd,fmulttd,hmulttd,fmultpoint,hmultpoint,timepoint,$
;fmultcolpoint,hmultcolpoint,timecolpoint
@common_steer1
;common_steer1.pro:common steer1,npix,pixsize,pixpitch,pixoff,nchop,dcy,dry,drz
@common_timer
;common timer,time,dtime,complete
@common_signal
;common signal,rs,cs,nch,s_in,s,badin,bad,rel,rms,glitch,jf,njf,ninchmax,rd,$
;nkf,kf,nkfmax,irelstart,nchopmed,gbad,npolyrms,nrmsmed,sigmaxfract
@common_mapper
;common mapper,sgridy,sgridz,nygrid,nzgrid,ygrid,zgrid,errflag
;
loadct,2 ;  GRN-RED-BLU-WHT
;
if(n_elements(template) le 0)then begin
print,'skyflat,template,skyin,polydegree,mediandegree,implement,ips'
print,'eg: skyin=float(template)'
print,'    skyin(*,*)=1.0'
print,'skyflat,template,skyin,replicate(0,npix),replicate(0,npix),0,'''' 
goto,c333
endif
;
if(ips eq 'ps')then begin
set_plot,'ps' ; first plot
device,filename='skyflat.ps',/color 
endif ; ips eq 'ps'
;
fmulttd=s
fmulttd(*,*)=1.0
hmulttd=fmulttd
hmulttd(*,*)=0.0
;
skydum=skyin
skydum=float(n_elements(skydum))*skydum/total(skydum) 
                              ; this is to ensure that the scale factor 
;                             printed below
;                             represents the actual background brightness.
;                             without this statement, and without the
;                             further normalisations below, absolute 
;                             photometric scaling to SKYIN would be achievable.
;
; make map cube from points with otf set and with simple weighting
makemapmulti,npix,lindgen(npix),mapb,mapr,mapd,mapy,mapz,mapn,0,1
; for testing
;mapcreate,npix,lindgen(npix),mapb,mapr,mapd,mapy,mapz,mapn,0,1
;
; then project to MAPBALL,MAPNALL
mapball=fltarr(nygrid,nzgrid)
mapnall=lonarr(nygrid,nzgrid)
;
for iygrid = 0,nygrid-1 do begin
for izgrid = 0,nzgrid-1 do begin
ii=where(mapn(*,iygrid,izgrid) gt 0,nii)
if(nii gt 0)then begin
mapball(iygrid,izgrid)=total(mapb(ii,iygrid,izgrid))/float(nii)
mapnall(iygrid,izgrid)=total(mapn(ii,iygrid,izgrid))
endif ; nii gt 0
if(nii le 0)then begin
mapball(iygrid,izgrid)=mapb(0,iygrid,izgrid) ; filled with error symbol
mapnall(iygrid,izgrid)=0
endif ; nii le 0
endfor  ; izgrid
endfor  ; iygrid
;
; scale SKYDUM such that it's average over map pixels where TEMPLATE is 1
; is the same as the average value of MAPBALL where this is sampled, not taking
; into account the errors so as not to bias in favour of any particular 
; detector pixel.
;
skypixuse=lonarr(npix) ; to be filled with 1 if a detector pixel is used
                       ; for a direction for which MAPNALL and TEMPLATE is 1
nskypixuse=skypixuse   ; to be filled with number of map directions for which
                       ; MAPNALL and TEMPLATE is 1
ratio=fltarr(npix)     ; to be filled with mean ratio of MAPB to SKYDUM
maptouse=lonarr(npix,nygrid,nzgrid) ; to be filled with 1 for a direction for 
;                                     which MAPN and TEMPLATE is 1
;
iiall=where(mapnall ge 1 and template eq 1,niiall)
;
if(niiall le 0)then begin
print,'SKYFLAT: no background directions with data from any detector pixel'
goto,c999
endif ; niiall le 0
;
for ipix=0,npix-1 do begin
itest=where(mapn(ipix,*,*) gt 0 and template(*,*) gt 0 and $
mapb(ipix,*,*) gt 0,nitest)
if(nitest le 0)then goto,c888 ; no positive background data for this pixel
skypixuse(ipix)=1
ratiotot=0.0
for iygrid=0,nygrid-1 do begin
for izgrid=0,nzgrid-1 do begin
if(template(iygrid,izgrid) ne 0 and mapn(ipix,iygrid,izgrid) ne 0)then begin 
if(mapr(ipix,iygrid,izgrid) le 0.0)then begin
print,'SKYFLAT: warning - negative or zero data for ipix,iygrid,izgrid = ',$
ipix,iygrid,izgrid
print,'... negative or zero data not used in flat calculation'
goto,c444 
endif ; (mapr(ipix,iygrid,izgrid) le 0.0
ratiotot=ratiotot+mapb(ipix,iygrid,izgrid)/skydum(iygrid,izgrid)
nskypixuse(ipix)=nskypixuse(ipix)+1
maptouse(ipix,iygrid,izgrid)=1
endif ; template(iygrid,izgrid) eq 1 and mapn(ipix,iygrid,izgrid) eq 1
c444:
endfor ; izgrid
endfor ; iygrid
;
ratio(ipix)=ratiotot/float(nskypixuse(ipix))
;
c888:
endfor ; ipix=0,npix-1
;
ii=where(skypixuse eq 1,nii)
print,'SKYFLAT: positive background data found for pixels ...'
print,ii
print,'... with number of directions  ...'
print,nskypixuse(ii)
print,'... and fraction of directions ...'
print,float(nskypixuse(ii))/float(nygrid*nzgrid)
;
; statistics for ratio
;
rr=total(ratio(ii))/float(nii)
rstat=ratio(ii)/rr
;print,rstat
;print,rr
print,'SKYFLAT: statistics for average map scale factors:'
stat,rstat,rmin,rmax,rmed,rq1,rq2,rsigequiv,rav,rsig,1
;
; scale SKYDUM such that mean ratio to data is unity
;
; if SKYDUM has unity average value over the background directions then
; the following is a measure of the background: 
print,'SKYFLAT: scaling SKY to data by multiplying by ',rr
if(nii gt 1)then print,'SKYFLAT: uncertainty in scaling factor =       ',$
rr*rsig/sqrt(float(nii-1))
;
skydum=skydum*rr
;
; find data points for fit for each pixel:
;
sfit=fltarr(npix,nygrid*nzgrid)
rfit=sfit
tfit=sfit
ntfit=fltarr(npix)
ntfit(*)=0
icount=0
for iygrid = 0,nygrid-1 do begin
for izgrid = 0,nzgrid-1 do begin
timemapdirection,iygrid,izgrid,timeyz,timeref
for ipix=0,npix-1 do begin
if(maptouse(ipix,iygrid,izgrid) eq 0)then goto, c777
i=ntfit(ipix) ; starts at 0
sfit(ipix,i)=mapb(ipix,iygrid,izgrid)/skydum(iygrid,izgrid)
rfit(ipix,i)=mapr(ipix,iygrid,izgrid)/skydum(iygrid,izgrid)
tfit(ipix,i)=timeref(ipix)
icount=icount+1
if(icount gt 1)then begin
if(sfit(ipix,i) gt ymax)then ymax=sfit(ipix,i)
if(sfit(ipix,i) lt ymin)then ymin=sfit(ipix,i)
endif ; icount gt 1
if(icount le 1)then begin
ymax=sfit(ipix,i) ; initial assignment for maxmin value
ymin=ymax
endif ; icount le 1
ntfit(ipix)=ntfit(ipix)+1
c777:
endfor ; ipix
endfor ; izgrid
endfor ; iygrid
;
; set plot limits
xmax=max(time)
xmin=0.0
diff=ymax-ymin
ymax=(ymax+0.1*diff)
ymin=(ymin-0.1*diff)
;
; plot data points, perform and perform fit for each pixel, 
; according to median degree and polydegree, checking that there are 
; sufficient points, and overlay the fit:
; 
color=[15,37,100,15,37,100,15,37,100] ; green red blue cycle
colorps=[15,70,100,15,70,100,15,70,100]
linestyle=[0,0,0,1,1,1,2,2,2] ; linestyle for overplots of fits
title='SKYFLAT'
if(ips ne 'ps')then begin
window,0,tit=title,xs=800,ys=400,xpos=470,ypos=570
endif ; ips ne 'ps'
iplot=-1
;
iwrite=0
;
for ipix=0,npix-1 do begin
;
print,'SKYFLAT: ipix,mediandegree,polydegree = ',ipix,mediandegree(ipix),$
polydegree(ipix)
;
if(skypixuse(ipix) eq 0)then goto, c666
iwrite=iwrite+1
;
if(skypixuse(ipix) gt 0 and nskypixuse(ipix) lt polydegree(ipix)+1)then begin
print,'SKYFLAT - run with lower POLYDEGREE - ipix, samples, polydegree= ',$
ipix,nskypixuse(ipix),polydegree(ipix)
goto, c999
endif ; skypixuse(ipix) gt 0 and skypixuse(ipix) lt polydegree(ipix)+1
;
; reorder in time
tplot=tfit(ipix,0:ntfit(ipix)-1)
splot=sfit(ipix,0:ntfit(ipix)-1)
rplot=rfit(ipix,0:ntfit(ipix)-1)
is=sort(tplot)
tplot=tplot(is)
splot=splot(is)
rplot=rplot(is)
iplot=iplot+1
if(ipix eq 0)then psym=1
if(ipix eq 1)then psym=1
if(ipix eq 2)then psym=1
if(ipix eq 3)then psym=2
if(ipix eq 4)then psym=2
if(ipix eq 5)then psym=2
if(ipix eq 6)then psym=4
if(ipix eq 7)then psym=4
if(ipix eq 8)then psym=4
if(iplot eq 0)then begin ; plot frame, first plot in white (no data), 
;                          overplot in color
if(ips eq '')then begin ; plot without title
plot,tplot,splot,xtit='TIME(s)',ytit='SIGNAL/BACKGROUND',yran=[ymin,ymax],$
xran=[xmin,xmax],yst=1,xst=1,/nodata
oplot,tplot,splot,color=color(ipix),psym=psym
endif ; ips eq ''
if(ips eq 'ps')then begin ; same plot but with title 
plot,tplot,splot,xtit='TIME(s)',ytit='SIGNAL/BACKGROUND',yran=[ymin,ymax],$
xran=[xmin,xmax],yst=1,xst=1,/nodata,tit=title
oplot,tplot,splot,color=color(ipix),psym=psym
endif ; ips eq 'ps'
endif ; iplot eq 0
;
if(iplot gt 0)then begin ; just overplot, irrespective of value of IPS
oplot,tplot,splot,color=color(ipix),psym=psym
endif ; iplot gt 0
;
; median filtering
;
if(mediandegree(ipix) gt 1)then begin
;print,'SKYFLAT: performing median filter of width    ',mediandegree(ipix)
splot=median(splot,mediandegree(ipix))
endif ; mediandegree(ipix) gt 1
;
; polynomial fits to FMULTTD array and overplot
;
;print,'SKYFLAT: performing polynomial fit of degree  ',polydegree(ipix)
wplot=(1.0/rplot)^2.0 ; weights
aa=polyfitw(tplot,splot,wplot,polydegree(ipix))
wk1=time
wk2=time
wk2(*)=0.0
for ipoly=0,polydegree(ipix) do begin 
if(ipoly eq 0)then wk2(*)=wk2(*)+aa(0,ipoly)
if(ipoly gt 0)then wk2(*)=wk2(*)+aa(0,ipoly)*wk1^(float(ipoly))
endfor ; ipoly=0,polydegree(ipix)
;
oplot,wk1,wk2(*),color=color(ipix),linest=linestyle(ipix)
;
if(min(1.0/wk2(*)) le 0.)then begin
print,'SKYFLAT: warning - negative or zero multiplitive correction factors'
print,'.... found in fit for detector pixel ',ipix
print,'.... aborting'
goto,c999
endif ; min(fmulttd(ipix,*) le 0.)
fmulttd(ipix,*)=1.0/wk2(*)
;
c666:
;
endfor ; ipix
;
;  for any detector pixels not viewing background apply average of temporal
;  fit for pixels viewing background. Plot solution in white for inverse of
;  average flat field correction factor for all pixels viewing background 
;  directions as a single overlay
;
fmulttdav=time
fmulttdav(*)=1.0
iuse=where(skypixuse eq 1,niuse)
inouse=where(skypixuse ne 1,ninouse)
if(niuse gt 0)then begin
;
xniuse=float(niuse)
for i=0L,n_elements(time)-1 do begin
fmulttdav(i)=total(fmulttd(iuse,i))/xniuse
if(ninouse gt 0)then fmulttd(inouse,i)=fmulttdav(i)
endfor ; i=0,n_elements(time)-1
;
if(min(fmulttdav) le 0.)then begin
print,'SKYFLAT: warning - negative or zero multiplitive correction factors'
print,'.... found in average of fit for detector pixels ',iuse
print,'.... aborting'
goto,c999
endif ; min(fmulttdav) le 0.
;
oplot,time,1.0/fmulttdav,color=255
;
endif ; niuse gt 0
;
; Note that because we require the F factors to fit the data the
; mean of them may not be unity (this is the average of a series of inverse
; correction factors). We require however that the  mean correction factor is 
; zero. Therefore we multiply (as the correction is multiplicive) so that
; the average for the flat correction for all pixels is unity:
;
av=total(fmulttd)/float(npix*n_elements(time))
fmulttd=fmulttd/av
fmulttdav=fmulttdav/av
;
; print average of fits
;
for ip=0,niuse-1 do begin
ipix=iuse(ip)
if(ipix eq 0)then col=' (green full, crosses)'
if(ipix eq 1)then col=' (red full,   crosses)' 
if(ipix eq 2)then col=' (blue full,  crosses)'
if(ipix eq 3)then col=' (green dots, stars)  '
if(ipix eq 4)then col=' (red dots,   stars)  ' 
if(ipix eq 5)then col=' (blue dots)  stars)  '
if(ipix eq 6)then col=' (green dash) circles)'
if(ipix eq 7)then col=' (red dash)   circles)' 
if(ipix eq 8)then col=' (blue dash)  circles)'
print,'SKYFLAT: mean correction for pixel',byte(ipix),col,' =',$
total(fmulttd(ipix,*))/float(n_elements(time))
endfor ; ip
print,'SKYFLAT: mean of correction for all pixels (white)           =',$
float(total(fmulttdav)/float(n_elements(time)))
;
; implement solution
;
if(implement eq 1)then implementflat_td
;
c999:
;
if(ips eq 'ps')then begin
device,/close 
; $lpr -P9 skyflat.ps 
set_plot,'x'
print,'written file skyflat.ps'
endif ; ips eq 'ps'
;
c333:
;
return
end



