pro solvefcsillumhist,beta,tau,imodel,illumsky,illumskyprevfilter,idarkbefore,$
tf2,illumfcs,tfcs,sillumfcsprev,signalfcsprev,signalshootfcsprev,$
signalbeforeraster,signalshootbeforeraster,fcsillum,fcstime,fcsresp,ibefore
;
; input: 
;     BETA          (single real) detector constant used in calculating
;                                 the illumination. (not from common block)
;                                 to allow SOLVEFCSILLUMHIST to be called
;                                 in optimisation routines.
;     TAU           (single real) detector constant used in calculating
;                                 the illumination
;     TF2           effective time after FCS uillumination step that data
;                   taking starts (This is an input parameter since
;                   it is needed to offset the time arrays when the FCS data
;                   is imported in the calling routine.
;                   routine)
;     ILLUMSKY      (single real) sky illumination at chopper rest position
;                                 at start of raster
;                                 in V/s for the current filter (should be
;                                 input as appropriate for either the first
;                                 or last raster pointing. 
;     ILLUMSKYPREVFILTER (single real) sky illumination at chopper rest 
;                                 position at start of raster
;                                 in V/s for the previous filter (only used
;                                 for IBEFORE=1) 
;     ILLUMFCS      (single real) the fcs illumination. Note this has no
;                                 influence on FCSILLUMHIST prior to the
;                                 FCS illumination (eg for applications
;                                 to find the detector state before the
;                                 FCS illumination. It is needed however
;                                 by applications needing to find the detector
;                                 state after the FCS illumination immediately
;                                 prior to the raster
;     TFCS          (single real) The duration of the FCS illumination in s
;     IMODEL        (integer)     detector model (=1 for foukes schubert)
;                                 (=2 for exponential)
;     IBEFORE                     =1 for fcs measurement prior to raster
;                                 =1 for fcs measurement following raster
;     IDARKBEFORE                 =1 for measurement sequence starting from 
;                                 dark (should apply for all iseq='01'
;                                 cases except serendipity slew onto target).
;                                 The value of IDARKBEFORE only has an effect
;                                 for ibefore=1 iseq='01' and array='c200'
;                   For the Foukes model one should be wary of using FCS
;                   measurements after a dark since the signal variation
;                   in the early part of the FCS plateau is small but far
;                   from the asymptote. 
;     ARRAY         (common STEERIN) = 'c100' or 'c200'
;     ISEQ   (common NAMES) string denoting sequence number of target source 
;             map (normally '01' or '03' or '05' for multifilter sequence 
;             separated by FCS measurements) 
;     CFILTER (common NAMES, integer) = either 50,60,70,90,100,105,
;                                              120,135,160,180,200
;
; output:
;     SILLUMFCSPREV (single real) - the illumination seen by the detector 
;                    immediately before the FCS illumination. 
;     SIGNALFCSPREV (single real) - the slow detector response 
;                    immediately before the FCS illumination step.
;                    (= total detector response for imodel le 2
;     SIGNALSHOOTFCSPREV (single real) - the fast detector response 
;                    immediately before the FCS illumination step. Only needed
;                    for imodel ge 3.
;     SIGNALBEFORERASTER (single real) the slow detector response immediately
;                    prior to starting the raster. For imodel=1 or 2 this is
;                    also the total response
;     SIGNALSHOOTBEFORERASTER (single real) the fast component of detector 
;                    response immediately prior to starting the raster.
;                    only needed for imodel ge 3.
;     FCSILLUM      (a 1D real array) contains the the detector illumination
;                                 history sampled at the times in FCSTIME
;     FCSTIME       (a 1D real array) The times for which the response 
;                                 history was calculated, covering times
;                                 from switch-on to 2s or 0.1s (depending on
;                                 the value of TF4, see below) after the fcs
;                                 switched of. This set to a sampling interval
;                                 of the internal parameter TSAMP=0.1s 
;                                 (quite fine to allow a good resolution for
;                                  the important parameter TF2 (see below).
;     FCSRESP       (a 1D real array) response of FCS.
;     
;
; Inspection of the instrument command sequences for P32 gives the following
; instrument sequences for two filter observations from which the illumination
; sequence for the FCS can be derived.
;
; C100 array
; t=0    PS0001 Switch on heating for C100 array. ICS duration 1s.
; t=1    PS0014 Switch on electronics from standby. Wait 6s.
;               Filter remains C160. ICS duration 8s.
; t=9    PS0002 Wait 90s (C100 array only). ICS duration 90s.
; t=99   PS0016 Switch to target filter 1. ICS duration 7,6s for cases of 
;               C100,C105 filters.
; t=106  PS0021 Change CRE voltage. ICS duration 1s.
; t=107  PS0020 Reconfigure electronics for FCS. ICS duration 1.0s.
; t=108  PS0005 Start FCS. Estimated duration 1s.
; t=109  PS0005 Select TRS and power FCS. Estimated ICS duration 1s
; t=110  PS0005 Move chopper to FCS position. Estimated ICS duration 1s.
; t=111  PS0005 Wait 2s. Estimated ICS duration 2s.
; t=113  PS0005 Start FCS measurement. Measure for 32s. 
;               Estimated ICS duration 32s.
; t=145  PS0005 Turn off FCS. Presumably detector still points at FCS and 
;               sees dark. However signals sugggest that in actual fact
;               detector sees the sky from the middle chop position.
; t=145  PS0021 Change CRE voltage. ICS duration 1s.
; t=146  PS0020 Reconfigure electronics for raster. ICS duration 1.0s.
; t=147  PS0019 Sawtooth chopper start. Perform raster.
; t=0    BREAK  raster (after a considerable dwell at last raster position,
;               stopping at a random chopper position)
; t=0    PS0001 Switch on heating for C100 array. ICS duration 1s.
; t=1    PS0017 reset electronics after break. ICS duration 1s.
; t=1    PS0014 Switch on electronics from standby. Wait 6s.
;               Filter remains filter from previous raster. ICS duration 8s.
; t=9    PS0002 Wait 60s (C100 array only). ICS duration 60s.
; t=69   PS0021 Change CRE voltage. ICS duration 1s.
; t=70   PS0020 Reconfigure electronics for FCS. ICS duration 1.0s.
; t=71   PS0005 Start FCS. Estimated duration 1s.
; t=72   PS0005 Select TRS and power FCS. Estimated ICS duration 1s
; t=73   PS0005 Move chopper to FCS position. Estimated ICS duration 1s.
; t=74   PS0005 Wait 2s. Estimated ICS duration 2s.
; t=76   PS0005 Start FCS measurement. Measure for 32s. 
;               Estimated ICS duration 32s.
; t=108  PS0005 Turn off FCS. Presumably detector still points at FCS and 
;               sees dark. However signals sugggest that in actual fact
;               detector sees the sky from the middle chop position.
;        SLEW   to start of next raster - allow 9s.
; t=0    PS0016 Switch to next target filter. ICS duration 7s for case of 
;               selection C100_105 from C100_100 filter. 
; t=7    PS0021 Change CRE voltage. ICS duration 1s.
; t=8    PS0020 Reconfigure electronics for FCS. ICS duration 1.0s.
; t=9    PS0005 Start FCS. Estimated duration 1s.
; t=10   PS0005 Select TRS and power FCS. Estimated ICS duration 1s
; t=11   PS0005 Move chopper to FCS position. Estimated ICS duration 1s.
; t=12   PS0005 Wait 2s. Estimated ICS duration 2s.
; t=14   PS0005 Start FCS measurement. Measure for 32s. 
;               Estimated ICS duration 32s.  
; t=39   PS0005 Turn off FCS. Presumably detector still points at FCS and 
;               sees dark. However signals sugggest that in actual fact
;               detector sees the sky from the middle chop position.
; t=39   PS0021 Change CRE voltage. ICS duration 1s.
; t=40   PS0020 Reconfigure electronics for raster. ICS duration 1.0s.
; t=41   PS0019 Sawtooth chopper start. Perform raster.
; t=0    BREAK  raster (after a considerable dwell at last raster position,
;               stopping at a random chopper position);
; t=0    PS0001 Switch on heating for C100 array. ICS duration 1s.
; t=1    PS0017 reset electronics after break. ICS duration 1s.
; t=1    PS0014 Switch on electronics from standby. Wait 6s.
;               Filter remains filter from previous raster. ICS duration 8s.
; t=9    PS0002 Wait 60s (C100 array only). ICS duration 60s.
; t=69   PS0021 Change CRE voltage. ICS duration 1s.
; t=70   PS0020 Reconfigure electronics for FCS. ICS duration 1.0s.
; t=71   PS0005 Start FCS. Estimated duration 1s.
; t=72   PS0005 Select TRS and power FCS. Estimated ICS duration 1s
; t=73   PS0005 Move chopper to FCS position. Estimated ICS duration 1s.
; t=74   PS0005 Wait 2s. Estimated ICS duration 2s.
; t=76   PS0005 Start FCS measurement. Measure for 32s. 
;               Estimated ICS duration 32s.
; t=108  PS0005 Turn off FCS. Presumably detector  still points at FCS and
;               sees dark. However signals sugggest that in actual fact
;               detector sees the sky from the middle chop position.
; t=108  PS0009 Switch off heating. ICS duration 1s.
; t=109  PS0008 Switch detector to standby. ICS duration 1s.
; t=110  PS0000 Configuration reset for serendipity, including filter. 
;               ICS duration 18s.
;
; For the purposes of FINDFCSILLUMHIST the detector illumination for
; P32 in the C100 detector can be summarised as
;
;************************** RASTER in FIRST FILTER
; t<0           first raster position in C160 filter (ie almost 
;               dark). detector stabilised during long wait.
; t=0 to t=8s   view first raster position in 1st filter. In fact  
;               the time since filter wheel motion started, will be ca. 11s,
;               and the time since stopping will be ca. 5s. However, 
;               illumination will be received partially during the wheel
;               rotation, so we adopt TF1=8s as a reasonable compromise for the
;               effective duration of this phase. The precise details will
;               depend on which filter is selected. However, the first FCS
;               exposure should generally start from a lower detector
;               response than subsequent ones and this may make it the best
;               for finding beta, tau in many cases.
; t=8 to t=43s  View FCS for 35s. Data is only recorded for the last TF3=32s -
;               ie TF2=3s after fcs starts to heat up.
;               In fact since the fcs is warming the effective starting
;               time may be somewhere between 2 and 3s before the fcs heat-up.
; t=43 to 45s   Either view cold FCS for 2s (ie almost dark) or view central
;               chopper position for TF4=2s. Experience of the data suggests 
;               the latter. 
; t=45s         Start raster at beginning of first sawtooth sweep
; ---------------------
; t=0 to t=73s   Raster ends at some unspecified sky position and detector 
;                state which can be estimated in DRIFTCORR. View central
;                chopper position for TF5=73s.
; t=73 to t=108s View FCS for 35s. Data is only recorded for the last TF3=32s -
;                ie TF2=3s after fcs starts to heat up.
;                In fact since the fcs is warming the effective TF2 may be
;                somewhere between 2 and 3s before the fcs heat-up.      
; ********************** RASTER IN SECOND FILTER
; t=-9 to 0s     View average of sky brightness for TF0=9s during slew to 
;                raster start position in filter of previous raster.
; t=0 to 8s      View first sky position in new filter for TF1=8s 
;                (again, 8s instead of 11s - see above)
; t=8 to 43 s    View FCS for 35s. Data is only recorded for the last TF3=32s -
;                ie TF2=3s after fcs starts to heat up
; t=43 to 45s    View central chopper position for TF4=2s. 
; t=45s          Start raster at beginning of first sawtooth sweep
; ----------------------
; t=0 to t=73s   Raster ends at some unspecified sky position and detector 
;                state which can be estimated in DRIFTCORR. View central
;                chopper position for TF5=73s.
; t=73 to t=108s View FCS for 35s. Data is only recorded for the last TF3=32s -
;                ie TF2=3s after fcs starts to heat up.
; **********************
;
; In turn the following scheme will be adopted as the best possible
; for the determination of detector state, for a two filter sequence.
;
; **** C100 array ISEQ='01' IBEFORE=1 **** (comes from C160 filter)
; VIEW BR0=ILLUMSKY*XATTEN (ILLUMSKY viewed through C160) filter for TF0=106s
;      treat this as setting intial state SIGNAL0,SILLUM0 = BR0,BR0
; VIEW ILLUMSKY for TF1=5s in current filter
; VIEW ILLUMFCS for TF2= between 2 and 3s - say 2s as signal prop T**4  
; VIEW ILLUMFCS for TFCS (normally 32s) in current filter. Data is taken during
;                   this time.
; VIEW ILLUMSKY for TF3=2s in current filter
; **** perform raster, then break. 
; **** C100 array ISEQ='01' IBEFORE=0 **** (comes from current filter)
; VIEW BR0=ILLUMSKY (for last raster position) for TF0=73s
;      treat this as setting intial state SIGNAL0,SILLUM0 = ILLUMSKY,ILLUMSKY
; VIEW ILLUMSKY for TF1=5s in current filter (note TF1 can be set to same TF1
;      as for IBEFORE=1 as detector is stabilised at ILLUMSKY.
; VIEW ILLUMFCS for TF2= between 2 and 3s - say 2s as signal prop T**4  
; VIEW ILLUMFCS for TFCS (normally 32s) in current filter. Data is taken during
;                   this time.
; VIEW ILLUMSKY for TF3=2s in current filter. In Fact this is instantaneous
;      a slew starts immediately to the next starting position in the raster,
;      which will mean no slew for even NZ. It's probably reasonable to
;      have TF3 the same for IBEFORE=0 as for IBEFORE=1.
; **** slew to start of next raster (allow ca. 10s for target aquisition,
;      though this will depend on the raster size).
; **** C100 array ISEQ='03' IBEFORE=1 **** (comes from previous filter)
; VIEW BR0=ILLUMSKYPREVFILTER (signal in V/s at start of raster viewed through 
;      previous filter) filter for TF0=ca. 10 seconds (the time normally spent
;      near a desination pointing before the otf set. treat this as setting 
;      initial state SIGNAL0,SILLUM0 = ILLUMSKYPREVFILTER,ILLUMSKYPREVFILTER
; VIEW ILLUMSKY for TF1=5s in current filter
; VIEW ILLUMFCS for TF2= between 2 and 3s - say 2s as signal prop T**4  
; VIEW ILLUMFCS for TFCS (normally 32s) in current filter. Data is taken during
;                   this time.
; VIEW ILLUMSKY for TF3=2s in current filter
; **** perform raster, then break. 
; **** C100 array ISEQ='03' IBEFORE=0 **** (comes from current filter)
; VIEW BR0=ILLUMSKY (for last raster position) for TF0=73s
;      treat this as setting intial state SIGNAL0,SILLUM0 = ILLUMSKY,ILLUMSKY
; VIEW ILLUMSKY for TF1=5s in current filter (note TF1 can be set to same TF1
;      as for IBEFORE=1 as detector is stabilised at ILLUMSKY.
; VIEW ILLUMFCS for TF2= between 2 and 3s - say 2s as signal prop T**4  
; VIEW ILLUMFCS for TFCS (normally 32s) in current filter. Data is taken during
;                   this time.
; VIEW ILLUMSKY for TF3=2s in current filter. 
; the simulation ends here ignoring the effect on the detector of setting
; up the serendipity configuration.
;
;
; For C200 we have a similar situation, but with no detector heating and
;      possibly coming from the C160 serendipity. If there is no serendipity
;      specify idarkbefore=1
; **** C200 array ISEQ='01' IBEFORE=1 **** (comes from C160 filter)
; VIEW BR0=ILLUMSKY*XATTEN (ILLUMSKY viewed through C160) filter for 
;      TF0=previous slew plus ca. 7s. If idarkbefore=1 xatten is set to a
;      low number.
;      treat this as setting intial state SIGNAL0,SILLUM0 = BR0,BR0
; VIEW ILLUMSKY for TF1=5s in current filter
; VIEW ILLUMFCS for TF2= between 2 and 3s - say 2s as signal prop T**4  
; VIEW ILLUMFCS for TFCS (normally 32s) in current filter. Data is taken during
;                   this time.
; VIEW ILLUMSKY for TF3=2s in current filter
; **** perform raster, then break. 
; **** C200 array ISEQ='01' IBEFORE=0 **** (comes from current filter)
; VIEW BR0=ILLUMSKY (for last raster position) for TF0= a few sec
;      treat this as setting intial state SIGNAL0,SILLUM0 = ILLUMSKY,ILLUMSKY
; VIEW ILLUMSKY for TF1=5s in current filter (note TF1 can be set to same TF1
;      as for IBEFORE=1 as detector is stabilised at ILLUMSKY.
; VIEW ILLUMFCS for TF2= between 2 and 3s - say 2s as signal prop T**4  
; VIEW ILLUMFCS for TFCS (normally 32s) in current filter. Data is taken during
;                   this time.
; VIEW ILLUMSKY for TF3=2s in current filter. In Fact this is instantaneous
;      a slew starts immediately to the next starting position in the raster,
;      which will mean no slew for even NZ. It's probably reasonable to
;      have TF3 the same for IBEFORE=0 as for IBEFORE=1.
; **** slew to start of next raster (allow ca. 10s for target aquisition,
;      though this will depend on the raster size).
; **** C200 array ISEQ='03' IBEFORE=1 **** (comes from previous filter)
; VIEW BR0=ILLUMSKYPREVFILTER (signal in V/s at start of raster viewed through 
;      previous filter) filter for TF0=ca. 10 seconds (the time normally spent
;      near a desination pointing before the otf set. treat this as setting 
;      initial state SIGNAL0,SILLUM0 = ILLUMSKYPREVFILTER,ILLUMSKYPREVFILTER
; VIEW ILLUMSKY for TF1=5s in current filter
; VIEW ILLUMFCS for TF2= between 2 and 3s - say 2s as signal prop T**4  
; VIEW ILLUMFCS for TFCS (normally 32s) in current filter. Data is taken during
;                   this time.
; VIEW ILLUMSKY for TF3=2s in current filter
; **** perform raster, then break. 
; **** C200 array ISEQ='03' IBEFORE=0 **** (comes from current filter)
; VIEW BR0=ILLUMSKY (for last raster position) for TF0=73s
;      treat this as setting intial state SIGNAL0,SILLUM0 = ILLUMSKY,ILLUMSKY
; VIEW ILLUMSKY for TF1=5s in current filter (note TF1 can be set to same TF1
;      as for IBEFORE=1 as detector is stabilised at ILLUMSKY.
; VIEW ILLUMFCS for TF2= between 2 and 3s - say 2s as signal prop T**4  
; VIEW ILLUMFCS for TFCS (normally 32s) in current filter. Data is taken during
;                   this time.
; VIEW ILLUMSKY for TF3=2s in current filter. 
; the simulation ends here ignoring the effect on the detector of setting
; up the serendipity configuration.
;
;
;
;
@common_steerin
;common steerin,array,nptin,npt,ninramp,imeas,osamp
@common_names
;common names,tdtnam,iseq,dirnam,caldir,cfilter
;
tsamp=0.1
;
if(imodel ne 1 and imodel ne 2 and imodel ne 3)then begin
print,'SOLVEFCSILLUMHIST - aborting - imodel must specify an existing model'
goto,c999
endif ; imodel ne 1 and imodel ne 2 and imodel ne 3
;
; set up time and illumination constants
;
if(array eq 'c200')then begin
xatten=1.0 ; c200 detector starts from serendipity
if(idarkbefore eq 1)then xatten=0.05 ; if no serendipity 
br0=illumsky
if(iseq eq '01' and ibefore eq 1)then br0=xatten*illumsky
if(iseq eq '01' and ibefore ne 1)then br0=illumsky
if(iseq ne '01' and ibefore eq 1)then br0=illumskyprevfilter
if(iseq ne '01' and ibefore ne 1)then br0=illumsky
tf1=5.0
;tf2=2.0 ; this is an imported number
tf3=2.0
endif ; array eq 'c200'
;
if(array eq 'c100')then begin
xatten=0.05 ; c100 detector always starts from dark 
br0=illumsky
if(iseq eq '01' and ibefore eq 1)then br0=xatten*illumsky
if(iseq eq '01' and ibefore ne 1)then br0=illumsky
if(iseq ne '01' and ibefore eq 1)then br0=illumskyprevfilter
if(iseq ne '01' and ibefore ne 1)then br0=illumsky
tf1=5.0
;tf2=2.0 ; this iss an imported number
tf3=2.0
endif ; array eq 'c100'
;
; starting detector state 
;
; assume detector in equilibrium before starting
;
sillum0=br0
signal0=br0
signalshoot0=0.0
;
; build FCSILLUM and FCSTIME arrays
;
; view of central chopper position in current filter before FCS illumination
n=1+long(tf1/tsamp)
dummyt=tsamp*findgen(n)
dummyf=dummyt
dummyf(*)=illumsky
fcsillum=dummyf
fcstime=dummyt+tsamp ; must not start at zero
;
;
; here calculate sillumfcsprev,signalfcsprev
;
if(imodel eq 1)then foukes,beta,tau,signal0,sillum0,fcsillum,fcstime,signal
if(imodel eq 2)then expfun,beta,tau,signal0,sillum0,fcsillum,fcstime,signal
if(imodel eq 3)then expshoot,beta,tau,signal0,signalshoot0,sillum0,fcsillum,$
fcstime,signal,signalslow,signalshoot
; plot,fcstime,fcsillum
; oplot,fcstime,signal
nall=n_elements(fcstime)
if(imodel eq 1 or imodel eq 2)then begin
signalfcsprev=signal(nall-1) ; total response = slow response
signalshootfcsprev=0.0 ; just to initialise
endif ; imodel eq 1 or imodel eq 2
if(imodel eq 3)then begin
signalfcsprev=signalslow(nall-1)
signalshootfcsprev=signalshoot(nall-1)
endif ; imodel eq 3
;
sillumfcsprev=fcsillum(nall-1)
;
; FCS illumination no data taking
n=1+long(tf2/tsamp)
dummyt=tsamp*findgen(n)+max(fcstime)
dummyf=dummyt
dummyf(*)=illumfcs
fcsillum=[fcsillum,dummyf]
fcstime=[fcstime,dummyt]
;
; FCS illumination and data taking
n=1+long(tfcs/tsamp)
dummyt=tsamp*findgen(n)+max(fcstime)
dummyf=dummyt
dummyf(*)=illumfcs
fcsillum=[fcsillum,dummyf]
fcstime=[fcstime,dummyt]
;
; view of central chopper position before raster starts
n=1+long(tf3/tsamp)
dummyt=tsamp*findgen(n)+max(fcstime)
dummyf=dummyt
dummyf(*)=illumsky
fcsillum=[fcsillum,dummyf]
fcstime=[fcstime,dummyt]
;
; here calculate signalbeforeraster,signalshootbeforeraster,fcsresp
;
if(imodel eq 1)then foukes,beta,tau,signal0,sillum0,fcsillum,fcstime,fcsresp
if(imodel eq 2)then expfun,beta,tau,signal0,sillum0,fcsillum,fcstime,fcsresp
if(imodel eq 3)then expshoot,beta,tau,signal0,signalshoot0,sillum0,fcsillum,$
fcstime,fcsresp,fcsrespslow,fcsrespshoot
nall=n_elements(fcstime)
if(imodel eq 1 or imodel eq 2)then begin
signalbeforeraster=fcsresp(nall-1) ; total response 
signalshootbeforeraster=0.0 ; just to initialise, though parameter is not used
endif ; imodel eq 1 or imodel eq 2
;
if(imodel eq 3)then begin
signalbeforeraster=fcsrespslow(nall-1) ; slow response 
signalshootbeforeraster=fcsrespshoot(nall-1)
endif ; imodel eq 3
;
; plot,fcstime,fcsillum
; oplot,fcstime,fcsresp
;
;print,'SOLVEFCSILLUMHIST: sillumfcsprev,signalfcsprev,signalbeforeraster = '
;print,sillumfcsprev,signalfcsprev,signalbeforeraster
;
c999:
;
return
end







