pro startendpoint,ipointstart,ipointstop,$
irasterstart,irasterstop,istartnoexpand,istopnoexpand,$
irasterstarte,irasterstope,istartexpand,istopexpand
; 
; STARTENDPOINT finds the starting and ending samples corresponding
; to the start of the s/c fine pointing IPOINTSTART and the end of the
; s/c fine pointing IPOINTSTOP. The s/c raster pointings are specified as
; a 1D sequence in time order.
;
; input:
;                IPOINTSTART First spacecraft fine pointing (in time order)
;                            in sequence 
;                IPOINTSTOP  Last spacecraft fine pointing (in time order)
;                            in sequence
;         IREDUCE   (1D array INTEGER common e32) This is set to 0 for data 
;                     which is transmitted to the ground and 1 for data not
;                     transmitted (in the fast readout modes).
; input from common PLOTTER:
;         OTFSTART,OTFSTOP long (ny,nz) integer identifiers of reads (in 
;                     unexpanded time line) corresponding to range
;                     where pointing is always within precision precotf 
;                     as set in POINT.
;         NYRASTER NZRASTER dimensions of spacecraft raster pointing   
;
; output:
;                ISTARTEXPAND  integer sample identifier of first read on 
;                   s/c fine pointing IPOINTSTART in expanded sampling scheme,
;                   if this has been calculated. Not assigned if expanded
;                   scheme does not exist.
;                ISTOPEXPAND  integer sample identifier of last read on
;                   s/c fine pointing IPOINTSTOP in expanded sampling scheme,
;                   if this has been calculated. Not assigned if expanded
;                   scheme does not exist.
;                ISTARTNOEXTEND sample in the unexpanded sampling scheme 
;                       corresponding to ISTARTEXTEND
;                ISTOPNOEXTEND sample in the unexpanded sampling scheme
;                       corresponding to ISTOPEXTEND
;                IRASTERSTART integer array dimension NYPRASTER*NZRASTER
;                       gives IDL identifier of starting sample of each s/c
;                       raster position in original sampling scheme
;                IRASTERSTOP  integer array dimension NYPRASTER*NZRASTER
;                       gives IDL identifier of last sample of each s/c
;                       raster position in original sampling scheme
;                IRASTERSTARTE integer array dimension NYPRASTER*NZRASTER
;                       gives IDL identifier of starting sample of each s/c
;                       raster position in original sampling scheme, if this
;                       has been calculated. Output as zeros if expanded
;                       scheme does not exist.
;                IRASTERSTOPE  integer array dimension NYPRASTER*NZRASTER
;                       gives IDL identifier of last sample of each s/c
;                       raster position in expanded sampling scheme, if this
;                       has been calculated. Output as zeros if expanded
;                       scheme does not exist.
;
@common_e32
;common e32,es,ireduce,eytrue,eztrue,etime,fpoint,echop,estep,ebad,neptin
@common_plotter
;common plotter,otfstart,otfstop,rdstat,chop,step,otf,rpid,yrel,zrel,$
;ytrue,ztrue,yzrpidcen,nyraster,nzraster,racenout,deccenout
;
iexpand=1
if(n_elements(ireduce) eq 0)then begin
print,'STARTENDPOINT: warning - can only find sampling for non-expanded scheme'
iexpand=0
endif ; n_elements(ireduce) eq 0
;
if(iexpand eq 1)then begin
itt=where(ireduce eq 0,nitt) ; list of transmitted points in expaanded scheme
iexparray=lindgen(n_elements(ireduce)) ; iorigarray contains mapping of
;                                      ; original into extended sampling scheme
iorigarray=iexparray(itt)          ; it could be generated by expand32 and put
;                                  ; into the common_e32 block to prevent
;                                  ; unnecessary recalculation 
endif ; iexpand eq 1
irasterstart=lonarr(nyraster*nzraster)
irasterstop=irasterstart
irasterstarte=irasterstart
irasterstope=irasterstop
icount=-1
;
for iy=0,nyraster-1 do begin
for iz=0,nzraster-1 do begin
;
icount=icount+1
dummy=otfstart(iy,iz)
irasterstart(icount)=dummy ; non-expanded solution
if(iexpand eq 1)then irasterstarte(icount)=itt(dummy) ; expanded solution
dummy=otfstop(iy,iz)
irasterstop(icount)=dummy ; non-expanded solution
if(iexpand eq 1)then irasterstope(icount)=itt(dummy) ; expanded solution
;
endfor ; iz
endfor ; iy
;
; reorder irasterstart,irasterstop (raster goes up and down raster legs)
isr=sort(irasterstart)
irasterstart=irasterstart(isr)
irasterstop=irasterstop(isr) ; sort(irasterstart) correct
;
irasterstarte=irasterstarte(isr)
irasterstope=irasterstope(isr) 
;
istartnoexpand=irasterstart(ipointstart)
istopnoexpand=irasterstop(ipointstop)
if(iexpand eq 1)then begin
istartexpand=irasterstarte(ipointstart)
istopexpand=irasterstope(ipointstop)
endif ; iexpand eq 1
;
return
end









