pro timelinefig,ifine1,ifine2,ifine,ipix,ips


; CG: Based on RJT's timelinefigure but using PIA capabilities 
;
; Reads diagnostic info from last run of DRIFTCORR for detector pixel IPIX 
; from disk file timelinefigure'ipix'.xdr and plots results for range of ISO 
; fine pointings starting at IFINE1 (IDL convention) and ending at IFINE2,
; if IFINE is 'fine', and from elementary point IFINE1 (IDL convention) to 
; elementary point IFINE2 if IFINE is ''. If IFINE is 'time' then the
; plot is versus time.
; If IPS is '' the output is written
; to screen X window IWINDOW. If IPS is 'ps' then the data is output to the
; colour ps file timelinefigure.ps (same name independent of value of IPIX). 
; The data are read from save files on disk rather eg from common blocks
; as the files are written directly after each DRIFTCORR run and thus contain 
; signals/corrections directly used/found by DRIFTCORR prior to
; restoration of subtracted backgrounds and negative or low signals from the
; signal conditioning for DRIFTCORR.
;
; must be called from IDL session from which ERDTOMAP and DRIFT32 were run
; eg timelinefigure,0,0,0,'fine',3,'' ; first pointing pixel 3 to window 0
; timelinefigure,0,0,0,,fine',3,'ps' ; first pointing pixel 3 to ps file
; timelinefigure,0,50,80,'',3,'' ; samples 50 to 80 of pixel 3 
;                                  to screen window 0
;
; NB to avoid confusion this routine loads only ONE colour table
; (2 ; GRN-RED-BLU-WHT), without returning to the input
; colour table so the plot colours can be preserved on the screen
;
; Data imported from the XDR file (all arrays as imported/exported from
;                                  DRIFTCORR)
; MODELFIT RESPCORR MSK FPOINT MASKOUT SIGNAL SKYPASS ECH
;
; internal parameters:
;
inumplot=1 ; =1 to relace time with data identifier on X axis in expanded 
;               resolution to compare with iverbose output
;
; CG- Data from drift_struct common rather than XDR files
COMMON drift_struct, drift_struct
@colour_indices

xtit='READOUT'
if(ifine eq 'time')then begin
inumplot=0
xtit='TIME (s)'
endif ; ifine eq 'time'
;
isimulfit=1 ; to overplot illumination as dotted line from S array
;             (eg from the IDL session after correction from common block). 
;              For algorithm diagnostics S can be overwritten with the 
;              illumination input (from the simulation without drift noise 
;              etc).
@common_all
;if(ipix eq 0)then restore,'timelinefigure0.xdr'
;if(ipix eq 1)then restore,'timelinefigure1.xdr'
;if(ipix eq 2)then restore,'timelinefigure2.xdr'
;if(ipix eq 3)then restore,'timelinefigure3.xdr'
;if(ipix eq 4)then restore,'timelinefigure4.xdr'
;if(ipix eq 5)then restore,'timelinefigure5.xdr'
;if(ipix eq 6)then restore,'timelinefigure6.xdr'
;if(ipix eq 7)then restore,'timelinefigure7.xdr'
;if(ipix eq 8)then restore,'timelinefigure8.xdr'
;
time=drift_struct.time 
fpoint=drift_struct.fpoint
msk=drift_struct.msk(ipix,*)
itrans=drift_struct.itrans
modelfit=drift_struct.modelfit(ipix,*) 
respcorr=drift_struct.respcorr(ipix,*) 
signal=drift_struct.signal(ipix,*) 
maskout=drift_struct.maskout(ipix,*) 
ech=drift_struct.ech 
savearray=drift_struct.savearray 
skypasssav=drift_struct.skypasssav(ipix,*)

ii=where(itrans eq 1,nii)
;
mpfit=modelfit(ii)               ; these arrays are not help in common
rpfit=respcorr(ii)*modelfit(ii)
mskbad=msk(ii)
fpn=fpoint(ii)
mk=maskout(ii)
sigin=signal(ii)
skyp=skypasssav(ii)
;
if(ipix eq 0)then tit=tdtnam+' '+iseq+' PIXEL 0'
if(ipix eq 1)then tit=tdtnam+' '+iseq+' PIXEL 1'
if(ipix eq 2)then tit=tdtnam+' '+iseq+' PIXEL 2'
if(ipix eq 3)then tit=tdtnam+' '+iseq+' PIXEL 3'
if(ipix eq 4)then tit=tdtnam+' '+iseq+' PIXEL 4'
if(ipix eq 5)then tit=tdtnam+' '+iseq+' PIXEL 5'
if(ipix eq 6)then tit=tdtnam+' '+iseq+' PIXEL 6'
if(ipix eq 7)then tit=tdtnam+' '+iseq+' PIXEL 7'
if(ipix eq 8)then tit=tdtnam+' '+iseq+' PIXEL 8'
;
;loadct,2 ; GRN-RED-BLU-WHT
;if(ips eq '')then window,iwindow,tit=tit,xs=800,ys=400,xpos=470,ypos=570
if(ips eq 'ps')then begin
set_plot,'ps'
device,filename='timelinefigure.ps',/color 
endif ; ips
;
;
; assign xiplot1 xiplot2 to plot range (original counter for non-extended
; data set) in IDL notation:
;
if(ifine eq 'fine')then begin ; ifine1 ifine2 denote fine pointing 
;
; find start and end points in original sampling IPLOT1 IPLOT2
;
startendpoint,ifine1,ifine2,$
irasterstart,irasterstop,iplot1,iplot2,$
irasterstarte,irasterstope,ieplot1,ieplot2
;
xiplot1=float(iplot1) ; add margin to get entry
xiplot2=float(iplot2) ; and exit from pointing
xxoffset=0.2*(xiplot2-xiplot1)
xiplot1=xiplot1-xxoffset
xiplot2=xiplot2+xxoffset
;
endif ; ifine eq 'fine'
;
if(ifine ne 'fine')then begin ; ifine1 and ifine2 denote elementary samples
;                               at original (unexpanded) time sampling
xiplot1=ifine1
xiplot2=ifine2
;
endif ; ifine eq 'fine'
;
xiplot1=long(xiplot1)
xiplot2=long(xiplot2)
if(xiplot1 lt 0)then xiplot1=0
if(xiplot2 gt nptin-1)then xiplot2=nptin-1 
if(xiplot2 gt xiplot1)then begin ; plot fits
igood=where(mskbad(xiplot1:xiplot2) eq 0,nigood)
ix=ii(igood)
; plot illumination in black by omitting COLOR keyword
xax=time(xiplot1+igood)
yrtop=$
max([rpfit(xiplot1+igood),sigin(xiplot1+igood),mpfit(xiplot1+igood)])/(0.8)
yrbot=0.0
if(inumplot eq 1)then xax=xiplot1+igood
;
if(ips ne 'ps')then pia_xplot,xax,rpfit(xiplot1+igood),xtitle=xtit,$
ytitle='SIGNAL (V/s)',xstyle=1,ystyle=1, $
title='Drift P32 results - Pixel '+STRTRIM(ipix+1,2), $
legend='Illumination level'
;
if(ips eq 'ps')then plot,xax,rpfit(xiplot1+igood),xtit=xtit,$
ytit='SIGNAL (V/s)',xsty=1,yst=1,yran=[yrbot,yrtop],tit=tit
;
; overplot signal conditioned in PREPARE colour tables depend on device
if(ips eq 'ps')then color=red ; red for colour table 2 ps file output
if(ips ne 'ps')then color=red ; red for colour table 2 screen output
;oplot,time(xiplot1+igood),sigin(xiplot1+igood),color=color ; (signal)
pia_xplot,xax,sigin(xiplot1+igood),color=color, /overplot, $
 legend='Signal in'
if(ips eq 'ps')then color=green ; green for colour table 2 ps file output
if(ips ne 'ps')then color=green ; green for colour table 2 screen output
;oplot,time(xiplot1+igood),mpfit(xiplot1+igood),color=color ; green (modelfit)
pia_xplot,xax,mpfit(xiplot1+igood),color=color, /overplot, $
  legend='Model fit' ; green (modelfit)
;
; overplot skypasssav array for good points on fine pointings
if(ips eq 'ps')then color=blue ; violet for colour table 2 ps file output
if(ips ne 'ps')then color=blue ; violet for colour table 2 screen output
ifgood=where(mskbad(xiplot1:xiplot2) eq 0 and fpn(xiplot1:xiplot2) eq 1,$
nifgood)
if(nifgood ge 1)then begin
xaxf=time(xiplot1+ifgood)
if(inumplot eq 1)then xaxf=xiplot1+ifgood
pia_xplot,xaxf,skyp(xiplot1+ifgood),color=color,psym=4, $
 symsize=0.5, /overplot, legend='Skyp' 
;oplot,xax,skyp(xiplot1+igood),color=color,psym=3, /overplot
endif ; nifgood ge 1
;
; overplot fpoint array at top of figure
iibot=where(fpn eq 0,niibot)
iitop=where(fpn ne 0,niitop)
fpn=float(fpn)
fpn(iibot)=yrbot+0.90*(yrtop-yrbot)
fpn(iitop)=yrbot+0.98*(yrtop-yrbot)
pia_xplot,xax,fpn(xiplot1+igood), /overplot, $
	color=orange, legend='Fpoint'
;
; overplot mk array at top of figure
iibot=where(mk eq 0,niibot)
iitop=where(mk ne 0,niitop)
mk=float(mk)
mlinebot=yrbot+0.81*(yrtop-yrbot)
if(niibot gt 0)then mk(iibot)=mlinebot
;if(niibot eq 0)then mk(*)=mlinebot
mlinetop=yrbot+0.89*(yrtop-yrbot)
if(niitop gt 0)then mk(iitop)=mlinetop
;if(niitop eq 0)then mk(*)=mlinetop
pia_xplot,xax,mk(xiplot1+igood), /overplot, $
 color=yellow, legend='MKarray'
;
; overplot mskbad array at top of figure
iibot=where(mskbad eq 0,niibot)
iitop=where(mskbad ne 0,niitop)
mlinebot=yrbot+0.84*(yrtop-yrbot)
mskbad=float(mskbad)
if(niibot gt 0)then mskbad(iibot)=mlinebot
;if(niibot eq 0)then mskbad(*)=mlinebot
mlinetop=yrbot+0.86*(yrtop-yrbot)
if(niitop gt 0)then mskbad(iitop)=mlinetop
;if(niitop eq 0)then mskbad(*)=mlinetop
if(ips eq 'ps')then color=red ; red for colour table 2 ps file output
if(ips ne 'ps')then color=red ; red for colour table 2 screen output
;oplot,xax,mskbad(xiplot1+igood),color=color
if(inumplot eq 1)then pia_xplot,xiplot1+lindgen(xiplot2-xiplot1+1),$
mskbad(xiplot1+lindgen(xiplot2-xiplot1+1)),psym=3, /overplot, $
	legend='Masking array' ; dots
if(inumplot ne 1)then pia_xplot,time(xiplot1+lindgen(xiplot2-xiplot1+1)),$
mskbad(xiplot1+lindgen(xiplot2-xiplot1+1)),psym=3, /overplot,$
	legend='Masking array' 
;
; plot vertical lines at start of each chopper sweep using the step array ECH:
; this makes use of the fact that the chopper sweeps always begin with a
; transmitted read
itest=lonarr(nii)
itest(1:nii-1)=ech(ii(1:nii-1))-ech(ii(0:nii-2))
if(savearray eq 'c100')then chswlim=12
if(savearray eq 'c200')then chswlim=6
iii=where(abs(itest) ge chswlim,niii)
;print,niii,chswlim,savearray,max(abs(itest))
if(niii gt 0)then begin
 
; for ipc=0,niii-1 do begin
  if(inumplot eq 1)then xpc=iii(0:niii-1) ; plot versus read
  if(inumplot ne 1)then xpc=time(iii(0:niii-1)) ; plot versus time
;if(ips eq 'ps')then color=100 ; violet for colour table 2 ps file output
;if(ips ne 'ps')then color=100 ; violet for colour table 2 screen output
  lin = (yrbot+yrtop) / 2
  linarr = FLTARR(niii) + lin
  pia_xplot, xpc, linarr , linarr, psym=3, yerrstyle=1, /overplot,$
    legend='Chopper sweeps' 
; endfor ; ipc=0,niii-1
endif ; niii gt 0
if(isimulfit eq 1)then begin ; overplot with simulation read into s array

pia_xplot,xax,s(ipix,xiplot1+igood),psym=5, legend='Signals ',$
	symsize=0.5, /overplot
endif
endif ; iplot2 gt iplot1
if(ips eq 'ps')then begin
device,/close 
; $lpr -P9 timelinefigure.ps 
set_plot,'x'
print,'written file timelinefigure.ps'
endif ; ips eq 'ps'
;
return
end




