pro zcompare,map1,mapn1,map2,mapn2,const,slope
;
; finds factors const and slope such that map1 * slope + constant = map2
; where the comparison is done not requiring data on the same map pixels
; (eg z flats for o/s < 1 p32 maps). However only pixels are used such that
; amount of data > (average per pixel) * wfraction. To avoid problems
; with bright sources being seen in one dataset but not the other, the upper
; fupper fraction of points is not used.
;
; input: map1(nygrid,nzgrid)  = brightness
;        map1n(nygrid,nzgrid) = number of data samples in each map pixel
;        map2, map2n as above
;
common mapper,sgridy,sgridz,nygrid,nzgrid,ygrid,zgrid,errflag
;
@common_mapper
;
wfraction=0.5
fupper=0.1
imap1=lonarr(nygrid,nzgrid) 
imap2=imap1
n1=total(mapn1)
xnthresh1=float(n1)/float(nygrid*nzgrid)
xnthresh1=xnthresh1*wfraction
n2=total(mapn2)
xnthresh2=float(n2)/float(nygrid*nzgrid)
xnthresh2=xnthresh2*wfraction
imap1=where(float(mapn1) gt xnthresh1,nimap1)
imap2=where(float(mapn2) gt xnthresh2,nimap2)
print,'nimap1,nimap2 = ',nimap1,nimap2
if(nimap1 le 0)then $
;print,'ZCOMPARE: no points with sufficient weights: nimap1 = ',nimap1
if(nimap2 le 0)then $
print,'ZCOMPARE: no points with sufficient weights: nimap2 = ',nimap2
;print,'nimap1,nimap2 = ',nimap1,nimap2
xx=dblarr(nimap1)
yy=dblarr(nimap2)
xx(*)=map1(imap1)
yy(*)=map2(imap2)
xx=xx(sort(xx))
yy=yy(sort(yy))
;print,'max(xx),min(xx) = ',max(xx),min(xx)
;print,'max(yy),min(yy) = ',max(yy),min(yy)
xnmap1=(1.0-fupper)*float(nimap1)
xnmap2=(1.0-fupper)*float(nimap2)
nmap1=long(xnmap1)
nmap2=long(xnmap2)
x=dblarr(nmap1)
y=dblarr(nmap2)
x(*)=xx(0:nmap1-1)
y(*)=yy(0:nmap2-1)
;help,x
;help,y
;print,'max(x),min(x) = ',max(x),min(x)
;print,'max(y),min(y) = ',max(y),min(y)
nmap=max([nmap1,nmap2])
x=congrid(x,nmap)
y=congrid(y,nmap)
;
; don't include rogue points (eg influenced by source or drifts)
a=poly_fit(x,y,1)
yr=y-a(0)-a(1)*x ; residuals
findsigma,yr,sigma
iii=where(abs(yr) lt 3.0*sigma,niii)
y=y(iii)
x=x(iii)
;
window,28,xs=400,ys=400
xmin=min([0.0,min(x)])
ymin=min([0.0,min(y)])
plot,x,y,xran=[xmin,max(x)],yran=[ymin,max(y)],psym=1
a=poly_fit(x,y,1)
const=a(0)
slope=a(1)
x1=xmin
x2=max(x)
y1=a(0)+a(1)*x1
y2=a(0)+a(1)*x2
oplot,[x1,x2],[y1,y2],linestyle=0
const=a(0)
slope=a(1)
;
return
end
