;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO AAP_DISC, tmpdata, flagarr
;+
; NAME:
;       AAP_DISC
;
; PURPOSE:
;       Return a flag array with flag=2 for all the chopper plateaux
;       discarded using the bitflag system
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       AAP_DISC, Tmpdata, Flagarr
;
; INPUTS:
;       Tmpdata: PHTAAP type temporary structure
;
; OUTPUTS:
;       Flagarr: Flag array of dimensions (# pixels, # chopper plateaux)
;		 # pixels does not include resistor and open pixel  
;
; PROCEDURES USED:
;       None
;
; MODIFICATION HISTORY:
;	Written by: Carlos Gabriel - ESA-SAI
;	Changed according to bitflag system (CG)
;	V7.4
;-
	ON_ERROR, 2

; Check number of parameters
	IF N_PARAMS() NE 2 THEN MESSAGE, /INFO, $
		'Syntax: aap_disc, tmpdata, flagarr'

; Fill flagarr first with discarded chopper plateaux
        dim1 = n_elements(tmpdata.mnfl(*,0))

; Ignore resistor and open pixels
;        IF STRMID(tmpdata.det,0,1) NE 'P' THEN dim1 = dim1 - 2
        dims_str = [6,11,130,132]
        ind = WHERE(dims_str EQ dim1, ndi)
        IF ndi EQ 1 THEN BEGIN
           dims_cor = [4,9,128,128]
           dim1 = dims_cor(ind(0))
        ENDIF

        flagarr = intarr(dim1,tmpdata.dims)

	get_validflag, tmpdata.flag(0:dim1-1,*), 'AAP', redflag, $
	   det=tmpdata.det
	   
	decode_piaflag, 'AAP', 'NSIG_1', tmpdata.flag(0:dim1-1,*), uflag, $
	   det=tmpdata.det
	
        FOR i=0,dim1-1 DO BEGIN
                scpdisc = WHERE(redflag(i,*) EQ 1, ncount)
                IF ncount gt 0 THEN flagarr(i,scpdisc) = 2
                scpdisc = WHERE(uflag EQ 1, ncount)
                IF ncount gt 0 THEN flagarr(i,scpdisc) = 1
        ENDFOR
		 	 
	RETURN
	END
