;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO AAP_INIT, index=index 
;+
; NAME:
;       aap_init
; PURPOSE:
;       Initializes the structure PHTAAP defining the contents as
;	a template structure PHTAAP_TYPE. It can be used for clearing
;	the whole AAP structure, in case this should show as necessary. 
; CATEGORY:
;	PIA - initialization
;
; CALLING SEQUENCE:
;       AAP_INIT
;
; INPUT PARAMETERS:
;	None       
;
; OUTPUT PARAMETERS: 
;	None
;
; KEYWORDS:
;	Index:	If set, only those will be deleted from buffer
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phtaap
;               phtaap_init
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel (ESA/VILSPA-SAI)		January 1996
;	Keyword index for clearing set of records added (CG+JA)	May 1997
;	V6.3
;-

@phtaap
	nelbuf = N_ELEMENTS(phtaap)
	IF nelbuf EQ 1 THEN RETURN

	flag = intarr(nelbuf)
	
	IF NOT KEYWORD_SET(index) THEN index = indgen(nelbuf-1)+1

	flag(index) = 1
		
	nele = N_ELEMENTS(index)

  	if nele ge 1 then $
    		for i = 0, nele - 1 do $
      		 for ihan = aap_first_handle, aap_last_handle do $
			handle_free, phtaap(index(i)).(ihan)

	ind = WHERE(flag EQ 0)
	phtaap = phtaap(ind)
	

END

