;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO AAR_INIT, index=index 
;+
; NAME:
;       AAR_INIT
;
; PURPOSE:
;       Initializes the structure PHTAAR defining the contents as
;	a template structure PHTAAR_TYPE. It can be used for clearing
;	the whole AAR structure, in case this should show as necessary. 
;
; CATEGORY:
;	PIA - initialisation
;
; CALLING SEQUENCE:
;       AAR_INIT
;
; INPUTS:
;	None       
;
; OUTPUTS: 
;	None
;
; KEYWORDS:
;	Index:	If set, only those will be deleted from buffer
;
; COMMON BLOCKS:
;	phtaar
;	
; PROCEDURES USED:
;
; MODIFICATION HISTORY:
;       Written by:	Carlos Gabriel
;	Oct 95 Version 3.5
;	Keyword index for clearing set of records added (CG+JA)	May 1997
;	V6.3
;-

@phtaar

	nelbuf = N_ELEMENTS(phtaar)
	IF nelbuf EQ 1 THEN RETURN

	flag = intarr(nelbuf)
	
	IF NOT KEYWORD_SET(index) THEN $
	 index = indgen(nelbuf-1)+1

	flag(index) = 1
		
	nele = N_ELEMENTS(index)

	IF nele GE 1 THEN $
	   FOR I = 0, nele - 1 DO BEGIN
		HANDLE_FREE, phtaar(index(i)).data
		HANDLE_FREE, phtaar(index(i)).hdr
	   ENDFOR

	ind = WHERE(flag EQ 0)
	phtaar = phtaar(ind)
	

END

