;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO ACC_FLG, DR, DIM, NNDR, STATUS, ADMN, OTF
;+
; NAME:
;	ACC_FLG
;
; PURPOSE:
;	To return an array of flagged read-outs
;       taking into account the diverse acceptance 
;	criteria for read-outs, reflected in the status word 
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	ACC_FLG, DR, Status
;
; INPUTS:
;	DR	: Array containing the destructive readout word 
;	Dim	: Actual measurement length 
;	NNDR	: Number of non-destructive read-outs
;	Admn	: Internal measurement name  
;	OTF	: On target flag
;
; OUTPUTS:
;	Status	: A flag array: 0=accepted, 1=not accepted
;
; COMMON BLOCKS:
;               phtacc
;               phtselndr
;
; PROCEDURE:
;	Using the status word, create a flag array
;	conform to the acceptance criteria
;
; PROCEDURES USED:
;	PIA LIB: READ_SELNDR
;
; MODIFICATION HISTORY:
;	Written by:	Carlos Gabriel
;	Oct 95 Version 3.5
;	allowing for gen criteria and 1st NDR deselected (CG)	May 1996
;-

@phtacc
@phtselndr

;
;
 On_ERROR,2                                          ;Return to caller
;
; Check the number of parameters
;
	IF N_PARAMS() LT 6 THEN MESSAGE, $
	   'Syntax: ACC_FLG, DR, DIM, NNDR, STATUS, ADMN, OTF '
	ALLRD = N_ELEMENTS(DR)

; Number of Read-outs per ramp
	ROPRAMP = NNDR + 1	 

; If Destructive Read's to be accepted
	IF DRNACC THEN STATUS = DR ELSE STATUS = INTARR(ALLRD)

; Which	NDRs to be accepted
	IF nselndr THEN BEGIN

           IF N_ELEMENTS(pp1sndr) EQ 0 THEN read_selndr

           ind = FIX( alog(ropramp) / alog(2) ) - 1

           CASE STRMID(admn,0,2) of
             'P1': var = PP1SNDR
             'P2': var = PP2SNDR
             'P3': var = PP3SNDR
             'C1': var = PC1SNDR
             'C2': var = PC2SNDR
             'SS': var = PSSSNDR
             'SL': var = PSLSNDR
           ENDCASE

	   IF var(ind) GT 0 THEN BEGIN 
           	ndrnacc = INDGEN(var(ind)) + 1
	   ENDIF ELSE BEGIN
	   	ndrnacc = 0
	   ENDELSE
        ENDIF  

	IF NDRNACC(0) GT 0 OR NDR1NAC GT 0 THEN BEGIN
	 NUM = 0
	 NDRNALL = [NDR1NAC,NDRNACC]
	 FOR I = 0L, ALLRD-1 DO BEGIN
	  IF DR(I) THEN BEGIN 
	   NUM = 0
	  ENDIF ELSE BEGIN	   
	   NUM = NUM + 1
    	   N = 0 
	   IND = WHERE(NUM EQ NDRNALL,N) 
	   STATUS(I) = N 
	  ENDELSE	
         ENDFOR
	ENDIF
; Status of fill-in "Read-outs" in Common is always 1
	DIM = DIM(0)
	IF DIM LT ALLRD THEN STATUS(DIM:ALLRD-1) = 1
; First or last Read-outs
	MINR = MINR(0)
	MAXR = MAXR(0)
	IF MINR GT 0 THEN STATUS(0:MINR*ROPRAMP) = 1
	IF MAXR GT 0 THEN STATUS(MAXR*ROPRAMP:ALLRD-1) = 1
	IF ANYR(0) GT 0 THEN STATUS(ANYR-1) = 1

; On target flag - using system variable otflow to make possible 
; EGSE data analysis (contrary logic)
	indotf = WHERE(otf EQ !otflow, n)
	IF n GT 0 THEN status(indotf) = 1

	RETURN
	END
