;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
PRO ACKNOWLEDGE_EVENT, Ev

  Widget_Control, Ev.Top, /DESTROY               ; destroy the modal widget

END

;***********************************************************************

PRO ACKNOWLEDGE, TEXT = text, TLB = tlb, ACK_STRING = ack_string, $
                 POSITION = position, group=group
;+
; NAME:
;	ACKNOWLEDGE
;
; PURPOSE:
;	This procedure opens a widget and waits for the user to close it.
;	It is a standard solution to the <Have you seen this> <yes> boxes
;	that are so useful in UIs.
;
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	ACKNOWLEDGE
;
; INPUTS:
;	None
;
; KEYWORD PARAMETERS:
;	TEXT:       The text to display
;	TLB:        Top level base to orient to
;	ACK_STRING: String to display on the acknowledge button
;	POSITION:   String to give placement guide
;
; OUTPUTS:
;	None
;
; PROCEDURES USED:
;	INTERNAL: ACKNOWLEDGE_EVENT
;
; EXAMPLE:
;	ACKNOWLEDGE, TEXT='Warning: Try again', TLB=widg1
;
; MODIFICATION HISTORY:
;	Written By:	Huw Morris (adapted from Mark Buckley)
;	Oct 95 Version 3.5
;	/Modal use according to IDL >= 5.0 (CG)
;	V7.3
;-

; Set up the button string, if none supplied
   IF NOT keyword_set(ack_string) THEN ack_string = '    ok    '
   IF not KEYWORD_SET(group) THEN group=''

; Create the base
   ack_base = Widget_Base(/column,title = 'Acknowledge or Die!', /modal, $
   		group=group)

   IF keyword_set(text) THEN BEGIN     ; if we have been given some text
      xsiz = max(strlen(text))         ; find the longest string in the input
      siz = size(text)                 ; find the SIZE info for the input
; If it is an array, use num of dims, else use 1      
      IF siz(0) gt 0 then ysiz = siz(1) ELSE ysiz = 1				
; Set up the text widget
      junk = Widget_Text(ack_base,value = text,xsize = xsiz,ysize = ysiz)
   ENDIF

   horiz_base = Widget_Base(ack_base,/row)  ; make a nice base for the buttons

; Set up the accept button
   acceptwid = Widget_Button(horiz_base,value = ack_string,uval = 'accept')

; Widget_Control,ack_base,map = 0							; make invisible
   Widget_Control,ack_base, /REALIZE           ; realize it

; position_base,ack_base,tlb=tlb,xpos,ypos,position = position			; position it on the tlb, if we were given one
; widget_control,ack_base,tlb_set_xoffset = xpos,tlb_set_yoffset = ypos		; set its position
; widget_control,ack_base,map = 1							; make it visible

   Widget_Control, acceptwid, /INPUT_FOCUS  ; put the cursor on the text widget

   xMANAGER,No_BLOCK=1, 'ACKNOWLEDGE', ack_base; manage it modally

END
