;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
pro addcomm2hdr, comment, header
;+
; NAME:
;	ADDCOMM2HDR
; PURPOSE:
;	Procedure to add comment line(s) to FITS header
;
; CALLING SEQUENCE
;	addcomm2hdr, comment, header
;
; INPUTS:
;	comment - string or string array containing comment line(s)
;		to add to the header
;	header - string array containing the FITS header
;
; OUTPUTS:
;	header - unpdated header
;
; EXAMPLES:
;	addcomm2hdr, 'I DID THIS', header
;
;	comm = strarr(3)
;	comm(0) = 'comment line number 1'
;	comm(1) = 'the next comment line'
;	comm(2) = 'the last comment line'
;	addcomm2hdr, comm, header
;
; Modified from the astronomical library for the ISOPHT FITS header,
;	WMT, 	Feb 1996
;-
;--------------------------------------------------------------------
 On_error,2

 if N_params() LT 2 then begin
    print, ' Syntax - ADDCOMM2HDR, comment, header '
    return
 endif

; Check input parameters

 s = size(comment) & ndim = s(0) & type = s(ndim+1)
 if type NE 7 then message, $
     'Invalid comment lines specified; must be a string or string array'
 
 nlines = N_elements(header)	      ;Number of lines in header
 nadd = N_elements(comment)	      ;Number of lines to add

; trim off the end line
 if nlines gt 2 then begin
   nlines = nlines - 2
   header = header(0:nlines)
 endif

 blank = string( replicate(32b,80) )
 header = [ header, replicate(blank,nadd) ] ;add space

; Add comment records to end of FITS header


 for i = 0, nadd-1 do begin

	newline = blank
	strput, newline, 'COMMENT    ' + comment(i)
	header(nlines + i) = newline

 endfor

 header =[ header,  'END' + string( replicate(32b,77) ) ]  ;add END keyword
 
 return
 end
