;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO APERTURE_INFO_INIT
;+
; NAME:
;	APERTURE_INFO_INIT
;
; PURPOSE:
;	This procedure initialises the Aperture_Info common block
;
; CATEGORY:
;	PIA - initialisation
;
; CALLING SEQUENCE:
;	APERTURE_INFO_INIT
;
; INPUTS:
;	None
;
; OUTPUTS:
;	None
;
; COMMON BLOCKS:
;	aperture_info
;	phtppsf
;
; SIDE EFFECTS:
;	The variables in the aperture info common block are initialised here
;
; MODIFICATION HISTORY:
;	Written by:	Huw Morris
;	Oct 95 Version 3.5
;	
;-

@aperture_info
@phtppsf

	ON_ERROR, 2           ; Return to calling procedure

; Number of filters
	N_Filt = 14

; Number of apertures
	N_Aper = 14


; Centre wavelengths of each PHT-P filter (microns)
	P_WaveL = [ 3.29, 3.60, 4.85, 7.30, 7.70, 10.0, 11.30, $
	            12.80, 16.0, 11.5, 20.0, 25.0, 60.0, 100.0 ]

; Centre wavelengths of each PHT-C filter (microns)
	C_WaveL = [ 125.0, 90.0, 50.0, 60.0, 70.0, 100.0, 105.0, $
	            90.0, 160.0, 200.0, 180.0, 135.0, 120.0, 0.0 ]

;  Ratio of relative system reponses for PHT-P in wheel position order
	P_Ratio = [ 0.998186, 0.951972, 0.651829, 0.298512, 0.984271, $
	            0.571516, 0.976208, 0.453098, 0.234683, 0.165154, $
	            0.108684, 0.113113, 0.039668, 0.026906 ]

;  Ratio of relative system response for PHT-C in wheel position order
	C_Ratio = [ 0.002532, 0.021532, 0.025153, 0.037567, 0.037917, $
	            0.022892, 0.035383, 0.019830, 0.011899, 0.025972, $
	            0.020973, 0.019083, 0.017677, 0.000000 ]

;OLD SYSTEM RESPONSES
;	P_Ratio = [ 0.996331, 0.949813, 0.650458, 0.300356, 0.977160, $
;	            0.564719, 0.974204, 0.448120, 0.229456, 0.163978, $
;	            0.104554, 0.112635, 0.039396, 0.025151 ]
;
;	C_Ratio = [ 0.002686, 0.023633, 0.025848, 0.054442, 0.041932, $
;	            0.033823, 0.036781, 0.024585, 0.014506, 0.024346, $
;	            0.019624, 0.012828, 0.021799, 0.000000 ]

;  The point spread function is in the common phtppsf as phtppsf
	Point_Spread = phtppsf

	END
