;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO Aperture_Size_Init
;+
; NAME:
;	APERTURE_SIZE_INIT
;
; PURPOSE:
;	This procedure initialises the phtapertures common block
;
; CALLING SEQUENCE:
;	APERTURE_SIZE_INIT
;
; INPUTS:
;	None
;
; OUTPUTS:
;	None
;
; COMMON BLOCKS:
;	phtapertures
;
; SIDE EFFECTS:
;	The variables in the phtapertures common block are initialised
;
; PROCEDURES USED:
;	None
;
; MODIFICATION HISTORY:
;	Written by:	Huw Morris
;	Oct 95 Version 3.5
;	Modified by: CG - Measured diameters and omegas in.	December 1996
;	CG - Now reading data from POMEGA.FITS file		January 1997
;	V6.0
;-

@phtapertures

	ON_ERROR, 2           ; Return to calling procedure


; Read POMEGA
	fxbopen, unit, !calg+'POMEGA.FITS', 1, hdr
	fxbread, unit, dmmy, 'POMEDMMY'
	fxbread, unit, dmmz, 'POMEDMMZ'

; Dimensions (in mm) of each PHT-P aperture 
	P_MM = [ [dmmy(0:13)], [dmmz(0:13)] ]
; 
;	P_MM = [ [ 2.30, 3.40, 4.30, 5.20, 5.50, 7.85, 7.85, 0.20, $
;	              0.357, 0.47, 0.60, 0.82, 0.83, 1.00 ],        $
;	         [ 2.30, 3.40, 4.30, 5.20, 5.50, 7.85, 7.85, 0.20, $
;	              0.357, 0.47, 0.60, 0.82, 1.36, 1.00 ] ]


	fxbread, unit, dasy, 'POMEDASY'
	fxbread, unit, dasz, 'POMEDASZ'
; Dimensions (in as) of each PHT-P aperture
	P_AS = [ [dasy(0:13)], [dasz(0:13)] ]

;	P_AS = [ [ 52.0, 79.0, 99.0, 120.0, 127.0, 180.0, 180.0,   $
;	              5.0, 7.6, 10.0, 13.8, 18.0, 20.0, 23.0 ],    $
;	         [ 52.0, 79.0, 99.0, 120.0, 127.0, 180.0, 180.0,   $
;	                 5.0, 7.6, 10.0, 13.8, 18.0, 32.0, 23.0 ] ]

; Dimensions of the PHT-P apertures (in steradians)
	
        fxbread, unit, omeg, 'POMEOMEG'
	P_SR = [ omeg(0:13) ] * 1.E-7

;	P_SR = [ 0.5129E-7, 1.1209E-7, 1.7928E-7, 2.6219E-7, $
;	         3.7346E-7, 5.9751E-7, 5.9751E-7, 0.003879E-7, $
;	         0.01236E-7, 0.02142E-7, 0.03491E-7, 0.06251E-7, $
;	         0.1394E-7, 0.09696E-7 ]


; Shape of each PHT-P aperture (c = circular, r = rectangular)
	P_Shape = 'ccccrcccccccrc'

; Pixel size for PHT-C100 (in mm, as and sr)
	C1_MM = dmmy(15)
	C1_AS = dasy(15)
	C1_SR = omeg(15) * 1.E-7
;	C1_MM = 1.9
;	C1_AS = 43.5
;	C1_SR = 0.4457E-7

; Pixel size for PHT-C200 (in mm, as and sr)
	C2_MM = dmmy(16)
	C2_AS = dasy(16)
	C2_SR = omeg(16) * 1.E-7

;	C2_MM = 3.9
;	C2_AS = 89.4
;	C2_SR = 1.8778E-7

	FXBCLOSE, unit
	FREE_LUN, UNIT
	END
