;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	APPEND_RP
;
; PURPOSE:
;	Merge pseudo measurements per RPID into an SCP unique measurement
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	APPEND_RP, indices, scpps
;
; INPUT PARAMETERS:
;	indices: all the positions of the pseudo meas. within the SCP buffer
;
; OUTPUT PARAMETERS:
;	scpps:	the position of the merged measurement within the SCP buffer
;
; RESTRICTIONS:
;	
;
; SIDE EFFECTS:
;	 
;
; METHOD: 
;	The different arrays corresponding to the SCP variables within the
;	given measurements are merged together and sorted accordingly to the
;	variable SCP.TIME
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phtscp
;
; MODIFICATION HISTORY:
;	Written by: C. Gabriel (ESA/VILSPA - SAI)		1996
;	Revised and hdr written				September 1997 
;	V6.5
;-
PRO append_rp, indices, scppos

@phtscp
@adm
	pia_load_iscp, phtscp(indices(0)), tmp
	tmpscp = tmp

	npix = N_ELEMENTS(tmp.aver(*,0))

	FOR ind=1, N_ELEMENTS(indices)-1 DO BEGIN
	
		pia_load_iscp, phtscp(indices(ind)), tmp
		
		dims = tmpscp.dims + N_ELEMENTS(tmp.chop)
		time = [tmpscp.time, tmp.time]
		chop = [tmpscp.chop, tmp.chop]
		step = [tmpscp.step, tmp.step]
		fcsn = [tmpscp.fcsn, tmp.fcsn]
		temp = [tmpscp.temp, tmp.temp]
		fcs1 = [tmpscp.fcs1, tmp.fcs1]
		fcs2 = [tmpscp.fcs2, tmp.fcs2]
		tkey = [tmpscp.tkey, tmp.tkey]

		rpid = BYTARR(2,dims)
		olddim = N_ELEMENTS(tmpscp.chop)
		newdim = N_ELEMENTS(tmp.chop)
		rpid(0,0:olddim-1) = tmpscp.rpid(0,*)
		rpid(0,olddim:*) = tmp.rpid(0,*)
		rpid(1,0:olddim-1) = tmpscp.rpid(1,*)
		rpid(1,olddim:*) = tmp.rpid(1,*)

		aver = FLTARR(npix,dims)
		avun = aver
		medi = aver
		q1me = aver 
		q3me = aver
		flag = aver
		arsi = aver
		andr = aver
		avsd = aver
		
		FOR ipix=0,npix-1 DO BEGIN
		 aver(ipix,0:olddim-1) = tmpscp.aver(ipix,*) 
		 avun(ipix,0:olddim-1) = tmpscp.avun(ipix,*)
		 medi(ipix,0:olddim-1) = tmpscp.medi(ipix,*) 
		 q3me(ipix,0:olddim-1) = tmpscp.q3me(ipix,*)
		 flag(ipix,0:olddim-1) = tmpscp.flag(ipix,*) 
		 arsi(ipix,0:olddim-1) = tmpscp.arsi(ipix,*) 
		 andr(ipix,0:olddim-1) = tmpscp.andr(ipix,*)
		 avsd(ipix,0:olddim-1) = tmpscp.avsd(ipix,*)
		  
		 aver(ipix,olddim:*) = tmp.aver(ipix,*) 
		 avun(ipix,olddim:*) =  tmp.avun(ipix,*) 
		 medi(ipix,olddim:*) =  tmp.medi(ipix,*) 
		 q3me(ipix,olddim:*) = tmp.q3me(ipix,*)
		 flag(ipix,olddim:*) = tmp.flag(ipix,*) 
		 arsi(ipix,olddim:*) =  tmp.arsi(ipix,*) 
		 andr(ipix,olddim:*) = tmp.andr(ipix,*)
		 avsd(ipix,olddim:*) = tmp.avsd(ipix,*) 
		ENDFOR
		
		tmpscp={dims:dims, time:time, chop:chop, step:step, fcsn:fcsn, $
			temp:temp, fcs1:fcs1, fcs2:fcs2, tkey:tkey, rpid:rpid,$
			aver:aver, avun:avun, medi:medi, q1me:q1me, q3me:q3me,$
			flag:flag, arsi:arsi, andr:andr, avsd:avsd}
		
	ENDFOR
	
	indsort = BSORT(tmpscp.time)

	tmpscp.time = tmpscp.time(indsort)
	tmpscp.chop = tmpscp.chop(indsort)
	tmpscp.step = tmpscp.step(indsort)
	tmpscp.fcsn = tmpscp.fcsn(indsort)
	tmpscp.temp = tmpscp.temp(indsort)
	tmpscp.fcs1 = tmpscp.fcs1(indsort)
	tmpscp.fcs2 = tmpscp.fcs2(indsort)
	tmpscp.tkey = tmpscp.tkey(indsort)

	tmpscp.rpid = tmpscp.rpid(*,indsort)
	
	tmpscp.aver = tmpscp.aver(*,indsort)
	tmpscp.avun = tmpscp.avun(*,indsort)
	tmpscp.medi = tmpscp.medi(*,indsort)
	tmpscp.q1me = tmpscp.q1me(*,indsort) 
	tmpscp.q3me = tmpscp.q3me(*,indsort)
	tmpscp.flag = tmpscp.flag(*,indsort)
	tmpscp.arsi = tmpscp.arsi(*,indsort)
	tmpscp.andr = tmpscp.andr(*,indsort)
	tmpscp.avsd = tmpscp.avsd(*,indsort)

;  Accomodate data into the scp structure and the scp handles after
;  creating the temporary ones                  
	  PHTSCPT = {PHTSCP_TYPE}
          PHTSCPT.HDR = HANDLE_CREATE()
          PHTSCPT.TIME = HANDLE_CREATE()
          PHTSCPT.AVER = HANDLE_CREATE()
          PHTSCPT.AVUN = HANDLE_CREATE()
          PHTSCPT.MEDI = HANDLE_CREATE()
          PHTSCPT.Q1ME = HANDLE_CREATE()
          PHTSCPT.Q3ME = HANDLE_CREATE()
          PHTSCPT.FLAG = HANDLE_CREATE()
          PHTSCPT.CHOP = HANDLE_CREATE()
          PHTSCPT.STEP = HANDLE_CREATE()
          PHTSCPT.FCSN = HANDLE_CREATE()
          PHTSCPT.TEMP = HANDLE_CREATE()
          PHTSCPT.FCS1 = HANDLE_CREATE()
          PHTSCPT.FCS2 = HANDLE_CREATE()
          PHTSCPT.TKEY = HANDLE_CREATE()
          PHTSCPT.ARSI = HANDLE_CREATE()
          PHTSCPT.ANDR = HANDLE_CREATE()
          PHTSCPT.AVSD = HANDLE_CREATE()
          PHTSCPT.RPID = HANDLE_CREATE()

;  Change the header according to the selection criteriae 
	  HANDLE_VALUE, PHTSCPT.HDR, tmp.hdr, /SET
; 	  
          PHTSCPT.UNIT = TMP.UNIT
          PHTSCPT.DET  = TMP.DET
	  PHTSCPT.ADMN = STRMID(TMP.ADMN,0,12)
          PHTSCPT.ORDR = TMP.ORDR
          PHTSCPT.DIMS = N_ELEMENTS(tmpscp.chop)

	  HANDLE_VALUE, PHTSCPT.TIME, Tmpscp.TIME, /SET
	  HANDLE_VALUE, PHTSCPT.AVER, Tmpscp.AVER, /SET 
          HANDLE_VALUE, PHTSCPT.AVUN, Tmpscp.AVUN, /SET
          HANDLE_VALUE, PHTSCPT.MEDI, Tmpscp.MEDI, /SET
          HANDLE_VALUE, PHTSCPT.Q1ME, Tmpscp.Q1ME, /SET
          HANDLE_VALUE, PHTSCPT.Q3ME, Tmpscp.Q3ME, /SET
          HANDLE_VALUE, PHTSCPT.FLAG, Tmpscp.FLAG, /SET
          HANDLE_VALUE, PHTSCPT.CHOP, Tmpscp.CHOP, /SET
          HANDLE_VALUE, PHTSCPT.STEP, Tmpscp.STEP, /SET
          HANDLE_VALUE, PHTSCPT.FCSN, Tmpscp.FCSN, /SET
          HANDLE_VALUE, PHTSCPT.TEMP, Tmpscp.TEMP, /SET
          HANDLE_VALUE, PHTSCPT.FCS1, Tmpscp.FCS1, /SET
          HANDLE_VALUE, PHTSCPT.FCS2, Tmpscp.FCS2, /SET
          HANDLE_VALUE, PHTSCPT.TKEY, Tmpscp.TKEY, /SET
	  HANDLE_VALUE, PHTSCPT.ARSI, Tmpscp.ARSI, /SET 
          HANDLE_VALUE, PHTSCPT.ANDR, Tmpscp.ANDR, /SET
          HANDLE_VALUE, PHTSCPT.AVSD, Tmpscp.AVSD, /SET
          HANDLE_VALUE, PHTSCPT.RPID, Tmpscp.RPID, /SET

; Update the PHTSCP structure using the temporary structure
	  PHTSCP = [PHTSCP, PHTSCPT]
; Update the PHTSCP value in the administration file using the index
	  SCPPOS = N_ELEMENTS(PHTSCP) - 1
;	  INDADM = WHERE (ADM.NAME EQ PHTSCPT.ADMN)
;	  ADM(INDADM).PHTSCP = SCPPOS
	  SCPPS = SCPPOS 
		
RETURN
END
	
	
	
	
