;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	BCKSUB_CALC
;
; PURPOSE:
;	Menu for PIA Background subtraction.
;	This is a display dependant level menu in the PIA hierarchy.
;
;	This routine should only be called by the PIA display menues
;	and should not be called directly from the command line.
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	BCKSUB_CALC, signal, unc, flag, aver, sigma 
;
; INPUTS:
;	signal: array containing the signals (SCP or SPD level)
;	unc: array containing the uncertainty of signals (SCP or SPD level)
;	flag: array containing the validity flag of signals (SCP or SPD level)
;	
; OUTPUTS:
;	aver: average of signals
;	sigma: sigma of signals
;
; PROCEDURES USED:
;	PIA LIB:
;		weight_mean
;	
; MODIFICATION HISTORY:
;	 Extracted from PIA_BCKSUBT, because is called 
;	 as a separate routine, eg pia_proc_gen (JAcosta)	April 1997
;	 Keyword MEDIAN added, as a different way to 
;	 project signals	(JAcosta)			August 1997
;
;-

; ****************************************************************************
;  Routine to calculate avaerages of subtracted signals 
; ****************************************************************************

PRO bcksub_calc, array, unc, flag, aver, sigm, MEDIAN = median

	IF NOT KEYWORD_SET(MEDIAN) THEN median = 0

	dim1 = N_ELEMENTS(array(*,0))
	aver = FLTARR(dim1)
	sigm = aver

	FOR I=0, dim1-1  DO BEGIN
		indok = WHERE(flag(i,*) LE 1, nok)
		CASE 1 OF 
		  nok GT 4: BEGIN 
		             IF MEDIAN EQ 1 THEN WEIGHT_MEAN, array(i,indok), $
		                  unc(i,indok), mean, stdev, /MEDIAN          $
		             ELSE WEIGHT_MEAN, array(i,indok), unc(i,indok),  $
				mean, stdev
		            END
		  nok GT 0: WEIGHT_MEAN, array(i,indok), unc(i,indok), $
				mean, stdev 
		ELSE:       BEGIN
		                mean = 0.0
		                stdev = 0.0
		            END    
		ENDCASE

		aver(i) = mean
		sigm(i) = stdev

	ENDFOR

       RETURN
END

