;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO CAL_INIT
;+
; NAME:
;	CAL_INIT
;
; PURPOSE:
;	To initialize all the parameters from Calibration G files
;
; CATEGORY:
;	PIA - initialisation
;
; CALLING SEQUENCE:
;	CAL_INIT
;
; INPUTS:
;	(none)
;
; OUTPUTS:
;	(none)
;
; COMMON BLOCKS:
;	(none)
;		
; PROCEDURE:
;	Calibration G files are used eventually together with parameters
;	which are direcly written into this routine and do not change
;	frequently. 
;
; PROCEDURES USED:
;	PIA LIB: darkcur_init
;	         die_trans_init
;	         phtcap_init
;	         phtfilter_prop_init
;		 read_chopcor
;		 read_crelin
;		 read_darkorb
;		 read_fcsill
;		 read_fcspow
;		 read_flatfield
;		 read_fluxconv
;		 read_omega
;		 read_pcpsf
;		 read_resp
;		 read_rlin
;		 read_specal
;
; MODIFICATION HISTORY:
;	Written by:	Carlos Gabriel, ESA/VILSPA	June 1999
;	V7.4
;       
;-
; 
; Read Cal G files  
;
 
 DIE_TRANS_INIT
;
; Initialize dark currents & filter properties
;
 darkcur_init
 phtfilter_prop_init

;
; Initialize capacitances
;
 phtcap_init

; Initialize  CBs needed for dynamic PHT-S calibration 
phtdyncaldb_init         ; dynamical calibration database

read_chopcor

read_crelin

read_darkorb

read_fcsill

read_fcspow

read_flatfield

read_fluxconv

read_omega

read_pcpsf

read_resp

;read_rlin   not yet implemented - set everything to 0
 a = rlin_fct(0,'C1_50',5, /fload)

read_specal

read_specal_chop

RETURN
END


