;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO Calc_Step, Step_No                              
;+
;
; NAME:
;	CALC_STEP
;
; PURPOSE:
;	This procedure calculates the step number within the chopper 
;	cycle of each readout
;
; CATEGORY:
;	 PIA - processing
;
; CALLING SEQUENCE:
;	CALC_STEP, Step_No
;
; INPUTS:
;	None
;
; OUTPUTS:
;	Step_No: Array of step numbers (from 0 to Steps-1)
;
; COMMON BLOCKS:
;	chop_info
;
; RESTRICTIONS:
;	Assumes measurement started correctly and the chop_info common
;	block is initialised
;
; PROCEDURE:
;	This procedure calculates the time spent on each plateau, and
;	from that, the time spent on each plateau in the cycle.
;	The modulus of the measurement with the cycle time thus gives
;	the point in the cycle of a particular measurement. 
;
; PROCEDURES USED:
;	None
;
; MODIFICATION HISTORY:
;	Written by:	Huw Morris
;	Modified by:	C. Gabriel
;	Oct 95 Version 3.5
;
;-

@chop_info

	ON_ERROR, 0

;  Check for a calibration
;  FCS observations are modes 2 and 32.
	IF ((Mode EQ 3 AND SubMode GE 2) OR Mode EQ 2) THEN BEGIN
	  Calibration = 1
	ENDIF ELSE BEGIN
	  Calibration = 0
	ENDELSE

;  Transition time for FCS takes longer than that for field of view
;  observations.
	IF Calibration THEN BEGIN
	  Trans_Time = Trans_Time_Cal
        ENDIF ELSE BEGIN
	  Trans_time = Trans_Time_Meas
	ENDELSE

;  Time on each plateau
;  Use long integer to avoid overflow
	Dwell_time = Dest_Read * Int_time * 128l

;  Calculate the time taken for each cycle
	Cycle_time = Plat * (Dwell_time + Trans_time)

;  Calculate time in cycle
	Time_in_cycle = (Current_time - Start_time) MOD Cycle_time

;  Calculate step number within cycle - Use internal conversion into floating
;  point to avoid overflow - Reconvert into longword
	Step_no = LONG(((Time_in_cycle * 1.0 * Plat) / Cycle_time) + 1)

	END
