;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;     	CREATE_PFITS
; PURPOSE:
;		Write a PHT FITS table.
; CATEGORY:
;		PIA - I/O
; CALLING SEQUENCE:
;       CREATE_FITS, filename, columns, col_names, col_types
;
; INPUT:
;	FILENAME: filename for the output file without extension
;	COLUMNS:  multi-dimensional array 
;       
;
; OPTIONAL INPUT:
;       PIPELINENAME: 	string type, default is the pipeline product name
;       USERNAME : 		the username line in the fits header, string type.
;                  		the maximum character length is 8.
;       COMMENT : 		the comment line in the fits header, string type
;       VERSION : 		the version number, string type, less than 8 chars
;                 		default is 0001
;
; OUTPUT:
;	(none)
;
; PROCEDURES USED: 
;	PIA Library:
;		write_fxisoheader	
;	ASTROLIB:
;		fxwrite
;		fxbhmake
;		fxbaddcol
;		fxbcreate
;		fxbwrite
;		fxbfinish
;
;		
; MODIFICATION HISTORY:
;       Written by: Carlos GABRIEL (ESA-SAI)			Jan. 1997
;-

PRO create_pfits, filename, columns, USERNAME=username, $
	COMMENT=COMMENT, VERSION=VERSION
	
	IF not KEYWORD_SET(USERNAME) THEN USERNAME=0
	IF not KEYWORD_SET(COMMENT) THEN COMMENT=0
	IF not KEYWORD_SET(VERSION) THEN VERSION=0

	write_fxisoheader, filename, header, columns, username=username, $
	   comment=comment, version=version
	
	IF filename EQ 'PC2ILLUM' or filename EQ 'PC1ILLUM' THEN BEGIN
	    val = FXPAR(header,'NAXIS*')
	    fxaddpar, header, 'NAXIS1',val(0), ' Detector pixel number'
	    fxaddpar, header, 'NAXIS2',val(1), ' Filters (in ch.wheel order)'
	    fxaddpar, header, 'NAXIS3',val(2), ' Each FCS  '
	    fxaddpar, header, 'NAXIS4',val(3), $
	       ' Illum. matrix value and uncertainty '
	ENDIF ELSE IF STRMID(filename,3,5)  EQ 'FCSAP' THEN BEGIN 
	    val = FXPAR(header,'NAXIS*')
	    fxaddpar, header, 'NAXIS1',val(0), ' Aperture (in ch.wheel order)'
	    fxaddpar, header, 'NAXIS2',val(1), ' Filters (in ch.wheel order)'
	    fxaddpar, header, 'NAXIS3',val(2), ' Each FCS  '
	    fxaddpar, header, 'NAXIS4',val(3), $
	       ' Aperture correction value and uncertainty '
	ENDIF ELSE IF STRMID(filename,3,4)  EQ 'VIGN' THEN BEGIN 
	    val = FXPAR(header,'NAXIS*')
	    fxaddpar, header, 'NAXIS1',val(0), ' Detector pixel number'
	    fxaddpar, header, 'NAXIS2',val(1), ' FP chopper position (15" units)'
	    fxaddpar, header, 'NAXIS3',val(2), ' Filters (in ch.wheel order)'
	ENDIF ELSE IF STRMID(filename,3,4)  EQ 'FLAT' THEN BEGIN 
	    val = FXPAR(header,'NAXIS*')
	    fxaddpar, header, 'NAXIS1',val(0), ' Detector pixel number'
	    fxaddpar, header, 'NAXIS2',val(1), ' Filters (in ch.wheel order)'
	    fxaddpar, header, 'NAXIS3',val(2), $
	    	' Flat field correction value and uncertainty'
	ENDIF
	 

	filename = !CALSAVE + filename + '.FITS'
	fxwrite, filename, header, columns
	
	
	RETURN
	END
