;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  PRO get_respchk_str, det, respchkstr
;+
; NAME:
;       GET_RESPCHK_STR
;
; PURPOSE:
;       Returns the responsivity check structure corresponding to detector
; 
; CATEGORY:
;	PIA - processing
;       
; CALLING SEQUENCE:
;       GET_RCHKSTR, Det, respchkstr
;
; INPUTS:
;       Det: Detector name. One of: P1, P2, P3, C1, C2, SL
;
; OUTPUTS:
;       Darkcstr: the corresponding dark current structure
;
; PROCEDURES USED:
;	None
;
; MODIFICATION HISTORY:
;	Written by: Jose Acosta
;	May 97 Version 6.4
;-

ON_ERROR, 2

	detind = STRMID(STRUPCASE(det),0,2)

	respchk_str_init
	
        CASE detind of
                'SS': respchk_str = {SLRESPCHKSTR_typ}
                'SL': respchk_str = {SLRESPCHKSTR_typ}
                'C2': respchk_str = {C2RESPCHKSTR_typ}
                'C1': respchk_str = {C1RESPCHKSTR_typ}
                ELSE: respchk_str = {PRESPCHKSTR_typ}
        ENDCASE

	filename = !CALSAVE+ detind + 'CALRECHK_STR.SAV'
	res = findfile(filename, count= count)

	IF count NE 0 THEN RESTORE, filename  $ 
	  ELSE BEGIN 
	    print,string(7b),'Filename '+ strtrim(filename,2)+' not found'
	    print,'Returning a dummy structure '
	  ENDELSE  
	        
	respchkstr = respchk_str 
	
END

