;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_CAL_ACTRESPONS
;
; PURPOSE:
;	Top level menu for Actual Responsivity handling  
;
; CATEGORY:
;       PIA - calibration
;
; CALLING SEQUENCE:
;       PIA_CAL_ACTRESPONS
;
; KEYWORD PARAMETERS:
;	GROUP=group: Group leader
;
; COMMON BLOCKS:
;	colour_indices
;	phtresact
;	pia_actrespons_cmn (internal)
;	cactresp_edit_cmn (internal)
;	cal_actresp_cmn (internal)
;
; PROCEDURES USED:
;	PIA LIB:
;		get_respstr
;		pia_select_var
;		pia_showstr
;		pia_write_author
;		pia_write_comment
;		pia_write_version
;		pia_xplot
;		read_asc_pdetect
;		read_resp
;		weight_mean
;		write_asc_pdetect
;		write_resp
;		write_respstr
;       ASTRO LIB:
;		boost_array
;		date_conv
;		fxhread
;		fxpar
;		match
;       INTERNAL:
;		resp2calu_weight_event
;		resp2calu_weight
;		respstruct_val_choice
;		respstr_show
;		respons_edit_event
;		respons_edit
;		crespons_edit_event
;		crespons_edit
;		cluresp_edit_event
;		cluresp_edit
;		clgresp_edit_event
;		clgresp_edit
;		pia_cal_respons_event
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel (ESA/ESTEC) 		March 1995
;	Modified (last) by: cg, wmt			Sept 1995
;	Oct 95 Version 3.5
;	Processing from measurements not allowed (CG)	January 1996
;	Replacing of accumulated structures added (CG)	January 1996
;	Handling from export version possible (CG)	April 1997
;	V6.2
;
;-

; *********************************************************************
; * 
; *********************************************************************
PRO ACTRESPONS_EDIT_event, event 

COMMON pia_actrespons_cmn, dets, detact, respons, newrespons, det_id, origin

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.id, GET_VALUE=value
	CASE uvalue of
	'list': PRINT, event.id, value
	'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
	ELSE:
	ENDCASE
END

; *********************************************************************
; * 
; *********************************************************************
PRO ACTRESPONS_EDIT 

COMMON pia_actrespons_cmn, dets, detact, respons, newrespons, det_id, origin

	edbase = WIDGET_BASE(TITLE =detact+' Actual Responses', $
			/column)
	edvalbase = WIDGET_BASE(edbase, /row)
	pixels = N_ELEMENTS(respons(*,0))
	pixlist = STRTRIM(STRING(indgen(pixels) + 1),2)
	pixlist = 'Pixel ' + pixlist 
	text = pixlist + '    ' + STRTRIM(respons(*,0),2) + '   +/-   ' + $
		STRTRIM(respons(*,1),2) 
		
	IF STRLEN(origin.n) GT 3 THEN $ 
	 decode_admn, origin.n, orig  $
	 ELSE orig = ''
	 
	text = [text, ' ','Origin: '+orig + $
		'   Filter: ' + origin.f ]
		
	edval = WIDGET_TEXT(edvalbase, XSIZE=50, YSIZE=pixels+3, $
		VALUE = text,uvalue='junk')
	quit = WIDGET_BUTTON(edbase, VALUE=' QUIT ', UVALUE='QUIT') 
	WIDGET_CONTROL, edbase, /REALIZE
	xMANAGER,No_BLOCK=1, "ACTRESPONS_EDIT", edbase, GROUP=group 
	RETURN
END 

; *********************************************************************
; * 
; *********************************************************************
PRO CACTRESPONS_EDIT_event, event 

COMMON pia_actrespons_cmn, dets, detact, respons, newrespons, det_id, origin
COMMON cactresp_edit_cmn, edval_id, pixels 


	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue of
	 'LIST': BEGIN
		 WIDGET_CONTROL, edval_id(0), GET_VALUE=value
		 WIDGET_CONTROL, edval_id(1), GET_VALUE=valunc

		IF N_ELEMENTS(value) EQ pixels THEN BEGIN
			newrespons(*,0) = float(value) 
			newrespons(*,1) = float(valunc)
		ENDIF ELSE BEGIN
                  	XDISPLAYFILE, "", $
                    		TITLE = "Input not accepted", $
                    		WIDTH = 50, $
                    		HEIGHT = 4, $
                    	  TEXT = [" Wrong respons input  ", $]
                          	  "     ", $ ]
                          	  " Fix it and try again, please "]
			RETURN
		ENDELSE
	 END
	 'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
         ELSE: 
	ENDCASE
END

; *********************************************************************
; * 
; *********************************************************************
PRO CACTRESPONS_EDIT 

COMMON pia_actrespons_cmn, dets, detact, respons, newrespons, det_id, origin
COMMON cactresp_edit_cmn, edval_id, pixels 

	edbase = WIDGET_BASE(TITLE =detact+' Computed Responses', $
			/column)

	edvalbase = WIDGET_BASE(edbase, /row)
	pixels = N_ELEMENTS(newrespons(*,0))
	pixlist = STRTRIM(STRING(indgen(pixels) + 1),2)
	pixlist = 'Pixel ' + pixlist 
	edval_id = lonarr(2)
	edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=pixels, $
	    VALUE = pixlist)
	edval_id(0) = WIDGET_TEXT(edvalbase, /editable, XSIZE=18, YSIZE=pixels, $
	    VALUE = STRTRIM(STRING(newrespons(*,0)),2), UVALUE='JUNK')
	edval_id(1) = WIDGET_TEXT(edvalbase, /editable, XSIZE=18, YSIZE=pixels, $
	    VALUE = STRTRIM(STRING(newrespons(*,1)),2), UVALUE='JUNK')
	edconbase = WIDGET_BASE(edbase, /row)
	ok = WIDGET_BUTTON(edconbase, VALUE='  OK  ', UVALUE='LIST')
	quit = WIDGET_BUTTON(edconbase, VALUE=' QUIT ', UVALUE='QUIT') 
	WIDGET_CONTROL, edbase, /REALIZE
	xMANAGER,No_BLOCK=1, "CACTRESPONS_EDIT", edbase, GROUP=group
	RETURN
END 

; *********************************************************************
; * 
; *********************************************************************
PRO PIA_CAL_ACTRESPONS_EVENT, event

@phtresact
@colour_indices
COMMON pia_actrespons_cmn, dets, detact, respons, newrespons, det_id, origin


	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	i = WHERE(dets EQ uvalue, n)
	i = i(0)
	IF n NE 0 THEN uvalue = 'DET'

	CASE uvalue of
	   'DET': BEGIN
	   		WIDGET_CONTROL, det_id, SET_VALUE=dets(i)
			detact = dets(i)
			origin = {n:'',f:''}
			CASE STRMID(detact,0,2) OF
				'P1': BEGIN
				   IF N_ELEMENTS(p1respact) EQ 0 THEN $
				     respons = FLTARR(1,2) ELSE BEGIN 
				      respons = p1respact
				      boost_array, respons, p1respunc
				      origin = {n:respact_origin.p1n,$
				      		f:respact_origin.p1f}
				     ENDELSE
				end
				'P2': BEGIN
				   IF N_ELEMENTS(p2respact) EQ 0 THEN $
				     respons = FLTARR(1,2) ELSE BEGIN 
				      respons = p2respact
				      boost_array, respons, p2respunc
				      origin = {n:respact_origin.p2n,$
				      		f:respact_origin.p2f}
				     ENDELSE
				end
				'P3': BEGIN
				   IF N_ELEMENTS(p3respact) EQ 0 THEN $
				     respons = FLTARR(1,2) ELSE BEGIN 
				      respons = p3respact
				      boost_array, respons, p3respunc
				      origin = {n:respact_origin.p3n,$
				      		f:respact_origin.p3f}
				     ENDELSE
				end
				'C1': BEGIN
				   IF N_ELEMENTS(c1respact) EQ 0 THEN $
				     respons = FLTARR(9,2) ELSE BEGIN 
				      respons = c1respact
				      boost_array, respons, c1respunc
				      origin = {n:respact_origin.c1n,$
				      		f:respact_origin.c1f}
				     ENDELSE
				end
				'C2': BEGIN
				   IF N_ELEMENTS(C2respact) EQ 0 THEN $
				     respons = FLTARR(4,2) ELSE BEGIN 
				      respons = c2respact
				      boost_array, respons, c2respunc
				      origin = {n:respact_origin.c2n,$
				      		f:respact_origin.c2f}
				     ENDELSE
				end
                        ENDCASE
			newrespons = respons
		  END	
	   	  
	   'PLOTACT': BEGIN 
			xind = indgen(N_ELEMENTS(respons(*,0))) + 1
			PIA_XPLOT, xind, respons(*,0), respons(*,1), psym=4, $
				title= detact + ' actual Response', $
				xtitle = ' Pixel ', $
				ytitle = 'Response      [A/W]', $
				legend = title   

		      END

	   'OPLOTACT': BEGIN 
			xind = indgen(N_ELEMENTS(respons(*,0))) + 1
			PIA_XPLOT, xind, respons(*,0), respons(*,1), $
				psym = 6, color = yellow, $
				title= detact + ' actual Response', $
				xtitle = ' Pixel ', $
				ytitle = 'Response      [A/W]', $
				legend = title, overplot = 99		
		      END

	   'PLOTCOM': BEGIN 
			IF N_ELEMENTS(newrespons) NE 0 THEN BEGIN
			 xind = indgen(N_ELEMENTS(newrespons(*,0))) + 1
			 PIA_XPLOT, xind, newrespons(*,0), $
				newrespons(*,1), psym=4, $
				title= detact + ' computed actual Response', $
				xtitle = ' Pixel ', $
				ytitle = 'Response      [A/W]', $
				legend = title   
                        ENDIF ELSE MESSAGE, /INFO, $
				'Sorry, no new responses computed'
		      END

	   'OPLOTCOM': BEGIN 
			IF N_ELEMENTS(newrespons) NE 0 THEN BEGIN
			 xind = indgen(N_ELEMENTS(newrespons(*,0))) + 1
			 PIA_XPLOT, xind, newrespons(*,0), $
				newrespons(*,1), psym = 6, color = yellow, $
				title= detact + ' computed actual Response', $
				xtitle = ' Pixel ', $
				ytitle = 'Response      [A/W]', $
				legend = title, overplot = 99		
                        ENDIF ELSE MESSAGE, /INFO, $
				'Sorry, no new responses computed'
		      END

	   'EDACTVAL': ACTRESPONS_EDIT

	   'EDCOMVAL': CACTRESPONS_EDIT

	   'WRICOM': BEGIN
			CASE STRMID(detact,0,2) OF
				'P1': p1respact = newrespons(*,0)
				'P2': p2respact = newrespons(*,0)
				'P3': p3respact = newrespons(*,0)
				'C1': c1respact = newrespons(*,0)
				'C2': c2respact = newrespons(*,0)
                        ENDCASE
			CASE STRMID(detact,0,2) OF
				'P1': p1respunc = newrespons(*,1)
				'P2': p2respunc = newrespons(*,1)
				'P3': p3respunc = newrespons(*,1)
				'C1': c1respunc = newrespons(*,1)
				'C2': c2respunc = newrespons(*,1)
                        ENDCASE
                 respons = newrespons
		END
	   
	   'QUIT': WIDGET_CONTROL, event.top, /DESTROY
		
	   ELSE: 
	ENDCASE
RETURN
END

; *********************************************************************
; * 
; *
; *
; *********************************************************************
PRO PIA_CAL_ACTRESPONS, GROUP=group

@phtresact
COMMON pia_actrespons_cmn, dets, detact, respons, newrespons, det_id, origin

	dets = ['P1','P2', 'P3', 'C100', 'C200'] 
; default startup detector id is C200
	detact = dets(4)
	
	IF N_ELEMENTS(C2respact) EQ 0 THEN BEGIN
	 respons = FLTARR(4,2)
	 origin = {n:'', f:''} 
	ENDIF ELSE BEGIN
	 respons = C2respact
	 boost_array, respons, C2respunc
	 origin = {n:respact_origin.c2n,f:respact_origin.c2f}
	ENDELSE

	newrespons = respons


	respbase = WIDGET_BASE(TITLE = 'PIA Actual Responses Menu', $
                                /COLUMN)

        choicebase = WIDGET_BASE(respbase, /ROW)

	det_id = WIDGET_BUTTON(choicebase, VALUE = detact, /MENU)

	FOR I=0,4 DO id_0 = WIDGET_BUTTON(det_id, VALUE=dets(i),UVALUE=dets(i))
  
        plot_id = WIDGET_BUTTON(choicebase, VALUE = ' Plot ', /MENU)
        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' Actual Values ', /MENU )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' New Plot ', UVALUE='PLOTACT')
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Overplot ', UVALUE='OPLOTACT')

        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' Computed Values ', /MENU)
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' New Plot ', UVALUE='PLOTCOM')
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Overplot ', UVALUE='OPLOTCOM')



	edit_id = WIDGET_BUTTON(choicebase, VALUE= ' Edit Values ', /MENU)
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'Actual Values', $
				UVALUE = 'EDACTVAL')
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'Computed Values', $
				UVALUE = 'EDCOMVAL')

	write_id = WIDGET_BUTTON(choicebase, VALUE = ' Write Values ', /MENU)
	id_1 = WIDGET_BUTTON(write_id, $
		VALUE = 'New values to internal common', $
				UVALUE = 'WRICOM')

	quit_id = WIDGET_BUTTON(respbase, VALUE = '  Quit  ', $
                        /FRAME, UVALUE = 'QUIT')

        WIDGET_CONTROL, respbase, /REALIZE, TLB_SET_XOFFSET=300, $
                        TLB_SET_YOFFSET=50

        xMANAGER,No_BLOCK=1, "pia_cal_actrespons", respbase, GROUP=group
	
RETURN
END
