;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_CAL_COLOUR_CORRECTION
;
; PURPOSE:
;	Top level menu for colour correction file display and editing
;
; CATEGORY:
;       PIA - graphics
;
; CALLING SEQUENCE:
;       PIA_CAL_COLOUR_CORRECTION
;
; KEYWORD PARAMETERS:
;	GROUP=group: Group leader
;
; COMMON BLOCKS:
;	colour_indices
;       pia_colour_correction_cmn
;
; PROCEDURES USED:
;	PIA LIB:
;		pia_disp_print_file
;       INTERNAL:
;		show_cc
;
; MODIFICATION HISTORY:
;       Written by: I. Heinrichsen		        August 1997
;
;-

; *********************************************************************
; *
; *********************************************************************
PRO SHOW_CC, calg_ccsel 

font = '-*-courier-bold-*-*-*-14-*'
title='PHT Colour Correction File: '+calg_ccsel
out=''
file=!CALG+calg_ccsel
savename=!CALSAVE+calg_ccsel
PIA_DISP_PRINT_FILE, file, TITLE=title, $
  TEXT=out, HEIGHT=40, FONT=font, SAVENAME=savename 
RETURN
END 

; *********************************************************************
; *
; *********************************************************************
PRO PIA_CAL_COLOUR_CORRECTION_EVENT, event

COMMON pia_colour_correction_cmn, cc_type, cc_act, $
  cc_id, show_id , edit_id, write_id, quit_id, calg_ccsel

@colour_indices

WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
i = WHERE(cc_type EQ uvalue, n)
i = i(0)
IF n NE 0 THEN uvalue = 'DET'

CASE uvalue of
    'DET': BEGIN
        WIDGET_CONTROL, cc_id, SET_VALUE=cc_type(i)
        CASE cc_type(i) OF
            'Power law': BEGIN
                calg_ccsel = 'cc_power.txt'
            END
            'Black Body': BEGIN
                calg_ccsel = 'cc_bb.txt'
            END
            'Modified Black Body nu^1': BEGIN
                calg_ccsel = 'cc_mbbnu1.txt'
            END
            'Modified Black Body nu^2': BEGIN
                calg_ccsel = 'cc_mbbnu2.txt'
            END
        ENDCASE
    END	

    'SHOWCALG': SHOW_CC, calg_ccsel
    
    'QUIT': WIDGET_CONTROL, event.top, /DESTROY
    
    ELSE: 
ENDCASE
RETURN
END

; *********************************************************************
; *
; *
; *
; *********************************************************************
PRO PIA_CAL_COLOUR_CORRECTION, GROUP=group

COMMON pia_colour_correction_cmn, cc_type, cc_act, $
  cc_id, show_id , edit_id, write_id, quit_id, calg_ccsel

cc_type = ['Power law', 'Black Body', 'Modified Black Body nu^1','Modified Black Body nu^2'] 

cc_act = cc_type(1)

calg_ccsel='cc_bb.txt'

ccbase = WIDGET_BASE(TITLE = 'PIA Colour Correction Factors', $
                       /COLUMN)

choicebase = WIDGET_BASE(ccbase, /ROW)

cc_id = WIDGET_BUTTON(choicebase, VALUE = cc_act, /MENU)

FOR I=0,3 DO id_0 = WIDGET_BUTTON(cc_id, VALUE=cc_type(i),UVALUE=cc_type(i))

show_id = WIDGET_BUTTON(choicebase, VALUE= ' Show + Change CAL-G Values ',UVALUE = 'SHOWCALG')

quit_id = WIDGET_BUTTON(ccbase, VALUE = '  Quit  ', $
                        /FRAME, UVALUE = 'QUIT')

WIDGET_CONTROL, ccbase, /REALIZE, TLB_SET_XOFFSET=300, $
  TLB_SET_YOFFSET=50

xMANAGER,No_BLOCK=1, "pia_cal_colour_correction", ccbase, GROUP=group

RETURN
END
