;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_CAL_CRELIN
;
; PURPOSE:
;	Top level menu for PHT CRE linearization Files production, one of
;	the Calibration Files Derivation Procedures (CFDP)  
;
; CATEGORY:
;       PIA - graphics
;
; CALLING SEQUENCE:
;       PIA_CAL_CRELIN
;
; COMMON BLOCKS:
;	colour_indices
;	phtcrelin
;
; PROCEDURES USED:
;	PIA LIB:
;		pia_multchoice
;		pia_xplot
;		pia_xsurface
;		read_crelin
;		write_crelin
;       ASTRO LIB:
;		fxread
;       INTERNAL:
;		crelin_edit
;		crelin_edit_event
;		ccrelin_edit
;		ccrelin_edit_event
;		pia_crelin_event
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel (ESA/ESTEC) 		March 1995
;	Modified (last) by: (CG)			September 1995
;	Oct 95 Version 3.5
;	Processing button deleted (CG)			April 1997
;	Version 6.2
;	Re-initialize button added (CG)			November 1997
;	V6.6
;	Format for editing added (CG)			January 1999
;	V7.3
;	/Modal use according to IDL >=5.0 (CG)		February 1999
;	V7.3.1
;-
; **********************************************************
; *
; **********************************************************
PRO CRELIN_EDIT_event, event 

COMMON pia_crelin_cmn, dets, detact, freqs, freqact, $
		crelin, newcrelin, wricalg_id, freq_id, det_id 


	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.id, GET_VALUE=value
	CASE uvalue of
	'list': 
	'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
	ENDCASE
END

; **********************************************************
; *
; **********************************************************
PRO CRELIN_EDIT, group=group 

COMMON pia_crelin_cmn, dets, detact, freqs, freqact, $
		crelin, newcrelin, wricalg_id, freq_id, det_id 

	IF not KEYWORD_SET(group) THEN group = !PIA_TOP_WID
	edbase = WIDGET_BASE(TITLE =detact+' Actual CRElin Tables', $
			/column, GROUP=group)

	cptlist = STRTRIM(STRING(indgen(121)*0.02-1.2),2) 

	pixels = N_ELEMENTS(crelin(0,*,0,0))

	pixlist = ''

	IF detact EQ 'P#' THEN pixchar = 'P' ELSE pixchar = 'Pixel ' 

	edvalbase = WIDGET_BASE(edbase, /row)
	
        edvalbas2 = WIDGET_BASE(edvalbase, /column)
	
	edval = WIDGET_TEXT(edvalbas2, XSIZE=12, YSIZE=1, $
	  VALUE = 'Voltages')
	edval = WIDGET_TEXT(edvalbas2, XSIZE=12, YSIZE=25, $
	  VALUE = cptlist, /SCROLL)

	FOR III=0,pixels-1 DO BEGIN  
	 edvalbas3 = WIDGET_BASE(edvalbase, /column)
	 edval = WIDGET_TEXT(edvalbas3, XSIZE=6, YSIZE=1, $
		VALUE = pixchar+STRTRIM(STRING(III+1),2))
	 edval = WIDGET_TEXT(edvalbas3, XSIZE=6, YSIZE=25, $
	   VALUE = STRMID(STRTRIM(STRING(format='(f5.2)',crelin(*,iii,freqact,0)),2),0,5),$
		UVALUE = 'list', /scroll)
        ENDFOR

	quit = WIDGET_BUTTON(edbase, VALUE=' QUIT ', UVALUE='QUIT') 
	WIDGET_CONTROL, edbase, /REALIZE
	xMANAGER,No_BLOCK=1, "CRELIN_EDIT", edbase, GROUP=group
	RETURN
END 

; **********************************************************
; *
; **********************************************************
PRO CCRELIN_EDIT_event, event 

COMMON pia_crelin_cmn, dets, detact, freqs, freqact, $
	crelin, newcrelin, wricalg_id, freq_id, det_id 
COMMON ccrel_edit_cmn, edval_id 

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue of
	 'LIST': BEGIN
		FOR III=0,N_ELEMENTS(edval_id) - 1 DO BEGIN
		 WIDGET_CONTROL, edval_id(III), GET_VALUE=value
		 IF N_ELEMENTS(value) EQ 121 THEN $
			newcrelin(*,III,freqact,0) = float(value) ELSE BEGIN
                  	XDISPLAYFILE, "", $
                    		TITLE = "Input not accepted", $
                    		WIDTH = 50, $
                    		HEIGHT = 4, $
                    	  TEXT = [" Wrong CRELIN factors input  ", $]
                          	  "     ", $ ]
                          	  " Fix it and try again, please "]
			RETURN
		 ENDELSE	
		ENDFOR
	 END
	 'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
         ELSE: 
	ENDCASE

RETURN
END

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

; **********************************************************
; *
; **********************************************************
PRO CCRELIN_EDIT, GROUP=group 

COMMON pia_crelin_cmn, dets, detact, freqs, freqact, $
crelin, newcrelin, wricalg_id, freq_id, det_id 
COMMON ccrel_edit_cmn, edval_id 

	IF not KEYWORD_SET(group) THEN group = !PIA_TOP_WID
	edbase = WIDGET_BASE(TITLE =detact+' Computed CRElin Tables', $
			/column, /MODAL, GROUP=group)

	cptlist = STRTRIM(STRING(indgen(121)*0.02-1.2),2) 

	pixels = N_ELEMENTS(crelin(0,*,0,0))

	pixlist = ''

	IF detact EQ 'P#' THEN pixchar = 'P' ELSE pixchar = 'Pixel ' 

	edvalbase = WIDGET_BASE(edbase, /row)
	
        edvalbas2 = WIDGET_BASE(edvalbase, /column)
	
	edval = WIDGET_TEXT(edvalbas2, XSIZE=12, YSIZE=1, $
	  VALUE = 'Voltages')
	edval = WIDGET_TEXT(edvalbas2, XSIZE=12, YSIZE=25, $
	  VALUE = cptlist, /SCROLL)

	nele = N_ELEMENTS(newcrelin(0,*,0,0))
	edval_id = lonarr(nele) 

	FOR III=0,pixels-1 DO BEGIN  
	 edvalbas3 = WIDGET_BASE(edvalbase, /column)
	 edval = WIDGET_TEXT(edvalbas3, XSIZE=6, YSIZE=1, $
		VALUE = pixchar+STRTRIM(STRING(III+1),2))
	 edval = WIDGET_TEXT(edvalbas3, /EDITABLE, XSIZE=6, YSIZE=25, $
	   VALUE = STRMID(STRTRIM(STRING(crelin(*,iii,freqact,0)),2),0,5),$
		UVALUE = 'list', /scroll)
	 edval_id(III) = edval
        ENDFOR

	edconbase = WIDGET_BASE(edbase, /row)
	ok = WIDGET_BUTTON(edconbase, VALUE='  ACCEPT  ', UVALUE='LIST')
	quit = WIDGET_BUTTON(edconbase, VALUE=' QUIT ', UVALUE='QUIT') 

	WIDGET_CONTROL, edbase, /REALIZE

	xMANAGER,No_BLOCK=1, "CCRELIN_EDIT", edbase, GROUP=group
	RETURN
END 

; **********************************************************
; *
; **********************************************************
PRO CLG_CRELIN_EDIT_event, event 

COMMON pia_crelin_cmn, dets, detact, freqs, freqact, $
		crelin, newcrelin, wricalg_id, freq_id, det_id 
COMMON cal_crelin_cmn, calg_crelin, calg_crelin_p, calg_crelin_c1, calg_crelin_c2


	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.id, GET_VALUE=value
	CASE uvalue of
	'list': 
	'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
	ENDCASE
END

PRO CLG_CRELIN_EDIT 

COMMON pia_crelin_cmn, dets, detact, freqs, freqact, $
		crelin, newcrelin, wricalg_id, freq_id, det_id 
COMMON cal_crelin_cmn, calg_crelin, calg_crelin_p, calg_crelin_c1, calg_crelin_c2

	edbase = WIDGET_BASE(TITLE =detact+' CALG CRElin Tables', $
			/column)

	cptlist = STRTRIM(STRING(indgen(121)*0.02-1.2),2) 

	pixels = N_ELEMENTS(calg_crelin(0,*,0,0))

	pixlist = ''

	IF detact EQ 'P#' THEN pixchar = 'P' ELSE pixchar = 'Pixel ' 

	edvalbase = WIDGET_BASE(edbase, /row)
	
        edvalbas2 = WIDGET_BASE(edvalbase, /column)
	
	edval = WIDGET_TEXT(edvalbas2, XSIZE=12, YSIZE=1, $
	  VALUE = 'Voltages')
	edval = WIDGET_TEXT(edvalbas2, XSIZE=12, YSIZE=25, $
	  VALUE = cptlist, /SCROLL)

	FOR III=0,pixels-1 DO BEGIN  
	 edvalbas3 = WIDGET_BASE(edvalbase, /column)
	 edval = WIDGET_TEXT(edvalbas3, XSIZE=6, YSIZE=1, $
		VALUE = pixchar+STRTRIM(STRING(III+1),2))
	 edval = WIDGET_TEXT(edvalbas3, XSIZE=6, YSIZE=25, $
	   VALUE = STRMID(STRTRIM(STRING(calg_crelin(*,iii,freqact,0)),2),0,5),$
		UVALUE = 'list', /scroll)
        ENDFOR

	quit = WIDGET_BUTTON(edbase, VALUE=' QUIT ', UVALUE='QUIT') 
	WIDGET_CONTROL, edbase, /REALIZE
	xMANAGER,No_BLOCK=1, "CLG_CRELIN_EDIT", edbase, GROUP=group
	RETURN
END 


; **********************************************************
; *
; **********************************************************
PRO PIA_CAL_CRELIN_EVENT, event

@phtcrelin
@colour_indices

COMMON pia_crelin_cmn, dets, detact, freqs, freqact, $
	crelin, newcrelin, wricalg_id, freq_id, det_id 
COMMON cal_crelin_cmn, calg_crelin, calg_crelin_p, calg_crelin_c1, calg_crelin_c2


	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	i = WHERE(freqs EQ uvalue, n)
	i = i(0)
	IF n NE 0 THEN BEGIN 
		uvalue = 'FREQ'
		GOTO, uvaleval
	ENDIF

	i = WHERE(dets EQ uvalue, n)
	i = i(0)
	IF n NE 0 THEN uvalue = 'DET'

uvaleval:
	CASE uvalue of

	   'FREQ': BEGIN
			freqact = i
	   		WIDGET_CONTROL, freq_id, SET_VALUE=freqs(i)
	   END

	   'DET': BEGIN
			detact = dets(i)
			CASE STRMID(detact,0,2) of
			  'P#': BEGIN 
				crelin = ppcrelin
				calg_crelin = calg_crelin_p
			  END
			  'C1': BEGIN
				crelin = pc1crelin
				calg_crelin = calg_crelin_c1
			  END
			  'C2': BEGIN
				crelin = pc2crelin
				calg_crelin = calg_crelin_c2
			  END
			ENDCASE
			newcrelin = crelin
	   		WIDGET_CONTROL, det_id, SET_VALUE=detact
	   END	  

	   'PLOTACT': BEGIN 
		 title=detact+' actual CRElin - Frequency '+freqs(freqact) 
		IF detact EQ 'P#' THEN pixchar = 'P' ELSE pixchar = 'Pixel ' 
                 pia_xsurface, crelin(*,*,freqact,0), wlego=1, $
			xtitle = 'Input Voltage    [V]', $
                        ytitle= pixchar, charsize=1.4, $
                        ztitle= ' CRElin correction  ', title=title, $
                        group=event.top  

		END

	   'PLOTACTPROJ': BEGIN
	        IF STRMID(detact,0,1) EQ 'P' THEN pixchar = 'P' ELSE $
					          pixchar = 'Pixel '  
                list = indgen(N_ELEMENTS(crelin(0,*,0,0)))
		elnames = pixchar + STRTRIM(STRING(list+1),2)
		pia_multchoice, list, ELEMNAMES = elnames   
		 		
		title = detact+' actual CRElin - Frequency '+freqs(freqact)
		ytitle = pixchar+STRTRIM(STRING(list+1),2)+ ' factors'
		x = (indgen(121) * 0.02) - 1.2  
                pia_xplot, x, crelin(*,list,freqact,0), $
			crelin(*,list,freqact,1), psym=4, $
			title= title, xtitle=' Input Voltage   [V]', $
			ytitle = ytitle, annotation = title, legend = ytitle
           END

	   'OPLOTACTPROJ': BEGIN
	        IF STRMID(detact,0,1) EQ 'P' THEN pixchar = 'P' ELSE $
					          pixchar = 'Pixel '  
                list = indgen(N_ELEMENTS(crelin(0,*,0,0)))
		elnames = pixchar + STRTRIM(STRING(list+1),2)
		pia_multchoice, list, ELEMNAMES = elnames   
		 		
		title = detact+' actual CRElin - Frequency '+freqs(freqact)
		ytitle = pixchar+STRTRIM(STRING(list+1),2)+ ' factors'
		x = (indgen(121) * 0.02) - 1.2  
                pia_xplot, x, crelin(*,list,freqact,0), color=yellow, $
			crelin(*,list,freqact,1), psym=6, $
			title= title, overplot=99,  $
			ytitle = ytitle, annotation = title, legend = ytitle
           END

	   'PLOTCOM': BEGIN 
		 title=detact+' computed CRElin - Frequency '+freqs(freqact) 
		IF detact EQ 'P#' THEN pixchar = 'P' ELSE pixchar = 'Pixel ' 
                 pia_xsurface, newcrelin(*,*,freqact,0), wlego=1, $
			xtitle = 'Input Voltage    [V]', $
                        ytitle= pixchar, charsize=1.4, $
                        ztitle= ' CRElin correction  ', title=title, $
                        group=event.top  
		END


	   'PLOTCOMPROJ': BEGIN
	        IF STRMID(detact,0,1) EQ 'P' THEN pixchar = 'P' ELSE $
					          pixchar = 'Pixel '  
                list = indgen(N_ELEMENTS(newcrelin(0,*,0,0)))
		elnames = pixchar + STRTRIM(STRING(list+1),2)
		pia_multchoice, list, ELEMNAMES = elnames   
		 		
		title = detact+' computed CRElin - Frequency '+freqs(freqact)
		ytitle = pixchar+STRTRIM(STRING(list+1),2)+ ' factors'
		x = (indgen(121) * 0.02) - 1.2  
                pia_xplot, x, newcrelin(*,list,freqact,0), $
			newcrelin(*,list,freqact,1), psym=4, $
			title= title, xtitle=' Input Voltage   [V]', $
			ytitle = ytitle, annotation = title, legend = ytitle
           END

	   'OPLOTCOMPROJ': BEGIN
	        IF STRMID(detact,0,1) EQ 'P' THEN pixchar = 'P' ELSE $
					          pixchar = 'Pixel '  
                list = indgen(N_ELEMENTS(crelin(0,*,0,0)))
		elnames = pixchar + STRTRIM(STRING(list+1),2)
		pia_multchoice, list, ELEMNAMES = elnames   
		 		
		title = detact+' computed CRElin - Frequency '+freqs(freqact)
		ytitle = pixchar+STRTRIM(STRING(list+1),2)+ ' factors'
		x = (indgen(121) * 0.02) - 1.2  
                pia_xplot, x, newcrelin(*,list,freqact,0), color=yellow, $
			newcrelin(*,list,freqact,1), psym=6, $
			title= title, overplot=99,  $
			ytitle = ytitle, annotation = title, legend = ytitle
           END

	   'PLOTCLG': BEGIN 
		 title=detact+' CALG CRElin - Frequency '+freqs(freqact) 
		IF detact EQ 'P#' THEN pixchar = 'P' ELSE pixchar = 'Pixel ' 
                 pia_xsurface, calg_crelin(*,*,freqact,0), wlego=1, $
			xtitle = 'Input Voltage    [V]', $
                        ytitle= pixchar, charsize=1.4, $
                        ztitle= ' CRElin correction  ', title=title, $
                        group=event.top  

		END

	   'PLOTCLGPROJ': BEGIN
	        IF STRMID(detact,0,1) EQ 'P' THEN pixchar = 'P' ELSE $
					          pixchar = 'Pixel '  
                list = indgen(N_ELEMENTS(calg_crelin(0,*,0,0)))
		elnames = pixchar + STRTRIM(STRING(list+1),2)
		pia_multchoice, list, ELEMNAMES = elnames   
		 		
		title = detact+' CALG CRElin - Frequency '+freqs(freqact)
		ytitle = pixchar+STRTRIM(STRING(list+1),2)+ ' factors'
		x = (indgen(121) * 0.02) - 1.2  
                pia_xplot, x, calg_crelin(*,list,freqact,0), $
			calg_crelin(*,list,freqact,1), psym=4, $
			title= title, xtitle=' Input Voltage   [V]', $
			ytitle = ytitle, annotation = title, legend = ytitle
           END

	   'OPLOTCLGPROJ': BEGIN
	        IF STRMID(detact,0,1) EQ 'P' THEN pixchar = 'P' ELSE $
					          pixchar = 'Pixel '  
                list = indgen(N_ELEMENTS(calg_crelin(0,*,0,0)))
		elnames = pixchar + STRTRIM(STRING(list+1),2)
		pia_multchoice, list, ELEMNAMES = elnames   
		 		
		title = detact+' CALG CRElin - Frequency '+freqs(freqact)
		ytitle = pixchar+STRTRIM(STRING(list+1),2)+ ' factors'
		x = (indgen(121) * 0.02) - 1.2  
                pia_xplot, x, calg_crelin(*,list,freqact,0), color=yellow, $
			calg_crelin(*,list,freqact,1), psym=6, $
			title= title, overplot=99,  $
			ytitle = ytitle, annotation = title, legend = ytitle
           END

	   'PROC': MESSAGE, /INFO, 'not yet implemented	

	   'EDACTVAL': CRELIN_EDIT, GROUP=event.top

	   'EDCOMVAL': CCRELIN_EDIT, GROUP=event.top

	   'EDCLGVAL': CLG_CRELIN_EDIT

	   'WRICOM': BEGIN
			CASE STRMID(detact,0,2) of
			  'P#': ppcrelin = newcrelin
			  'C1': pc1crelin = newcrelin
			  'C2': pc2crelin = newcrelin
			ENDCASE
			crelin = newcrelin
		 WIDGET_CONTROL, wricalg_id, /sensitive
		END

	   'WRICALG': BEGIN
		IF detact EQ 'P#' THEN det = 'P' ELSE det = STRMID(detact,0,2)
		 write_crelin, 'PIA_'+detact+'_CRELIN', det, newcrelin
		END

	   'QUIT': WIDGET_CONTROL, event.top, /DESTROY
		
	   'INIT': BEGIN
	        read_crelin
		CASE STRMID(detact,0,2) of
			  'P#': BEGIN 
				crelin = ppcrelin
			  END
			  'C1': BEGIN
				crelin = pc1crelin
			  END
			  'C2': BEGIN
				crelin = pc2crelin
			  END
		ENDCASE
		newcrelin = crelin
	   END
	   	   
	   ELSE: 
	ENDCASE
RETURN
END

; **********************************************************
; *
; **********************************************************
PRO PIA_CAL_CRELIN, GROUP=group

@phtcrelin

COMMON pia_crelin_cmn, dets, detact, freqs, freqact, $
	crelin, newcrelin, wricalg_id, freq_id, det_id 
COMMON cal_crelin_cmn, calg_crelin, calg_crelin_p, calg_crelin_c1, calg_crelin_c2


; Is the common filled up?
	IF N_ELEMENTS(ppcrelin) EQ 0 THEN read_crelin

; Initial choices: C100 

	freqs = ['1KHz','4KHz','8KHz']

	dets = ['P#', 'C100', 'C200'] 

	freqact = 1
	detact = dets(1)

	crelin = PC1CRELIN

	newcrelin = crelin
; initialize the calg common block
	FXREAD, !CALG+'PPCRELIN.FITS', calg_crelin_p
        FXREAD, !CALG+'PC1CRELIN.FITS', calg_crelin_c1
        FXREAD, !CALG+'PC2CRELIN.FITS', calg_crelin_c2
	calg_crelin = calg_crelin_c1

	crelbase = WIDGET_BASE(TITLE = 'PIA CRE linearization CFDP Menu', $
                                /COLUMN)

        choicebase = WIDGET_BASE(crelbase, /ROW)

	det_id = WIDGET_BUTTON(choicebase, VALUE = dets(1), /MENU)

	FOR I=0,2 DO id_0 = WIDGET_BUTTON(det_id, $
		VALUE=dets(i),UVALUE=dets(i))
  
	freq_id = WIDGET_BUTTON(choicebase, VALUE = freqs(1), /MENU)

	FOR I=0,2 DO id_0 = WIDGET_BUTTON(freq_id, $
		VALUE=freqs(i),UVALUE=freqs(i))
  
        plot_id = WIDGET_BUTTON(choicebase, VALUE = ' Plot ', /MENU)
        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' Actual Values ', /MENU)
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Lego Plot ', $
				UVALUE='PLOTACT' )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Plot Projection ', $
				UVALUE='PLOTACTPROJ' )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' OverPlot Projection ', $
				UVALUE='OPLOTACTPROJ' )
        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' Computed Values ', /MENU)
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Plot Projection ', $
				UVALUE='PLOTCOMPROJ' )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' OverPlot Projection ', $
				UVALUE='OPLOTCOMPROJ' )
        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' CALG Values ', /MENU)
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Lego Plot ', $
				UVALUE='PLOTCLG' )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Plot Projection ', $
				UVALUE='PLOTCLGPROJ' )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' OverPlot Projection ', $
				UVALUE='OPLOTCLGPROJ' )

;	proc_id = WIDGET_BUTTON(choicebase, VALUE= ' Process ', UVALUE='PROC')

	edit_id = WIDGET_BUTTON(choicebase, VALUE= ' Edit Values ', /MENU)
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'Actual Values', $
				UVALUE = 'EDACTVAL')
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'Computed Values', $
				UVALUE = 'EDCOMVAL')
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'CALG Values', $
				UVALUE = 'EDCLGVAL')

	write_id = WIDGET_BUTTON(choicebase, VALUE = ' Write Values ', /MENU)
	id_1 = WIDGET_BUTTON(write_id, VALUE = 'to internal common', $
				UVALUE = 'WRICOM')
	wricalg_id = WIDGET_BUTTON(write_id, VALUE = 'to Cal G file', $
				UVALUE = 'WRICALG')
	WIDGET_CONTROL, wricalg_id, SENSITIVE=0	

	init_id = WIDGET_BUTTON(choicebase, VALUE = ' Re-initialize ', $
			UVAL="INIT")

	quit_id = WIDGET_BUTTON(crelbase, VALUE = '  Quit  ', $
                        /FRAME, UVALUE = 'QUIT')

        WIDGET_CONTROL, crelbase, /REALIZE, TLB_SET_XOFFSET=300, $
                        TLB_SET_YOFFSET=50

        xMANAGER,No_BLOCK=1, "pia_cal_crelin", crelbase, GROUP=group
	
RETURN
END
