;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_CAL_DARKCUR
;
; PURPOSE:
;	Top level menu for Dark Current File production, one of
;	the Calibration Files Derivation Procedures (CFDP)  
;
; CATEGORY:
;       PIA - graphics
;
; CALLING SEQUENCE:
;       PIA_CAL_DARKCUR
;
; COMMON BLOCKS:
;	colour_indices
;	phtcap
;	phtdarkcur
;	pia_caldark_cmn (internal)
;	darkc2calu_cmn (internal)
;	cdark_edit_cmn (internal_)
;	cal_pdet (internal)
;	pia_dspchz_cmn (internal)
;	
; PROCEDURES USED:
;	PIA LIB:
;		get_darkcstr
;		get_darkcur
;		phtcap_init
;		pia_multchoice
;		pia_select_var
;		pia_showstr
;		pia_write_author
;		pia_write_version
;		pia_xplot
;		read_asc_pdetect
;		weight_mean
;		write_asc_pdetect
;		write_darkcstr
;		write_detdarkcur
;       ASTRO LIB:
;		avg
;		boost_array
;		date_conv
;		fxhread
;		fxpar
;		match
;       INTERNAL:
;		darkc2calu_weight_event
; 		darkc2calu_weight
;		darkc_struct_val_choice
;		darkcstr_show
;		darkcur_edit_event
;		darkcur_edit
;		cludarkcur_edit_event
;		cludarkcur_edit
;		clgdarkcur_edit_event
;		clgdarkcur_edit
;		pia_cal_darkcur_event
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel (ESA/ESTEC)		March 1995
;	Modified (last) by: CG, WMT			September 1995
;	Oct 95 Version 3.5
;	Cal G overplot added (CG)			December 1995
;	The final value of dark current and min NEP is 
;	taken as the median value, not as weighted 
;	mean  [Rout:DARKC_STRUCT_VAL_CHOICE] (J.Acosta)	March 1996 
;	Processing can start from SCP level (J.Acosta0	October 1996
;	Handling from export version possible (CG)	April 1997
;	V6.2
;	Bug for non-existence of cal_struct fixed (CG)	May 1997
;	V6.3 
;	Change the access to calsave files (JA)		Oct 1997
;	V6.5
;	/Modal use according to IDL >=5.0 (CG)		February 1999
;	V7.3.1
;-

; *************************************************************
;;;;;; Events from Menu for weighting dark currents ;;;;;;;;
; *************************************************************

PRO darkc2calu_weight_event, event

COMMON pia_caldark_cmn, dets, detact, darkcurr, newdarkcurr, newstruct, $
	pixl_weight, det_id, darkstruct, newnep, ext_version 
COMMON darkc2calu_cmn, edval_id, pixels 

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue of
	 'LIST': BEGIN
		IF STRMID(detact,0,1) EQ 'S' THEN BEGIN
		 WIDGET_CONTROL, edval_id(0), GET_VALUE=value
		 WIDGET_CONTROL, edval_id(1), GET_VALUE=valu2
		 WIDGET_CONTROL, edval_id(2), GET_VALUE=valu3
		 WIDGET_CONTROL, edval_id(3), GET_VALUE=valu4
		 value = [value,valu2,valu3,valu4]
		ENDIF ELSE $
		 WIDGET_CONTROL, edval_id, GET_VALUE=value

		IF N_ELEMENTS(value) EQ pixels THEN $
			pixl_weight = float(value) ELSE BEGIN
                  	XDISPLAYFILE, "", $
                    		TITLE = "Input not accepted", $
                    		WIDTH = 50, $
                    		HEIGHT = 4, $
                    	  TEXT = [" Wrong dark current weighting input  ", $]
                          	  "     ", $ ]
                          	  " Fix it and try again, please "]
			RETURN
		ENDELSE
	 END
	 'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
         ELSE: 
	ENDCASE
END

; *************************************************************
;;;;;; Menu for weighting dark currents ;;;;;;;;
; *************************************************************

PRO darkc2calu_weight, group=group

COMMON pia_caldark_cmn, dets, detact, darkcurr, newdarkcurr, newstruct, $
	pixl_weight, det_id, darkstruct, newnep, ext_version 
COMMON darkc2calu_cmn, edval_id, pixels 
		 
	nelem = N_ELEMENTS(pixl_weight)
	pixels = N_ELEMENTS(newdarkcurr(*,0)) 
		 
	IF nelem NE pixels THEN $
		pixl_weight = fltarr(pixels) + 1.
   
	IF not KEYWORD_SET(group) THEN group = !PIA_TOP_WID
	edbase = WIDGET_BASE(TITLE =detact+' Dark Currents weighting', $
			/column, /MODAL, group=group)

	edvalbase = WIDGET_BASE(edbase, /row)
	pixlist = STRTRIM(STRING(indgen(pixels) + 1),2)
	pixlist = 'Pixel ' + pixlist 

	if STRMID(detact, 0, 1) EQ 'S' then begin
	  edval_id = LONARR(4)
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(0:31))
	  edval_id(0) = WIDGET_TEXT(edvalbase, /editable, XSIZE=18, YSIZE=32, $
		VALUE = STRTRIM(STRTRIM(STRING(pixl_weight(0:31)),2)), $
		UVALUE='JUNK')
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(32:63))
	  edval_id(1) = WIDGET_TEXT(edvalbase, /editable, XSIZE=18, YSIZE=32, $
		VALUE = STRTRIM(STRTRIM(STRING(pixl_weight(32:63)),2)),$
		 UVALUE='JUNK')
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(64:95), UVALUE='JUNK')
	  edval_id(2) = WIDGET_TEXT(edvalbase, /editable, XSIZE=18, YSIZE=32, $
		VALUE = STRTRIM(STRTRIM(STRING(pixl_weight(64:95)),2)),$
		UVALUE='JUNK')
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(96:127), UVALUE='JUNK')
	  edval_id(3) = WIDGET_TEXT(edvalbase, /editable, XSIZE=18, YSIZE=32, $
		VALUE = STRTRIM(STRTRIM(STRING(pixl_weight(96:127)),2)), $
		UVALUE='JUNK')
	ENDIF ELSE BEGIN
	  edval = WIDGET_TEXT(edvalbase, XSIZE=8, YSIZE=pixels, $
	    VALUE = pixlist)
	  edval_id = WIDGET_TEXT(edvalbase, /editable, XSIZE=18, YSIZE=pixels, $
	    VALUE = STRTRIM(STRING(pixl_weight),2), UVALUE='JUNK')
	ENDELSE

	edconbase = WIDGET_BASE(edbase, /row)
	ok = WIDGET_BUTTON(edconbase, VALUE='  OK  ', UVALUE='LIST')
	quit = WIDGET_BUTTON(edconbase, VALUE=' QUIT ', UVALUE='QUIT') 
	WIDGET_CONTROL, edbase, /REALIZE
	xMANAGER,No_BLOCK=1, "DARKC2CALU_WEIGHT", edbase, GROUP=group
	RETURN
END 

; *************************************************************
; ***************  choice menu for structure elements
; *************************************************************

PRO DARKC_STRUCT_VAL_CHOICE

COMMON pia_caldark_cmn, dets, detact, darkcurr, newdarkcurr, newstruct, $
	pixl_weight, det_id, darkstruct, newnep, ext_version 

	data_names = ['Flag ', 'Date ', 'Orbit position', 'treset', $
	       'Temperature']
        data_exa = [STRING(darkstruct(0).flag), darkstruct(0).date, $
	  STRING(darkstruct(0).orbpos), STRING(darkstruct(0).treset), $ 
	  STRING(darkstruct(0).temp)]
	  
; get variables limits
        pia_select_var, data_exa, limvars, VARNAMES=data_names, GROUP=group, $
          STOP = canc_sel
          
        IF canc_sel THEN RETURN
	
	indnot = WHERE(limvars(0,*) EQ '',nnot)

	nelem = N_ELEMENTS(darkstruct)
	indall = indgen(nelem)

        IF limvars(0,0) NE '' AND limvars(1,0) NE '' THEN BEGIN
	     flaglim = FIX(limvars(*,0)) 
	     indfl = WHERE(darkstruct.flag GE flaglim(0) AND $
			   darkstruct.flag LE flaglim(1), nflag)
	     IF nflag EQ 0 THEN BEGIN

                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" No flags corresponding to selection  "]
                        RETURN
	     ENDIF
        ENDIF ELSE indfl = indall 

        IF limvars(0,1) NE '' AND limvars(1,1) NE '' THEN BEGIN
	     
	     datelim = [date_conv(limvars(0,1)), date_conv(limvars(1,1))]
	     alldates = dblarr(nelem)
	     FOR I=0, nelem-1 DO alldates(i) = date_conv(darkstruct(i).date)
	     
             inddate = $
		WHERE(alldates GE datelim(0) AND alldates LE datelim(1),ndate)

	     IF ndate EQ 0 THEN BEGIN
                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" No dates corresponding to selection  "]
                        RETURN
	     ENDIF
	ENDIF ELSE inddate = indall 

        IF limvars(0,2) NE '' AND limvars(1,2) NE '' THEN BEGIN
	     orbplim = FLOAT(limvars(*,2)) 
	     indorb = WHERE(darkstruct.orbpos GE orbplim(0) AND $
			   darkstruct.orbpos LE orbplim(1), norbp)
	     IF norbp EQ 0 THEN BEGIN

                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" No orbit pos corresponding to selection"]
                        RETURN
	     ENDIF
        ENDIF ELSE indorb = indall 

        IF limvars(0,3) NE '' AND limvars(1,3) NE '' THEN BEGIN
	     treslim = FIX(limvars(*,3)) 
	     indtres = WHERE(darkstruct.treset GE treslim(0) AND $
			   darkstruct.treset LE treslim(1), ntres)
	     IF ntres EQ 0 THEN BEGIN

                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" No reset interval corresponding to selection"]
                        RETURN
	     ENDIF
        ENDIF ELSE indtres = indall 

        IF limvars(0,4) NE '' AND limvars(1,4) NE '' THEN BEGIN
	     templim = FLOAT(limvars(*,4)) 
	     indtemp = WHERE(darkstruct.temp GE templim(0) AND $
			   darkstruct.temp LE templim(1), ntemp)
	     IF ntemp EQ 0 THEN BEGIN

                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" No temperatures corresponding to selection"]
                        RETURN
	     ENDIF
        ENDIF ELSE indtemp = indall 

	; flag match
	match, indall, indfl, suba, subb, count=count
	indall = indall(suba)
	
	; Date match
	match, indall, inddate, suba, subb, count=count
	IF count EQ 0 THEN BEGIN
                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" Combined selection discard all elements "]
                        RETURN
	ENDIF
	indall = indall(suba)

	; orbital position match
	match, indall, indorb, suba, subb, count=count
	IF count EQ 0 THEN BEGIN
                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" Combined selection discard all elements "]
                        RETURN
	ENDIF
	indall = indall(suba)

	; reset interval match
	match, indall, indtres, suba, subb, count=count
	IF count EQ 0 THEN BEGIN
                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" Combined selection discard all elements "]
                        RETURN
	ENDIF
	indall = indall(suba)

	; temperature match
	match, indall, indtemp, suba, subb, count=count
	IF count EQ 0 THEN BEGIN
                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" Combined selection discard all elements "]
                        RETURN
	ENDIF
	indall = indall(suba)

	npix = n_elements(newdarkcurr(*,0))
	newnep = fltarr(npix)

	newstruct = darkstruct(indall)
	
	FOR I=0, npix-1 DO BEGIN 			
		indok = WHERE(darkstruct(indall).sflg(i) EQ 0, n)
		IF n GT 0 THEN BEGIN
		  	;WEIGHT_MEAN, darkstruct(indall(indok)).darkc(i), $
			;	darkstruct(indall(indok)).darku(i), avr, sig  
			;newdarkcurr(i,0) = avr
			;newdarkcurr(i,1) = sig
			;newnep(i) = avg(darkstruct(indall).nep(i))
		 	newdarkcurr(i,0) = median(darkstruct(indall(indok)).darkc(i))
                        indmed = $
                	  where(darkstruct(indall(indok)).darkc(i)) LT newdarkcurr(i,0)
		 	newdarkcurr(i,1) = $
		 	     median(darkstruct(indall(indok(indmed))).darkc(i))
			newnep(i) = median(darkstruct(indall(indok)).nep(i))
		ENDIF ELSE BEGIN 
		  	indok = WHERE(darkstruct(indall).sflg(i) EQ 1, n)
			IF n GT 0 THEN BEGIN
		  		;WEIGHT_MEAN, $
				;  darkstruct(indall(indok)).darkc(i), $
				;  darkstruct(indall(indok)).darku(i), avr, sig  
				;newdarkcurr(i,0) = avr
				;newdarkcurr(i,1) = sig
				;newnep(i) = avg(darkstruct(indok).nep(i))
		 		newdarkcurr(i,0) = $ 
		 		 median(darkstruct(indall(indok)).darkc(i))
                        	indmed = $
                	         where(darkstruct(indall(indok)).darkc(i)) LT newdarkcurr(i,0)
		 		newdarkcurr(i,1) = $
		 	    	 median(darkstruct(indall(indok(indmed))).darkc(i))
				newnep(i) = median(darkstruct(indall(indok)).nep(i))

			        MESSAGE, /INFO, 'Pixel'+STRING(I+1)+$
					' has only warning flags'
			ENDIF ELSE BEGIN   
				newdarkcurr(i,0) = 0.
				newdarkcurr(i,1) = 0.
				newnep(i) = 0.
			        MESSAGE, /INFO, 'Pixel'+STRING(I+1)+$
					' has only bad flags'
			ENDELSE
		ENDELSE
	ENDFOR

	nacc = N_ELEMENTS(indall)
	Text =  ["New dark currents and NEPs have been calculated ", $
		"using a total of "+ STRTRIM(STRING(nacc),2) + " measurements"]
        XDISPLAYFILE, "", $
                TITLE = "New Dark Current Calculation", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [text]

END 

; *************************************************************
; shows a dark current structure
; *************************************************************
PRO DARKCSTR_SHOW, darkstr, GROUP=group

	data_names = ['Flag ', 'ADMN', 'Date ', 'Orbit position', 't_reset',   $
		      'treset_cor','Temperature', 'Dark currents ',            $
		      'Uncertainties ', 'NEP', 'Responsivity', 'Signal flags', $
		      'Julian Date','Rev','Processing date']  
	
        pia_showstr, darkstr, VALNAMES=data_names

END 

; *************************************************************
; *
; *************************************************************
PRO DARKCUR_EDIT_event, event 

COMMON pia_caldark_cmn, dets, detact, darkcurr, newdarkcurr, newstruct, $
	pixl_weight, det_id, darkstruct, newnep, ext_version 

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.id, GET_VALUE=value
	CASE uvalue of
	 'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
	 ELSE:
	ENDCASE
END

; *************************************************************
; *
; *************************************************************
PRO DARKCUR_EDIT 

COMMON pia_caldark_cmn, dets, detact, darkcurr, newdarkcurr, newstruct, $
	pixl_weight, det_id, darkstruct, newnep, ext_version 

	edbase = WIDGET_BASE(TITLE =detact+' Actual Dark Current', $
			/column)
	edvalbase = WIDGET_BASE(edbase, /row)
	pixels = N_ELEMENTS(darkcurr)
	pixlist = STRTRIM(STRING(indgen(pixels) + 1),2)
	pixlist = 'Pixel ' + pixlist 

	if strmid(detact, 0, 1) EQ 'S' then begin
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(0:31))
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
		VALUE = STRTRIM(STRING(darkcurr(0:31))))
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(32:63))
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
		VALUE = STRTRIM(STRING(darkcurr(32:63))))
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(64:95))
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
		VALUE = STRTRIM(STRING(darkcurr(64:95))))
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(96:127))
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
		VALUE = STRTRIM(STRING(darkcurr(96:127))))
	ENDIF ELSE BEGIN
	  edval = WIDGET_TEXT(edvalbase, XSIZE=8, YSIZE=pixels, $
	   VALUE = pixlist)
	  edval = WIDGET_TEXT(edvalbase, XSIZE=18, YSIZE=pixels, $
	   VALUE = STRTRIM(STRING(darkcurr)))
	ENDELSE
	quit = WIDGET_BUTTON(edbase, VALUE=' QUIT ', UVALUE='QUIT') 
	WIDGET_CONTROL, edbase, /REALIZE
	xMANAGER,No_BLOCK=1, "DARKCUR_EDIT", edbase, GROUP=group 
	RETURN
END 

; *************************************************************
; *
; *************************************************************
PRO CDARKCUR_EDIT_event, event 

COMMON pia_caldark_cmn, dets, detact, darkcurr, newdarkcurr, newstruct, $
	pixl_weight, det_id, darkstruct, newnep, ext_version 
COMMON cdark_edit_cmn, edval_id, pixels 

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue of
	 'LIST': BEGIN
		IF STRMID(detact,0,1) EQ 'S' THEN BEGIN
		 WIDGET_CONTROL, edval_id(0), GET_VALUE=value
		 WIDGET_CONTROL, edval_id(1), GET_VALUE=valu2
		 WIDGET_CONTROL, edval_id(2), GET_VALUE=valu3
		 WIDGET_CONTROL, edval_id(3), GET_VALUE=valu4
		 value = [value,valu2,valu3,valu4]
		ENDIF ELSE $
		 WIDGET_CONTROL, edval_id, GET_VALUE=value
		IF N_ELEMENTS(value) EQ pixels THEN $
			newdarkcurr(*,0) = float(value) ELSE BEGIN
                  	XDISPLAYFILE, "", $
                    		TITLE = "Input not accepted", $
                    		WIDTH = 50, $
                    		HEIGHT = 4, $
                    	  TEXT = [" Wrong dark current input  ", $]
                          	  "     ", $ ]
                          	  " Fix it and try again, please "]
			RETURN
		ENDELSE
	 END
	 'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
         ELSE: 
	ENDCASE
END

; *************************************************************
; *
; *************************************************************
PRO CDARKCUR_EDIT 

COMMON pia_caldark_cmn, dets, detact, darkcurr, newdarkcurr, newstruct, $
	pixl_weight, det_id, darkstruct, newnep, ext_version 
COMMON cdark_edit_cmn, edval_id, pixels 

	edbase = WIDGET_BASE(TITLE =detact+' Computed Dark Current', $
			/column)

	edvalbase = WIDGET_BASE(edbase, /row)
	pixels = N_ELEMENTS(newdarkcurr(*,0))
	pixlist = STRTRIM(STRING(indgen(pixels) + 1),2)
	pixlist = 'Pixel ' + pixlist 
	if strmid(detact, 0, 1) EQ 'S' then begin
	  edval_id = LONARR(4)
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(0:31))
	  edval_id(0) = WIDGET_TEXT(edvalbase, /editable, XSIZE=10, YSIZE=32, $
		VALUE = STRTRIM(STRING(newdarkcurr(0:31,0))), UVALUE='JUNK')
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(32:63))
	  edval_id(1) = WIDGET_TEXT(edvalbase, /editable, XSIZE=10, YSIZE=32, $
		VALUE = STRTRIM(STRING(newdarkcurr(32:63,0))), UVALUE='JUNK')
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(64:95))
	  edval_id(2) = WIDGET_TEXT(edvalbase, /editable, XSIZE=10, YSIZE=32, $
		VALUE = STRTRIM(STRING(newdarkcurr(64:95,0))), UVALUE='JUNK')
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(96:127))
	  edval_id(3) = WIDGET_TEXT(edvalbase, /editable, XSIZE=10, YSIZE=32, $
		VALUE = STRTRIM(STRING(newdarkcurr(96:127,0))), UVALUE='JUNK')
	ENDIF ELSE BEGIN
	 edval = WIDGET_TEXT(edvalbase, XSIZE=8, YSIZE=pixels, $
	  VALUE = pixlist, /SCROLL)
	 edval_id = WIDGET_TEXT(edvalbase, /editable, XSIZE=18, YSIZE=pixels, $
	  VALUE = STRTRIM(STRING(newdarkcurr(*,0)),2), /SCROLL, UVALUE='JUNK')
	ENDELSE

	edconbase = WIDGET_BASE(edbase, /row)
	ok = WIDGET_BUTTON(edconbase, VALUE='  OK  ', UVALUE='LIST')
	quit = WIDGET_BUTTON(edconbase, VALUE=' QUIT ', UVALUE='QUIT') 
	WIDGET_CONTROL, edbase, /REALIZE
	xMANAGER,No_BLOCK=1, "CDARKCUR_EDIT", edbase, GROUP=group 
	RETURN
END 

; *************************************************************
; *
; *************************************************************
PRO CLUDARKCUR_EDIT_event, event 

COMMON pia_caldark_cmn, dets, detact, darkcurr, newdarkcurr, newstruct, $
	pixl_weight, det_id, darkstruct, newnep, ext_version 
COMMON cdark_edit_cmn, edval_id, pixels 
COMMON cal_pdet, calu_pdet, calg_dark, calg_darkcur_p1, calg_darkcur_p2, calg_darkcur_p3, $
                 calg_darkcur_c1, calg_darkcur_c2, calg_darkcur_sssl

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue of
	 'LIST':
	 'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
         ELSE: 
	ENDCASE
END

; *************************************************************
; *
; *************************************************************
PRO CLUDARKCUR_EDIT 

COMMON pia_caldark_cmn, dets, detact, darkcurr, newdarkcurr, newstruct, $
	pixl_weight, det_id, darkstruct, newnep, ext_version 
COMMON cdark_edit_cmn, edval_id, pixels 
COMMON cal_pdet, calu_pdet, calg_dark, calg_darkcur_p1, calg_darkcur_p2, calg_darkcur_p3, $
                 calg_darkcur_c1, calg_darkcur_c2, calg_darkcur_sssl

	edbase = WIDGET_BASE(TITLE =' CALU Uplink Table for p_detect.txt', $
			/column)

	edvalbase = WIDGET_BASE(edbase, /row)
        edvalbas2 = WIDGET_BASE(edvalbase, /column)

        detlist = ['P1', 'P2', 'P3', 'C1', 'C2', 'SS', 'SL']
	detlist = 'Detector ' + detlist 
	xsize = strlen(detlist(0))
        edval = WIDGET_TEXT(edvalbas2, XSIZE=xsize, YSIZE=1, $
          VALUE = 'PHT Detectors')
	edval = WIDGET_TEXT(edvalbas2, XSIZE=xsize, YSIZE=7, $
	  VALUE = detlist)

        pdet_values = ['Idark', 'NEPread', 'darkcurr', 'ETA']
        FOR III=0, 3 DO BEGIN
          edvalbas3 = WIDGET_BASE(edvalbase, /column)
          edval = WIDGET_TEXT(edvalbas3, XSIZE=10, YSIZE=1, $
                VALUE = pdet_values(III))
          edval = WIDGET_TEXT(edvalbas3, XSIZE=10, YSIZE=7, $
            VALUE = STRING(FORMAT='(f10.4)',calu_pdet(III,*)),$
                UVALUE = 'list')
        ENDFOR

        edconbase = WIDGET_BASE(edbase, /row)
        quit = WIDGET_BUTTON(edconbase, /frame, VALUE=' QUIT ', UVALUE='QUIT')

	WIDGET_CONTROL, edbase, /REALIZE
	xMANAGER,No_BLOCK=1, "CLUDARKCUR_EDIT", edbase, GROUP=group 
	RETURN
END 

; *************************************************************
; *
; *************************************************************
PRO CLGDARKCUR_EDIT_event, event 

COMMON pia_caldark_cmn, dets, detact, darkcurr, newdarkcurr, newstruct, $
	pixl_weight, det_id, darkstruct, newnep, ext_version 
COMMON cal_pdet, calu_pdet, calg_dark, calg_darkcur_p1, calg_darkcur_p2, calg_darkcur_p3, $
                 calg_darkcur_c1, calg_darkcur_c2, calg_darkcur_sssl

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.id, GET_VALUE=value
	CASE uvalue of
	'list': PRINT, event.id, value
	'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
	ENDCASE
END

; *************************************************************
; *
; *************************************************************
PRO CLGDARKCUR_EDIT 

COMMON pia_caldark_cmn, dets, detact, darkcurr, newdarkcurr, newstruct, $
	pixl_weight, det_id, darkstruct, newnep, ext_version 
COMMON cal_pdet, calu_pdet, calg_dark, calg_darkcur_p1, calg_darkcur_p2, calg_darkcur_p3, $
                 calg_darkcur_c1, calg_darkcur_c2, calg_darkcur_sssl

	edbase = WIDGET_BASE(TITLE =detact+' CalG Dark Current', $
			/column)
	edvalbase = WIDGET_BASE(edbase, /row)
	pixels = N_ELEMENTS(calg_dark)
	pixlist = STRTRIM(STRING(indgen(pixels) + 1),2)
	pixlist = 'Pixel ' + pixlist 
	if strmid(detact, 0, 2) EQ 'SL' then begin
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(0:31))
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
		VALUE = STRTRIM(STRING(calg_dark(0:31))))
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(32:63))
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
		VALUE = STRTRIM(STRING(calg_dark(32:63))))
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(64:95))
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
		VALUE = STRTRIM(STRING(calg_dark(64:95))))
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(96:127))
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
		VALUE = STRTRIM(STRING(calg_dark(96:127))))
	endif else begin
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=pixels, $
	        VALUE = pixlist)
	  edval = WIDGET_TEXT(edvalbase, XSIZE=18, YSIZE=pixels, $
		VALUE = STRTRIM(STRING(calg_dark)),uvalue='list')
	endelse

        edconbase = WIDGET_BASE(edbase, /row)
        quit = WIDGET_BUTTON(edconbase, /frame, VALUE=' QUIT ', UVALUE='QUIT')

	WIDGET_CONTROL, edbase, /REALIZE
	xMANAGER,No_BLOCK=1, "CLGDARKCUR_EDIT", edbase, GROUP=group 
	RETURN
END 

; *************************************************************
; *
; *************************************************************
PRO PIA_CAL_DARKCUR_EVENT, event

@phtdarkcur
@colour_indices
@phtcap
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
COMMON pia_caldark_cmn, dets, detact, darkcurr, newdarkcurr, newstruct, $
	pixl_weight, det_id, darkstruct, newnep, ext_version 
COMMON cal_pdet, calu_pdet, calg_dark, calg_darkcur_p1, calg_darkcur_p2, calg_darkcur_p3, $
                 calg_darkcur_c1, calg_darkcur_c2, calg_darkcur_sssl


	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	i = WHERE(dets EQ uvalue, n)
	i = i(0)
	IF n NE 0 THEN uvalue = 'DET'

	CASE uvalue of
	   'DET': BEGIN
	   		WIDGET_CONTROL, det_id, SET_VALUE=dets(i)
			detact = dets(i)
			case strmid(detact, 0,2) of
			  'P1': calg_dark = calg_darkcur_p1
			  'P2': calg_dark = calg_darkcur_p2
			  'P3': calg_dark = calg_darkcur_p3
			  'C1': calg_dark = calg_darkcur_c1
			  'C2': calg_dark = calg_darkcur_c2
			  'SL': calg_dark = calg_darkcur_sssl
			endcase

			get_darkcur, detact, darkcurr
			newdarkcurr = darkcurr
			boost_array, newdarkcurr, newdarkcurr * 0.

			IF NOT ext_version THEN BEGIN
 			 get_darkcstr, detact, darkstruct
			 newstruct = darkstruct
			ENDIF
			newnep = 0
		  END	
	   	  
	   'PLOTACT': BEGIN 
			xind = indgen(N_ELEMENTS(darkcurr)) + 1
			PIA_XPLOT, xind, darkcurr, psym=4, $
				title= detact + ' default Dark Current', $
				xtitle = ' Pixel ', $
				ytitle = 'Dark Current      [V/s]', $
				legend = title   

		      END

	   'OPLOTACT': BEGIN 
			xind = indgen(N_ELEMENTS(darkcurr)) + 1

			IF N_ELEMENTS(zoom_color) EQ 0 THEN zoom_color=-1
                	IF zoom_color EQ -1 THEN zoom_color = green ELSE $
                        	zoom_color = zoom_color + 1
                        IF zoom_color EQ 9 then zoom_color = 2

			IF N_ELEMENTS(zoom_psymch) EQ 0 THEN zoom_psymch=-1
                	IF zoom_psymch EQ -1 THEN zoom_psymch = 2 ELSE $
                        	zoom_psymch = zoom_psymch + 1
                        IF zoom_psymch EQ 8 then zoom_psymch = 2


			PIA_XPLOT, xind, darkcurr, psym = zoom_psymch, $
				color = zoom_color, $
				title= detact + ' default Dark Current', $
				xtitle = ' Pixel ', $
				ytitle = 'Dark Current      [V/s]', $
				legend = title, overplot = 99		
		      END

	   'PLOTNEP': BEGIN 
			xind = indgen(N_ELEMENTS(newnep)) + 1
			PIA_XPLOT, xind, newnep, psym=4, $
				title= detact + ' minimum NEP', $
				xtitle = ' Pixel ', $
				ytitle = 'NEP      [W / Hz^0.5]', $
				legend = title   

		      END

	   'OPLOTNEP': BEGIN 
			xind = indgen(N_ELEMENTS(newnep)) + 1

			IF N_ELEMENTS(zoom_color) EQ 0 THEN zoom_color=-1
                	IF zoom_color EQ -1 THEN zoom_color = green ELSE $
                        	zoom_color = zoom_color + 1
                        IF zoom_color EQ 9 then zoom_color = 2

			IF N_ELEMENTS(zoom_psymch) EQ 0 THEN zoom_psymch=-1
                	IF zoom_psymch EQ -1 THEN zoom_psymch = 2 ELSE $
                        	zoom_psymch = zoom_psymch + 1
                        IF zoom_psymch EQ 8 then zoom_psymch = 2


			PIA_XPLOT, xind, newnep, psym = zoom_psymch, $
				color = zoom_color, $
				title= detact + ' minimum NEP', $
				xtitle = ' Pixel ', $
				ytitle = 'NEP      [W / Hz^0.5]', $
				legend = title, overplot = 99		
		      END

	   'PLOTCOM': BEGIN 
			IF N_ELEMENTS(newdarkcurr) NE 0 THEN BEGIN
			 xind = indgen(N_ELEMENTS(newdarkcurr(*,0))) + 1
			 PIA_XPLOT, xind, newdarkcurr(*,0), GROUP=event.top, $
				newdarkcurr(*,1), psym=4, $
				title= detact + ' computed Dark Current', $
				xtitle = ' Pixel ', $
				ytitle = 'Dark Current      [V/s]', $
				legend = title   
                        ENDIF ELSE MESSAGE, /INFO, $
				'Sorry, no new dark current computed'
		      END

	   'OPLOTCOM': BEGIN 
			IF N_ELEMENTS(newdarkcurr) NE 0 THEN BEGIN
			 xind = indgen(N_ELEMENTS(newdarkcurr(*,0))) + 1
			 IF N_ELEMENTS(zoom_color) EQ 0 THEN zoom_color=-1
                	 IF zoom_color EQ -1 THEN zoom_color = green ELSE $
                        	zoom_color = zoom_color + 1
                         IF zoom_color EQ 9 then zoom_color = 2

			 IF N_ELEMENTS(zoom_psymch) EQ 0 THEN zoom_psymch=-1
                	 IF zoom_psymch EQ -1 THEN zoom_psymch = 2 ELSE $
                        	zoom_psymch = zoom_psymch + 1
                         IF zoom_psymch EQ 8 then zoom_psymch = 2

			 PIA_XPLOT, xind, newdarkcurr(*,0), GROUP=event.top, $
				newdarkcurr(*,1), psym = zoom_psymch, $
				color = zoom_color, $
				title= detact + ' computed Dark Current', $
				xtitle = ' Pixel ', $
				ytitle = 'Dark Current      [V/s]', $
				legend = title, overplot = 99		
                        ENDIF ELSE MESSAGE, /INFO, $
				'Sorry, no new dark current computed'
		      END
           'PLOTCALU': begin
                darkchoice = ['Dark current', 'NEPread detector noice', $
                    'darkcurrivity [A/W] of the detector', $
                    'ETA: Quantum efficiency of detector']
                darkchoice = darkchoice
                pia_multchoice, list, elemnames=darkchoice
                pltbuf = transpose(calu_pdet(list, *))
                xind = indgen(7) + 1
                title = 'CalU values from p_detect.txt' 
                xtitle = 'PHT Detectors: (P1, P2, P3, C1, C2, SS, SL)'
                ytitle = darkchoice(list)
                
                pia_xplot, xind, pltbuf, psym=4, $
                     title=title, xtitle=xtitle, $
                     ytitle = ytitle, $
                     annotation = title, legend=ytitle
            END
           'OPLOTCALU': begin
                darkchoice = ['Dark current', 'NEPread detector noice', $
                    'darkcurrivity [A/W] of the detector', $
                    'ETA: Quantum efficiency of detector']
                darkchoice = darkchoice
                pia_multchoice, list, elemnames=darkchoice
                pltbuf = transpose(calu_pdet(list, *))
                xind = indgen(7) + 1
                title = 'CalU values from p_detect.txt : ' 
                xtitle = 'PHT Detectors'
                ytitle = darkchoice(list)
                
                pia_xplot, xind, pltbuf, psym=6, $
                     color=yellow, overplot=99, $
                     title=title, xtitle=xtitle, $
                     ytitle = ytitle, $
                     annotation = title, legend=ytitle
            END
	   'PLOTCALG': BEGIN 
			IF N_ELEMENTS(calg_dark) NE 0 THEN BEGIN
			 xind = indgen(N_ELEMENTS(calg_dark)) + 1
			 PIA_XPLOT, xind, calg_dark, GROUP=event.top, $
				newdarkcurr(*,1), psym=4, $
				title= detact + ' CalG Dark Current', $
				xtitle = ' Pixel ', $
				ytitle = 'Dark Current      [V/s]', $
				legend = title   
                        ENDIF ELSE MESSAGE, /INFO, $
				'Sorry, no new dark current computed'
		      END
         

	   'OPLOTCALG': BEGIN 
			IF N_ELEMENTS(calg_dark) NE 0 THEN BEGIN
			 xind = indgen(N_ELEMENTS(calg_dark)) + 1
			 IF N_ELEMENTS(zoom_color) EQ 0 THEN $
			 	zoom_color = green ELSE $
                        	zoom_color = zoom_color + 1
                         IF zoom_color EQ 9 then zoom_color = 2

			 IF N_ELEMENTS(zoom_psymch) EQ 0 THEN $
			 	zoom_psymch = 2 ELSE $
                        	zoom_psymch = zoom_psymch + 1
                         IF zoom_psymch EQ 8 then zoom_psymch = 2

			 PIA_XPLOT, xind, calg_dark, GROUP=event.top, $
				newdarkcurr(*,1), psym=zoom_psymch, $
				title= detact + ' CalG Dark Current', $
				xtitle = ' Pixel ', $
				ytitle = 'Dark Current      [V/s]', $
				legend = title, color=zoom_color, overplot=99  
                        ENDIF ELSE MESSAGE, /INFO, $
				'Sorry, no new dark current computed'
		      END
         

	   'PROC': $
		PIA_CAL_DARKCUR_PROC, STRMID(detact,0,2), newdarkcurr, $
			newstruct, newnep

	   'PROC_SRD': $
		PIA_CAL_DARKCUR_PROC, STRMID(detact,0,2), newdarkcurr, $
			newstruct, newnep, /FROM_SRD

	   'PROC_SCP': BEGIn
		PIA_CAL_DARKCUR_PROC, STRMID(detact,0,2), newdarkcurr, $
			newstruct, newnep, /FROM_SCP
			END 

	   'PROC_STR': BEGIN
; choose the parameters to be used and calculate newdarkcurr from them
		DARKC_STRUCT_VAL_CHOICE
	   END

           'EDACTVAL': DARKCUR_EDIT

           'EDCOMVAL': CDARKCUR_EDIT

           'EDCLUVAL': CLUDARKCUR_EDIT

           'EDCLGVAL': CLGDARKCUR_EDIT

	   'EDACTSTR': BEGIN
 		DARKCSTR_SHOW, darkstruct, GROUP=event.top  
	   END

	   'EDCOMSTR': BEGIN
		DARKCSTR_SHOW, newstruct, GROUP=event.top  
	   END


	   'WRICOM': BEGIN
		 write_detdarkcur, detact, newdarkcurr(*,0)
		 darkcurr = newdarkcurr(*,0)
		END

	   'WRISTR': BEGIN
		 write_darkcstr, detact, newstruct
		 darkstruct = [darkstruct,newstruct]
		END

	   'WRISTR_REP': BEGIN
		 write_darkcstr, detact, newstruct, /replace
		 darkstruct = newstruct
		END

	   'WRICALG': BEGIN
		 write_detdarkcur, detact, newdarkcurr(*,0), $
			fitsfil='PIA_DARKCUR'
		END

	   'WRICALU': BEGIN

; get the pixel weights
                IF STRMID(detact,0,1) NE 'P' THEN $
			darkc2calu_weight, group=event.top ELSE $
			PIXL_WEIGHT = 1.
		
		IF STRMID(detact,0,1) EQ 'S' THEN detu='SS' ELSE detu=detact  

                pia_write_author, author
                auth = ''
                FOR I=0,N_ELEMENTS(author)-1 DO auth = auth+author(i)

                pia_write_version, version
                vers = ''
                FOR I=0,N_ELEMENTS(version)-1 DO vers = vers+version(i)

		INPUT = !CALSAVE + 'pdetect_pia.txt'
		OUTPUT = !CALSAVE + 'pdetect_pia.txt'
		
; get capacitances from phtcap
		IF N_ELEMENTS(slcap) EQ 0 THEN phtcap_init

		CASE detact of
		  'P1': capac = p1cap
		  'P2': capac = p2cap
		  'P3': capac = p3cap
		  'C100': capac = c1cap
		  'C200': capac = c2cap
		  ELSE: capac = [sscap,slcap]
		ENDCASE

		IF detu EQ 'SS' THEN BEGIN
		 idark = fltarr(2)
		 idark(0) = TOTAL(newdarkcurr(0:63,0) * pixl_weight(0:63)) $
			    / TOTAL(pixl_weight(0:63)) * capac(0) * 1.E+17  
		 idark(1) = TOTAL(newdarkcurr(64:127,0) * pixl_weight(64:127)) $
			    / TOTAL(pixl_weight(64:127)) * capac(1) * 1.E+17 
		ENDIF ELSE $ 
		 idark = TOTAL(newdarkcurr(*,0) * pixl_weight) $
				/ TOTAL(pixl_weight) * capac * 1.E+17 

		strdark = STRTRIM(STRING(idark),2)

                XDISPLAYFILE, "", $
                    		TITLE = "New cal U Value", $
                    		WIDTH = 50, $
                    		HEIGHT = 4, $
                    	  TEXT = [" New cal U value(s):  ", $
                    	  	    strdark + " [1E-17 A] " ]
			
		write_asc_pdetect, detu, idark = idark(0), version=vers, $
			author=auth, inputfile=input, outputfile=output

		IF detu EQ 'SS' THEN BEGIN
			detu = 'SL'
		  write_asc_pdetect, detu, idark = idark(1), version=vers, $
			 author=auth, inputfile=output, outputfile=output
		ENDIF
		
	   END  		

	   'WRINEP': BEGIN

	   IF n_elements(newnep) LT 1 or newnep(0) NE 0 THEN BEGIN
; get the pixel weights
                IF STRMID(detact,0,1) NE 'P' THEN $
			darkc2calu_weight ELSE $
			PIXL_WEIGHT = 1.
		
		IF STRMID(detact,0,1) EQ 'S' THEN detu='SS' ELSE detu=detact  

                pia_write_author, author
                auth = ''
                FOR I=0,N_ELEMENTS(author)-1 DO auth = auth+author(i)

                pia_write_version, version
                vers = ''
                FOR I=0,N_ELEMENTS(version)-1 DO vers = vers+version(i)

		INPUT = !CALSAVE + 'pdetect_pia.txt'
		OUTPUT = !CALSAVE + 'pdetect_pia.txt'
		
		IF detu EQ 'SS' THEN BEGIN
		 inep = fltarr(2)
		 inep(0) = TOTAL(newnep(0:63) * pixl_weight(0:63)) $
			    / TOTAL(pixl_weight(0:63)) * 1.E+17
		 inep(1) = TOTAL(newnep(64:127) * pixl_weight(64:127)) $
			    / TOTAL(pixl_weight(64:127)) * 1.E+17 
		ENDIF ELSE $ 

		 inep = TOTAL(newnep * pixl_weight) $
				/ TOTAL(pixl_weight) * 1.E+17 

		strnep = STRTRIM(STRING(inep),2)

                XDISPLAYFILE, "", $
                    		TITLE = "New cal U NEP Value", $
                    		WIDTH = 50, $
                    		HEIGHT = 4, $
                    	  TEXT = [" New cal U NEP value(s):  ", $
                    	  	    strnep + " [1E-17 W / Hz^0.5] " ]
			
		write_asc_pdetect, detu, nepread = inep(0), version=vers, $
			author=auth, inputfile=input, outputfile=output

		IF detu EQ 'SS' THEN BEGIN
			detu = 'SL'
		  write_asc_pdetect, detu, nepread = inep(1), version=vers, $
			 author=auth, inputfile=output, outputfile=output
		ENDIF
		
	
	   ENDIF  ELSE BEGIN 		

                XDISPLAYFILE, "", $
                    		TITLE = "No NEP Values", $
                    		WIDTH = 50, $
                    		HEIGHT = 4, $
                    	  TEXT = [" Please calculate values and  ", $
                    	  	   " come back if you want       " ]

	   ENDELSE
	   
	   END

           'INIT': BEGIN 
; in future it should be initialized for orbit dependant dark currents !!
;               read_darkorb
		darkcur_init
               get_darkcur, detact, darkcurr
               newdarkcurr = darkcurr
               boost_array, newdarkcurr, newdarkcurr * 0.
           END
	   
	   'QUIT': WIDGET_CONTROL, event.top, /DESTROY
		
	   ELSE: 
	ENDCASE
RETURN
END

; *************************************************************
; *
; *
; *
; *************************************************************
PRO PIA_CAL_DARKCUR, GROUP=group

@phtdarkcur

COMMON pia_caldark_cmn, dets, detact, darkcurr, newdarkcurr, newstruct, $
       pixl_weight, det_id, darkstruct, newnep, ext_version

; the common block below contain the calu values from pdetect.txt where
; the index 0 is the idark, 1 for the nepread, 2, for the respons and
;   3 for the eta
COMMON cal_pdet, calu_pdet, calg_dark, calg_darkcur_p1, calg_darkcur_p2, calg_darkcur_p3, $
                 calg_darkcur_c1, calg_darkcur_c2, calg_darkcur_sssl


 

	newnep = 0
	dets = ['P1','P2', 'P3', 'C100', 'C200', 'SL/SS'] 

; take C100 as initial choice
	detact = dets(4)

; write darkcur into the buffers  -  use initially for new dc the old one 
	get_darkcur, detact, darkcurr
	newdarkcurr = darkcurr
	boost_array, newdarkcurr, newdarkcurr * 0.

; write darkstructure into the local structure  -  use initially for new old 
	export = '(e)'
	posi = STRPOS(!PIA_VERSION,export)

	IF posi EQ -1 THEN ext_version = 0 ELSE ext_version = 1

	IF NOT ext_version  THEN BEGIN 
	   get_darkcstr, detact, darkstruct
	   newstruct = darkstruct
	ENDIF   
	 
; initialize the calu pdetect common block
        calu_pdet = fltarr(4, 7)
        read_asc_pdetect, calu_pdet, inputfile=!CALU+'p_detect.txt'
; initialize the calg common block
	openr, unit, !CALG+'PDARKCURR.FITS', /get_lun
	fxhread, unit, hdr
	calg_darkcur_p1 = fxpar(hdr, 'DARKP1')
	calg_darkcur_p2 = fxpar(hdr, 'DARKP2')
	calg_darkcur_p3 = fxpar(hdr, 'DARKP3')
	calg_darkcur_c1 = fxpar(hdr, 'DARK1C*')
	calg_darkcur_c2 = fxpar(hdr, 'DARK2C*')
	calg_darkcur_sssl = fxpar(hdr, 'DARKS*')
	calg_dark = calg_darkcur_c2
	free_lun, unit
	
	darkbase = WIDGET_BASE(TITLE = 'PIA Dark Current CFDP Menu', $
                                /COLUMN)

        choicebase = WIDGET_BASE(darkbase, /ROW)

	det_id = WIDGET_BUTTON(choicebase, VALUE = detact, /MENU)

	FOR I=0,5 DO id_0 = WIDGET_BUTTON(det_id, VALUE=dets(i),UVALUE=dets(i))
  
        plot_id = WIDGET_BUTTON(choicebase, VALUE = ' Plot ', /MENU)
        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' Actual Values ', /MENU )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' New Plot ', UVALUE='PLOTACT')
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Overplot ', UVALUE='OPLOTACT')
        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' Computed Values ', /MENU)
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' New Plot ', UVALUE='PLOTCOM')
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Overplot ', UVALUE='OPLOTCOM')
        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' NEP Values ', /MENU)
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' New Plot ', UVALUE='PLOTNEP')
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Overplot ', UVALUE='OPLOTNEP')
        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' CALU Values ', /MENU)
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' New Plot ', UVALUE='PLOTCALU')
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Overplot ', UVALUE='OPLOTCALU')
        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' CALG Values ', /MENU)
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' New Plot ',UVALUE='PLOTCALG')
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Overplot ',UVALUE='OPLOTCALG')

	proc_id = WIDGET_BUTTON(choicebase, VALUE= ' Process ', /MENU)
	IF ext_version THEN WIDGET_CONTROL, proc_id, sensitive=0

	id_1 = WIDGET_BUTTON(proc_id, $
		VALUE= 'New values and new Table Records from ERD measurements ', $
				UVALUE='PROC')
	id_1 = WIDGET_BUTTON(proc_id, $
		VALUE= 'New values and new Table Records from SRD measurements ', $
				UVALUE='PROC_SRD')
	id_1 = WIDGET_BUTTON(proc_id, $
		VALUE= 'New values and new Table Records from SCP measurements ', $
				UVALUE='PROC_SCP')
	id_1 = WIDGET_BUTTON(proc_id, $
		VALUE= 'New values from Cumulated Table ', $
				UVALUE='PROC_STR')

	edit_id = WIDGET_BUTTON(choicebase, VALUE= ' Edit Values ', /MENU)
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'Actual Values', $
				UVALUE = 'EDACTVAL')
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'Computed Values', $
				UVALUE = 'EDCOMVAL')
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'CALU Values', $
				UVALUE = 'EDCLUVAL')
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'CALG Values', $
				UVALUE = 'EDCLGVAL')

	edit_id = WIDGET_BUTTON(choicebase, $
		VALUE= 'Results Cumulated Table', /MENU)
	IF ext_version THEN WIDGET_CONTROL, edit_id, sensitive=0

	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'Actual Values', $
				UVALUE = 'EDACTSTR')
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'Computed Values', $
				UVALUE = 'EDCOMSTR')

	write_id = WIDGET_BUTTON(choicebase, VALUE = ' Write Values ', /MENU)
	id_1 = WIDGET_BUTTON(write_id, $
		VALUE = 'New Dark Currents to internal common', $
				UVALUE = 'WRICOM')
	id_1 = WIDGET_BUTTON(write_id, $
		VALUE = 'Add new Table Records to Cumulated Table', $
				UVALUE = 'WRISTR')
	id_1 = WIDGET_BUTTON(write_id, $
		VALUE = 'Replace new Table Records in Cumulated Table', $
				UVALUE = 'WRISTR_REP')
	IF ext_version THEN WIDGET_CONTROL, id_1, sensitive=0
	wricalg_id = WIDGET_BUTTON(write_id, $
		VALUE = 'New Dark Currents to Cal G file', $
				UVALUE = 'WRICALG')
	wricalu_id = WIDGET_BUTTON(write_id, $
		VALUE = 'New Dark Currents to Cal U file', $
				UVALUE = 'WRICALU')

	wricalu_id2 = WIDGET_BUTTON(write_id, $
		VALUE = 'New NEP values to Cal U file', $
				UVALUE = 'WRINEP')

        init_id = WIDGET_BUTTON(choicebase, VALUE = ' Re-initialize ', $
                       UVAL="INIT")

	quit_id = WIDGET_BUTTON(darkbase, VALUE = '  Quit  ', $
                        /FRAME, UVALUE = 'QUIT')

        WIDGET_CONTROL, darkbase, /REALIZE, TLB_SET_XOFFSET=300, $
                        TLB_SET_YOFFSET=50

        xMANAGER,No_BLOCK=1, "pia_cal_darkcur", darkbase, GROUP=group
	
RETURN
END
