;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_CAL_DARKCUR_ORB
;
; PURPOSE:
;	Top level menu for orbital position dependant Dark Currents File 
;
; CATEGORY:
;       PIA - calibration
;
; CALLING SEQUENCE:
;       PIA_CAL_DARKCUR_orb
;
; COMMON BLOCKS:
;	colour_indices
;	phtcap
;	phtdarkorb
;	pia_caldark__orb_cmn (internal)
;	
; PROCEDURES USED:
;	PIA LIB:
;		pia_xplot
;		read_darkorb
;		pia_cal_darkcur_orb_event
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel (ESA/VILSPA-SAI)			Feb.98
;	V7.0		
;-

; *************************************************************
; *
; *************************************************************
PRO PIA_CAL_DARKCUR_ORB_EVENT, event

@phtdarkorb
@colour_indices
@phtcap
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
COMMON pia_caldark_orb_cmn, dets, detact, darkcurr, newdarkcurr, newstruct, $
	pixl_weight, det_id, darkstruct, newnep, ext_version 
COMMON cal_pdet, calu_pdet, calg_dark, calg_darkcur_p1, calg_darkcur_p2, calg_darkcur_p3, $
                 calg_darkcur_c1, calg_darkcur_c2, calg_darkcur_sssl


	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	i = WHERE(dets EQ uvalue, n)
	i = i(0)
	IF n NE 0 THEN uvalue = 'DET'

	CASE uvalue of
	   'DET': BEGIN
	   		WIDGET_CONTROL, det_id, SET_VALUE=dets(i)
			detact = dets(i)
			case strmid(detact, 0,2) of
			  'P1': darkcurr = ppdarkorb(*,0,*)
			  'P2': darkcurr = ppdarkorb(*,1,*)
			  'P3': darkcurr = ppdarkorb(*,2,*)
			  'C1': darkcurr = c1darkorb
			  'C2': darkcurr = c2darkorb
			  'SL': darkcurr = sldarkorb
			endcase

			newdarkcurr = darkcurr
		  END	
	   	  
	   'PLOTACT': BEGIN 
	   		IF N_ELEMENTS(darkcurr(0,*,0)) GT 1 THEN $
	   		   PIA_WRITE_ANYTHING, 'Pixel ?', pix  ELSE pix=1
	   		pix = FIX(pix(0))
	   		
			xind = indgen(100) / 100. + 0.005
			PIA_XPLOT, xind, darkcurr(*,pix-1,0), $
				darkcurr(*,pix-1,1),psym=4, $
				title= detact + ' default Dark Current', $
				xtitle = ' Orbital position ', $
		ytitle = 'Dark Current Pixel '+STRTRIM(pix,2)+ '  [V/s]', $
				legend = title   

		      END

	   'OPLOTACT': BEGIN 
			IF N_ELEMENTS(zoom_color) EQ 0 THEN zoom_color=-1
                	IF zoom_color EQ -1 THEN zoom_color = green ELSE $
                        	zoom_color = zoom_color + 1
                        IF zoom_color EQ 9 then zoom_color = 2

			IF N_ELEMENTS(zoom_psymch) EQ 0 THEN zoom_psymch=-1
                	IF zoom_psymch EQ -1 THEN zoom_psymch = 2 ELSE $
                        	zoom_psymch = zoom_psymch + 1
                        IF zoom_psymch EQ 8 then zoom_psymch = 2


	   		IF N_ELEMENTS(darkcurr(0,*,0)) GT 1 THEN $
	   		   PIA_WRITE_ANYTHING, 'Pixel ?', pix  ELSE pix=1
	   		pix = fix(pix(0))
	   		
			xind = indgen(100) / 100. + 0.005
			PIA_XPLOT, xind, darkcurr(*,pix-1,0), color=zoom_color,$
				darkcurr(*,pix-1,1),psym=zoom_psymch, $
				title= detact + ' default Dark Current', $
				xtitle = ' Orbital position ', $
		ytitle = 'Dark Current Pixel '+STRTRIM(pix,2)+ '  [V/s]', $
				legend = title, overplot = 99		
		      END

           'INIT': BEGIN 
; in future it should be initialized for orbit dependant dark currents !!
               read_darkorb
	       
			case strmid(detact, 0,2) of
			  'P1': darkcurr = ppdarkorb(*,0,*)
			  'P2': darkcurr = ppdarkorb(*,1,*)
			  'P3': darkcurr = ppdarkorb(*,2,*)
			  'C1': darkcurr = c1darkorb
			  'C2': darkcurr = c2darkorb
			  'SL': darkcurr = sldarkorb
			endcase

			newdarkcurr = darkcurr

           END
	   
	   'EDVAL': BEGIN
	   
	 	text = ['Orbital position dependent dark currents', '',$
	 		'Detector ' + detact, ' ']
	 	IF detact EQ 'SL/SS' THEN BEGIN
	 	   PIA_WRITE_ANYTHING, 'Pixel ?', pix
	 	   pix = fix(pix-1)
	 	   npix = 1
	 	ENDIF ELSE BEGIN
	 	   npix = N_ELEMENTS(darkcurr(0,*,0))
	 	   pix = indgen(npix)
	 	ENDELSE
	 	
		orbpos = STRTRIM(indgen(100)+1,2)
	 	FOR i=0,npix-1 DO BEGIN
	 	   text = [text, 'Pixel ' + STRTRIM(pix(i)+1,2) + ':', '']
	 	   txtorb = 'Orb. position '+ orbpos + ':  ' + $
	 	   	STRTRIM(darkcurr(*,pix(i),0),2) + ' +/- ' + $
			STRTRIM(darkcurr(*,pix(i),1),2)
	 	   text = [text, txtorb, ' ']
	 	ENDFOR
	 	PIA_disp_print_file, '', TITLE='Orb.dependent dark currents',$
	 		TEXT=text
	 	
            END
	 	
	 	  	
	   'QUIT': WIDGET_CONTROL, event.top, /DESTROY
		
	   ELSE: 
	ENDCASE
RETURN
END

; *************************************************************
; *
; *
; *
; *************************************************************
PRO PIA_CAL_DARKCUR_ORB, GROUP=group

@phtdarkorb

COMMON pia_caldark_orb_cmn, dets, detact, darkcurr, newdarkcurr, newstruct, $
       pixl_weight, det_id, darkstruct, newnep, ext_version

; the common block below contain the calu values from pdetect.txt where
; the index 0 is the idark, 1 for the nepread, 2, for the respons and
;   3 for the eta
COMMON cal_pdet, calu_pdet, calg_dark, calg_darkcur_p1, calg_darkcur_p2, calg_darkcur_p3, $
                 calg_darkcur_c1, calg_darkcur_c2, calg_darkcur_sssl


	 

	newnep = 0
	dets = ['P1','P2', 'P3', 'C100', 'C200', 'SL/SS'] 

; take C100 as initial choice
	detact = dets(4)

; write darkcur into the buffers  -  use initially for new dc the old one 
	IF N_ELEMENTS(c1darkorb) EQ 0 THEN read_darkorb
	darkcurr = c2darkorb
	newdarkcurr = darkcurr

	dark_orb_base = WIDGET_BASE(TITLE = 'PIA orbital position Dark Currents', $
                                /COLUMN)

        choicebase = WIDGET_BASE(dark_orb_base, /ROW)

	det_id = WIDGET_BUTTON(choicebase, VALUE = detact, /MENU)

	FOR I=0,5 DO id_0 = WIDGET_BUTTON(det_id, VALUE=dets(i),UVALUE=dets(i))
  
        plot_id = WIDGET_BUTTON(choicebase, VALUE = ' Plot ', /MENU)
        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' Actual Values ', /MENU )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' New Plot ', UVALUE='PLOTACT')
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Overplot ', UVALUE='OPLOTACT')


	edit_id = WIDGET_BUTTON(choicebase, VALUE= ' Edit Values ', $
			UVALUE='EDVAL')


        init_id = WIDGET_BUTTON(choicebase, VALUE = ' Re-initialize ', $
                       UVAL="INIT")

	quit_id = WIDGET_BUTTON(dark_orb_base, VALUE = '  Quit  ', $
                        /FRAME, UVALUE = 'QUIT')

        WIDGET_CONTROL, dark_orb_base, /REALIZE, TLB_SET_XOFFSET=300, $
                        TLB_SET_YOFFSET=50

        Xmanager,No_BLOCK=1, "pia_cal_darkcur_orb", dark_orb_base, GROUP=group
	
RETURN
END
