;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_CAL_DEFRESP_ORB
;
; PURPOSE:
;	Top level menu for orbital position dependant Default Responses files 
;
; CATEGORY:
;       PIA - calibration
;
; CALLING SEQUENCE:
;       PIA_CAL_DEFRESP_orb
;
; COMMON BLOCKS:
;	colour_indices
;	phtcap
;	phtresporb
;	pia_caldresp__orb_cmn (internal)
;	
; PROCEDURES USED:
;	PIA LIB:
;		pia_xplot
;		read_resporb
;		pia_cal_defresp_orb_event
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel (ESA/VILSPA-SAI)			Feb.98
;	V7.0		
;-

; *************************************************************
; *
; *************************************************************
PRO PIA_CAL_DEFRESP_ORB_EVENT, event

@phtresporb
@colour_indices
COMMON pia_caldresp_orb_cmn, dets, detact, dresporb
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
COMMON pia_caldresp_orb_cmn, dets, detact, dresporb


	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	i = WHERE(dets EQ uvalue, n)
	i = i(0)
	IF n NE 0 THEN uvalue = 'DET'

	CASE uvalue of
	   'DET': BEGIN
		idpar = WIDGET_INFO(event.id, /parent)
                WIDGET_CONTROL, idpar, SET_VALUE=dets(i)
                detact = dets(i)

		IF STRMID(detact,0,1) EQ 'P' THEN orig_name='PPRESP' ELSE BEGIN
	         detsh = STRMID(detact,0,2)
        	 orig_name = 'P'+detsh+'RESP'
        	ENDELSE
        	get_caltdep_file, orig_name, tdep_name
		READ_RESPORB, filename=tdep_name+'.FITS'

       		detact = dets(i)
			case strmid(detact, 0,2) of
			  'P1': dresporb = ppresporb(*,0,*)
			  'P2': dresporb = ppresporb(*,1,*)
			  'P3': dresporb = ppresporb(*,2,*)
			  'C1': dresporb = c1resporb
			  'C2': dresporb = c2resporb
			endcase
		  END	
	   	  
	   'PLOTACT': BEGIN 
	   		IF N_ELEMENTS(dresporb(0,*,0)) GT 1 THEN $
	   		   PIA_WRITE_ANYTHING, 'Pixel ?', pix  ELSE pix=1
	   		pix = FIX(pix(0))
	   		
			xind = indgen(100) / 100. + 0.005
			PIA_XPLOT, xind, dresporb(*,pix-1,0), $
				dresporb(*,pix-1,1),psym=4, $
				title= detact + ' default Response', $
				xtitle = ' Orbital position ', $
			ytitle = 'Default Response Pixel '+STRTRIM(pix,2)+' [A/W]', $
				legend = title   

		      END

	   'OPLOTACT': BEGIN 
			IF N_ELEMENTS(zoom_color) EQ 0 THEN zoom_color=-1
                	IF zoom_color EQ -1 THEN zoom_color = green ELSE $
                        	zoom_color = zoom_color + 1
                        IF zoom_color EQ 9 then zoom_color = 2

			IF N_ELEMENTS(zoom_psymch) EQ 0 THEN zoom_psymch=-1
                	IF zoom_psymch EQ -1 THEN zoom_psymch = 2 ELSE $
                        	zoom_psymch = zoom_psymch + 1
                        IF zoom_psymch EQ 8 then zoom_psymch = 2


	   		IF N_ELEMENTS(dresporb(0,*,0)) GT 1 THEN $
	   		   PIA_WRITE_ANYTHING, 'Pixel ?', pix  ELSE pix=1
	   		pix=fix(pix(0))
	   		
			xind = indgen(100) / 100. + 0.005
			PIA_XPLOT, xind, dresporb(*,pix-1,0), color=zoom_color,$
				dresporb(*,pix-1,1),psym=zoom_psymch, $
				title= detact + ' default Response', $
				xtitle = ' Orbital position ', $
			ytitle = 'Default Response Pixel '+STRTRIM(pix,2)+' [A/W]', $
				legend = title, overplot = 99		
		      END

           'INIT': BEGIN 
		IF STRMID(detact,0,1) EQ 'P' THEN orig_name='PPRESP' ELSE BEGIN
	          detsh = STRMID(detact,0,2)
        	  orig_name = 'P'+detsh+'RESP'
        	ENDELSE
        	get_caltdep_file, orig_name, tdep_name
		READ_RESPORB, filename=tdep_name+'.FITS'
	       
			case strmid(detact, 0,2) of
			  'P1': dresporb = ppresporb(*,0,*)
			  'P2': dresporb = ppresporb(*,1,*)
			  'P3': dresporb = ppresporb(*,2,*)
			  'C1': dresporb = c1resporb
			  'C2': dresporb = c2resporb
			  'SL': dresporb = slresporb
			endcase

           END
	   
	   'EDVAL': BEGIN
	   
	 	text = ['Orbital position dependent default responses', '',$
	 		'Detector ' + detact, ' ']
	 	IF detact EQ 'SL/SS' THEN BEGIN
	 	   PIA_WRITE_ANYTHING, 'Pixel ?', pix
	 	   pix = fix(pix-1)
	 	   npix = 1
	 	ENDIF ELSE BEGIN
	 	   npix = N_ELEMENTS(dresporb(0,*,0))
	 	   pix = indgen(npix)
	 	ENDELSE
	 	
		orbpos = STRTRIM(indgen(100)+1,2)
	 	FOR i=0,npix-1 DO BEGIN
	 	   text = [text, 'Pixel ' + STRTRIM(pix(i)+1,2) + ':', '']
	 	   txtorb = 'Orb. position '+ orbpos + ':  ' + $
	 	   	STRTRIM(dresporb(*,pix(i),0),2) + ' +/- ' + $
			STRTRIM(dresporb(*,pix(i),1),2)
	 	   text = [text, txtorb, ' ']
	 	ENDFOR
	 	PIA_disp_print_file, '', TITLE='Orb.dependent default responses',$
	 		TEXT=text
	 	
            END
	 	
	 	  	
	   'QUIT': WIDGET_CONTROL, event.top, /DESTROY
		
	   ELSE: 
	ENDCASE
RETURN
END

; *************************************************************
; *
; *
; *
; *************************************************************
PRO PIA_CAL_DEFRESP_ORB, GROUP=group

@phtresporb

COMMON pia_caldresp_orb_cmn, dets, detact, dresporb

	dets = ['P1','P2', 'P3', 'C100', 'C200'] 

; take C200 as initial choice
	detact = dets(4)

; write defresp into the buffers  - 
	        detsh = STRMID(detact,0,2)
        	orig_name = 'P'+detsh+'RESP'
        	get_caltdep_file, orig_name, tdep_name
		READ_RESPORB, filename=tdep_name+'.FITS'
	  
	dresporb = c2resporb

	resp_orb_base = $
	 WIDGET_BASE(TITLE = 'PIA orbital position Default Responses ', $
                                /COLUMN)

        choicebase = WIDGET_BASE(resp_orb_base, /ROW)

	det_id = WIDGET_BUTTON(choicebase, VALUE = detact, /MENU)

	FOR I=0,4 DO id_0 = WIDGET_BUTTON(det_id, VALUE=dets(i),UVALUE=dets(i))
  
        plot_id = WIDGET_BUTTON(choicebase, VALUE = ' Plot ', /MENU)
        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' Actual Values ', /MENU )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' New Plot ', UVALUE='PLOTACT')
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Overplot ', UVALUE='OPLOTACT')


	edit_id = WIDGET_BUTTON(choicebase, VALUE= ' Edit Values ', $
			UVALUE='EDVAL')


        init_id = WIDGET_BUTTON(choicebase, VALUE = ' Re-initialize ', $
                       UVAL="INIT")

	quit_id = WIDGET_BUTTON(resp_orb_base, VALUE = '  Quit  ', $
                        /FRAME, UVALUE = 'QUIT')

        WIDGET_CONTROL, resp_orb_base, /REALIZE, TLB_SET_XOFFSET=300, $
                        TLB_SET_YOFFSET=50

        Xmanager,No_BLOCK=1, "pia_cal_defresp_orb", resp_orb_base, GROUP=group
	
RETURN
END
