;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_CAL_DIETRAN
;
; PURPOSE:
;	Top level menu for DIE1 and DIE2 (Digital Interface Electronics) 
;	Files production, one of the Calibration Files Derivation 
;	Procedures (CFDP)  
;
; CATEGORY:
;          PIA - graphics
;
; CALLING SEQUENCE:
;       PIA_CAL_DIETRAN
;
; KEYWORD PARAMETERS:
;	GROUP=group: group leader
;
; COMMON BLOCKS:
;	phtdietrans
;	pia_dietran_cmn (internal)
;
; PROCEDURES USED:
;	PIA LIB:
;		pia_write_comment
;		pia_write_version
;		write_dietrans
;       INTERNAL:
;		dietran_edit_event
;		dietarn_edit
;		cdietarn_edit_event
;		cdietran_edit
;		pia_cal_dietran_event
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel (ESA/ESTEC) 		March 1995
;	Modified (last) by: CG				September 1995
;	Oct 95 Version 3.5
;	Re-initialize button added (CG)			November 1997
;	V6.6
;	/Modal use according to IDL >=5.0 (CG)		February 1999
;	V7.3.1
;
;-
;
; ***********************************************************
; *
; ***********************************************************
PRO DIETRAN_EDIT_event, event 

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.id, GET_VALUE=value
	CASE uvalue of
	'list': PRINT, event.id, value
	'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
	ENDCASE
END

; ***********************************************************
; *
; ***********************************************************
PRO DIETRAN_EDIT 
@phtdietrans

	edbase = WIDGET_BASE(TITLE ='Actual DieTrans Values', $
			/column)

	edvallab = WIDGET_LABEL(edbase, VALUE='        Selected Gain DIE1' )
                       
	edvalbas0 = WIDGET_BASE(edbase, /row)
      	edval = WIDGET_TEXT(edvalbas0, XSIZE=12, YSIZE=1, $
	  VALUE = 'GAIN')
	edval = WIDGET_TEXT(edvalbas0, XSIZE=45, YSIZE=1, $
		VALUE = STRING(FORMAT='(I11,2(4x,I11))',[1,8,40]), uvalue='list')

	edvalbase = WIDGET_BASE(edbase, /row)
      	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=1, $
	  VALUE = 'D0')
	edval = WIDGET_TEXT(edvalbase, XSIZE=45, YSIZE=1, $
		VALUE = STRING(FORMAT='(3E15.4)',pdiefix(*,0)), uvalue='list')

	edvalbase = WIDGET_BASE(edbase, /row)
      	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=1, $
	  VALUE = 'U_off [V]')
	edval = WIDGET_TEXT(edvalbase, XSIZE=45, YSIZE=1, $
		VALUE = STRING(FORMAT='(3E15.4)',pdieuof(*,0)), uvalue='list')

	edvalbase = WIDGET_BASE(edbase, /row)
      	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=1, $
	  VALUE = 'GAIN1')
	edval = WIDGET_TEXT(edvalbase, XSIZE=45, YSIZE=1, $
		VALUE = STRING(FORMAT='(3E15.4)',pdiegn1(*,0)), uvalue='list')

	edvalbase = WIDGET_BASE(edbase, /row)
      	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=1, $
	  VALUE = 'GAIN2')
	edval = WIDGET_TEXT(edvalbase, XSIZE=45, YSIZE=1, $
		VALUE = STRING(FORMAT='(3E15.4)',pdiegn2(*,0)), uvalue='list')

	edvallab = WIDGET_LABEL(edbase, VALUE='       ')
	edvallab = WIDGET_LABEL(edbase, VALUE='       ')

	edvallab = WIDGET_LABEL(edbase, VALUE='        Selected Gain DIE2')
                       
	edvalbas0 = WIDGET_BASE(edbase, /row)
      	edval = WIDGET_TEXT(edvalbas0, XSIZE=12, YSIZE=1, $
	  VALUE = 'GAIN')
	edval = WIDGET_TEXT(edvalbas0, XSIZE=45, YSIZE=1, $
		VALUE = STRING(FORMAT='(I11,2(4x,I11))',[1,8,40]), uvalue='list')

	edvalbase = WIDGET_BASE(edbase, /row)
      	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=1, $
	  VALUE = 'D0')
	edval = WIDGET_TEXT(edvalbase, XSIZE=45, YSIZE=1, $
		VALUE = STRING(FORMAT='(3E15.4)',pdiefix(*,1)), uvalue='list')

	edvalbase = WIDGET_BASE(edbase, /row)
      	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=1, $
	  VALUE = 'U_off [V]')
	edval = WIDGET_TEXT(edvalbase, XSIZE=45, YSIZE=1, $
		VALUE = STRING(FORMAT='(3E15.4)',pdieuof(*,1)), uvalue='list')

	edvalbase = WIDGET_BASE(edbase, /row)
      	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=1, $
	  VALUE = 'GAIN1')
	edval = WIDGET_TEXT(edvalbase, XSIZE=45, YSIZE=1, $
		VALUE = STRING(FORMAT='(3E15.4)',pdiegn1(*,1)), uvalue='list')

	edvalbase = WIDGET_BASE(edbase, /row)
      	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=1, $
	  VALUE = 'GAIN2')
	edval = WIDGET_TEXT(edvalbase, XSIZE=45, YSIZE=1, $
		VALUE = STRING(FORMAT='(3E15.4)',pdiegn2(*,1)), uvalue='list')

	quit = WIDGET_BUTTON(edbase, VALUE=' QUIT ', UVALUE='QUIT') 
	WIDGET_CONTROL, edbase, /REALIZE
	xMANAGER,No_BLOCK=1, "DIETRAN_EDIT", edbase, GROUP=group 
	RETURN
END 

; ***********************************************************
; *
; ***********************************************************
PRO CDIETRAN_EDIT_event, event 
COMMON pia_dietran_cmn, newpdiefix, newpdieuof, newpdiegn1, newpdiegn2, $
		id_list, wricalg_id


	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue of
	 'LIST': BEGIN
	   FOR i=0,2 DO BEGIN

		WIDGET_CONTROL, id_list(i), GET_VALUE=value
		newpdiefix(i,0) = float(value) 

		WIDGET_CONTROL, id_list(i+3), GET_VALUE=value
		newpdieuof(i,0) = float(value) 

		WIDGET_CONTROL, id_list(i+6), GET_VALUE=value
		newpdiegn1(i,0) = float(value) 

		WIDGET_CONTROL, id_list(i+9), GET_VALUE=value
		newpdiegn2(i,0) = float(value) 

		WIDGET_CONTROL, id_list(i+12), GET_VALUE=value
		newpdiefix(i,1) = float(value) 

		WIDGET_CONTROL, id_list(i+15), GET_VALUE=value
		newpdieuof(i,1) = float(value) 

		WIDGET_CONTROL, id_list(i+18), GET_VALUE=value
		newpdiegn1(i,1) = float(value) 

		WIDGET_CONTROL, id_list(i+21), GET_VALUE=value
		newpdiegn2(i,1) = float(value) 
	    ENDFOR
	 END
	 'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
         ELSE: 
	ENDCASE
END

; ***********************************************************
; *
; ***********************************************************
PRO CDIETRAN_EDIT, group=group 

COMMON pia_dietran_cmn, newpdiefix, newpdieuof, newpdiegn1, newpdiegn2, $
		id_list, wricalg_id

	IF not KEYWORD_SET(group) THEN group = !PIA_TOP_WID
	edbase = WIDGET_BASE(TITLE ='Computed DieTrans Values', $
			/column, GROUP=group, /MODAL)


	edvallab = WIDGET_LABEL(edbase, VALUE='        Selected Gain DIE1' )
                       
	edvalbas0 = WIDGET_BASE(edbase, /row)
      	edval = WIDGET_TEXT(edvalbas0, XSIZE=12, YSIZE=1, $
	  VALUE = 'GAIN')
	edval = WIDGET_TEXT(edvalbas0, XSIZE=15, YSIZE=1, $
		VALUE = STRING(FORMAT='(I11)',1), uvalue='list')
	edval = WIDGET_TEXT(edvalbas0, XSIZE=15, YSIZE=1, $
		VALUE = STRING(FORMAT='(I11)',8), uvalue='list')
	edval = WIDGET_TEXT(edvalbas0, XSIZE=15, YSIZE=1, $
		VALUE = STRING(FORMAT='(I11)',40), uvalue='list')

	edvalbase = WIDGET_BASE(edbase, /row)
      	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=1, $
	  VALUE = 'D0')
	id_list(0) = WIDGET_TEXT(edvalbase, /EDITABLE, XSIZE=15, YSIZE=1, $
		VALUE = STRING(newpdiefix(0,0)), uvalue='junk')
	id_list(1) = WIDGET_TEXT(edvalbase, /EDITABLE, XSIZE=15, YSIZE=1, $
		VALUE = STRING(newpdiefix(1,0)), uvalue='junk')
	id_list(2) = WIDGET_TEXT(edvalbase, /EDITABLE, XSIZE=15, YSIZE=1, $
		VALUE = STRING(newpdiefix(2,0)), uvalue='junk')

	edvalbase = WIDGET_BASE(edbase, /row)
      	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=1, $
	  VALUE = 'U_off [V]')
	id_list(3) = WIDGET_TEXT(edvalbase, /editable, XSIZE=15, YSIZE=1, $
		VALUE = STRING(newpdieuof(0,0)), uvalue='junk')
	id_list(4) = WIDGET_TEXT(edvalbase, /editable, XSIZE=15, YSIZE=1, $
		VALUE = STRING(newpdieuof(1,0)), uvalue='junk')
	id_list(5) = WIDGET_TEXT(edvalbase, /editable, XSIZE=15, YSIZE=1, $
		VALUE = STRING(newpdieuof(2,0)), uvalue='junk')

	edvalbase = WIDGET_BASE(edbase, /row)
      	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=1, $
	  VALUE = 'GAIN1')
	id_list(6) = WIDGET_TEXT(edvalbase, /editable, XSIZE=15,  YSIZE=1, $
		VALUE = STRING(newpdiegn1(0,0)), uvalue='junk')
	id_list(7) = WIDGET_TEXT(edvalbase, /editable, XSIZE=15,  YSIZE=1, $
		VALUE = STRING(newpdiegn1(1,0)), uvalue='junk')
	id_list(8) = WIDGET_TEXT(edvalbase, /editable, XSIZE=15,  YSIZE=1, $
		VALUE = STRING(newpdiegn1(2,0)), uvalue='junk')

	edvalbase = WIDGET_BASE(edbase, /row)
      	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=1, $
	  VALUE = 'GAIN2')
	id_list(9) = WIDGET_TEXT(edvalbase, /editable, XSIZE=15, YSIZE=1, $
		VALUE = STRING(newpdiegn2(0,0)), uvalue='junk')
	id_list(10) = WIDGET_TEXT(edvalbase, /editable, XSIZE=15, YSIZE=1, $
		VALUE = STRING(newpdiegn2(1,0)), uvalue='junk')
	id_list(11) = WIDGET_TEXT(edvalbase, /editable, XSIZE=15, YSIZE=1, $
		VALUE = STRING(newpdiegn2(2,0)), uvalue='junk')

	edvallab = WIDGET_LABEL(edbase, VALUE='       ')
	edvallab = WIDGET_LABEL(edbase, VALUE='       ')

	edvallab = WIDGET_LABEL(edbase, VALUE='        Selected Gain DIE2')
                       
	edvalbas0 = WIDGET_BASE(edbase, /row)
      	edval = WIDGET_TEXT(edvalbas0, XSIZE=12, YSIZE=1, $
	  VALUE = 'GAIN')
	edval = WIDGET_TEXT(edvalbas0, XSIZE=15, YSIZE=1, $
		VALUE = STRING(FORMAT='(I11)',1), uvalue='list')
	edval = WIDGET_TEXT(edvalbas0, XSIZE=15, YSIZE=1, $
		VALUE = STRING(FORMAT='(I11)',8), uvalue='list')
	edval = WIDGET_TEXT(edvalbas0, XSIZE=15, YSIZE=1, $
		VALUE = STRING(FORMAT='(I11)',40), uvalue='list')

	edvalbase = WIDGET_BASE(edbase, /row)
      	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=1, $
	  VALUE = 'D0')
	id_list(12) = WIDGET_TEXT(edvalbase, /editable, XSIZE=15, YSIZE=1, $
		VALUE = STRING(newpdiefix(0,1)), uvalue='junk')
	id_list(13) = WIDGET_TEXT(edvalbase, /editable, XSIZE=15, YSIZE=1, $
		VALUE = STRING(newpdiefix(1,1)), uvalue='junk')
	id_list(14) = WIDGET_TEXT(edvalbase, /editable, XSIZE=15, YSIZE=1, $
		VALUE = STRING(newpdiefix(2,1)), uvalue='junk')

	edvalbase = WIDGET_BASE(edbase, /row)
      	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=1, $
	  VALUE = 'U_off [V]')
	id_list(15) = WIDGET_TEXT(edvalbase, /editable, XSIZE=15, YSIZE=1, $
		VALUE = STRING(newpdieuof(0,1)), uvalue='junk')
	id_list(16) = WIDGET_TEXT(edvalbase, /editable, XSIZE=15, YSIZE=1, $
		VALUE = STRING(newpdieuof(1,1)), uvalue='junk')
	id_list(17) = WIDGET_TEXT(edvalbase, /editable, XSIZE=15, YSIZE=1, $
		VALUE = STRING(newpdieuof(2,1)), uvalue='junk')

	edvalbase = WIDGET_BASE(edbase, /row)
      	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=1, $
	  VALUE = 'GAIN1')
	id_list(18) = WIDGET_TEXT(edvalbase, /editable, XSIZE=15, YSIZE=1, $
		VALUE = STRING(newpdiegn1(0,1)), uvalue='junk')
	id_list(19) = WIDGET_TEXT(edvalbase, /editable, XSIZE=15, YSIZE=1, $
		VALUE = STRING(newpdiegn1(1,1)), uvalue='junk')
	id_list(20) = WIDGET_TEXT(edvalbase, /editable, XSIZE=15, YSIZE=1, $
		VALUE = STRING(newpdiegn1(2,1)), uvalue='junk')

	edvalbase = WIDGET_BASE(edbase, /row)
      	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=1, $
	  VALUE = 'GAIN2')
	id_list(21) = WIDGET_TEXT(edvalbase, /editable, XSIZE=15, YSIZE=1, $
		VALUE = STRING(newpdiegn2(0,1)), uvalue='junk')
	id_list(22) = WIDGET_TEXT(edvalbase, /editable, XSIZE=15, YSIZE=1, $
		VALUE = STRING(newpdiegn2(1,1)), uvalue='junk')
	id_list(23) = WIDGET_TEXT(edvalbase, /editable, XSIZE=15, YSIZE=1, $
		VALUE = STRING(newpdiegn2(2,1)), uvalue='junk')

	edconbase = WIDGET_BASE(edbase, /row)
	ok = WIDGET_BUTTON(edconbase, VALUE='  OK  ', UVALUE='LIST')
	quit = WIDGET_BUTTON(edconbase, VALUE=' QUIT ', UVALUE='QUIT') 

	WIDGET_CONTROL, edbase, /REALIZE
	xMANAGER,No_BLOCK=1, "CDIETRAN_EDIT", edbase, GROUP=group 
	RETURN
END 


; ***********************************************************
; *
; ***********************************************************
PRO PIA_CAL_DIETRAN_EVENT, event
@phtdietrans
COMMON pia_dietran_cmn, newpdiefix, newpdieuof, newpdiegn1, newpdiegn2, $
		id_list, wricalg_id


	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue of

	   'EDACTVAL': DIETRAN_EDIT

	   'EDCOMVAL': CDIETRAN_EDIT, GROUP=event.top

	   'WRICOM': BEGIN
	    	 pdiefix = newpdiefix	 
	    	 pdieuof = newpdieuof	 
	    	 pdiegn1 = newpdiegn1	 
	    	 pdiegn2 = newpdiegn2	 
		 WIDGET_CONTROL, wricalg_id, /sensitive
		END

	   'WRICALG': BEGIN
		 pia_write_comment, comment
		 comm = ''
		 FOR I=0,N_ELEMENTS(comment)-1 DO comm = comm+comment(i)
		 pia_write_version, version
		 vers = ''
		 FOR I=0,N_ELEMENTS(version)-1 DO vers = vers+version(i)
		 write_dietrans, 'PIA_DIE1TRANS', 1, pdiefix(*,0),$
			pdieuof(*,0), pdiegn1(*,0), pdiegn2(*,0),$
			comment=comm, version=vers 
		 write_dietrans, 'PIA_DIE2TRANS', 2, pdiefix(*,1),$
			pdieuof(*,1), pdiegn1(*,1), pdiegn2(*,1),$
			comment=comm, version=vers 
		END

	   'QUIT': WIDGET_CONTROL, event.top, /DESTROY
		
	   'INIT': BEGIN
	   	die_trans_init
		newpdiefix = pdiefix
		newpdieuof = pdieuof
		newpdiegn1 = pdiegn1
		newpdiegn2 = pdiegn2
	   END
	   
	   ELSE: 
	ENDCASE
RETURN
END

; ***********************************************************
; *
; *
; *
; ***********************************************************
PRO PIA_CAL_DIETRAN, GROUP=group

@phtdietrans
COMMON pia_dietran_cmn, newpdiefix, newpdieuof, newpdiegn1, newpdiegn2, $
		id_list, wricalg_id

	newpdiefix = pdiefix
	newpdieuof = pdieuof
	newpdiegn1 = pdiegn1
	newpdiegn2 = pdiegn2
	id_list = lonarr(24)

	pdiebase = WIDGET_BASE(TITLE = 'PIA DieTrans CFDP Menu', $
                                /COLUMN)

        choicebase = WIDGET_BASE(pdiebase, /ROW)

;	proc_id = WIDGET_BUTTON(choicebase, VALUE= ' Process ', UVALUE='PROC')

	edit_id = WIDGET_BUTTON(choicebase, VALUE= ' Edit Values ', /MENU)
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'Actual Values', $
				UVALUE = 'EDACTVAL')
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'Computed Values', $
				UVALUE = 'EDCOMVAL')

	write_id = WIDGET_BUTTON(choicebase, VALUE = ' Write Values ', /MENU)
	id_1 = WIDGET_BUTTON(write_id, VALUE = 'to internal common', $
				UVALUE = 'WRICOM')
	wricalg_id = WIDGET_BUTTON(write_id, VALUE = 'to Cal G file', $
				UVALUE = 'WRICALG')
	WIDGET_CONTROL, wricalg_id, SENSITIVE=0	

	quit_id = WIDGET_BUTTON(pdiebase, VALUE = '  Quit  ', $
                        /FRAME, UVALUE = 'QUIT')

	init_id = WIDGET_BUTTON(choicebase, VALUE = ' Re-initialize ', $
			UVAL="INIT")

        WIDGET_CONTROL, pdiebase, /REALIZE, TLB_SET_XOFFSET=300, $
                        TLB_SET_YOFFSET=50

        xMANAGER,No_BLOCK=1, "pia_cal_dietran", pdiebase, GROUP=group

RETURN
END
