;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_CAL_FCSILL
;
; PURPOSE:
;	Top level menu for FCS illumination File production, one of
;	the Calibration Files Derivation Procedures (CFDP)  
;
; CATEGORY:
;       PIA - graphics
;
; CALLING SEQUENCE:
;       PIA_CAL_FCSILL
;
; KEYWORD PARAMETERS:
;	Group=group: Group leader
;
; COMMON BLOCKS:
;	colour_indices
;	phtillum
;	pia_verselectedf_cmn (internal)
; 	pia_fcsil_cmn (internal)
;	cfcsill_edit_cmn (internal)
;	cal_fcsill_cmn (internal)
;		
; PROCEDURES USED:
;	PIA LIB:
;		pia_write_comment
;		pia_write_version
;		pia_xplot
;		read_fcsill
;		write_illum
;       ASTRO LIB:
;		fxbclose
;		fxbopen
;		fxbread
;       INTERNAL:
;		fcsill_struct_val_choice
;		fcsill_edit_event
;		fcsill_edit
;		cfcsill_edit_event
;		cfcsill_edit
;		clg_fcsill_edit_event
;		clg_fcsill_edit
;		pia_cal_fcsill_event
;		
; MODIFICATION HISTORY:
;       Written by: C. Gabriel (ES/ESTEC) 			March 1995
;	Modified (last) by: CG, WMT				Sep 1995
;	Oct 95 Version 3.5
;	Changed for new FCSPOW cumulated structures (CG)	February 1996
;	Writing Cal G fixed for C200 pipeline pixel order &
;	Bug for non-existence of cal_struct fixed (CG)		May 1997
;	V6.3
;
;-
; ****************************************************************
; *
; ****************************************************************
PRO FCSILL_STRUCT_VAL_CHOICE

COMMON pia_varselected_cmn, vars
COMMON pia_fcsil_cmn, dets, detact, fcsill, newfcsill, fcsunc, newfcsunc, $
	wricalg_id, det_id, fcs, fcsact, strfcsp, filters, filtact, $
	full_fcsill, full_fcsunc, filt_id


	data_names = ['Flag ', 'Date ', 'Source', 'Filter', 'In-Band-Flux',$
			'Heating Power', 'Pixel #']
        data_exa = [STRING(strfcsp(0).flag), strfcsp(0).date, $
	  strfcsp(0).source, STRING(strfcsp(0).filt_id), $
	  STRING(strfcsp(0).f_star), STRING(strfcsp(0).heatpow), '1' ]
	  
; get variables limits
        pia_select_var, data_exa, VARNAMES=data_names, $
		VARTYP=[0,0,1,1,0,0,1], GROUP=group
	
	indnot = WHERE(vars(0,*) EQ '',nnot)

	nelem = N_ELEMENTS(strfcsp)
	indall = indgen(nelem)

; Flag
        IF vars(0,0) NE '' AND vars(1,0) NE '' THEN BEGIN
	     flaglim = FIX(vars(*,0)) 
	     indfl = WHERE(strfcsp.flag GE flaglim(0) AND $
			   strfcsp.flag LE flaglim(1), nflag)
	     IF nflag EQ 0 THEN BEGIN

                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" No flags corresponding to selection  "]
                        RETURN
	     ENDIF
        ENDIF ELSE indfl = indall 

; date
        IF vars(0,1) NE '' AND vars(1,1) NE '' THEN BEGIN
	     
	     datelim = [date_conv(vars(0,1)), date_conv(vars(1,1))]
	     alldates = dblarr(nelem)
	     FOR I=0, nelem-1 DO alldates(i) = date_conv(strfcsp(i).date)
	     
             inddate = $
		WHERE(alldates GE datelim(0) AND alldates LE datelim(1),ndate)

	     IF ndate EQ 0 THEN BEGIN
                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" No dates corresponding to selection  "]
                        RETURN
	     ENDIF
	ENDIF ELSE inddate = indall 

; source
        IF vars(0,2) NE '' THEN BEGIN
	     srclim = vars(0,2) 
	     indsrc = WHERE(STRTRIM(strfcsp.source,2) EQ $ 
			    STRTRIM(srclim,2), nsrc)
	     IF nsrc EQ 0 THEN BEGIN

                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" No source corresponding to selection"]
                        RETURN
	     ENDIF
        ENDIF ELSE indsrc = indall 

; filter
        IF vars(0,3) NE '' THEN BEGIN
	     filtlim = vars(0,3) 
	     indfilt = WHERE(strfcsp.filt_id EQ filtlim, nfilt)
	     IF nfilt EQ 0 THEN BEGIN

                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" No filter corresponding to selection"]
                        RETURN
	     ENDIF
        ENDIF ELSE indfilt = indall

; In band flux
        IF vars(0,4) NE '' AND vars(1,4) NE '' THEN BEGIN
	     ibflim = FLOAT(vars(*,4)) 
	     indibf = WHERE(strfcsp.f_star GE ibflim(0) AND $
			   strfcsp.f_star LE ibflim(1), nibfl)
	     IF nibfl EQ 0 THEN BEGIN

                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                    TEXT = [" No In-Band-fluxes corresponding to selection  "]
                        RETURN
	     ENDIF
        ENDIF ELSE indibf = indall 

; Heating power
        IF vars(0,5) NE '' AND vars(1,5) NE '' THEN BEGIN
	     hpwlim = FLOAT(vars(*,5)) 
	     indhpw = WHERE(strfcsp.heatpow GE hpwlim(0) AND $
			   strfcsp.heatpow LE hpwlim(1), nhpw)
	     IF nhpw EQ 0 THEN BEGIN

                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                    TEXT = [" No Heating Powers corresponding to selection  "]
                        RETURN
	     ENDIF
        ENDIF ELSE indhpw = indall 

; reference pixel
        IF vars(0,6) NE '' THEN $
	     ref_pixl = FIX(vars(0,6)-1) ELSE BEGIN
			IF detact EQ 'C1' THEN ref_pixl = 0 ELSE ref_pixl = 2
			Message, /INFO, $
			 'Default reference pixel taken following no choice' 
        ENDELSE
; Not choosable variables - Values coming from common

; FCS
        indfcs = WHERE(strfcsp.fcs-1 EQ fcsact, nfcs)
        IF nfcs EQ 0 THEN BEGIN
                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" No FCS corresponding to selection"]
                        RETURN
        ENDIF

; Search combinations of accepted variables

	match, indall, indfl, suba, subb, count=count
	indall = indall(suba)

	match, indall, inddate, suba, subb, count=count
	IF count EQ 0 THEN GOTO, nocomb
	indall = indall(suba)

	match, indall, indsrc, suba, subb, count=count
	IF count EQ 0 THEN GOTO, nocomb
	indall = indall(suba)

	match, indall, indfilt, suba, subb, count=count
	IF count EQ 0 THEN GOTO, nocomb
	indall = indall(suba)

	match, indall, indibf, suba, subb, count=count
	IF count EQ 0 THEN GOTO, nocomb
	indall = indall(suba)

	match, indall, indhpw, suba, subb, count=count
	IF count EQ 0 THEN GOTO, nocomb
	indall = indall(suba)

	match, indall, indfcs, suba, subb, count=count
	IF count EQ 0 THEN GOTO, nocomb
	indall = indall(suba)

	indok = WHERE(strfcsp(indall).sflg(ref_pixl) LT 2, n)

	IF n GT 0 THEN BEGIN

		n_pixl = N_ELEMENTS(strfcsp(0).fcspow)
		n_entries = N_ELEMENTS(strfcsp)
; normalize to chosen pixel	   
		
		fcsill_all = fltarr(n_entries,n_pixl)
		fcsill_unc = fcsill_all
		FOR I=0, n_entries-1 DO BEGIN 	
	   		fcsill_all(i,*) = strfcsp(i).fcspow(*) / $
	   		 	strfcsp(i).fcspow(ref_pixl)
			fcsill_unc(i,*) = strfcsp(i).fcspun(*) / $
	   		 	strfcsp(i).fcspow(ref_pixl)
	   	ENDFOR


		FOR I=0,n_pixl - 1 DO BEGIN
			indpok = WHERE(strfcsp(indall(indok)).sflg(i) LT 2,npok)
			IF npok GT 0 THEN BEGIN
			   weight_mean, fcsill_all(indall(indok(indpok)),i), $
				fcsill_unc(indall(indok(indpok)),i), mean, stdev
			   newfcsill(i) = mean
			   newfcsunc(i) = stdev
			ENDIF ELSE BEGIN
			   text = 'No elements OK for pixel ' + $
			   		STRTRIM(STRING(I+1),2) 
			   MESSAGE, /INFO, text
			   newfcsill(i) = 0.
			   newfcsunc(i) = 0.
			ENDELSE 
		ENDFOR		

	nacc = N_ELEMENTS(indall)
	Text =  ["The new FCS illumination matrix have been calculated ", $
		"using a total of "+ STRTRIM(STRING(nacc),2) + " observations"]
        XDISPLAYFILE, "", $
                TITLE = "New FCS illumination matrix Calculation", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [text]      

	

	ENDIF ELSE BEGIN   

		  MESSAGE, /INFO, 'Data has only bad flags'
	ENDELSE


	RETURN
NOCOMB: 
        XDISPLAYFILE, "", $
            TITLE = "Input not accepted", $
            WIDTH = 50, $
            HEIGHT = 4, $
            TEXT = [" Combined selection discards all elements "]
        RETURN



END 

; ****************************************************************
; *
; ****************************************************************
PRO FCSILL_EDIT_event, event 

COMMON pia_fcsil_cmn, dets, detact, fcsill, newfcsill, fcsunc, newfcsunc, $
	wricalg_id, det_id, fcs, fcsact, strfcsp, filters, filtact, $
	full_fcsill, full_fcsunc, filt_id

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.id, GET_VALUE=value
	CASE uvalue of
	'list': PRINT, event.id, value
	'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
	ENDCASE
END

; ****************************************************************
; *
; ****************************************************************
PRO FCSILL_EDIT 

COMMON pia_fcsil_cmn, dets, detact, fcsill, newfcsill, fcsunc, newfcsunc, $
	wricalg_id, det_id, fcs, fcsact, strfcsp, filters, filtact, $
	full_fcsill, full_fcsunc, filt_id
	
	edbase = WIDGET_BASE(TITLE =detact+' Actual FCS '+$
		STRTRIM(STRING(fcsact+1),2)+' illumination tables', /column)

	edvalbase = WIDGET_BASE(edbase, /row)
	edlabel = WIDGET_LABEL(edvalbase, VALUE = '   Pixel   ')
	edlabel = WIDGET_LABEL(edvalbase, VALUE = '  Factor   ')
	edlabel = WIDGET_LABEL(edvalbase, VALUE = '   Uncertainty')

	pixels = N_ELEMENTS(fcsill(*,0))
	pixlist = STRTRIM(STRING(indgen(pixels) + 1),2)
	pixlist = 'Pixel ' + pixlist 

	edvalbase = WIDGET_BASE(edbase, /row)
	edval = WIDGET_TEXT(edvalbase, XSIZE=8, YSIZE=10, $
	  VALUE = pixlist)
	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=10, $
		VALUE = STRTRIM(STRING(fcsill(*,fcsact))), uvalue='list')
	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=10, $
		VALUE = STRTRIM(STRING(fcsunc(*,fcsact))), uvalue='list')

	quit = WIDGET_BUTTON(edbase, VALUE=' QUIT ', UVALUE='QUIT') 
	WIDGET_CONTROL, edbase, /REALIZE
	xMANAGER,No_BLOCK=1, "FCSILL_EDIT", edbase, GROUP=group 
	RETURN
END 

; ****************************************************************
; *
; ****************************************************************
PRO CFCSILL_EDIT_event, event 

COMMON pia_fcsil_cmn, dets, detact, fcsill, newfcsill, fcsunc, newfcsunc, $
	wricalg_id, det_id, fcs, fcsact, strfcsp, filters, filtact, $
	full_fcsill, full_fcsunc, filt_id

COMMON cfcsill_edit_cmn, edval_id, edunc_id, pixels 

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue of
	 'LIST': BEGIN
		WIDGET_CONTROL, edval_id, GET_VALUE=value
		IF N_ELEMENTS(value) EQ pixels THEN $
			newfcsill(*,fcsact) = float(value) ELSE BEGIN
                  	XDISPLAYFILE, "", $
                    		TITLE = "Input not accepted", $
                    		WIDTH = 50, $
                    		HEIGHT = 4, $
                    	  TEXT = [" Wrong fcsill input  ", $]
                          	  "     ", $ ]
                          	  " Fix it and try again, please "]
			RETURN
		ENDELSE
		WIDGET_CONTROL, edunc_id, GET_VALUE=value
		IF N_ELEMENTS(value) EQ pixels THEN $
			newfcsunc(*,fcsact) = float(value) ELSE BEGIN
                  	XDISPLAYFILE, "", $
                    		TITLE = "Input not accepted", $
                    		WIDTH = 50, $
                    		HEIGHT = 4, $
                    	  TEXT = [" Wrong fcsill input  ", $]
                          	  "     ", $ ]
                          	  " Fix it and try again, please "]
			RETURN
		ENDELSE
	 END
	 'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
         ELSE: 
	ENDCASE
END

; ****************************************************************
; *
; ****************************************************************
PRO CFCSILL_EDIT 

COMMON pia_fcsil_cmn, dets, detact, fcsill, newfcsill, fcsunc, newfcsunc, $
	wricalg_id, det_id, fcs, fcsact, strfcsp, filters, filtact, $
	full_fcsill, full_fcsunc, filt_id

COMMON cfcsill_edit_cmn, edval_id, edunc_id, pixels 
COMMON cal_fcsill_cmn, calg_fcsill, calg_fcsunc, calg_c1cor, calg_c1lun, $
	calg_c2cor, calg_c2lun

	edbase = WIDGET_BASE(TITLE =detact+' Computed FCS '+$
		STRTRIM(STRING(fcsact+1),2)+' illumination tables', /column)

	edvalbase = WIDGET_BASE(edbase, /row)
	edlabel = WIDGET_LABEL(edvalbase, VALUE = '   Pixel   ')
	edlabel = WIDGET_LABEL(edvalbase, VALUE = '  Factor   ')
	edlabel = WIDGET_LABEL(edvalbase, VALUE = '   Uncertainty')

	pixels = N_ELEMENTS(newfcsill(*,fcsact))
	pixlist = STRTRIM(STRING(indgen(pixels) + 1),2)
	pixlist = 'Pixel ' + pixlist 

	edvalbase = WIDGET_BASE(edbase, /row)
	edval = WIDGET_TEXT(edvalbase, XSIZE=8, YSIZE=10, $
	  VALUE = pixlist)
	edval_id = WIDGET_TEXT(edvalbase, /editable, XSIZE=12, YSIZE=10, $
	  VALUE = STRTRIM(STRING(newfcsill(*,fcsact)),2), UVALUE='JUNK')
	edunc_id = WIDGET_TEXT(edvalbase, /editable, XSIZE=12, YSIZE=10, $
	  VALUE = STRTRIM(STRING(newfcsunc(*,fcsact)),2), UVALUE='JUNK')
	edconbase = WIDGET_BASE(edbase, /row)

	ok = WIDGET_BUTTON(edconbase, VALUE='  OK  ', UVALUE='LIST')
	quit = WIDGET_BUTTON(edconbase, VALUE=' QUIT ', UVALUE='QUIT') 
	WIDGET_CONTROL, edbase, /REALIZE
	xMANAGER,No_BLOCK=1, "CFCSILL_EDIT", edbase, GROUP=group 
	RETURN
END 

; ****************************************************************
; *
; ****************************************************************
PRO CLG_FCSILL_EDIT_event, event 

COMMON pia_fcsil_cmn, dets, detact, fcsill, newfcsill, fcsunc, newfcsunc, $
	wricalg_id, det_id, fcs, fcsact, strfcsp, filters, filtact, $
	full_fcsill, full_fcsunc, filt_id
COMMON cal_fcsill_cmn, calg_fcsill, calg_fcsunc, calg_c1cor, calg_c1lun, $
	calg_c2cor, calg_c2lun

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.id, GET_VALUE=value
	CASE uvalue of
	'list': 
	'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
	ENDCASE
END

; ****************************************************************
; *
; ****************************************************************
PRO CLG_FCSILL_EDIT 

COMMON pia_fcsil_cmn, dets, detact, fcsill, newfcsill, fcsunc, newfcsunc, $
	wricalg_id, det_id, fcs, fcsact, strfcsp, filters, filtact, $
	full_fcsill, full_fcsunc, filt_id
COMMON cal_fcsill_cmn, calg_fcsill, calg_fcsunc, calg_c1cor, calg_c1lun, $
	calg_c2cor, calg_c2lun

	edbase = WIDGET_BASE(TITLE =detact+' CALG FCS '+$
		STRTRIM(STRING(fcsact+1),2)+' illumination tables', /column)

	edvalbase = WIDGET_BASE(edbase, /row)
	edlabel = WIDGET_LABEL(edvalbase, VALUE = '   Pixel   ')
	edlabel = WIDGET_LABEL(edvalbase, VALUE = ' Factor ')
	edlabel = WIDGET_LABEL(edvalbase, VALUE = 'Uncertainty')

	pixels = N_ELEMENTS(calg_fcsill(*,0))
	pixlist = STRTRIM(STRING(indgen(pixels) + 1),2)
	pixlist = 'Pixel ' + pixlist 

	edvalbase = WIDGET_BASE(edbase, /row)
	edval = WIDGET_TEXT(edvalbase, XSIZE=8, YSIZE=10, $
	  VALUE = pixlist)
	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=10, $
		VALUE = STRTRIM(STRING(calg_fcsill(*,fcsact))), uvalue='list')
	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=10, $
		VALUE = STRTRIM(STRING(calg_fcsunc(*,fcsact))), uvalue='list')

        edconbase = WIDGET_BASE(edbase, /row)
        quit = WIDGET_BUTTON(edconbase, /frame, VALUE=' QUIT ', UVALUE='QUIT')

	WIDGET_CONTROL, edbase, /REALIZE
	xMANAGER,No_BLOCK=1, "CLG_FCSILL_EDIT", edbase, GROUP=group
	RETURN
END 

; ****************************************************************
; *
; ****************************************************************
PRO PIA_CAL_FCSILL_EVENT, event

@phtfilter
@phtillum
@colour_indices
COMMON pia_fcsil_cmn, dets, detact, fcsill, newfcsill, fcsunc, newfcsunc, $
	wricalg_id, det_id, fcs, fcsact, strfcsp, filters, filtact, $
	full_fcsill, full_fcsunc, filt_id
COMMON cal_fcsill_cmn, calg_fcsill, calg_fcsunc, calg_c1cor, calg_c1lun, $
	calg_c2cor, calg_c2lun
COMMON ext_version, ext_version


	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	i = WHERE(dets EQ uvalue, n)
	i = i(0)
	IF n NE 0 THEN uvalue = 'DET' ELSE BEGIN
	 i = WHERE(fcs EQ uvalue, n)
	 i = i(0)
	 IF n NE 0 THEN uvalue = 'FCS'
	ENDELSE

	CASE uvalue of
	   'NEWCALG': BEGIN
		detsh = STRMID(detact,0,2)
	   	orig_name = "P"+detsh+"ILLUM"
		get_caltdep_file, orig_name, tdep_name
	
		read_fcsill, tdep_name+".FITS"
	
		IF detsh EQ 'C1' THEN BEGIN
		 full_fcsill = c1ilcor
		 full_fcsunc = c1illun
		ENDIF ELSE BEGIN
		 full_fcsill = c2ilcor
		 full_fcsunc = c2illun
		ENDELSE
		 
		fcsill = reform(full_fcsill(*,filtact,*))
		newfcsill = fcsill
		fcsunc = reform(full_fcsunc(*,filtact,*))
		newfcsunc = fcsunc
	    END

	   'DET': BEGIN
	   		WIDGET_CONTROL, det_id, SET_VALUE=dets(i)
			detact = dets(i)
; Write FCS power tables into the local cumulated table 

			IF not ext_version THEN get_fcspstr, detact, strfcsp
			
			CASE STRMID(detact,0,2) OF
				'C1': BEGIN
					filtact = 1
					full_fcsill=c1ilcor
					full_fcsunc=c1illun
					fcsill = reform(c1ilcor(*,filtact,*))
					fcsunc = reform(c1illun(*,filtact,*))
		 		  	filters = c1filters
					WIDGET_CONTROL, filt_id, $
					  SET_VALUE=filters(filtact)
;				  	calg_fcspow = calg_fcspow_c1
;					calg_fcsill = calg_c1cor
;					calg_fcsunc = calg_c1lun
				END
				'C2': BEGIN
					orig_name = "PC2ILLUM"
					get_caltdep_file, orig_name, tdep_name
					read_fcsill, tdep_name+".FITS"

					filtact = 1
					full_fcsill=c2ilcor
					full_fcsunc=c2illun
					fcsill = reform(c2ilcor(*,filtact,*))
					fcsunc = reform(c2illun(*,filtact,*))
		 		  	filters = c2filters
					filtact = 1
					WIDGET_CONTROL, filt_id, $
					  SET_VALUE=filters(filtact)
;				  	calg_fcspow = calg_fcspow_c2
;					calg_fcsill = calg_c2cor
;					calg_fcsunc = calg_c2lun
				END
                        ENDCASE
			newfcsill = fcsill
			newfcsunc = fcsunc
		  END	

	   'FCS': BEGIN
			fcs_id = WIDGET_INFO(event.id, /parent)
	   		WIDGET_CONTROL, fcs_id, SET_VALUE=fcs(i)
			fcsact = i
		  END	
	   	  
	   'FILTER': BEGIN
	   		pia_multchoice, filtact, ELEMNAMES=filters
	   		filtact = filtact(0)
	   		WIDGET_CONTROL, event.id, SET_VALUE=filters(filtact)
			fcsill = reform(full_fcsill(*,filtact,*))
			fcsunc = reform(full_fcsunc(*,filtact,*))
			newfcsill = fcsill
			newfcsunc = fcsunc
	   END
	   		
	  	   
	   
	   'PLOTACT': BEGIN 
			xind = indgen(N_ELEMENTS(fcsill(*,0))) + 1
			gtitle = filters(filtact) 
			PIA_XPLOT, xind, fcsill(*,fcsact), fcsunc(*,fcsact),$
			 psym=4, $
			 title= gtitle + ' default FCS illum factors', $
				xtitle = ' Pixel ', $
				ytitle = 'FCS illumination factor', $
				legend = gtitle   
		      END

	   'OPLOTACT': BEGIN 
			xind = indgen(N_ELEMENTS(fcsill(*,0))) + 1
			gtitle = filters(filtact) 
			PIA_XPLOT, xind, fcsill(*,fcsact), fcsunc(*,fcsact), $
				psym = 6, color = yellow, $
			 title= gtitle + ' default FCS illum factors', $
				xtitle = ' Pixel ', $
				ytitle = 'FCS illumination factor', $
				legend = gtitle, overplot = 99		
		      END

	   'PLOTCOM': BEGIN 
			gtitle = filters(filtact) 
			IF N_ELEMENTS(newfcsill) NE 0 THEN BEGIN
			 xind = indgen(N_ELEMENTS(newfcsill(*,fcsact))) + 1
			 PIA_XPLOT, xind, newfcsill(*,fcsact), $
				newfcsunc(*,fcsact), psym=4, $
			   title=gtitle + ' computed FCS illum factors', $
				xtitle = ' Pixel ', $
				ytitle = 'FCS illumination factor', $
				legend = gtitle   
                        ENDIF ELSE MESSAGE, /INFO, $
				'Sorry, no new FCS illums computed'
		      END

	   'OPLOTCOM': BEGIN 
			gtitle = filters(filtact) 
			IF N_ELEMENTS(newfcsill) NE 0 THEN BEGIN
			 xind = indgen(N_ELEMENTS(newfcsill(*,0))) + 1
			 PIA_XPLOT, xind, newfcsill(*,fcsact), $
				newfcsunc(*,fcsact), psym = 6, color = yellow, $
			  title=gtitle+ ' computed FCS illum factors', $
				xtitle = ' Pixel ', $
				ytitle = 'FCS illumination factor', $
				legend = gtitle, overplot = 99		
                        ENDIF ELSE MESSAGE, /INFO, $
				'Sorry, no new fcsilles computed'
		      END

	   'PLOTCLG': BEGIN 
			xind = indgen(N_ELEMENTS(calg_fcsill(*,0))) + 1
			PIA_XPLOT, xind, calg_fcsill(*,fcsact), $
			 calg_fcsunc(*,fcsact), psym=4, $
			 title= detact + ' CALG FCS illumination factors', $
				xtitle = ' Pixel ', $
				ytitle = 'FCS illumination factor', $
				legend = title   
		      END

	   'OPLOTCLG': BEGIN 
			xind = indgen(N_ELEMENTS(calg_fcsill(*,0))) + 1
			PIA_XPLOT, xind, calg_fcsill(*,fcsact), $
				calg_fcsunc(*,calg_fcsunc), $
				psym = 6, color = yellow, $
			 title= detact + ' CALG FCS illumination factors', $
				xtitle = ' Pixel ', $
				ytitle = 'FCS illumination factor', $
				legend = title, overplot = 99		
		      END

	   'PROC_TABLE': FCSILL_STRUCT_VAL_CHOICE
	   
	   'EDACTVAL': FCSILL_EDIT

	   'EDCOMVAL': CFCSILL_EDIT

	   'EDCLGVAL': CLG_FCSILL_EDIT

	   'WRICOM': BEGIN
			CASE STRMID(detact,0,2) OF
				'C1': BEGIN
					c1ilcor(*,filtact,*) = newfcsill
					c1illun (*,filtact,*)= newfcsunc
					full_fcsill = c1ilcor
					full_fcsunc = c1illun
				END
				'C2': BEGIN
					c2ilcor(*,filtact,*) = newfcsill
					c2illun(*,filtact,*) = newfcsunc
					full_fcsill = c2ilcor
					full_fcsunc = c2illun
				END
                        ENDCASE
                 fcsill = newfcsill
		 fcsunc = newfcsunc
		
		 WIDGET_CONTROL, wricalg_id, /sensitive
		END

	   'WRICALG': BEGIN
		 pia_write_comment, comment
		 comm = ''
		 FOR I=0,N_ELEMENTS(comment)-1 DO comm = comm+comment(i)

		 IF STRMID(detact,0,2) EQ 'C1' THEN filename = 'PC1ILLUM' $
		 		ELSE filename = 'PC2ILLUM'
		 fullarr = full_fcsill
		 boost_array, fullarr, full_fcsunc

		 IF STRMID(detact,0,2) EQ 'C2' THEN BEGIN
		   c2p_ia2pipe, fullarr, fullarr_w
		 ENDIF ELSE fullarr_w = fullarr
		 
		 create_pfits, filename, fullarr_w, username="PIA", $
		    comment=comm, version=!PIA_VERSION 
		 		 
		 WIDGET_CONTROL, wricalg_id, sensitive=0
		END

	   'QUIT': WIDGET_CONTROL, event.top, /DESTROY
		
	   ELSE: 
	ENDCASE
RETURN
END

; ****************************************************************
; *
; *
; *
; ****************************************************************
PRO PIA_CAL_FCSILL, GROUP=group
                                                                           
@phtillum
@phtfilter
COMMON pia_fcsil_cmn, dets, detact, fcsill, newfcsill, fcsunc, newfcsunc, $
	wricalg_id, det_id, fcs, fcsact, strfcsp, filters, filtact, $
	full_fcsill, full_fcsunc, filt_id
COMMON cal_fcsill_cmn, calg_fcsill, calg_fcsunc, calg_c1cor, calg_c1lun, $
	calg_c2cor, calg_c2lun
COMMON ext_version, ext_version

	dets = ['C100', 'C200'] 
	fcs = ['FCS1', 'FCS2'] 

	detact = dets(0)
	fcsact = 0


	IF N_ELEMENTS(c1filters) EQ 0 THEN PHTFILTER_INIT
	filters = c1filters
	filtact = 1

; Write FCS power tables into the local cumulated table 
	export = '(e)'
	posi = STRPOS(!PIA_VERSION,export)

	IF posi EQ -1 THEN BEGIN
 	  filename = !CALSAVE+ 'C1' + 'CALFCSP_STR.SAV'
	  res = findfile(filename, count=count) 	 
	 IF count NE 0 THEN BEGIN
	  ext_version = 0
	  get_fcspstr, detact, strfcsp
	 ENDIF ELSE BEGIN
	  XDISPLAYFILE, "", $
              TITLE = "File not found", $
              WIDTH = 80, $
              HEIGHT = 4, $
              TEXT = ["File " + filename + " not found " , $ 
		      "... will continue without processing possibility"]
	  
	  ext_version = 1  
	 ENDELSE  
	ENDIF ELSE ext_version = 1

	orig_name = "PC1ILLUM"
	get_caltdep_file, orig_name, tdep_name
	
	read_fcsill, tdep_name+".FITS"
	
	full_fcsill = c1ilcor
	full_fcsunc = c1illun
	fcsill = reform(c1ilcor(*,filtact,*))
	newfcsill = fcsill
	fcsunc = reform(c1illun(*,filtact,*))
	newfcsunc = fcsunc

; initialize the calg common block
;	fxbopen, unit, !CALG+'PC1ILLUM.FITS', 1
;	fxbread, unit, calg_c1cor, 'PC1ILCOR'
;	fxbread, unit, calg_c1lun, 'PC1ILLUN'
;	fxbclose, unit
;	fxbopen, unit, !CALG+'PC2ILLUM.FITS', 1
;	fxbread, unit, calg_c2cor, 'PC2ILCOR'
;	fxbread, unit, calg_c2lun, 'PC2ILLUN'
;	fxbclose, unit
;	calg_fcsill = calg_c1cor
;	calg_fcsunc = calg_c1lun


	illubase = WIDGET_BASE(TITLE ='PIA FCS illumination Matrix CFDP Menu', $
                                /COLUMN)

        choicebase = WIDGET_BASE(illubase, /ROW)

	det_id = WIDGET_BUTTON(choicebase, VALUE = detact, /MENU)

	FOR I=0,1 DO id_0 = WIDGET_BUTTON(det_id, VALUE=dets(i),UVALUE=dets(i))

	fcs_id = WIDGET_BUTTON(choicebase, VALUE = fcs(fcsact), /MENU)

	FOR I=0,1 DO id_0 = WIDGET_BUTTON(fcs_id, VALUE=fcs(i),UVALUE=fcs(i))
  
	filt_id = WIDGET_BUTTON(choicebase, VALUE = filters(filtact), $
				UVALUE="FILTER")

        plot_id = WIDGET_BUTTON(choicebase, VALUE = ' Plot ', /MENU)
        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' Actual Values ', /MENU )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Plot  ', $
        		UVALUE='PLOTACT')
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Overplot ', $
        		UVALUE='OPLOTACT')
        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' Computed Values ', /MENU)
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Plot ', $
        	UVALUE='PLOTCOM')
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Overplot ', $
        	UVALUE='OPLOTCOM')
;        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' CALG Values ', /MENU)
;        id_2 = WIDGET_BUTTON(id_1, VALUE = ' New Plot ', UVALUE='PLOTCLG')
;        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Overplot ', UVALUE='OPLOTCLG')

	proc_id = WIDGET_BUTTON(choicebase, VALUE= ' Process ', /MENU)
	id_1 = WIDGET_BUTTON(proc_id, $
			VALUE= 'New Values from FCS Cumulated Table', $
			UVALUE = 'PROC_TABLE')
	IF ext_version THEN WIDGET_CONTROL, proc_id, SENSITIVE=0

	edit_id = WIDGET_BUTTON(choicebase, VALUE= ' Edit Values ', /MENU)
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'Actual Values', $
				UVALUE = 'EDACTVAL')
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'Computed Values', $
				UVALUE = 'EDCOMVAL')
;	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'CALG Values', $
;				UVALUE = 'EDCLGVAL')

	newc_id = WIDGET_BUTTON(choicebase, VALUE= ' New Cal G ', $
			UVALUE="NEWCALG")

	write_id = WIDGET_BUTTON(choicebase, VALUE = ' Write Values ', /MENU)
	id_1 = WIDGET_BUTTON(write_id, VALUE = 'to internal common', $
				UVALUE = 'WRICOM')
	wricalg_id = WIDGET_BUTTON(write_id, VALUE = 'to Cal G file', $
				UVALUE = 'WRICALG')
	WIDGET_CONTROL, wricalg_id, SENSITIVE=0	

	quit_id = WIDGET_BUTTON(illubase, VALUE = '  Quit  ', $
                        /FRAME, UVALUE = 'QUIT')

        WIDGET_CONTROL, illubase, /REALIZE, TLB_SET_XOFFSET=300, $
                        TLB_SET_YOFFSET=50

        xMANAGER,No_BLOCK=1, "pia_cal_fcsill", illubase, GROUP=group
	
RETURN
END
