;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_CAL_FCSPOW
;
; PURPOSE:
;	Top level menu for PHT FCS power Files production, one of
;	the Calibration Files Derivation Procedures (CFDP)  
;
; CATEGORY:
;       PIA - calibration menues
;
; CALLING SEQUENCE:
;       PIA_CAL_FCSPOW
;
; KEYWORD PARAMETERS:
;	GROUP=group: Group leader
;
; COMMON BLOCKS:
;		colour_indices
;		phtfcs
;		phtfilter
;		phtoptpow
;		pia_varselected_cmn (internal)
;		pia_fcsp_cmn (internal)
;		cfcs_edit_cmn (internal)
;		calu_fcspow (internal)
;		calg_fcs (internal)
;		
; PROCEDURES USED:
;	PIA Lib:
;		get_fcspstr
;		phtfilter_init
;		pia_disp_print_file
;		pia_multchoice
;		pia_select_var
;		pia_showstr
;		pia_write_author
;		pia_write_comment
;		pia_write_version
;		pia_xplot
;		pia_xsurface
;		read_asc_fcspow
;		read_fcspow
;		write_asc_fcspow
;		write_fcspow
;		write_fcspstr
;	Astro Lib:
;		avg
;		bsort
;		date_conv
;		fxread
;		match
;		sigma
;       INTERNAL:
;		fcsp_struct_val_coice
;		fcspstr_show
;		fcspow_edit_event
;		fcspow_edit
;		cfcspow_edit_event
;		cfcspow_edit
;		clufcspow_edit_event
;		clufcspow_edir
;		pia_cal_fcspow_event
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel (ESA/ESTEC) 		March 1995
;	Modified (last) by: Jose Acosta (IAC)		June 1996
;	Version 5.0 	August 1996
;	Handling from export version possible (CG)	April 1997
;	V6.2
;	Bug for non-existence of cal_struct fixed (CG)	May 1997
;	V6.3 
;	/Modal use according to IDL >=5.0 (CG)		February 1999
;	V7.3.1
;-

; *****************************************************************
; ***************  choice menu for structure elements
; *****************************************************************
PRO FCSP_STRUCT_VAL_CHOICE, rescale_int=rescale_int, rescale_ext=rescale_ext, $
		fit=fit, ndeg=ndeg, noproc=noproc

@colour_indices
@phtfilter
@phtoptpow
COMMON pia_varselected_cmn, vars
COMMON pia_fcsp_cmn, dets, detact, filts, filtact, fcsa, trsa, $
		fcspow, newfcspow, wricalg_id, det_id, strfcsp,$
                newstrfcsp, filters,calg_fcspow, strfcspre, newstrfcspre 
COMMON pia_cal_fcspow_proc_res, heatpow, optpow, optpun, cal_fcspow_str,$
		 cal_fcspre_str, proc_status

	data_names = ['Flag ', 'Date ', 'Source', 'Filter', 'Aperture',$
			'In-Band-Flux', 'Heating Power','Proc Time','Pixel #']

	IF STRLEN(strfcsp(0).proc_time) EQ 24 THEN $
		conv_procdate, strfcsp(0).proc_time, proc_time ELSE $
		proc_time = strfcsp(0).proc_time
		
        data_exa = [STRING(strfcsp(0).flag), strfcsp(0).date, $
	  strfcsp(0).source, strfcsp(0).filt_id, strfcsp(0).aper_id, $
	  STRING(strfcsp(0).f_star), STRING(strfcsp(0).heatpow), $
	  proc_time, '1' ]
	  
; get variables limits
        pia_select_var, data_exa, VARNAMES=data_names, $
		VARTYP=[0,0,1,1,1,0,0,0,1], GROUP=group
	
	indnot = WHERE(vars(0,*) EQ '',nnot)

	nelem = N_ELEMENTS(strfcsp)
	indall = indgen(nelem)

; Flag
        IF vars(0,0) NE '' AND vars(1,0) NE '' THEN BEGIN
	     flaglim = FIX(vars(*,0)) 
	     indfl = WHERE(strfcsp.flag GE flaglim(0) AND $
			   strfcsp.flag LE flaglim(1), nflag)
	     IF nflag EQ 0 THEN BEGIN

                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" No flags corresponding to selection  "]
                        RETURN
	     ENDIF
        ENDIF ELSE indfl = indall 

; proc time
        IF vars(0,7) NE '' AND vars(1,7) NE '' THEN BEGIN
	     
	     datelim = [date_conv(vars(0,7)), date_conv(vars(1,7))]
	     alldates = dblarr(nelem)
	     FOR I=0, nelem-1 DO BEGIN
	     	IF STRLEN(strfcsp(i).proc_time) EQ 24 THEN $
	     	  conv_procdate, strfcsp(i).proc_time, proc_time ELSE $
		  proc_time = strfcsp(i).proc_time	
	     	alldates(i) = date_conv(proc_time)
	     ENDFOR
	     
             indproct = $
		WHERE(alldates GE datelim(0) AND alldates LE datelim(1),ndate)

	     IF ndate EQ 0 THEN BEGIN
                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" No dates corresponding to selection  "]
                        RETURN
	     ENDIF
	ENDIF ELSE indproct = indall 

; date
        IF vars(0,1) NE '' AND vars(1,1) NE '' THEN BEGIN
	     
	     datelim = [date_conv(vars(0,1)), date_conv(vars(1,1))]
	     alldates = dblarr(nelem)
	     FOR I=0, nelem-1 DO alldates(i) = date_conv(strfcsp(i).date)
	     
             inddate = $
		WHERE(alldates GE datelim(0) AND alldates LE datelim(1),ndate)

	     IF ndate EQ 0 THEN BEGIN
                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" No dates corresponding to selection  "]
                        RETURN
	     ENDIF
	ENDIF ELSE inddate = indall 

; source
        IF vars(0,2) NE '' THEN BEGIN
	     srclim = vars(0,2) 
	     indsrc = WHERE(STRTRIM(strfcsp.source,2) EQ $ 
			    STRTRIM(srclim,2), nsrc)
	     IF nsrc EQ 0 THEN BEGIN

                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" No source corresponding to selection"]
                        RETURN
	     ENDIF
        ENDIF ELSE indsrc = indall 

; filter
        IF vars(0,3) NE '' THEN BEGIN
	     filtlim = vars(0,3) 
	     indfilt = WHERE(STRTRIM(strfcsp.filt_id,2) EQ $
	     		STRTRIM(filtlim,2), nfilt)
	     IF nfilt EQ 0 THEN BEGIN

                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" No filter corresponding to selection"]
                        RETURN
	     ENDIF
; convert filtlim to position within the file
	CASE STRMID(filtlim,0,2) OF
		'P1': allf=p1filters
		'P2': allf=p2filters
		'P3': allf=p3filters
		'C1': allf=c1filters
		'C2': allf=c2filters
		ELSE:
	ENDCASE
	ind = WHERE(STRTRIM(allf,2) EQ STRTRIM(filtlim,2))
	filtlim = ind
	
        ENDIF ELSE BEGIN 
                        XDISPLAYFILE, "", $
                                TITLE = "Missing input", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" No filter selected"]
                        RETURN
	ENDELSE

; aperture
        IF vars(0,4) NE '' THEN BEGIN
	     aperlim = vars(0,4) 
	     indaper = WHERE(strfcsp.aper_id EQ aperlim, naper)
	     IF naper EQ 0 THEN BEGIN

                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" No aperture corresponding to selection"]
                        RETURN
	     ENDIF
        ENDIF ELSE indaper = indall

; In band flux
        IF vars(0,5) NE '' AND vars(1,5) NE '' THEN BEGIN
	     ibflim = FLOAT(vars(*,5)) 
	     indibf = WHERE(strfcsp.f_star GE ibflim(0) AND $
			   strfcsp.f_star LE ibflim(1), nibfl)
	     IF nibfl EQ 0 THEN BEGIN

                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                    TEXT = [" No In-Band-fluxes corresponding to selection  "]
                        RETURN
	     ENDIF
        ENDIF ELSE indibf = indall 

; Heating power
        IF vars(0,6) NE '' AND vars(1,6) NE '' THEN BEGIN
	     hpwlim = FLOAT(vars(*,6)) 
	     indhpw = WHERE(strfcsp.heatpow GE hpwlim(0) AND $
			   strfcsp.heatpow LE hpwlim(1), nhpw)
	     IF nhpw EQ 0 THEN BEGIN

                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                    TEXT = [" No Heating Powers corresponding to selection  "]
                        RETURN
	     ENDIF
        ENDIF ELSE indhpw = indall 

; pixel
        IF vars(0,8) NE '' THEN $
	     pixel = FIX(vars(0,8)-1) ELSE BEGIN
			pixel = 0
			Message, /INFO, 'Pixel 1 taken following no choice' 
			Message, /INFO, '(but all pixels for scaling)' 
        ENDELSE
; Not choosable variables - Values coming from common

; FCS
        indfcs = WHERE(strfcsp.fcs-1 EQ fcsa, nfcs)
        IF nfcs EQ 0 THEN BEGIN
                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" No FCS corresponding to selection"]
                        RETURN
        ENDIF

; TRS
        indtrs = WHERE(strfcsp.trs-1 EQ trsa, ntrs)
        IF ntrs EQ 0 THEN BEGIN
                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                  HEIGHT = 4, $
                          TEXT = [" No TRS corresponding to selection"]
                        RETURN
        ENDIF


; Search combinations of accepted variables

	match, indall, indfl, suba, subb, count=count
	indall = indall(suba)

	match, indall, inddate, suba, subb, count=count
	IF count EQ 0 THEN GOTO, nocomb
	indall = indall(suba)

	match, indall, indproct, suba, subb, count=count
	IF count EQ 0 THEN GOTO, nocomb
	indall = indall(suba)

	match, indall, indsrc, suba, subb, count=count
	IF count EQ 0 THEN GOTO, nocomb
	indall = indall(suba)

	match, indall, indfilt, suba, subb, count=count
	IF count EQ 0 THEN GOTO, nocomb
	indall = indall(suba)

	match, indall, indaper, suba, subb, count=count
	IF count EQ 0 THEN GOTO, nocomb
	indall = indall(suba)

	match, indall, indibf, suba, subb, count=count
	IF count EQ 0 THEN GOTO, nocomb
	indall = indall(suba)

	match, indall, indhpw, suba, subb, count=count
	IF count EQ 0 THEN GOTO, nocomb
	indall = indall(suba)

	match, indall, indfcs, suba, subb, count=count
	IF count EQ 0 THEN GOTO, nocomb
	indall = indall(suba)

	match, indall, indtrs, suba, subb, count=count
	IF count EQ 0 THEN GOTO, nocomb
	indall = indall(suba)

	indok = WHERE(strfcsp(indall).sflg(pixel) LT 2, n)


	IF n GT 0 THEN BEGIN
; replace the new Table
	   newstrfcsp = strfcsp(indall)

	   IF KEYWORD_SET(rescale_int) or KEYWORD_SET(rescale_ext) THEN BEGIN

; interpolate to obtain the fcs fluxes which correspond to the heating powers
; in the original curve:
		heatpow = strfcsp(indall(indok)).heatpow
		
		IF KEYWORD_SET(rescale_ext) THEN BEGIN
		  th_file = pickfile(/READ, $
		  	TITLE='Input FCS power spectrum file?')
		  readcol, th_file, th_heatpow, th_optpow
		ENDIF ELSE BEGIN
		  th_optpow = longpow
		  th_heatpow = fcspow(*,filtlim,trsa,fcsa)
		ENDELSE

		theor_flux = $
			interpol(th_optpow,th_heatpow,heatpow)

		text = ' '

		IF vars(0,8) NE '' THEN BEGIN
		 ratio = strfcsp(indall(indok)).fcspow(pixel) / theor_flux 
		 ratio_ave = avg(ratio)
		 ratio_sig = sigma(ratio)

		 text = [text, '  ', "The ratios calculated for pixel "$
			+STRTRIM(STRING(pixel+1),2)+ " are: ", $
				string(ratio), " ", $
				"Average:" + STRING(ratio_ave) + $
				" +/-" + STRTRIM(ratio_sig)] 
		ENDIF ELSE BEGIN

		  FOR Ipix = 0, N_ELEMENTS(strfcsp(0).fcspow)-1 DO BEGIN 
		 	ratio = strfcsp(indall(indok)).fcspow(ipix) / theor_flux 
		 	ratio_ave = avg(ratio)
		 	ratio_sig = sigma(ratio)

		 	text = [text, '  ', "The ratios calculated for pixel "$
			+STRTRIM(STRING(ipix+1),2)+ " are: ", $
				string(ratio), " ", $
				"Average:" + STRING(ratio_ave) + $
				" +/-" + STRTRIM(ratio_sig)] 
		  ENDFOR
		ENDELSE
		
		pia_disp_print_file,  "", $
                		TITLE = "New FCS Table using ratios", $
                                WIDTH = 50, $
                                HEIGHT = 10, $
                          	TEXT = [text]

		newoptpow = th_optpow * ratio_ave

; now interpolate to obtain the expected heating powers corresponding to the
; fluxes desired
		
		newfcspow(*,filtlim,trsa,fcsa) = $
			interpol(th_heatpow,newoptpow,longpow)

	   ENDIF ELSE IF KEYWORD_SET(fit) THEN BEGIN

; sort in ascending order 
	   	inds = bsort(strfcsp(indall(indok)).fcspow(pixel), optpow)
	   	optpun = strfcsp(indall(indok(inds))).fcspun(pixel)
	   	heatpow = strfcsp(indall(indok(inds))).heatpow
; call fit routine
		CASE ndeg of
		
			2: BEGIN

			  res = polyfitw(alog(heatpow),alog(optpow),$
			  		1./alog(optpun)^2, ndeg)
			  
			  heatall = 0.01 + indgen(99) * 0.001
			  heatall = [heatall, heatall*10., heatall*100., $
			  		heatall*1000./2.+5.] 

			  optpow = exp( res(0) + res(1)*alog(heatall) + $
			  		res(2)*alog(heatall)^2 )

			  dif = optpow - shift(optpow,1)
			  ind = WHERE(optpow GT 0.)
			  max_ind = max(ind)
			  min_ind = WHERE(optpow EQ min(optpow(0:max_ind(0))))
			  min_ind=min_ind(0)

			  newfcspow(*,filtlim,trsa,fcsa) = $
				interpol(heatall(min_ind:max_ind), $
					optpow(min_ind:max_ind), longpow)
			END 
			
			3: BEGIN

			  res = polyfitw(alog(heatpow),alog(optpow),$
			  		1./alog(optpun)^2, ndeg)
			  
			  heatall = 0.01 + indgen(99) * 0.001
			  heatall = [heatall, heatall*10., heatall*100., $
			  		heatall*1000./2.+5.] 

			  optpow = exp( res(0) + res(1)*alog(heatall) + $
			  	res(2)*alog(heatall)^2 + $
			  	res(3)*alog(heatall)^3 )
			  	
			  dif = optpow - shift(optpow,1)
			  ind = WHERE(optpow GT 0.)
			  max_ind = max(ind)
			  min_ind = WHERE(optpow EQ min(optpow(0:max_ind(0))))
			  min_ind=min_ind(0)

			  newfcspow(*,filtlim,trsa,fcsa) = $
				interpol(heatall(min_ind:max_ind), $
					optpow(min_ind:max_ind), longpow)
			END
			
			ELSE: Message, /info, 'Incorrect choice'
			
		ENDCASE
		
	   ENDIF ELSE IF KEYWORD_SET(noproc) THEN BEGIN

	   	optpow = strfcsp(indall(indok)).fcspow
	   	optpun = strfcsp(indall(indok)).fcspun
	   	heatpow = strfcsp(indall(indok)).heatpow

	  	   	
	   ENDIF ELSE BEGIN

; sort in ascending order (because of interpol routine)
	   	inds = bsort(strfcsp(indall(indok)).fcspow(pixel), optpow)
	   	optpun = strfcsp(indall(indok(inds))).fcspun(pixel)
	   	heatpow = strfcsp(indall(indok(inds))).heatpow

; interpolate  
	   	newfcspow(*,filtlim,trsa,fcsa) = $
			interpol(heatpow, optpow, longpow) 
			
	   ENDELSE

; in any case plot all fcspow selected
	   c_heatpow = strfcsp(indall(indok)).heatpow
	   c_fcspow = strfcsp(indall(indok)).fcspow
	   c_fcspun = strfcsp(indall(indok)).fcspun
	   dims = size(c_fcspow)
	   IF dims(0) EQ 1 THEN BEGIN
	     c_fcspow = FLTARR(1,dims(1))
	     c_fcspun = c_fcspow
	     c_fcspow(0,*) = strfcsp(indall(indok)).fcspow
	     c_fcspun(0,*) = strfcsp(indall(indok)).fcspun
	   ENDIF
	   
           overplot = 0
	   psymch = 2
	   colch = 39
           IF vars(0,8) NE '' THEN BEGIN
		  legend = 'Pixel '+ STRTRIM(STRING(pixel+1),2)
		  PIA_XPLOT, c_heatpow, c_fcspow(pixel,*), c_fcspun(pixel,*), $
			title='New FCS values obtained', psym=psymch, $
			xtitle= 'Heating power', ytitle='Optical Power', $
			legend=legend, overplot=overplot
	   ENDIF ELSE BEGIN
       	     FOR I=0,N_ELEMENTS(c_fcspow(*,0))-1 DO BEGIN  
		  legend = 'Pixel '+ STRTRIM(STRING(I+1),2)
		  PIA_XPLOT, c_heatpow, c_fcspow(i,*), c_fcspun(i,*), $
			psym=psymch, color=colch, $
			title='New FCS values obtained', $
			xtitle= 'Heating power', ytitle='Optical Power', $
			legend=legend, overplot=overplot
		  overplot = 99
		  psymch = psymch+1
		  IF psymch EQ 8 THEN psymch = 2
		  colch = colch+1
		  IF colch GT 9 THEN colch=1
             ENDFOR
           ENDELSE

	ENDIF ELSE BEGIN   

		  MESSAGE, /INFO, 'Data has only bad flags'
	ENDELSE


; Bring all values to the allowed range:
	indout = WHERE(newfcspow LT 0., minc)
	IF minc GT 0 THEN newfcspow(indout) = 0.
	indout = WHERE(newfcspow GT 50.0, maxc)
	IF maxc GT 0 THEN newfcspow(indout) = 50.0
	
	nacc = N_ELEMENTS(indall)
	Text =  ["The new FCS powers have been calculated ", $
		"using a total of "+ STRTRIM(STRING(nacc),2) + " observations"]
        XDISPLAYFILE, "", $
                TITLE = "New FCS Table Calculation", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [text]      

	RETURN
NOCOMB: 
        XDISPLAYFILE, "", $
            TITLE = "Input not accepted", $
            WIDTH = 50, $
            HEIGHT = 4, $
            TEXT = [" Combined selection discards all elements "]
        RETURN



END 

; *****************************************************************
; * shows the FCS powers structure
; *****************************************************************
PRO FCSPSTR_SHOW, fcsp_str, GROUP=group
COMMON pia_struc_exch, ch_struc, ch_type 


	data_names = ['Flag ', 'TDTNR', 'Date ', 'Source', 'Filter_ID', $ 
	                'Aperture', 'In-Band-Flux', 'Photons/s', 'PSF_COR', $
			'FCS', 'TRS', 'Heating power', 'FCS power', $
			'FCS power uncertainty', 'Signal Flag', $
			'Processing date', 'SED_file']

	ch_struc = fcsp_str
	ch_type = 'FCSP_STR'
	
        pia_showstr, fcsp_str, VALNAMES=data_names

END 


; *****************************************************************
; * shows the FCS pre-reduced Signal Table
; *****************************************************************
PRO FCSPRESTR_SHOW, fcspre_str, GROUP=group
COMMON pia_struc_exch, ch_struc, ch_type

	data_names = ['Type_ID ', 'Filter', 'Aperture', 'Orb.pos.', $
			'Date', 'TDTnr', 'Source name', $
			'FCS', 'TRS', 'Heating power', 'Int. time', $
			'Signals', 'S-Uncertainties', $
			'Reduced signals', 'RS-Uncertainties', 'Signal Flags',$
			'General flag', 'Processing date']

	ch_struc = fcspre_str
	ch_type = 'FCSPRE_STR'
        pia_showstr, fcspre_str, VALNAMES=data_names

END 


; *****************************************************************
; * 
; *****************************************************************
PRO FCSPOW_EDIT_event, event 

COMMON pia_fcsp_cmn, dets, detact, filts, filtact, fcsa, trsa, $
		fcspow, newfcspow, wricalg_id, det_id, strfcsp, $
                newstrfcsp, filters,calg_fcspow, strfcspre, newstrfcspre 
 
	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.id, GET_VALUE=value
	CASE uvalue of
	'list': 
	'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
	ENDCASE
END

; *****************************************************************
; * 
; *****************************************************************
PRO FCSPOW_EDIT 

@phtfilter
@phtoptpow
COMMON pia_fcsp_cmn, dets, detact, filts, filtact, fcsa, trsa, $
		fcspow, newfcspow, wricalg_id, det_id, strfcsp,$
                newstrfcsp, filters,calg_fcspow, strfcspre, newstrfcspre 
                
	edbase = WIDGET_BASE(TITLE =detact+' Actual FCS Power Tables', $
			/column)

	IF STRMID(detact,0,1) EQ 'P' THEN $
	  cptlist = STRING(FORMAT='(e9.3)',longpow) + ' W/mm^2' ELSE $
 	  cptlist = STRING(FORMAT='(e9.3)',longpow) + ' Watts '
	  

	edvalbase = WIDGET_BASE(edbase, /row)
	
        edvalbas2 = WIDGET_BASE(edvalbase, /column)
	
	edval = WIDGET_TEXT(edvalbas2, XSIZE=17, YSIZE=1, $
	  VALUE = 'Optical Power')
	edval = WIDGET_TEXT(edvalbas2, XSIZE=17, YSIZE=25, $
	  VALUE = cptlist, /SCROLL)

	FOR III=0,N_ELEMENTS(fcspow(0,*,0,0))-1 DO BEGIN  
	 edvalbas3 = WIDGET_BASE(edvalbase, /column)
	 edval = WIDGET_TEXT(edvalbas3, XSIZE=5, YSIZE=1, $
		VALUE = filters(III))
	 edval = WIDGET_TEXT(edvalbas3, XSIZE=5, YSIZE=25, $
	   VALUE = STRING(FORMAT='(f5.2)',fcspow(*,III,trsa,fcsa)),$
		/SCROLL, UVALUE = 'list')
        ENDFOR

	quit = WIDGET_BUTTON(edbase, VALUE=' QUIT ', UVALUE='QUIT') 
	WIDGET_CONTROL, edbase, /REALIZE
	xMANAGER,No_BLOCK=1, "FCSPOW_EDIT", edbase, GROUP=group
	RETURN
END 

; *****************************************************************
; * 
; *****************************************************************
PRO CFCSPOW_EDIT_event, event 

COMMON pia_fcsp_cmn, dets, detact, filts, filtact, fcsa, trsa, $
		fcspow, newfcspow, wricalg_id, det_id, strfcsp,$
                newstrfcsp, filters,calg_fcspow, strfcspre, newstrfcspre 
COMMON cfcs_edit_cmn, edval_id 


	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue of
	 'LIST': BEGIN
		FOR III=0,N_ELEMENTS(edval_id) - 1 DO BEGIN
		 WIDGET_CONTROL, edval_id(III), GET_VALUE=value
		 IF N_ELEMENTS(value) EQ 45 THEN $
			newfcspow(*,III,trsa,fcsa) = float(value) ELSE BEGIN
                  	XDISPLAYFILE, "", $
                    		TITLE = "Input not accepted", $
                    		WIDTH = 50, $
                    		HEIGHT = 4, $
                    	  TEXT = [" Wrong FCS powers input  ", $]
                          	  "     ", $ ]
                          	  " Fix it and try again, please "]
			RETURN
		 ENDELSE	
		ENDFOR
	 END
	 'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
         ELSE: 
	ENDCASE

RETURN
END


; *****************************************************************
; * 
; *****************************************************************
PRO CFCSPOW_EDIT 

@phtfilter
@phtoptpow
COMMON pia_fcsp_cmn, dets, detact, filts, filtact, fcsa, trsa, $
		fcspow, newfcspow, wricalg_id, det_id, strfcsp, $
                newstrfcsp, filters,calg_fcspow, strfcspre, newstrfcspre 
COMMON cfcs_edit_cmn, edval_id 


	IF not KEYWORD_SET(group) THEN group = !PIA_TOP_WID
	edbase = WIDGET_BASE(TITLE =detact+' Computed FCS power Tables', $
			/column)

	IF STRMID(detact,0,1) EQ 'P' THEN $
	  cptlist = STRING(FORMAT='(e9.3)',longpow) + ' W/mm^2' ELSE $
 	  cptlist = STRING(FORMAT='(e9.3)',longpow) + ' Watts '
	  

	edvalbase = WIDGET_BASE(edbase, /row)
	
        edvalbas2 = WIDGET_BASE(edvalbase, /column)
	
	edval = WIDGET_TEXT(edvalbas2, XSIZE=17, YSIZE=1, $
	  VALUE = 'Optical Power')
	edval = WIDGET_TEXT(edvalbas2, XSIZE=17, YSIZE=25, $
	  VALUE = cptlist, /SCROLL)

	nele = N_ELEMENTS(newfcspow(0,*,0,0))
	edval_id = lonarr(nele) 

	FOR III=0,N_ELEMENTS(fcspow(0,*,0,0))-1 DO BEGIN  
	 edvalbas3 = WIDGET_BASE(edvalbase, /column)
	 edval = WIDGET_TEXT(edvalbas3, XSIZE=5, YSIZE=1, $
		VALUE = filters(III))
	 edval_id(III) = WIDGET_TEXT(edvalbas3, /EDITABLE, XSIZE=5, YSIZE=25, $
	   VALUE = STRING(FORMAT='(f5.2)',newfcspow(*,III,trsa,fcsa)),$
		/SCROLL, UVALUE = 'junk')
        ENDFOR

	edconbase = WIDGET_BASE(edbase, /row)
	ok = WIDGET_BUTTON(edconbase, VALUE='  ACCEPT  ', UVALUE='LIST')
	quit = WIDGET_BUTTON(edconbase, VALUE=' QUIT ', UVALUE='QUIT') 

	WIDGET_CONTROL, edbase, /REALIZE

	xMANAGER,No_BLOCK=1, "CFCSPOW_EDIT", edbase, GROUP=group 
	RETURN
END 


; *****************************************************************
; * 
; *****************************************************************
PRO CLUFCSPOW_EDIT_event, event 

COMMON pia_fcsp_cmn, dets, detact, filts, filtact, fcsa, trsa, $
		fcspow, newfcspow, wricalg_id, det_id, strfcsp, $
                newstrfcsp, filters,calg_fcspow, strfcspre, newstrfcspre 
COMMON cfcs_edit_cmn, edval_id 
COMMON calu_fcspow, calu_fcs, calu_ind, calu_nkeys, calu_det


	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue of
	 'LIST':
	 'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
         ELSE: 
	ENDCASE

RETURN
END


; *****************************************************************
; * 
; *****************************************************************
PRO CLUFCSPOW_EDIT 

@phtfilter
@phtoptpow
COMMON pia_fcsp_cmn, dets, detact, filts, filtact, fcsa, trsa, $
		fcspow, newfcspow, wricalg_id, det_id, strfcsp,$
                newstrfcsp, filters,calg_fcspow, strfcspre, newstrfcspre 
COMMON cfcs_edit_cmn, edval_id 
COMMON calu_fcspow, calu_fcs, calu_ind, calu_nkeys, calu_det


	edbase = WIDGET_BASE(TITLE =detact+' CalU FCS ' + $
                 strtrim(string(fcsa + 1), 2) + ' power Tables', $
			/column)

        calu_ind = calu_det + fcsa * 5
	handle_value, calu_fcs(calu_ind), calu_buf
	IF STRMID(detact,0,1) EQ 'P' THEN $
	  cptlist = STRING(FORMAT='(e9.3)',calu_buf(0, *)) + ' W/mm^2' ELSE $
 	  cptlist = STRING(FORMAT='(e9.3)',calu_buf(0, *)) + ' Watts '
	  

	edvalbase = WIDGET_BASE(edbase, /row)
	
        edvalbas2 = WIDGET_BASE(edvalbase, /column)

	xsize = strlen(cptlist(0))
	edval = WIDGET_TEXT(edvalbas2, XSIZE=xsize, YSIZE=1, $
	  VALUE = 'Optical Power')
	edval = WIDGET_TEXT(edvalbas2, XSIZE=xsize, YSIZE=45, $
	  VALUE = cptlist)

	nele = (N_ELEMENTS(calu_buf(*,0)) - 1)/2
	edval_id = lonarr(nele*2) 

	FOR III = 0, nele - 1 DO BEGIN  
	 edvalbas3 = WIDGET_BASE(edvalbase, /column)
	 xsize = strlen(filters(III))
	 edval = WIDGET_TEXT(edvalbas3, XSIZE=xsize, YSIZE=1, $
		VALUE = filters(III))
         ind = III * 2 + 1
	 edval_id(ind - 1) = WIDGET_TEXT(edvalbas3, /EDITABLE, XSIZE=xsize,$
	   YSIZE=45, VALUE = STRING(FORMAT='(f5.2)',calu_buf(ind,*)),$
		UVALUE = 'junk')
	 edvalbas3 = WIDGET_BASE(edvalbase, /column)
	 edval = WIDGET_TEXT(edvalbas3, XSIZE=3, YSIZE=1, $
		VALUE = 'TRS')
	 edval_id(ind) = WIDGET_TEXT(edvalbas3, /EDITABLE, XSIZE=3, YSIZE=45, $
	   VALUE = STRTRIM(STRING(fix(calu_buf(ind+1,*))),2),$
		UVALUE = 'junk')
        ENDFOR

	edconbase = WIDGET_BASE(edbase, /row)
	quit = WIDGET_BUTTON(edconbase, VALUE=' QUIT ', UVALUE='QUIT') 

	WIDGET_CONTROL, edbase, /REALIZE

	xMANAGER,No_BLOCK=1, "CLUFCSPOW_EDIT", edbase, GROUP=group
	RETURN
END 


; *****************************************************************
; * 
; *****************************************************************
PRO PIA_CAL_FCSPOW_EVENT, event

@phtfilter
@phtoptpow
@phtfcs
@colour_indices
COMMON pia_fcsp_cmn, dets, detact, filts, filtact, fcsa, trsa, $
		fcspow, newfcspow, wricalg_id, det_id, strfcsp, $
                newstrfcsp, filters,calg_fcspow, strfcspre, newstrfcspre 
COMMON calu_fcspow, calu_fcs, calu_ind, calu_nkeys, calu_det
COMMON calg_fcs, calg_fcspow_p1, calg_fcspow_p2, calg_fcspow_p3, calg_fcspow_c1, calg_fcspow_c2
COMMON pia_cal_fcspow_proc_res, heatpow, obsfcspow, obsfcspun, cal_fcspow_str,$
		 cal_fcspre_str, proc_status
COMMON pia_cal_fcspow_cros_res, cros_heatpow, cros_fcspow, cros_fcspun, $
		cros_cal_fcspow_str, cros_proc_status
COMMON pia_get_inbp_res, c_inbp
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
COMMON pia_struc_exch, ch_struc, ch_type
COMMON ext_version, ext_version

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue


        i = WHERE(dets EQ uvalue, n)
        i = i(0)
        IF n NE 0 THEN uvalue = 'DET'

        CASE uvalue of
	   'NEWCALG': BEGIN
	   	detsh = STRMID(detact,0,2)
	   	orig_name = "P"+detsh+"FCSPOW"
		get_caltdep_file, orig_name, tdep_name
		
		read_fcspow, tdep_name + '.FITS'
; Write fcspower into the buffers
		CASE detsh OF
		 'P1': fcspow = p1fcspow
		 'P2': fcspow = p2fcspow
		 'P3': fcspow = p3fcspow
		 'C1': fcspow = c1fcspow
		 'C2': fcspow = c2fcspow
		ENDCASE 
		newfcspow = fcspow
	   END		


           'DET': BEGIN
		 	idpar = WIDGET_INFO(event.id, /parent)
                 	WIDGET_CONTROL, idpar, SET_VALUE=dets(i)
                        detact = dets(i)
; Write FCS tables into the local tables - use for new ones initially old ones

			IF NOT ext_version THEN BEGIN
			 get_fcspstr, detact, strfcsp
			 newstrfcsp = strfcsp 
			 get_fcspre_str, detact, strfcspre
			 newstrfcspre = strfcspre 
                        ENDIF
                        
	   		detsh = STRMID(detact,0,2)
	   		orig_name = "P"+detsh+"FCSPOW"
			get_caltdep_file, orig_name, tdep_name
			read_fcspow, tdep_name + ".FITS"

                        CASE STRMID(detact,0,2) OF

                                'P1': begin
				  fcspow = p1fcspow
 				  calu_det = 0
		 		  filters = 'P1_' + ['3P29', '3P6', $
                          	  '4P85', '7P3', '7P7', '10', '11P3', '12P8', $
                          	  '16P0', '11P5'] + '_UM'
;				  calg_fcspow = calg_fcspow_p1
				end
                                'P2': begin
				  fcspow = p2fcspow
 				  calu_det = 1
		 		  filters = 'P2_' + ['20', '25'] + '_UM'
;				  calg_fcspow = calg_fcspow_p2
				end
                                'P3': begin
				  fcspow = p3fcspow
 				  calu_det = 2
		 		  filters = 'P3_' + ['60', '100'] + '_UM' 
;				  calg_fcspow = calg_fcspow_p3
				end
                                'C1': begin
				  fcspow = c1fcspow
 				  calu_det = 3
		 		  filters = 'C100_' + ['90_RED', '50_UM', $
                          	  '60_UM', '70_UM', '100_UM', '105_UM', $
                          	  '90_UM']
;				  calg_fcspow = calg_fcspow_c1
				end
                                'C2': begin
				  fcspow = c2fcspow
 				  calu_det = 4
		 		  filters = 'C200_' + ['160', $
                          	  '200', '180', '135', '120'] + '_UM'
;				  calg_fcspow = calg_fcspow_c2
				end
                                ELSE:
                        ENDCASE
                        newfcspow = fcspow
                  END

	   'FCS(1,1)': BEGIN
		 idpar = WIDGET_INFO(event.id, /parent)
                 WIDGET_CONTROL, idpar, SET_VALUE=uvalue
		 fcsa = 0
		 trsa = 0
	    END	

	   'FCS(1,2)': BEGIN
		 idpar = WIDGET_INFO(event.id, /parent)
                 WIDGET_CONTROL, idpar, SET_VALUE=uvalue
		 fcsa = 0
		 trsa = 1
	    END	

	   'FCS(2,1)': BEGIN
		 idpar = WIDGET_INFO(event.id, /parent)
                 WIDGET_CONTROL, idpar, SET_VALUE=uvalue
		 fcsa = 1
		 trsa = 0
	    END	

	   'FCS(2,2)': BEGIN
		 idpar = WIDGET_INFO(event.id, /parent)
                 WIDGET_CONTROL, idpar, SET_VALUE=uvalue
		 fcsa = 1
		 trsa = 1
	    END	

	   'PLOTACT': BEGIN 
		 title=detact+' actual FCS power - FCS('+$
		   STRTRIM(STRING(fcsa+1),2)+','+STRTRIM(STRING(trsa+1),2)+')' 
           	 pia_xsurface, fcspow(*,*,trsa,fcsa), wlego=1, $
			xtitle = 'Power Index', $
                        ytitle= 'Filter Index', charsize=2, $
                        ztitle= ' Electrical Power [mW]  ', title=title, $
                        group=event.top  

		END

	   'PLOTACTPROJ': BEGIN

		elnames = filters + 'Filter'
		pia_multchoice, list, ELEMNAMES = elnames   
		 		
		title = detact+' actual FCS power - FCS('+$
		  STRTRIM(STRING(fcsa+1),2)+','+STRTRIM(STRING(trsa+1),2)+')'+$
		  ' Filter '+filters(list)                                   

                indok = WHERE(fcspow(*,list,trsa,fcsa) GE 0.01 AND $
                          fcspow(*,list,trsa,fcsa) LE 50.0, ncount)
                if (ncount eq 0) then begin
                  message, /info, 'All points equal zero, cannot plot!'
                  return
                endif
		x = longpow(indok)
		 
                pia_xplot, fcspow(indok,list,trsa,fcsa), x, psym=-4, $
			title= title, ytitle=' Optical power  [W]', $
			xtitle = ' Electrical Power  [mW]', $
			annotation = title, legend = ytitle,$
			xtype=1, ytype=1, linestyle=2                                    
           END

	   'OPLOTACTPROJ': BEGIN

		elnames = filters + 'Filter'
		pia_multchoice, list, ELEMNAMES = elnames   
		 		
		title = detact+' actual FCS power - FCS('+$
		   STRTRIM(STRING(fcsa+1),2)+','+STRTRIM(STRING(trsa+1),2)+')'+$
		  ' Filter '+filters(list)                                    

                indok = WHERE(fcspow(*,list,trsa,fcsa) GE 0.01 AND $
                          fcspow(*,list,trsa,fcsa) LE 50.0)
		x = longpow(indok)
		 

		change_zplot_param		
                pia_xplot, fcspow(indok,list,trsa,fcsa), x,$
			title= title, overplot=99,  $
			annotation = title, legend = ' Optical power  [W]',$
			xtype=1, ytype=1, psym=-zoom_psymch, color=zoom_color,$
			linestyle=2                                
           END

	   'PLOTCOM': BEGIN 
		 title=detact+' computed FCS power - FCS('+$
		   STRTRIM(STRING(fcsa+1),2)+','+STRTRIM(STRING(trsa+1),2)+')' 
           	 pia_xsurface, newfcspow(*,*,trsa,fcsa), wlego=1, $
			xtitle = 'Power Index', $
                        ytitle= 'Filter Index', charsize=2, $
                        ztitle= ' Electrical Power [mW]  ', title=title, $
                        group=event.top  

		END

	   'PLOTCOMPROJ': BEGIN

		elnames = filters + 'Filter'
		pia_multchoice, list, ELEMNAMES = elnames   

		 		
		title = detact+' computed FCS power - FCS('+$
		   STRTRIM(STRING(fcsa+1),2)+','+STRTRIM(STRING(trsa+1),2)+')'+$
		  ' Filter '+filters(list)                                    

		xtitle = 'Electrical Power  [mW]'
		ytitle = 'Optical Power  [W]'

                indok = WHERE(newfcspow(*,list,trsa,fcsa) GE 0.01 AND $
                          newfcspow(*,list,trsa,fcsa) LE 50.)
		x = longpow(indok)
		 
                pia_xplot, newfcspow(indok,list,trsa,fcsa), x, psym=-4, $
			title= title, xtitle=xtitle, linestyle=2, $
			ytitle = ytitle , $
			annotation = title, legend = ytitle,$
			xtype=1, ytype=1                                    
           END

	   'OPLOTCOMPROJ': BEGIN

		elnames = filters + 'Filter'
		pia_multchoice, list, ELEMNAMES = elnames   
		 		
		title = detact+' computed FCS power - FCS('+$
		   STRTRIM(STRING(fcsa+1),2)+','+STRTRIM(STRING(trsa+1),2)+')'+$
		  ' Filter '+filters(list)                                    

		xtitle = 'Electrical Power  [mW]'
		ytitle = 'Optical Power  [W]'

                indok = WHERE(newfcspow(*,list,trsa,fcsa) GE 0.01 AND $
                          newfcspow(*,list,trsa,fcsa) LE 50.)
		x = longpow(indok)
		 
		change_zplot_param
                pia_xplot, newfcspow(indok,list,trsa,fcsa), x,  $
			title= title, overplot=99,  $
			ytitle = ytitle, annotation = title, legend = ytitle,$
			xtype=1, ytype=1,  psym=-zoom_psymch, color=zoom_color,$
			linestyle=2                                         
           END

	   'PLOTEXT': BEGIN

		IF N_ELEMENTS(obsfcspow) EQ 0 THEN BEGIN
			MESSAGE, /info, 'Nothing extracted yet'
			RETURN
		ENDIF
		
		title = detact+' extracted FCS power '                        

		xtitle = 'Electrical Power  [mW]'
		ytitle = 'Optical Power  [W]'

                pia_xplot, heatpow, obsfcspow(0,*), obsfcspun(0,*), psym=4, $
			title= title, xtitle=xtitle, linestyle=2, $
			ytitle = ytitle , $
			annotation = title, legend = ytitle,$
			xtype=1, ytype=1                                    
		npix = N_ELEMENTS(obsfcspow(*,0))
		IF npix GT 1 THEN BEGIN
			FOR i=1,npix-1 DO BEGIN
				change_zplot_param
                		pia_xplot, heatpow, obsfcspow(i,*), $
                		 obsfcspun(i,*),$
                		 overplot=99,  $
				 ytitle = ytitle , $
				 annotation = title, legend = ytitle,$
				 psym=zoom_psymch, color=zoom_color
			ENDFOR
		ENDIF
           END

	   'OPLOTEXT': BEGIN

		IF N_ELEMENTS(obsfcspow) EQ 0 THEN BEGIN
			MESSAGE, /info, 'Nothing extracted yet'
			RETURN
		ENDIF
		
		title = detact+' extracted FCS power '                        

		xtitle = 'Electrical Power  [mW]'
		ytitle = 'Optical Power  [W]'

		npix = N_ELEMENTS(obsfcspow(*,0))

			FOR i=0,npix-1 DO BEGIN 
				change_zplot_param
                		pia_xplot, heatpow, obsfcspow(i,*), $
                		 obsfcspun(i,*),$
                		 overplot=99,  $
				ytitle = ytitle , $
				annotation = title, legend = ytitle,$
				psym=zoom_psymch, color=zoom_color
			ENDFOR
           END

	   'PLOTCLUPROJ': BEGIN

		elnames = filters + ' Filter'
		pia_multchoice, list, ELEMNAMES = elnames   

		 		
		title = detact+' CalU FCS power - FCS('+$
		   STRTRIM(STRING(fcsa+1),2)+','+STRTRIM(STRING(trsa+1),2)+')'+$
		  ' Filter '+filters(list)                                    

		xtitle = 'Electrical Power  [mW]'
		ytitle = 'Optical Power  [W]'

; the tind is the actual index for the calu array
		tind = list * 2 + 1
                calu_ind = calu_det + fcsa * 5
                handle_value, calu_fcs(calu_ind), clu_buf
                indok = WHERE(clu_buf(tind, *) GE 0.01 AND $
                          clu_buf(tind, *) LE 50.)
		x = clu_buf(0, indok)
		 
                pia_xplot, clu_buf(tind, indok), x, psym=4, $
			title= title, xtitle=xtitle, $
			ytitle = ytitle , $
			annotation = title, legend = ytitle,$
			xtype=1, ytype=1                                    
           END

	   'OPLOTCLUPROJ': BEGIN

		elnames = filters + ' Filter'
		pia_multchoice, list, ELEMNAMES = elnames   

		 		
		title = detact+' CalU FCS power - FCS('+$
		   STRTRIM(STRING(fcsa+1),2)+','+STRTRIM(STRING(trsa+1),2)+')'+$
		  ' Filter '+filters(list)                                    

		xtitle = 'Electrical Power  [mW]'
		ytitle = 'Optical Power  [W]'

; the tind is the actual index for the calu array
		tind = list * 2 + 1
                calu_ind = calu_det + fcsa * 5
                handle_value, calu_fcs(calu_ind), clu_buf
                indok = WHERE(clu_buf(tind, *) GE 0.01 AND $
                          clu_buf(tind, *) LE 50.)
		x = clu_buf(0, indok)
		 
		change_zplot_param
                pia_xplot, clu_buf(tind, indok), x, $
			title= title, overplot=99,  $
			ytitle = ytitle , $
			annotation = title, legend = ytitle,$
			xtype=1, ytype=1, psym=-zoom_psymch, color=zoom_color,$
			linestyle=2                                      
           END

	   'PLOTCLGPROJ': BEGIN 
		elnames = filters + 'Filter'
		pia_multchoice, list, ELEMNAMES = elnames   
		 		
		title = detact+' CalG FCS power - FCS('+$
		  STRTRIM(STRING(fcsa+1),2)+','+STRTRIM(STRING(trsa+1),2)+')'+$
		  ' Filter '+filters(list)                                   

                indok = WHERE(calg_fcspow(*,list,trsa,fcsa) GE 0.01 AND $
                          calg_fcspow(*,list,trsa,fcsa) LE 50., ncount)
                if (ncount eq 0) then begin
                  message, /info, 'All points equal zero, cannot plot!'
                  return
                endif
		x = longpow(indok)
		 
                pia_xplot, calg_fcspow(indok,list,trsa,fcsa), x, psym=4, $
			title= title, ytitle=' Optical power  [W]', $
			xtitle = ' Electrical Power  [mW]', $
			annotation = title, legend = ytitle,$
			xtype=1, ytype=1                                    

		END

	   'PROC': BEGIN
		
		PIA_CAL_FCSPOW_PROC, STRMID(detact,0,2)
			
		IF proc_status NE 0 THEN RETURN
			
		newstrfcsp = cal_fcspow_str
		newstrfcspre = cal_fcspre_str 	

                overplot = 0
		psymch = 2
		colch = 1
		FOR I=0,N_ELEMENTS(obsfcspow(*,0))-1 DO BEGIN  
		  anntmp = 'Pixel '+ STRTRIM(STRING(I+1),2)
		  PIA_XPLOT, heatpow, obsfcspow(i,*), obsfcspun(i,*), $
			psym=psymch, color=colch, $
			title='New FCS values obtained', $
			xtitle= 'Heating power', ytitle='Optical Power', $
			annotation=anntmp, overplot=overplot
		  overplot = 99
		  psymch = psymch+1
		  IF psymch EQ 8 THEN psymch = 2
		  colch = colch+1
                 ENDFOR
	   END

	   'PROC_FSRD': BEGIN
		
		PIA_CAL_FCSPOW_PROC, STRMID(detact,0,2), /FROM_SRD
			
		IF proc_status NE 0 THEN RETURN
			
		newstrfcsp = cal_fcspow_str
		newstrfcspre = cal_fcspre_str 	

                overplot = 0
		psymch = 2
		colch = 1
		
		FOR I=0,N_ELEMENTS(obsfcspow(*,0))-1 DO BEGIN  
		  anntmp = 'Pixel '+ STRTRIM(STRING(I+1),2)
		  PIA_XPLOT, heatpow, obsfcspow(i,*), obsfcspun(i,*), $
			psym=psymch, color=colch, $
			title='New FCS values obtained', $
			xtitle= 'Heating power', ytitle='Optical Power', $
			annotation=anntmp, overplot=overplot
		  overplot = 99
		  psymch = psymch+1
		  IF psymch EQ 8 THEN psymch = 2
		  colch = colch+1
                 ENDFOR
	   END


	   'PROC_FSCP': BEGIN
		
		PIA_CAL_FCSPOW_PROC, STRMID(detact,0,2), /FROM_SCP
			
		IF proc_status NE 0 THEN RETURN
			
		newstrfcsp = cal_fcspow_str
		newstrfcspre = cal_fcspre_str 	

                overplot = 0
		psymch = 2
		colch = 1
		
		FOR I=0,N_ELEMENTS(obsfcspow(*,0))-1 DO BEGIN  
		  anntmp = 'Pixel '+ STRTRIM(STRING(I+1),2)
		  PIA_XPLOT, heatpow, obsfcspow(i,*), obsfcspun(i,*), $
			psym=psymch, color=colch, $
			title='New FCS values obtained', $
			xtitle= 'Heating power', ytitle='Optical Power', $
			annotation=anntmp, overplot=overplot
		  overplot = 99
		  psymch = psymch+1
		  IF psymch EQ 8 THEN psymch = 2
		  colch = colch+1
                 ENDFOR
	   END

	   'PROC_CROSSCAL': BEGIN
		pia_write_comment, instcom="Number of FCS measurements", fcs_nr
		
		PIA_CAL_FCSPOW_CROS, STRMID(detact,0,2), fcspow, $
			fcs_nr=fcs_nr
	   	
	   END
	   
	   'PROC_STR': FCSP_STRUCT_VAL_CHOICE

	   'PROC_STR_SCALE': FCSP_STRUCT_VAL_CHOICE, /rescale_int

	   'PROC_STR_SCALE_EXT': FCSP_STRUCT_VAL_CHOICE, /rescale_ext

	   'PROC_STR_FIT2': FCSP_STRUCT_VAL_CHOICE, /fit, ndeg=2

	   'PROC_STR_FIT3': FCSP_STRUCT_VAL_CHOICE, /fit, ndeg=3

	   'PROC_STR_EXTR': FCSP_STRUCT_VAL_CHOICE, /noproc

	   'EDACTVAL': FCSPOW_EDIT

	   'EDCOMVAL': CFCSPOW_EDIT, GROUP=event.top

	   'EDCLUVAL': CLUFCSPOW_EDIT

	   'EDCLGVAL': fcs_buffer_view, calg_fcspow, detact, longpow, fcsa,$
		trsa, filters, prefix='CALG'

	   'EDACTSTR': BEGIN
	   	FCSPSTR_SHOW, strfcsp, GROUP=event.top 
	   END

	   'EDACTSTR_REPL': BEGIN
	   	IF ch_type EQ 'FCSP_STR' THEN $
	   	   strfcsp = ch_struc ELSE $
	   	   PRINT, 'Wrong structure type, nothing replaced'
	   END

	   'EDCOMSTR': BEGIN
	   	FCSPSTR_SHOW, newstrfcsp, GROUP=event.top 
	   END

	   'EDCOMSTR_CROSS': BEGIN
	   	IF N_ELEMENTS(cros_cal_fcspow_str) GT 0 THEN $
	   	  FCSPSTR_SHOW, cros_cal_fcspow_str, GROUP=event.top ELSE $
	   	  XDISPLAYFILE, "", $
                                TITLE = "No cross calibration table", $
                                WIDTH = 35, $
                                HEIGHT = 4, $
                          TEXT = [" Cross calibration process not ", $
                                  " yet performed, friend " ]
           END

	   'EDACTSTRPRE': BEGIN
	   	FCSPRESTR_SHOW, strfcspre, GROUP=event.top 
	   END

	   'EDACTSTRPRE_REPL': BEGIN
	   	IF ch_type EQ 'FCSPRE_STR' THEN $
	   	   strfcsp = ch_struc ELSE $
	   	   PRINT, 'Wrong structure type, nothing replaced'
	   END

	   'EDCOMSTRPRE': BEGIN
	   	FCSPRESTR_SHOW, newstrfcspre, GROUP=event.top 
	   END

	   'WRICOM': BEGIN
			CASE STRMID(detact,0,2) of
			  'P1': p1fcspow = newfcspow
			  'P2': p2fcspow = newfcspow
			  'P3': p3fcspow = newfcspow
			  'C1': c1fcspow = newfcspow
			  'C2': c2fcspow = newfcspow
			ENDCASE
			 fcspow = newfcspow
		END

	   'WRISTR': BEGIN
		write_fcspstr, detact, newstrfcsp
		strfcsp = [strfcsp,newstrfcsp]
	   END

	   'WRISTR_REPL': BEGIN
		write_fcspstr, detact, strfcsp, /REPLACE
	   END

	   'WRISTR_REPL_NEW': BEGIN
		write_fcspstr, detact, newstrfcsp, /REPLACE
		strfcsp = newstrfcsp
	   END

	   'WRISTR_CROSS': BEGIN
		write_fcspstr, detact, cros_cal_fcspow_str
		strfcsp = [strfcsp, cros_cal_fcspow_str]
	   END

	   'WRIPRESTR': BEGIN
		write_fcspre_str, detact, newstrfcspre
		strfcspre = [strfcspre, newstrfcspre]
	   END

	   'WRIPRESTR_REPL': BEGIN
	   	write_fcspre_str, detact, strfcspre, /REPLACE
	   END

	   'WRIPRESTR_REPL_NEW': BEGIN
		write_fcspre_str, detact, newstrfcspre, /REPLACE
		strfcspre = newstrfcspre
	   END

	   'WRICALG': BEGIN
                 pia_write_comment, comment
                 comm = ''
                 FOR I=0,N_ELEMENTS(comment)-1 DO comm = comm+comment(i)
                 pia_write_version, version
                 vers = ''
                 FOR I=0,N_ELEMENTS(version)-1 DO vers = vers+version(i)

		 filnam = 'PIA_'+detact+'_FCSPOW'
		 write_fcspow, filnam, $
			STRMID(detact,0,2), $
			newfcspow, COMMENT=comm, VERSION=vers

                 XDISPLAYFILE, "", $
                                TITLE = "Cal G file written", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" Cal G file written under ", $
                                  filnam+'.FITS' ]

		END

	   'WRICALU': BEGIN

                 pia_write_version, version
                 vers = ''
                 FOR I=0,N_ELEMENTS(version)-1 DO vers = vers+version(i)

                 pia_write_author, author
                 auth = ''
                 FOR I=0,N_ELEMENTS(author)-1 DO auth = auth+author(i)

		 trs_num = trsa + 1

		 fcsstr = STRTRIM(STRING(fcsa+1),2)
		 filnam = !CALSAVE+'PIA_FC'+fcsstr+$
			   '_'+detact+'.TAB'
		 write_asc_fcspow, filnam, fcsstr, trs_num, $
			STRMID(detact,0,2), $
			newfcspow, VERSION=vers, AUTHOR=auth
		 XDISPLAYFILE, "", $
                    		TITLE = "Uplink file written", $
                    		WIDTH = 50, $
                    		HEIGHT = 4, $
                    	  TEXT = [" Uplink file written under ", $
                          	  filnam ]


		END

	   'WRICALU_FCSM': BEGIN

		 pia_write_anything, $
		    'Uplink File to be used as input to be changed', caluf,$
		    proposal = !calu + 'p_pfiltr.txt'
		 caluf = caluf(0) 
		 read_asc_pfiltr, buffer, inputfile = caluf
		 CASE STRMID(detact,0,2) OF
		 'P1': BEGIN
		    	FOR I=0,9 DO BEGIN  
		 	  ind = WHERE(newfcspow(*,i,0,0) GE 50., n)
		 	  IF n GT 0 THEN $
		 	  	buffer(9,i) = longpow(ind(0)) ELSE $
		 	  	buffer(9,i) = longpow(N_ELEMENTS(longpow)-1)
		 	  ind = WHERE(newfcspow(*,i,0,1) GE 50., n)
		 	  IF n GT 0 THEN $
		 	  	buffer(10,i) = longpow(ind(0)) ELSE $
		 	  	buffer(10,i) = longpow(N_ELEMENTS(longpow)-1)
		    	ENDFOR
		       END
		 'P2': BEGIN
		    	FOR I=0,1 DO BEGIN  
		 	  ind = WHERE(newfcspow(*,i,0,0) GE 50., n)
		 	  IF n GT 0 THEN $
		 	  	buffer(9,9+i) = longpow(ind(0)) ELSE $
		 	  	buffer(9,9+i) = longpow(N_ELEMENTS(longpow)-1)
		 	  ind = WHERE(newfcspow(*,i,0,1) GE 50., n)
		 	  IF n GT 0 THEN $
		 	  	buffer(10,9+i) = longpow(ind(0)) ELSE $
		 	  	buffer(10,9+i) = longpow(N_ELEMENTS(longpow)-1)
		    	ENDFOR
		       END
		 'P3': BEGIN
		    	FOR I=0,1 DO BEGIN  
		 	  ind = WHERE(newfcspow(*,i,0,0) GE 50., n)
		 	  IF n GT 0 THEN $
		 	  	buffer(9,11+i) = longpow(ind(0)) ELSE $
		 	  	buffer(9,11+i) = longpow(N_ELEMENTS(longpow)-1)
		 	  ind = WHERE(newfcspow(*,i,0,1) GE 50., n)
		 	  IF n GT 0 THEN $
		 	  	buffer(10,11+i) = longpow(ind(0)) ELSE $
		 	  	buffer(10,11+i) = longpow(N_ELEMENTS(longpow)-1)
		    	ENDFOR
		       END
		  ELSE: BEGIN
		  	 XDISPLAYFILE,"", $
                    		TITLE = "Not applicable", $
                    		WIDTH = 30, $
                    		HEIGHT = 4, $
                    	  	TEXT = [" Chosen detector does not have  ", $
                          	  " corresponding Cal U file elements "]
                          RETURN
		  	END
		  ENDCASE
		 
		 
                 pia_write_version, version
                 vers = ''
                 FOR I=0,N_ELEMENTS(version)-1 DO vers = vers+version(i)

                 pia_write_author, author
                 auth = ''
                 FOR I=0,N_ELEMENTS(author)-1 DO auth = auth+author(i)

		 filnam = !CALSAVE+'PIA_pfiltr.txt'

; update only the FCS which is in use
		 IF fcsa EQ 0 THEN BEGIN
		    write_asc_pfiltr, 10, reform(buffer(9,*)), $
		 	inputfile=caluf, outputfile = filnam, $
			VERSION=vers, AUTHOR = auth
			
		    XDISPLAYFILE, "", $
                    		TITLE = "Uplink file written", $
                    		WIDTH = 50, $
                    		HEIGHT = 4, $
                    	  TEXT = [" Uplink file written under ", $
                          	  filnam ]
		 ENDIF

		 IF fcsa EQ 1 THEN BEGIN 
		    write_asc_pfiltr, 11, reform(buffer(10,*)), $
		 	inputfile=caluf, outputfile = filnam, $
			VERSION=vers, AUTHOR=auth
					 	
		    XDISPLAYFILE, "", $
                    		TITLE = "Uplink file written", $
                    		WIDTH = 50, $
                    		HEIGHT = 4, $
                    	  TEXT = [" Uplink file written under ", $
                          	  filnam ]
		 ENDIF

		END

	   'QUIT': WIDGET_CONTROL, event.top, /DESTROY
		
	   ELSE: 
	ENDCASE
RETURN
END


; *****************************************************************
; *
; *
; * 
; *****************************************************************
PRO PIA_CAL_FCSPOW, GROUP=group

@phtfilter
@phtoptpow
@phtfcs
COMMON pia_fcsp_cmn, dets, detact, filts, filtact, fcsa, trsa, $
		fcspow, newfcspow, wricalg_id, det_id, strfcsp, newstrfcsp,$
		filters, calg_fcspow, strfcspre, newstrfcspre
; the common below is to allocate a 10 elts handle to hold the
; calu files, where 
; index     calu file
;   0       p_fc1_p1.txt
;   1       p_fc1_p1.txt
;   2       p_fc1_p3.txt
;   3       p_fc1_c1.txt
;   4       p_fc1_c2.txt
;   5       p_fc2_p1.txt
;   6       p_fc2_p1.txt
;   7       p_fc2_p3.txt
;   8       p_fc2_c1.txt
;   9       p_fc2_c2.txt
COMMON calu_fcspow, calu_fcs, calu_ind, calu_nkeys, calu_det
COMMON calg_fcs, calg_fcspow_p1, calg_fcspow_p2, calg_fcspow_p3, calg_fcspow_c1, calg_fcspow_c2
COMMON ext_version, ext_version

; Are the common filled up?

	IF N_ELEMENTS(c1filters) EQ 0 THEN PHTFILTER_INIT

; Initial choices: C200 - FCS(1,2)

	dets = ['P1','P2', 'P3', 'C100', 'C200'] 

; the calu index order depends on the order of the above dets
	detact = dets(4)
	fcsa = 0
	trsa = 1
	inval = 'FCS(1,2)'

	orig_name = "PC2FCSPOW"
	get_caltdep_file, orig_name, tdep_name
	read_fcspow, tdep_name + ".FITS"


; init the calu common block, initial calu_index is 

	calu_ind = 4
; for the nkeys in the calu files, where the detectors order is
; P1, P2, P3, C1, C2
; to calculate the calu_ind = fcsa * 5 + calu_det
        calu_nkeys = [21, 5, 5, 15, 11]
	calu_fcs = lonarr(10)
	calu_det = 4

        for i = 0, 4 do begin
	  read_asc_fcspow, '1', strmid(dets(i), 0, 2), temp
          calu_fcs(i) = handle_create()
          handle_value, calu_fcs(i), temp, /set 
	endfor

        for i = 5, 9 do begin
	  read_asc_fcspow, '2', strmid(dets(i-5), 0, 2), temp
          calu_fcs(i) = handle_create()
          handle_value, calu_fcs(i), temp, /set 
	endfor
; filters for different detector, initialize for C200
	filters = 'C200_' + ['160', '200', '180', '135', '120'] + '_UM'
; initialize the calg common block
;	fxread, !CALG+'PP1FCSPOW.FITS', calg_fcspow_p1
;	fxread, !CALG+'PP2FCSPOW.FITS', calg_fcspow_p2
;	fxread, !CALG+'PP3FCSPOW.FITS', calg_fcspow_p3
;	fxread, !CALG+'PC1FCSPOW.FITS', calg_fcspow_c1
;	fxread, !CALG+'PC2FCSPOW.FITS', calg_fcspow_c2
;	calg_fcspow = calg_fcspow_c2

; Write fcspower into the buffers
	fcspow = c2fcspow
	newfcspow = fcspow

; Write FCS tables into the local table - use for new initially old
	export = '(e)'
	posi = STRPOS(!PIA_VERSION,export)

	IF posi EQ -1 THEN BEGIN

 	 filename = !CALSAVE+ 'C2' + 'CALFCSP_STR.SAV'
	 res = findfile(filename, count=count) 	 
 	 filename2 = !CALSAVE+ 'C2' + 'CALFCS_PRE_STR.SAV'
	 res = findfile(filename2, count=count2) 	 
	

	 IF count NE 0 AND count2 NE 0 THEN BEGIN

 	  get_fcspstr, detact, strfcsp
	  newstrfcsp = strfcsp 

	  get_fcspre_str, detact, strfcspre
	  newstrfcspre = strfcspre 
	  ext_version = 0
	 ENDIF ELSE BEGIN
	  XDISPLAYFILE, "", $
              TITLE = "File(s) not found", $
              WIDTH = 80, $
              HEIGHT = 4, $
              TEXT = ["File " + filename + " not found and/or" , $
		      "file " + filename + " not found " , $ 
		      "... will continue without processing possibility"]
	  ext_version = 1    
	 ENDELSE
	ENDIF ELSE ext_version=1

	fcspbase = WIDGET_BASE(TITLE = 'PIA FCS Calibration Curves CFDP Menu', $
                                /COLUMN)

        choicebase = WIDGET_BASE(fcspbase, /ROW)

	det_id = WIDGET_BUTTON(choicebase, VALUE = detact, /MENU)

	FOR I=0,4 DO id_0 = WIDGET_BUTTON(det_id, $
		VALUE=dets(i),UVALUE=dets(i))
  
	fcs_id = WIDGET_BUTTON(choicebase, VALUE = inval, /MENU)
        id_1 = WIDGET_BUTTON(fcs_id, VALUE = 'FCS(1,1)', $
				UVALUE='FCS(1,1)')
        id_1 = WIDGET_BUTTON(fcs_id, VALUE = 'FCS(1,2)', $
				UVALUE='FCS(1,2)')
        id_1 = WIDGET_BUTTON(fcs_id, VALUE = 'FCS(2,1)', $
				UVALUE='FCS(2,1)')
        id_1 = WIDGET_BUTTON(fcs_id, VALUE = 'FCS(2,2)', $
				UVALUE='FCS(2,2)')


        plot_id = WIDGET_BUTTON(choicebase, VALUE = ' Plot ', /MENU)
        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' Actual Values ', /MENU)
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Lego Plot ', $
				UVALUE='PLOTACT' )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Plot Projection ', $
				UVALUE='PLOTACTPROJ' )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' OverPlot Projection ', $
				UVALUE='OPLOTACTPROJ' )
        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' Computed Values ', /MENU)
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Lego Plot ', $
				UVALUE='PLOTCOM' )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Plot Projection ', $
				UVALUE='PLOTCOMPROJ' )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' OverPlot Projection ', $
				UVALUE='OPLOTCOMPROJ' )
        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' CalU Values ', /MENU)
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Plot Projection ', $
				UVALUE='PLOTCLUPROJ' )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' OverPlot Projection ', $
				UVALUE='OPLOTCLUPROJ' )
;        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' CalG Values ', $
;				UVALUE='PLOTCLGPROJ' )
        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' Extracted Values ', /MENU)
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Plot ', $
				UVALUE='PLOTEXT' )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' OverPlot  ', $
				UVALUE='OPLOTEXT' )

	proc_id = WIDGET_BUTTON(choicebase, VALUE= ' Process ', /MENU )

	IF ext_version THEN WIDGET_CONTROL, proc_id, sensitive=0
	
	id_1 = WIDGET_BUTTON(proc_id, $
		VALUE='New values and new Table Records from measurements', $
			UVALUE='PROC')
	id_1 = WIDGET_BUTTON(proc_id, $
		VALUE='New values and Records from measurements (from SRD)', $
			UVALUE='PROC_FSRD')
	id_1 = WIDGET_BUTTON(proc_id, $
		VALUE='New values and Records from measurements (from SCP)', $
			UVALUE='PROC_FSCP')
	id_1 = WIDGET_BUTTON(proc_id, $
			VALUE='New values and Records from Cumulated Table ', /menu)
	id_2 = WIDGET_BUTTON(id_1, VALUE='Full interpolation ', $
			UVALUE='PROC_STR')
	id_2 = WIDGET_BUTTON(id_1, VALUE='Scaling existing curve ', $
			UVALUE='PROC_STR_SCALE')
	id_2 = WIDGET_BUTTON(id_1, $
			VALUE='Scaling existing external curve ', $
			UVALUE='PROC_STR_SCALE_EXT')
	id_2 = WIDGET_BUTTON(id_1, VALUE='Fitting a polynom ',  /MENU)
	id_3 = WIDGET_BUTTON(id_2, VALUE='2nd order polynom ', $
			UVALUE='PROC_STR_FIT2')
	id_3 = WIDGET_BUTTON(id_2, VALUE='3rd order polynom ', $
			UVALUE='PROC_STR_FIT3')
	id_1 = WIDGET_BUTTON(proc_id, VALUE='FCS1-FCS2 cross calibration ', $
			UVALUE='PROC_CROSSCAL')
	id_1 = WIDGET_BUTTON(proc_id, $
		VALUE='Extract points and Records from Cumulated Table ', $
		UVALUE='PROC_STR_EXTR')
			
	edit_id = WIDGET_BUTTON(choicebase, VALUE= ' Edit Values ', /MENU)
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'Actual Values', $
				UVALUE = 'EDACTVAL')
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'Computed Values', $
				UVALUE = 'EDCOMVAL')
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'CalU Values', $
				UVALUE = 'EDCLUVAL')
;	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'CalG Values', $
;				UVALUE = 'EDCLGVAL')

	edit0_id = WIDGET_BUTTON(choicebase, VALUE= 'Cumulated Tables ', /MENU)

	IF ext_version THEN WIDGET_CONTROL, edit0_id, sensitive=0
	

	edit_id = WIDGET_BUTTON(edit0_id, VALUE= 'Internal handling ', /MENU)
	id_1 = WIDGET_BUTTON(edit_id, $
				VALUE = 'Show FCS Data Table Values', $
				UVALUE = 'EDACTSTR')
	id_1 = WIDGET_BUTTON(edit_id, $
				VALUE = 'Replace FCS Data Table Values', $
				UVALUE = 'EDACTSTR_REPL')
	id_1 = WIDGET_BUTTON(edit_id, $
				VALUE = 'Show new computed FCS Table Values', $
				UVALUE = 'EDCOMSTR')
	id_1 = WIDGET_BUTTON(edit_id, $
				VALUE = 'Show CROSS CALibrated FCS Table Values', $
				UVALUE = 'EDCOMSTR_CROSS')

	id_1 = WIDGET_BUTTON(edit_id, $
				VALUE = 'Show Pre-reduced Signal Table Values',$
				UVALUE = 'EDACTSTRPRE')
	id_1 = WIDGET_BUTTON(edit_id, $
				VALUE = 'Replace Pre-reduced Signal Table Values', $
				UVALUE = 'EDACTSTRPRE_REPL')
	id_1 = WIDGET_BUTTON(edit_id, $
			VALUE = 'Show new computed Pre-reduced Table Values', $
				UVALUE = 'EDCOMSTRPRE')

	edit_id = WIDGET_BUTTON(edit0_id, VALUE= 'External handling ', /MENU)
	id_1 = WIDGET_BUTTON(edit_id, $
			VALUE = 'Replace FCS Cumulated Table by Full Table', $
				UVALUE = 'WRISTR_REPL')
	id_1 = WIDGET_BUTTON(edit_id, $
			VALUE = 'Add new FCS Table Records to Cumulated Table', $
				UVALUE = 'WRISTR')
	id_1 = WIDGET_BUTTON(edit_id, $
		VALUE = 'Replace Cumulated Table by new FCS Table Records', $
				UVALUE = 'WRISTR_REPL_NEW')

	id_1 = WIDGET_BUTTON(edit_id, $
			VALUE = 'Add CROSS CALibrated FCS TRecs to Cum. Table', $
				UVALUE = 'WRISTR_CROSS')

	id_1 = WIDGET_BUTTON(edit_id, $
			VALUE = 'Replace Pre-reduced Table by Full Table', $
				UVALUE = 'WRIPRESTR_REPL')
	id_1 = WIDGET_BUTTON(edit_id, $
		VALUE = 'Add new Pre-reduced Table Records to Cumulated Table', $
				UVALUE = 'WRIPRESTR')
	id_1 = WIDGET_BUTTON(edit_id, $
		VALUE = 'Replace Pre-reduced Table by new Table Records', $
				UVALUE = 'WRIPRESTR_REPL_NEW')

	new_calgid = WIDGET_BUTTON(choicebase, VALUE=' New Cal G file ', $
				UVALUE="NEWCALG")


	write_id = WIDGET_BUTTON(choicebase, VALUE = ' Write Values ', /MENU)
	id_1 = WIDGET_BUTTON(write_id, VALUE = 'New values to internal common', $
				UVALUE = 'WRICOM')
	wricalg_id = WIDGET_BUTTON(write_id, VALUE = 'New Values to Cal G file', $
				UVALUE = 'WRICALG')
	wricalu_id = WIDGET_BUTTON(write_id, VALUE = 'New Values to Cal U file', $
				UVALUE = 'WRICALU')
	wricalu2_id = WIDGET_BUTTON(write_id, $
				VALUE = 'Update p_pfiltr Cal U file', $
				UVALUE = 'WRICALU_FCSM')

	quit_id = WIDGET_BUTTON(fcspbase, VALUE = '  Quit  ', $
                        /FRAME, UVALUE = 'QUIT')

        WIDGET_CONTROL, fcspbase, /REALIZE, TLB_SET_XOFFSET=300, $
                        TLB_SET_YOFFSET=50

        xMANAGER,No_BLOCK=1, "pia_cal_fcspow", fcspbase, GROUP=group
	
RETURN
END
