;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_CAL_flatf
;
; PURPOSE:
;	Top level menu for FCS illumination File production, one of
;	the Calibration Files Derivation Procedures (CFDP)  
;
; CATEGORY:
;       PIA - graphics
;
; CALLING SEQUENCE:
;       PIA_CAL_flatf
;
; KEYWORD PARAMETERS:
;	Group=group: Group leader
;
; COMMON BLOCKS:
;	colour_indices
;	phtillum
;	pia_verselectedf_cmn (internal)
; 	pia_flatf_cmn (internal)
;	cflatf_edit_cmn (internal)
;	cal_flatf_cmn (internal)
;		
; PROCEDURES USED:
;	PIA LIB:
;		pia_write_comment
;		pia_write_version
;		pia_xplot
;		read_flatf
;		write_illum
;       ASTRO LIB:
;		fxbclose
;		fxbopen
;		fxbread
;       INTERNAL:
;		flatf_struct_val_choice
;		flatf_edit_event
;		flatf_edit
;		cflatf_edit_event
;		cflatf_edit
;		clg_flatf_edit_event
;		clg_flatf_edit
;		pia_cal_flatf_event
;		
; MODIFICATION HISTORY:
;       Written by: C. Gabriel (ES/ESTEC) 			March 1995
;	Modified (last) by: CG, WMT				Sep 1995
;	Oct 95 Version 3.5
;	Changed for new FCSPOW cumulated structures (CG)	February 1996
;	Re-initialize button added (CG)			November 1997
;	V6.6
;
;-
; ****************************************************************
; *
; ****************************************************************
PRO flatf_EDIT_event, event 

COMMON pia_flatf_cmn, dets, detact, flatf, newflatf, flatu, newflatu, $
	wricalg_id, det_id, fcs, fcsact, strfcsp, filters, filtact, $
	full_flatf, full_flatu, filt_id

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.id, GET_VALUE=value
	CASE uvalue of
	'list': PRINT, event.id, value
	'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
	ENDCASE
END

; ****************************************************************
; *
; ****************************************************************
PRO flatf_EDIT 

COMMON pia_flatf_cmn, dets, detact, flatf, newflatf, flatu, newflatu, $
	wricalg_id, det_id, fcs, fcsact, strfcsp, filters, filtact, $
	full_flatf, full_flatu, filt_id
	
	edbase = WIDGET_BASE(TITLE =detact+' Actual flatfield table', /column)

	edvalbase = WIDGET_BASE(edbase, /row)
	edlabel = WIDGET_LABEL(edvalbase, VALUE = '   Pixel   ')
	edlabel = WIDGET_LABEL(edvalbase, VALUE = '  Factor   ')
	edlabel = WIDGET_LABEL(edvalbase, VALUE = '   Uncertainty')

	pixels = N_ELEMENTS(flatf(*,0))
	pixlist = STRTRIM(STRING(indgen(pixels) + 1),2)
	pixlist = 'Pixel ' + pixlist 

	edvalbase = WIDGET_BASE(edbase, /row)
	edval = WIDGET_TEXT(edvalbase, XSIZE=8, YSIZE=10, $
	  VALUE = pixlist)
	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=10, $
		VALUE = STRTRIM(STRING(flatf)), uvalue='list')
	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=10, $
		VALUE = STRTRIM(STRING(flatu)), uvalue='list')

	quit = WIDGET_BUTTON(edbase, VALUE=' QUIT ', UVALUE='QUIT') 
	WIDGET_CONTROL, edbase, /REALIZE
	xMANAGER,No_BLOCK=1, "flatf_EDIT", edbase, GROUP=group 
	RETURN
END 

; ****************************************************************
; *
; ****************************************************************
PRO Cflatf_EDIT_event, event 

COMMON pia_flatf_cmn, dets, detact, flatf, newflatf, flatu, newflatu, $
	wricalg_id, det_id, fcs, fcsact, strfcsp, filters, filtact, $
	full_flatf, full_flatu, filt_id

COMMON cflatf_edit_cmn, edval_id, edunc_id, pixels 

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue of
	 'LIST': BEGIN
		WIDGET_CONTROL, edval_id, GET_VALUE=value
		IF N_ELEMENTS(value) EQ pixels THEN $
			newflatf = float(value) ELSE BEGIN
                  	XDISPLAYFILE, "", $
                    		TITLE = "Input not accepted", $
                    		WIDTH = 50, $
                    		HEIGHT = 4, $
                    	  TEXT = [" Wrong flatf input  ", $]
                          	  "     ", $ ]
                          	  " Fix it and try again, please "]
			RETURN
		ENDELSE
		WIDGET_CONTROL, edunc_id, GET_VALUE=value
		IF N_ELEMENTS(value) EQ pixels THEN $
			newflatu = float(value) ELSE BEGIN
                  	XDISPLAYFILE, "", $
                    		TITLE = "Input not accepted", $
                    		WIDTH = 50, $
                    		HEIGHT = 4, $
                    	  TEXT = [" Wrong flatf input  ", $]
                          	  "     ", $ ]
                          	  " Fix it and try again, please "]
			RETURN
		ENDELSE
	 END
	 'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
         ELSE: 
	ENDCASE
END

; ****************************************************************
; *
; ****************************************************************
PRO Cflatf_EDIT 

COMMON pia_flatf_cmn, dets, detact, flatf, newflatf, flatu, newflatu, $
	wricalg_id, det_id, fcs, fcsact, strfcsp, filters, filtact, $
	full_flatf, full_flatu, filt_id

COMMON cflatf_edit_cmn, edval_id, edunc_id, pixels 
COMMON cal_flatf_cmn, calg_flatf, calg_flatu, calg_c1cor, calg_c1lun, $
	calg_c2cor, calg_c2lun

	edbase = WIDGET_BASE(TITLE =detact+' Computed FCS '+$
		STRTRIM(STRING(fcsact+1),2)+' illumination tables', /column)

	edvalbase = WIDGET_BASE(edbase, /row)
	edlabel = WIDGET_LABEL(edvalbase, VALUE = '   Pixel   ')
	edlabel = WIDGET_LABEL(edvalbase, VALUE = '  Factor   ')
	edlabel = WIDGET_LABEL(edvalbase, VALUE = '   Uncertainty')

	pixels = N_ELEMENTS(newflatf)
	pixlist = STRTRIM(STRING(indgen(pixels) + 1),2)
	pixlist = 'Pixel ' + pixlist 

	edvalbase = WIDGET_BASE(edbase, /row)
	edval = WIDGET_TEXT(edvalbase, XSIZE=8, YSIZE=10, $
	  VALUE = pixlist)
	edval_id = WIDGET_TEXT(edvalbase, /editable, XSIZE=12, YSIZE=10, $
	  VALUE = STRTRIM(STRING(newflatf),2), UVALUE='JUNK')
	edunc_id = WIDGET_TEXT(edvalbase, /editable, XSIZE=12, YSIZE=10, $
	  VALUE = STRTRIM(STRING(newflatu),2), UVALUE='JUNK')
	edconbase = WIDGET_BASE(edbase, /row)

	ok = WIDGET_BUTTON(edconbase, VALUE='  OK  ', UVALUE='LIST')
	quit = WIDGET_BUTTON(edconbase, VALUE=' QUIT ', UVALUE='QUIT') 
	WIDGET_CONTROL, edbase, /REALIZE
	xMANAGER,No_BLOCK=1, "Cflatf_EDIT", edbase, GROUP=group 
	RETURN
END 

; ****************************************************************
; *
; ****************************************************************
PRO CLG_flatf_EDIT_event, event 

COMMON pia_flatf_cmn, dets, detact, flatf, newflatf, flatu, newflatu, $
	wricalg_id, det_id, fcs, fcsact, strfcsp, filters, filtact, $
	full_flatf, full_flatu, filt_id
COMMON cal_flatf_cmn, calg_flatf, calg_flatu, calg_c1cor, calg_c1lun, $
	calg_c2cor, calg_c2lun

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.id, GET_VALUE=value
	CASE uvalue of
	'list': 
	'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
	ENDCASE
END

; ****************************************************************
; *
; ****************************************************************
PRO CLG_flatf_EDIT 

COMMON pia_flatf_cmn, dets, detact, flatf, newflatf, flatu, newflatu, $
	wricalg_id, det_id, fcs, fcsact, strfcsp, filters, filtact, $
	full_flatf, full_flatu, filt_id
COMMON cal_flatf_cmn, calg_flatf, calg_flatu, calg_c1cor, calg_c1lun, $
	calg_c2cor, calg_c2lun

	edbase = WIDGET_BASE(TITLE =detact+' CALG FCS '+$
		STRTRIM(STRING(fcsact+1),2)+' illumination tables', /column)

	edvalbase = WIDGET_BASE(edbase, /row)
	edlabel = WIDGET_LABEL(edvalbase, VALUE = '   Pixel   ')
	edlabel = WIDGET_LABEL(edvalbase, VALUE = ' Factor ')
	edlabel = WIDGET_LABEL(edvalbase, VALUE = 'Uncertainty')

	pixels = N_ELEMENTS(calg_flatf)
	pixlist = STRTRIM(STRING(indgen(pixels) + 1),2)
	pixlist = 'Pixel ' + pixlist 

	edvalbase = WIDGET_BASE(edbase, /row)
	edval = WIDGET_TEXT(edvalbase, XSIZE=8, YSIZE=10, $
	  VALUE = pixlist)
	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=10, $
		VALUE = STRTRIM(STRING(calg_flatf)), uvalue='list')
	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=10, $
		VALUE = STRTRIM(STRING(calg_flatu)), uvalue='list')

        edconbase = WIDGET_BASE(edbase, /row)
        quit = WIDGET_BUTTON(edconbase, /frame, VALUE=' QUIT ', UVALUE='QUIT')

	WIDGET_CONTROL, edbase, /REALIZE
	xMANAGER,No_BLOCK=1, "CLG_flatf_EDIT", edbase, GROUP=group
	RETURN
END 

; ****************************************************************
; *
; ****************************************************************
PRO PIA_CAL_flatfield_EVENT, event

@phtfilter
@phtffield
@phtftof
@colour_indices
COMMON pia_flatf_cmn, dets, detact, flatf, newflatf, flatu, newflatu, $
	wricalg_id, det_id, fcs, fcsact, strfcsp, filters, filtact, $
	full_flatf, full_flatu, filt_id
COMMON cal_flatf_cmn, calg_flatf, calg_flatu, calg_c1cor, calg_c1lun, $
	calg_c2cor, calg_c2lun


	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	i = WHERE(dets EQ uvalue, n)
	i = i(0)
	IF n NE 0 THEN uvalue = 'DET' ELSE BEGIN
	 i = WHERE(fcs EQ uvalue, n)
	 i = i(0)
	 IF n NE 0 THEN uvalue = 'FCS'
	ENDELSE

	CASE uvalue of

	   'DET': BEGIN
	   		WIDGET_CONTROL, det_id, SET_VALUE=dets(i)
			detact = dets(i)
			
			CASE STRMID(detact,0,2) OF
				'C1': BEGIN
					filtact = 1
					full_flatf=c1flatf
					full_flatu=c1flatu
					flatf = reform(c1flatf(*,filtact))
					flatu = reform(c1flatu(*,filtact))
		 		  	filters = c1filters
					WIDGET_CONTROL, filt_id, $
					  SET_VALUE=filters(filtact)
				END
				'C2': BEGIN
					filtact = 1
					full_flatf=c2flatf
					full_flatu=c2flatu
					flatf = reform(c2flatf(*,filtact))
					flatu = reform(c2flatu(*,filtact))
		 		  	filters = c2filters
					filtact = 1
					WIDGET_CONTROL, filt_id, $
					  SET_VALUE=filters(filtact)
				END
				'P#': BEGIN
					filtact = 1
					full_flatf=TRANSPOSE(ppftof)
					full_flatu=TRANSPOSE(ppftofu)
					flatf = reform([ppftof(filtact)])
					flatu = reform([ppftofu(filtact)])
		 		  	filters = $
						[p1filters,p2filters,p3filters]
					filtact = 1
					WIDGET_CONTROL, filt_id, $
					  SET_VALUE=filters(filtact)
				END
                        ENDCASE
			newflatf = flatf
			newflatu = flatu
		  END	

	   	  
	   'FILTER': BEGIN
	   		pia_multchoice, filtact, ELEMNAMES=filters
	   		filtact = filtact(0)
	   		WIDGET_CONTROL, event.id, SET_VALUE=filters(filtact)
			flatf = reform(full_flatf(*,filtact))
			flatu = reform(full_flatu(*,filtact))
			newflatf = flatf
			newflatu = flatu
	   END
	   		
	  	   
	   
	   'PLOTACT': BEGIN 
			xind = indgen(N_ELEMENTS(flatf(*,0))) + 1
			gtitle = filters(filtact) 
			PIA_XPLOT, xind, flatf, flatu,$
			 psym=4, $
			 title= gtitle + ' default flatfield factors', $
				xtitle = ' Pixel ', $
				ytitle = 'Flatfield factor', $
				legend = gtitle   
		      END

	   'OPLOTACT': BEGIN 
			xind = indgen(N_ELEMENTS(flatf)) + 1
			gtitle = filters(filtact) 
			PIA_XPLOT, xind, flatf, flatu, $
				psym = 6, color = yellow, $
			 title= gtitle + ' default flatfield factors', $
				xtitle = ' Pixel ', $
				ytitle = 'Flatfield factor', $
				legend = gtitle, overplot = 99		
		      END

	   'PLOTCOM': BEGIN 
			gtitle = filters(filtact) 
			IF N_ELEMENTS(newflatf) NE 0 THEN BEGIN
			 xind = indgen(N_ELEMENTS(newflatf)) + 1
			 PIA_XPLOT, xind, newflatf, $
				newflatu, psym=4, $
			   title=gtitle + ' computed flatfield factors', $
				xtitle = ' Pixel ', $
				ytitle = 'Flatfield factor', $
				legend = gtitle   
                        ENDIF ELSE MESSAGE, /INFO, $
				'Sorry, no new flatfields computed'
		      END

	   'OPLOTCOM': BEGIN 
			gtitle = filters(filtact) 
			IF N_ELEMENTS(newflatf) NE 0 THEN BEGIN
			 xind = indgen(N_ELEMENTS(newflatf)) + 1
			 PIA_XPLOT, xind, newflatf, $
				newflatu, psym = 6, color = yellow, $
			  title=gtitle+ ' computed flatfield factors', $
				xtitle = ' Pixel ', $
				ytitle = 'Flatfield factor', $
				legend = gtitle, overplot = 99		
                        ENDIF ELSE MESSAGE, /INFO, $
				'Sorry, no new flatfields computed'
		      END

	   
	   'EDACTVAL': flatf_EDIT

	   'EDCOMVAL': Cflatf_EDIT

	   'EDCLGVAL': CLG_flatf_EDIT

	   'WRICOM': BEGIN
			CASE STRMID(detact,0,2) OF
				'C1': BEGIN
					c1flatf(*,filtact) = newflatf
					c1flatu (*,filtact)= newflatu
					full_flatf = c1flatf
					full_flatu = c1flatu
				END
				'C2': BEGIN
					c2flatf(*,filtact) = newflatf
					c2flatu(*,filtact) = newflatu
					full_flatf = c2flatf
					full_flatu = c2flatu
				END
                        ENDCASE
                 flatf = newflatf
		 flatu = newflatu
		
		 WIDGET_CONTROL, wricalg_id, /sensitive
		END

	   'WRICALG': BEGIN
		 pia_write_comment, comment
		 comm = ''
		 FOR I=0,N_ELEMENTS(comment)-1 DO comm = comm+comment(i)

		 IF STRMID(detact,0,2) EQ 'C1' THEN filename = 'PC1FLAT' $
		 		ELSE filename = 'PC2FLAT'

		 fullfl= full_flatf
		 fullfu= full_flatu
		 IF STRMID(detact,0,2) EQ 'C2' THEN BEGIN
		   c2p_ia2pipe, full_flatf, fullfl
		   c2p_ia2pipe, full_flatu, fullfu
		 ENDIF
		 
		 fullarr = fullfl
		 boost_array, fullarr, fullfu
		 		 
		 
		 create_pfits, filename, fullarr, username="PIA", $
		    comment=comm, version=!PIA_VERSION 
		 WIDGET_CONTROL, wricalg_id, sensitive=0
		END

	   'QUIT': WIDGET_CONTROL, event.top, /DESTROY
		
	   'INIT': BEGIN
	   	read_flatfield
		IF detact EQ 'C100' THEN BEGIN
		      filters = c1filters
		      full_flatf = c1flatf
		      full_flatu = c1flatu
		ENDIF ELSE BEGIN
		      filters = c2filters
		      full_flatf = c2flatf
		      full_flatu = c2flatu
		ENDELSE
							 
		flatf = reform(full_flatf(*,filtact)) 
		flatu = reform(full_flatu(*,filtact)) 
		newflatf = flatf
		newflatu = flatu
	    END	    
	   
	   ELSE: 
	ENDCASE
RETURN
END

; ****************************************************************
; *
; *
; *
; ****************************************************************
PRO PIA_CAL_FLATFIELD, GROUP=group
                                                                           
@phtffield
@phtfilter
COMMON pia_flatf_cmn, dets, detact, flatf, newflatf, flatu, newflatu, $
	wricalg_id, det_id, fcs, fcsact, strfcsp, filters, filtact, $
	full_flatf, full_flatu, filt_id
COMMON cal_flatf_cmn, calg_flatf, calg_flatu, calg_c1cor, calg_c1lun, $
	calg_c2cor, calg_c2lun

	dets = ['C100', 'C200', 'P#'] 
	fcs = ['FCS1', 'FCS2'] 

	detact = dets(0)
	fcsact = 0


	IF N_ELEMENTS(c1filters) EQ 0 THEN PHTFILTER_INIT
	filters = c1filters
	filtact = 1

	IF N_ELEMENTS(c1flatf) EQ 0 THEN read_flatfield
		
	full_flatf = c1flatf
	full_flatu = c1flatu
	flatf = reform(c1flatf(*,filtact))
	newflatf = flatf
	flatu = reform(c1flatu(*,filtact))
	newflatu = flatu

	illubase = WIDGET_BASE(TITLE ='PIA Flat Field Calibration Menu', $
                                /COLUMN)

        choicebase = WIDGET_BASE(illubase, /ROW)

	det_id = WIDGET_BUTTON(choicebase, VALUE = detact, /MENU)

	FOR I=0,2 DO id_0 = WIDGET_BUTTON(det_id, VALUE=dets(i),UVALUE=dets(i))

  	filt_id = WIDGET_BUTTON(choicebase, VALUE = filters(filtact), $
				UVALUE="FILTER")

        plot_id = WIDGET_BUTTON(choicebase, VALUE = ' Plot ', /MENU)
        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' Actual Values ', /MENU )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Plot  ', $
        		UVALUE='PLOTACT')
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Overplot ', $
        		UVALUE='OPLOTACT')
        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' Computed Values ', /MENU)
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Plot ', $
        	UVALUE='PLOTCOM')
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Overplot ', $
        	UVALUE='OPLOTCOM')

	edit_id = WIDGET_BUTTON(choicebase, VALUE= ' Edit Values ', /MENU)
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'Actual Values', $
				UVALUE = 'EDACTVAL')
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'Computed Values', $
				UVALUE = 'EDCOMVAL')

	write_id = WIDGET_BUTTON(choicebase, VALUE = ' Write Values ', /MENU)
	id_1 = WIDGET_BUTTON(write_id, VALUE = 'to internal common', $
				UVALUE = 'WRICOM')
	wricalg_id = WIDGET_BUTTON(write_id, VALUE = 'to Cal G file', $
				UVALUE = 'WRICALG')
	WIDGET_CONTROL, wricalg_id, SENSITIVE=0	

	init_id = WIDGET_BUTTON(choicebase, VALUE = ' Re-initialize ', $
			UVAL="INIT")

	quit_id = WIDGET_BUTTON(illubase, VALUE = '  Quit  ', $
                        /FRAME, UVALUE = 'QUIT')

        WIDGET_CONTROL, illubase, /REALIZE, TLB_SET_XOFFSET=300, $
                        TLB_SET_YOFFSET=50

        xMANAGER,No_BLOCK=1, "pia_cal_flatfield", illubase, GROUP=group
	
RETURN
END
