;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_CAL_footpr
;
; PURPOSE:
;	Menu for accessing and plotting the calibration files P#FOOTPR  
;
; CATEGORY:
;       PIA - graphics
;
; CALLING SEQUENCE:
;       PIA_CAL_footpr
;
; KEYWORD PARAMETERS:
;	Group=group: Group leader
;
; COMMON BLOCKS:
;	phtfilter
;		
; PROCEDURES USED:
;	PIA LIB:
;		pia_xsurface
;		read_footpr
;       ASTRO LIB:
;		fxread
;       INTERNAL:
;		pia_cal_footpr_event
;		
; MODIFICATION HISTORY:
;       Written by: C. Gabriel (ESA/VILSPA) 			July 1998
;	V7.2
;
;-
; ****************************************************************
; *
; ****************************************************************
; ****************************************************************
; *
; ****************************************************************
PRO PIA_CAL_footpr_EVENT, event

@phtfilter

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.top, GET_UVALUE=all_ids

	i = WHERE(all_ids.dets EQ uvalue, n)
	i = i(0)
	IF n NE 0 THEN uvalue = 'DET' 

	CASE uvalue of

	   'DET': BEGIN
	   		WIDGET_CONTROL, all_ids.det_id, SET_VALUE=all_ids.dets(i)
			detact = all_ids.dets(i)
			all_ids.detact = detact
			
			CASE STRMID(detact,0,2) OF
			  'C1': BEGIN
				WIDGET_CONTROL, all_ids.aper_id, sensitive=0
				filtact = 1
		 		filters = c1filters
				handle_value, all_ids.filters, filters, /set
				WIDGET_CONTROL, all_ids.filt_id, $
					  SET_VALUE=filters(filtact)
				read_footpr, detact, fpr
				handle_value, all_ids.footp, fpr, /SET
				red_footp = REFORM(fpr(filtact,*,*))
				handle_value, all_ids.red_footp, red_footp, /SET				
				
			  END
			  'C2': BEGIN
				WIDGET_CONTROL, all_ids.aper_id, sensitive=0
				filtact = 1
		 		filters = c2filters
				filtact = 1
				handle_value, all_ids.filters, filters, /set
				WIDGET_CONTROL, all_ids.filt_id, $
					  SET_VALUE=filters(filtact)
				read_footpr, detact, fpr
				handle_value, all_ids.footp, fpr, /SET
				red_footp = REFORM(fpr(filtact,*,*))
				handle_value, all_ids.red_footp, red_footp, /SET				
			  END
 			  'P2': BEGIN
				WIDGET_CONTROL, all_ids.aper_id, sensitive=1
				filtact = 1
		 		filters = p2filters
				apact = 0
				handle_value, all_ids.filters, filters, /set
				WIDGET_CONTROL, all_ids.filt_id, $
					  SET_VALUE=filters(filtact)
				WIDGET_CONTROL, all_ids.aper_id, $
					  SET_VALUE=all_ids.apert(apact)
				read_footpr, detact, fpr
				handle_value, all_ids.footp, fpr, /SET
				red_footp = REFORM(fpr(filtact,apact,*,*))
				handle_value, all_ids.red_footp, red_footp, /SET				
			  END
			  'P3': BEGIN
				WIDGET_CONTROL, all_ids.aper_id, sensitive=1
				filtact = 1
		 		filters = p3filters
				filtact = 1
				apact = 0
				handle_value, all_ids.filters, filters, /set
				WIDGET_CONTROL, all_ids.filt_id, $
					  SET_VALUE=filters(filtact)
				WIDGET_CONTROL, all_ids.aper_id, $
					  SET_VALUE=all_ids.apert(apact)
				read_footpr, detact, fpr
				handle_value, all_ids.footp, fpr, /SET
				red_footp = REFORM(fpr(filtact,apact,*,*))
				handle_value, all_ids.red_footp, red_footp, /SET				
			  END
                       ENDCASE
		  END	

	   	  
	   'FILTER': BEGIN
	   		handle_value, all_ids.filters, filters
	   		pia_multchoice, filtact, ELEMNAMES=filters
	   		filtact = filtact(0)
			all_ids.filtact = filtact
	   		WIDGET_CONTROL, event.id, SET_VALUE=filters(filtact)
			handle_value, all_ids.footp, fpr
			IF STRMID(all_ids.detact,0,1) EQ 'C' THEN $
			 red_footp = REFORM(fpr(filtact,*,*)) ELSE $
			 red_footp = $
			  REFORM(fpr(filtact,all_ids.apact,*,*))

			handle_value, all_ids.red_footp, red_footp, /SET
			
			
	   END
	   		
	  	   
	   'APERT': BEGIN
	   		pia_multchoice, apact, ELEMNAMES=all_ids.apert
	   		apact = apact(0)
			all_ids.apact = apact
	   		WIDGET_CONTROL, event.id, SET_VALUE=all_ids.apert(apact)
			handle_value, all_ids.footp, fpr
			red_footp = $
			  REFORM(fpr(all_ids.filtact,apact,*,*))
			handle_value, all_ids.red_footp, red_footp, /SET
			
			
	   END
	   		
	   
	   'SURF': BEGIN 
	   		handle_value, all_ids.red_footp, red_footp
			PIA_XSURFACE, red_footp, Title='Footprint Image'
		      END


	   'QUIT': WIDGET_CONTROL, event.top, /DESTROY
		
	   
	   ELSE: 
	ENDCASE

	IF uvalue NE 'QUIT' THEN $
	WIDGET_CONTROL, event.top, SET_UVALUE=all_ids

RETURN
END

; ****************************************************************
; *
; *
; *
; ****************************************************************
PRO PIA_CAL_FOOTPR, GROUP=group
                                                                           
@phtfilter


	dets = ['P2', 'P3', 'C100', 'C200'] 
	apert = ['52"', '79"', '99"', '120"', '127"x127"', '180"', '180Block', $
                 '5"', '7.6"', '10"', '13.8"', '18"', '20"x32"', '23"' ]

	detact = dets(0)
	apact = 0


	IF N_ELEMENTS(c1filters) EQ 0 THEN PHTFILTER_INIT
	filters = p2filters
	filtact = 1

	read_footpr, detact, fpr, error=error
	IF error THEN RETURN

	fpbase = WIDGET_BASE(TITLE ='PIA Footprints Calibration Menu', $
                                /COLUMN)

        choicebase = WIDGET_BASE(fpbase, /ROW)

	det_id = WIDGET_BUTTON(choicebase, VALUE = detact, /MENU)

	FOR I=0,3 DO id_0 = $
	   WIDGET_BUTTON(det_id, VALUE=dets(i),UVALUE=dets(i), XSIZE=40)

  	filt_id = WIDGET_BUTTON(choicebase, VALUE = filters(filtact), $
				UVALUE="FILTER", XSIZE=60)

  	aper_id = WIDGET_BUTTON(choicebase, VALUE = apert(apact), $
				UVALUE="APERT", XSIZE=60)

        plot_id = WIDGET_BUTTON(choicebase, VALUE = ' Surface ', UVAL="SURF")

	quit_id = WIDGET_BUTTON(fpbase, VALUE = '  Quit  ', $
                        /FRAME, UVALUE = 'QUIT')

        WIDGET_CONTROL, fpbase, /REALIZE, TLB_SET_XOFFSET=300, $
                        TLB_SET_YOFFSET=50

	footp = HANDLE_CREATE()
	handle_value, footp, fpr, /SET

	h_filter = HANDLE_CREATE()
	handle_value, h_filter, filters, /SET

	red_footp = HANDLE_CREATE()
	red_fpr = REFORM(fpr(filtact,apact,*,*))
	handle_value, red_footp, red_fpr, /SET


	all_ids = {footp:footp, red_footp:red_footp, detact:detact, $
		     filtact:filtact, apact:apact, filt_id:filt_id, $
	             aper_id:aper_id, dets:dets, apert:apert, $
		     filters:h_filter, det_id:det_id} 
	WIDGET_CONTROL, fpbase, SET_UVALUE= all_ids

        xMANAGER,No_BLOCK=1, "pia_cal_footpr", fpbase, GROUP=group
	
RETURN
END
