;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_CAL_FPGC
;
; PURPOSE:
;	Top level menu for Focal Plane Geometry calibration 
;
; CATEGORY:
;       PIA - graphics
;
; CALLING SEQUENCE:
;       PIA_CAL_FPGC
;
; KEYWORD PARAMETERS:
;	GROUP=group: Group leader
;
; COMMON BLOCKS:
;	colour_indices
;	pia_multi_fit_results (internal)
;	pia_cal_fpgc_cmn (internal)
;	pia_cal_fpgres (internal)
;
; PROCEDURES USED:
;	PIA LIB:
;		fpg_cross
;		fpgc_manager
;		interpol_fpgc
;		pia_disp_print_file
;		pia_xplot
;       INTERNAL:
;		pia_cal_fpgc_event
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel (ESA/ESTEC)		September 1995
;	Modified by: cg					October 1995
;	Oct 95 Version 3.5
;	Scan direction bug fixed, CG			October 1995
;			
;-
; *******************************************************************
; *
; *******************************************************************
PRO PIA_CAL_FPGC_event, event

@colour_indices
COMMON pia_multi_fit_results, 	xmf1, ymf1, parmf1, sigmf1, $
				xmf2, ymf2, parmf2, sigmf2

COMMON pia_cal_fpgc_cmn, fpgc_id, iscp_id, act_fpgcfile, act_iscpfile, $
		act_scanpixl, act_scancoor, x_id, y_id, pixl_id, scan_id  
COMMON pia_cal_fpgres, centre

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue of

	   'PIXL': BEGIN
		WIDGET_CONTROL, event.id, GET_VALUE=pixl
	   	act_scanpixl = pixl(0)
	   END
	    
	   'COOR': BEGIN
		WIDGET_CONTROL, event.id, GET_VALUE=coor
	   	act_scancoor = STRTRIM(STRUPCASE(coor(0)),2)
	   	IF act_scancoor NE "Y" and act_scancoor NE "Z" THEN BEGIN
	   		Xdisplayfile, "", group=event.top, $
	   			TEXT="Wrong coordinates, setting it back"
	   		act_scancoor = "Y"
	   	ENDIF
	   END
	   
	   'SFPGC': BEGIN 
	   	fpgc_manager
	   END

	   'STAKE': WIDGET_CONTROL, fpgc_id, SET_VALUE=act_fpgcfile
	   	   	
	   'SSCPF': BEGIN
	   	file = pickfile(PATH=!INTDIR, FILTER='*.ISCP', /READ,$
	   		GROUP=event.top)
	   	act_iscpfile = file(0)
	   	WIDGET_CONTROL, iscp_id, SET_VALUE=act_iscpfile
	   END  

	   'SCANAUT': BEGIN
		WIDGET_CONTROL, pixl_id, GET_VALUE=act_scanpixl
	   	WIDGET_CONTROL, fpgc_id, GET_VALUE=act_fpgcfile
	   	WIDGET_CONTROL, iscp_id, GET_VALUE=act_iscpfile
	   	WIDGET_CONTROL, scan_id, GET_VALUE=act_scancoor
	   	act_fpgcfile = act_fpgcfile(0) 
	   	act_scanpixl = act_scanpixl(0)
	   	act_iscpfile = act_iscpfile(0)
	   	act_scancoor = act_scancoor(0)
	   	fpg_cross, act_iscpfile, act_fpgcfile, centre, INTER="N", $
			PIXEL=act_scanpixl, SCAN=act_scancoor

                TEXT = [" Center moment calculation ", $ 
			" ========================= ", ' ']                   		
                TEXT = [TEXT, " For ISCP file "+ act_iscpfile + " and ",  $
                          	   "   FPGC file "+ act_fpgcfile, " " ]

                FOR i=0, N_ELEMENTS(centre(0,*))-1 DO $ 
		 TEXT = [TEXT, "Pixel "+ STRTRIM(STRING(I+1),2), $
                          	   "Central pos. 1st Scan = " + $
                          	   STRTRIM(STRING(centre(0,i)),2),  $ 
				   " ", "Central pos. 2nd Scan = " + $
                          	   STRTRIM(STRING(centre(1,i)),2) ]

		avr = TOTAL(centre)/N_ELEMENTS(centre)
		TEXT = [TEXT, " ", "Average of all pixels: " + $
				STRTRIM(STRING(avr),2) ]

		pia_disp_print_file, "FPGC_Results", $
                    	   TITLE = "Scan results", $
                    	   WIDTH = 30, $
                    	   HEIGHT = 40, $
                    	   TEXT = text
	
	   END


	   'PRSCRES': BEGIN
	   
		IF N_ELEMENTS(centre) EQ 0 THEN RETURN
		
		TEXT = [" Function Fit Results "]
		TEXT = [TEXT, " ==================", " "]
                TEXT = [TEXT, " For ISCP file "+ act_iscpfile + " and ",  $
                          	   "   FPGC file "+ act_fpgcfile ]
                          	   
		TEXT = [TEXT, " ", "Fitting parameters found (forwards):"]
		FOR I=0,n_elements(parmf1)-1 DO $
			TEXT=[TEXT,STRING(parmf1(i))+" +/- "+STRING(sigmf1(i))]

		TEXT= [TEXT," "]
		TEXT = [TEXT, " ", "Fitting parameters found (backwards):"]
		FOR I=0,n_elements(parmf2)-1 DO $
			TEXT=[TEXT,STRING(parmf2(i))+" +/- "+STRING(sigmf2(i))]


		TEXT= [TEXT," "]
                TEXT = [TEXT, "--------------------------------", $
				" Center moment calculation ", $ 
				" ========================= ", ' ']
                FOR i=0, N_ELEMENTS(centre(0,*))-1 DO $ 
                 TEXT = [TEXT,"Pixel "+ STRTRIM(STRING(I+1),2), $
                          	   "Central pos. 1st Scan = " + $
                          	   STRTRIM(STRING(centre(0,i)),2),  $ 
				   " ", "Central pos. 2nd Scan = " + $
                          	   STRTRIM(STRING(centre(1,i)),2) ]

		avr = TOTAL(centre)/N_ELEMENTS(centre)
		TEXT = [TEXT, " ", "Average of all pixels: " + $
				STRTRIM(STRING(avr),2) ]

		pia_disp_print_file, "FPGC_Results", $
                    	   TITLE = "Scan results", $
                    	   WIDTH = 30, $
                    	   HEIGHT = 40, $
                    	   TEXT = text

	   END

	   'PLSCRES': BEGIN
		 WIDGET_CONTROL, pixl_id, GET_VALUE=act_scanpixl
	   	 xxplfit = indgen(N_ELEMENTS(xmf1)*10) * (max(xmf1) $
	   	 	- min(xmf1)) / (N_ELEMENTS(xmf1)*10) + min(xmf1) 
 		 xxplfit = [xxplfit, max(xmf1)]
		 fct_sum, xmf1, parmf1, yfit
		 fct_sum, xxplfit, parmf1, yyplfit
		 title="Scan Results forwards - Pixel " + act_scanpixl(0)
		 
		 pia_xplot, xmf1, ymf1, psym=4, $
		 	title=title, $
		 	legend= "Measured points", annotation="Files used:"
		 pia_xplot, xmf1, yfit, color = red, psym=5, overplot=99, $
		 	legend="Fitted points", annotation=act_iscpfile	
		 pia_xplot, xxplfit, yyplfit, color=red, overplot=99, $
		 	legend="Fitted function", annotation=act_fpgcfile

	   	 xxplfit = indgen(N_ELEMENTS(xmf2)*10) * (max(xmf2) $
	   	 	- min(xmf2)) / (N_ELEMENTS(xmf2)*10) + min(xmf2) 
 		 xxplfit = [xxplfit, max(xmf2)]
		 fct_sum, xmf2, parmf2, yfit
		 fct_sum, xxplfit, parmf2, yyplfit
		 title="Scan Results backwards - Pixel " + act_scanpixl(0)

		 pia_xplot, xmf2, ymf2, psym=4, title=title, $
		 	legend= "Measured points", annotation="Files used:"
		 pia_xplot, xmf2, yfit, color = red, psym=5, /overplot, $
		 	legend="Fitted points", annotation=act_iscpfile 		
		 pia_xplot, xxplfit, yyplfit, color=red, /overplot, $
		 	legend="Fitted function", annotation=act_fpgcfile

	   END

	   'SCANINT': BEGIN
	   	WIDGET_CONTROL, event.top, /hourglass

		WIDGET_CONTROL, pixl_id, get_VALUE=act_scanpixl
		WIDGET_CONTROL, scan_id, get_VALUE=act_scancoor
	   	WIDGET_CONTROL, fpgc_id, get_VALUE=act_fpgcfile
	   	WIDGET_CONTROL, iscp_id, get_VALUE=act_iscpfile
	   	act_fpgcfile = act_fpgcfile(0)
	   	act_iscpfile = act_iscpfile(0)
	   	act_scancoor = act_scancoor(0)
	   	act_scanpixl = act_scanpixl(0)
	   	fpg_cross, act_iscpfile, act_fpgcfile, centre,INTER="Y", $
			PIXEL=act_scanpixl, SCAN=act_scancoor


	   END

	   'INTER': BEGIN
	   	WIDGET_CONTROL, x_id, get_VALUE=xstr
		x = FLOAT(xstr)
	   	WIDGET_CONTROL, y_id, get_VALUE=ystr
		y = FLOAT(ystr)
		IF N_ELEMENTS(x) EQ 0 or N_ELEMENTS(y) EQ 0 THEN BEGIN
			MESSAGE,/info, ' Raster coordinates not defined'
			RETURN
		ENDIF
	   	interpol_fpgc, act_fpgcfile, x(0), y(0), scy, scz
		text = ["The interpolation of raster coordinates", $
			"x = "+ xstr + "   and    y = "+ ystr , $
			"yields ", $
			"SC Y = "+STRTRIM(STRING(scy),2) +  "  and  " +$ 
			"SC Z = "+STRTRIM(STRING(scz),2)] 
		pia_disp_print_file, "FPGC Coordinates Interpolation", $
                    	   TITLE = "Results", $
                    	   WIDTH = 30, $
                    	   HEIGHT = 40, $
                    	   TEXT = text
	   END
	   
	   'QUIT': WIDGET_CONTROL, event.top, /DESTROY
		
	   ELSE: 
	ENDCASE
RETURN
END

; *******************************************************************
; *
; *
; *
; *******************************************************************
PRO PIA_CAL_FPGC, GROUP=group


COMMON pia_cal_fpgc_cmn, fpgc_id, iscp_id, act_fpgcfile, act_iscpfile, $
		act_scanpixl, act_scancoor, x_id, y_id, pixl_id, scan_id  


	export = '(e)'
	posi = STRPOS(!PIA_VERSION,export)
	IF posi NE -1 THEN BEGIN
	   MESSAGE, /INFO, 'Not available for this version, returning'
	   RETURN
	ENDIF

	IF N_ELEMENTS(act_fpgcfile) EQ 0 THEN act_fpgcfile = ""
	IF N_ELEMENTS(act_iscpfile) EQ 0 THEN act_iscpfile = ""
	IF N_ELEMENTS(act_scanpixl) EQ 0 THEN act_scanpixl = '1'
	IF N_ELEMENTS(act_scancoor) EQ 0 THEN act_scancoor = "Y" ELSE $
		IF STRUPCASE(act_scancoor(0)) NE "Z" THEN act_scancoor="Y"
	
	
	fpgcbase = $
	    WIDGET_BASE(TITLE = 'PIA Focal Plane Geometry Calibration Menu', $
                                /COLUMN)

        filebase = WIDGET_BASE(fpgcbase, /row)

	fpgc_id = WIDGET_LABEL(filebase, VALUE='FPGC file:')
	fpgc_id = WIDGET_TEXT(filebase, /editable, VALUE=act_fpgcfile, $
		UVALUE='junk', XSIZE=45)
	search_but = WIDGET_BUTTON(filebase, VALUE='Search', UVALUE='SFPGC')
	search_but = WIDGET_BUTTON(filebase, VALUE='Take it', UVALUE='STAKE')
		
        filebase = WIDGET_BASE(fpgcbase, /row)

	iscp_id = WIDGET_LABEL(filebase, VALUE='ISCP file:')
	iscp_id = WIDGET_TEXT(filebase, /editable, VALUE=act_iscpfile, $
		UVALUE='junk',XSIZE=45)
	search_but = WIDGET_BUTTON(filebase, VALUE='Search', UVALUE='SSCPF')

        filebase = WIDGET_BASE(fpgcbase, /row)

	pixl_id = WIDGET_LABEL(filebase, $
		VALUE='Pixel for Scan Interactive Fitting:')
	pixl_id = WIDGET_TEXT(filebase, /editable, VALUE=act_scanpixl, $
		UVALUE='PIXL', XSIZE=4)
		
        filebase = WIDGET_BASE(fpgcbase, /row)

	scan_id = WIDGET_LABEL(filebase,VALUE='Scan Raster Direction (Y or Z):')
	scan_id = WIDGET_TEXT(filebase, /editable, VALUE=act_scancoor, $
		UVALUE='COOR', XSIZE = 4)
		

        actbase = WIDGET_BASE(fpgcbase, /row)
	cross_id = WIDGET_LABEL(actbase, VALUE = 'Cross Scan:')
        id_1 = WIDGET_BUTTON(actbase, VALUE = 'Central Moment', UVALUE="SCANAUT")
	id_1 = WIDGET_BUTTON(actbase, VALUE = 'Function Fit', UVALUE="SCANINT") 
	id_1 = WIDGET_BUTTON(actbase, $
		VALUE = 'Print results', UVALUE="PRSCRES")
	id_1 = WIDGET_BUTTON(actbase, VALUE="Plot results", UVALUE="PLSCRES")

	lab = WIDGET_LABEL(fpgcbase, VALUE='    ')
	lab = WIDGET_LABEL(fpgcbase, $
		VALUE='Interpolation to S/C coordinates (only for raster maps)')
        actbase = WIDGET_BASE(fpgcbase, /row)
	x_id = WIDGET_LABEL(actbase, VALUE='X-Coord:')
	x_id = WIDGET_TEXT(actbase, /editable, VALUE=" ", $
		UVALUE='junk',XSIZE=5)
	y_id = WIDGET_LABEL(actbase, VALUE='Y-Coord:')
	y_id = WIDGET_TEXT(actbase, /editable, VALUE=" ", $
		UVALUE='junk',XSIZE=5)
	id_1 = WIDGET_BUTTON(actbase, VALUE = 'Interpolate', UVALUE="INTER") 

	
	quit_id = WIDGET_BUTTON(fpgcbase, VALUE = '  Quit  ', $
                         UVALUE = 'QUIT')

        WIDGET_CONTROL, fpgcbase, /REALIZE, TLB_SET_XOFFSET=300, $
                        TLB_SET_YOFFSET=50

        xMANAGER,No_BLOCK=1, "pia_cal_fpgc", fpgcbase, GROUP=group
RETURN
END
