;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_CAL_NDRSEL
;
; PURPOSE:
;	Top level menu for NDR general Selection File production
;
; CATEGORY:
;       PIA - graphics
;
; CALLING SEQUENCE:
;       PIA_CAL_NDRSEL
;
; KEYWORD PARAMETERS:
;	GROUP=group: Group leader
;
; COMMON BLOCKS:
;	colour_indices
;	phtselndr
;	pia_ndrsel_cmn (internal)
;	cndrs_edit_cmn (internal)
;	cal_ndrsel_cmn (internal)
;
; PROCEDURES USED:
;	PIA LIB:
;		pia_write_comment
;		pia_write_version
;		read_selndr
;		write_selndr
;       ASTRO LIB:
;		boost_array
;		fxbclose
;		fxbopen
;		fxbread
;       INTERNAL:
;		ndrsel_edit_event
;		ndrsel_edit
;		cndrsel_edit_event
;		cndrsel_edit
;		pia_cal_ndrsel_event
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel (ESA/ESTEC)		March 1995
;	Modified (last) by: cg, wmt			September 1995
;	Oct 95 Version 3.5
;	Re-initialize button added (CG)			November 1997
;	V6.6
;	/Modal use according to IDL >=5.0 (CG)		February 1999
;	V7.3.1
;
;-
; *********************************************************************
; *
; *********************************************************************
PRO NDRSEL_EDIT_event, event 

COMMON pia_ndrsel_cmn, dets, detact, ndrsel, newndrsel, $
	wricalg_id, det_id

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.id, GET_VALUE=value
	CASE uvalue of
	'list': PRINT, event.id, value
	'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
	ENDCASE
END

; *********************************************************************
; *
; *********************************************************************
PRO NDRSEL_EDIT 

COMMON pia_ndrsel_cmn, dets, detact, ndrsel, newndrsel, $
	wricalg_id, det_id

	edbase = WIDGET_BASE(TITLE = detact+ 'Actual Ndr Selection Criteria', $
			/column)

	edlab = WIDGET_LABEL(edbase, VALUE='NDRs/Ramp        Discard up to')

	ndrrmp = strarr(7)
	FOR I=0,6 DO ndrrmp(i) = STRING(2^(i+1) - 1)    

	edvalbase = WIDGET_BASE(edbase, /row)

	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=7, $
	  VALUE = ndrrmp)
	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=7, $
		VALUE = STRTRIM(STRING(ndrsel),2), uvalue='list')

	quit = WIDGET_BUTTON(edbase, VALUE=' QUIT ', UVALUE='QUIT') 
	WIDGET_CONTROL, edbase, /REALIZE

	xMANAGER,No_BLOCK=1, "NDRSEL_EDIT", edbase, GROUP=group 
	RETURN
END 

; *********************************************************************
; *
; *********************************************************************
PRO CNDRSEL_EDIT_event, event 

COMMON pia_ndrsel_cmn, dets, detact, ndrsel, newndrsel, $
	wricalg_id, det_id

COMMON cndrs_edit_cmn, edval_id, pixels 

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue of
	 'LIST': BEGIN
		WIDGET_CONTROL, edval_id, GET_VALUE=value
		IF N_ELEMENTS(value) EQ 7 THEN $
			newndrsel = float(value) ELSE BEGIN
                  	XDISPLAYFILE, "", $
                    		TITLE = "Input not accepted", $
                    		WIDTH = 50, $
                    		HEIGHT = 4, $
                    	  TEXT = [" Wrong ndrsel input  ", $]
                          	  "     ", $ ]
                          	  " Fix it and try again, please "]
			RETURN
		ENDELSE
	 END
	 'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
         ELSE: 
	ENDCASE
END

; *********************************************************************
; *
; *********************************************************************
PRO CNDRSEL_EDIT, group=group 

COMMON pia_ndrsel_cmn, dets, detact, ndrsel, newndrsel, $
	wricalg_id, det_id

COMMON cndrs_edit_cmn, edval_id, pixels 

	IF not KEYWORD_SET(group) THEN group = !PIA_TOP_WID
	edbase = WIDGET_BASE(TITLE =detact+' Computed Ndr Selection Criteria', $
			/column, /MODAL, group=group)

	edlab = WIDGET_LABEL(edbase, VALUE='NDRs/Ramp      Discard up to')

	edvalbase = WIDGET_BASE(edbase, /row)

	ndrrmp = strarr(7)
	FOR I=0,6 DO ndrrmp(i) = STRING(2^(i+1) - 1)    

	edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=7, $
	  VALUE = ndrrmp)
	edval_id = WIDGET_TEXT(edvalbase, /editable, XSIZE=10, YSIZE=7, $
	  VALUE = STRTRIM(STRING(newndrsel),2), UVALUE='JUNK')
	edconbase = WIDGET_BASE(edbase, /row)
	ok = WIDGET_BUTTON(edconbase, VALUE='  OK  ', UVALUE='LIST')
	quit = WIDGET_BUTTON(edconbase, VALUE=' QUIT ', UVALUE='QUIT') 
	WIDGET_CONTROL, edbase, /REALIZE
	xMANAGER,No_BLOCK=1, "CNDRSEL_EDIT", edbase, GROUP=group 
	RETURN
END 

; *********************************************************************
; *
; *********************************************************************
PRO CLGNDRSEL_EDIT_event, event 

COMMON pia_ndrsel_cmn, dets, detact, ndrsel, newndrsel, $
	wricalg_id, det_id
COMMON cal_ndrsel_cmn, calg_ndrsel, calg_ndrsel_p1, calg_ndrsel_p2, calg_ndrsel_p3, calg_ndrsel_c1, $
       calg_ndrsel_c2, calg_ndrsel_ss, calg_ndrsel_sl

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.id, GET_VALUE=value
	CASE uvalue of
	'list': 
	'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
	ENDCASE
END

; *********************************************************************
; *
; *********************************************************************
PRO CLGNDRSEL_EDIT 

COMMON pia_ndrsel_cmn, dets, detact, ndrsel, newndrsel, $
	wricalg_id, det_id
COMMON cal_ndrsel_cmn, calg_ndrsel, calg_ndrsel_p1, calg_ndrsel_p2, calg_ndrsel_p3, calg_ndrsel_c1, $
       calg_ndrsel_c2, calg_ndrsel_ss, calg_ndrsel_sl

	edbase = WIDGET_BASE(TITLE = detact+ 'CALG Ndr Selection Criteria', $
			/column)

	edlab = WIDGET_LABEL(edbase, VALUE='NDRs/Ramp        Discard up to')

	ndrrmp = strarr(7)
	FOR I=0,6 DO ndrrmp(i) = STRING(2^i - 1)    

	edvalbase = WIDGET_BASE(edbase, /row)

	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=7, $
	  VALUE = ndrrmp)
	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=7, $
		VALUE = STRTRIM(STRING(calg_ndrsel),2), uvalue='list')

	quit = WIDGET_BUTTON(edbase, VALUE=' QUIT ', UVALUE='QUIT') 
	WIDGET_CONTROL, edbase, /REALIZE

	xMANAGER,No_BLOCK=1, "CLGNDRSEL_EDIT", edbase, GROUP=group
	RETURN
END 

; *********************************************************************
; *
; *********************************************************************
PRO PIA_CAL_NDRSEL_EVENT, event

@phtselndr
@colour_indices
COMMON pia_ndrsel_cmn, dets, detact, ndrsel, newndrsel, $
	wricalg_id, det_id
COMMON cal_ndrsel_cmn, calg_ndrsel, calg_ndrsel_p1, calg_ndrsel_p2, calg_ndrsel_p3, calg_ndrsel_c1, $
       calg_ndrsel_c2, calg_ndrsel_ss, calg_ndrsel_sl


	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	i = WHERE(dets EQ uvalue, n)
	i = i(0)
	IF n NE 0 THEN uvalue = 'DET'

	CASE uvalue of
	   'DET': BEGIN
	   		WIDGET_CONTROL, det_id, SET_VALUE=dets(i)
			detact = dets(i)
			CASE STRMID(detact,0,2) OF
				'P1': BEGIN
                                   ndrsel = pp1sndr
				   calg_ndrsel = calg_ndrsel_p1
				END
				'P2': BEGIN
                                   ndrsel = pp2sndr
				   calg_ndrsel = calg_ndrsel_p2
				END
				'P3': BEGIN
                                   ndrsel = pp3sndr
				   calg_ndrsel = calg_ndrsel_p3
				END
				'C1': BEGIN
                                   ndrsel = pc1sndr
				   calg_ndrsel = calg_ndrsel_c1
				END
				'C2': BEGIN
                                   ndrsel = pc2sndr
				   calg_ndrsel = calg_ndrsel_c2
				END
				'SS': BEGIN
                                   ndrsel = psssndr
				   calg_ndrsel = calg_ndrsel_ss
				END
				'SL': BEGIN
                                   ndrsel = pslsndr
				   calg_ndrsel = calg_ndrsel_sl
				END
                        ENDCASE
			newndrsel = ndrsel
		  END	
	   	  
	   'PROC': MESSAGE, /INFO, ' Ndr SEL calculation not yet implemented'	

	   'EDACTVAL': NDRSEL_EDIT

	   'EDCOMVAL': CNDRSEL_EDIT, group=event.top

	   'EDCLGVAL': CLGNDRSEL_EDIT

	   'WRICOM': BEGIN
			CASE STRMID(detact,0,2) OF
				'P1': pp1sndr = newndrsel
				'P2': pp2sndr = newndrsel
				'P3': pp3sndr = newndrsel
				'C1': pc1sndr = newndrsel
				'C2': pc2sndr = newndrsel
				'SS': psssndr = newndrsel
				'SL': pslsndr = newndrsel
                        ENDCASE
                 ndrsel = newndrsel
		 WIDGET_CONTROL, wricalg_id, /sensitive
		END

	   'WRICALG': BEGIN

		 pia_write_comment, comment
                 comm = ''
                 FOR I=0,N_ELEMENTS(comment)-1 DO comm = comm+comment(i)
                 pia_write_version, version
                 vers = ''
                 FOR I=0,N_ELEMENTS(version)-1 DO vers = vers+version(i)
                 pia_write_author, author
                 auth = ''
                 FOR I=0,N_ELEMENTS(author)-1 DO auth = auth+author(i)

		 write_selndr, 'PIA_SELNDR', $
		     pp1sndr, pp2sndr, pp3sndr, $
                     pc1sndr, pc2sndr, psssndr, pslsndr, $
                     username = auth, $
                     comment = comm, version = vers

		END

	   'QUIT': WIDGET_CONTROL, event.top, /DESTROY
		
	   'INIT': BEGIN
	      	read_selndr
	      	WIDGET_CONTROL, det_id, SET_VALUE='C100'
		ndrsel = pc1sndr
		newndrsel = ndrsel
	   END
	      
	      
	   
	   ELSE: 
	ENDCASE
RETURN
END

; *********************************************************************
; *
; *
; *
; *********************************************************************
PRO PIA_CAL_NDRSEL, GROUP=group

@phtselndr
COMMON pia_ndrsel_cmn, dets, detact, ndrsel, newndrsel, $
	wricalg_id, det_id
COMMON cal_ndrsel_cmn, calg_ndrsel, calg_ndrsel_p1, calg_ndrsel_p2, calg_ndrsel_p3, calg_ndrsel_c1, $
       calg_ndrsel_c2, calg_ndrsel_ss, calg_ndrsel_sl

	dets = ['P1','P2', 'P3', 'C100', 'C200', 'SS', 'SL'] 

	detact = dets(3)

	IF N_ELEMENTS(pc1sndr) EQ 0 THEN read_selndr
	ndrsel = pc1sndr

	newndrsel = ndrsel
;initialize the calg common block
	FXBOPEN, unit, !CALG+'PSELNDR.FITS', 1
        FXBREAD, unit, calg_ndrsel_p1, 'PP1SNDR'
        FXBREAD, unit, calg_ndrsel_p2, 'PP2SNDR'
        FXBREAD, unit, calg_ndrsel_p3, 'PP3SNDR'
        FXBREAD, unit, calg_ndrsel_c1, 'PC1SNDR'
        FXBREAD, unit, calg_ndrsel_c2, 'PC2SNDR'
        FXBREAD, unit, calg_ndrsel_ss, 'PSSSNDR'
        FXBREAD, unit, calg_ndrsel_sl, 'PSLSNDR'
	FXBCLOSE, unit
	calg_ndrsel = calg_ndrsel_c1

	sndrbase = WIDGET_BASE(TITLE = 'PIA NDR Default Selection CFDP Menu', $
                                /COLUMN)

        choicebase = WIDGET_BASE(sndrbase, /ROW)

	det_id = WIDGET_BUTTON(choicebase, VALUE = detact, /MENU)

	FOR I=0,6 DO id_0 = WIDGET_BUTTON(det_id, VALUE=dets(i),UVALUE=dets(i))
  
;	proc_id = WIDGET_BUTTON(choicebase, VALUE= ' Process ', UVALUE='PROC')

	edit_id = WIDGET_BUTTON(choicebase, VALUE= ' Edit Values ', /MENU)
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'Actual Values', $
				UVALUE = 'EDACTVAL')
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'Computed Values', $
				UVALUE = 'EDCOMVAL')
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'CALG Values', $
				UVALUE = 'EDCLGVAL')

	write_id = WIDGET_BUTTON(choicebase, VALUE = ' Write Values ', /MENU)
	id_1 = WIDGET_BUTTON(write_id, VALUE = 'to internal common', $
				UVALUE = 'WRICOM')
	wricalg_id = WIDGET_BUTTON(write_id, VALUE = 'to Cal G file', $
				UVALUE = 'WRICALG')
	WIDGET_CONTROL, wricalg_id, SENSITIVE=0	

	init_id = WIDGET_BUTTON(choicebase, VALUE = ' Re-initialize ', $
			UVAL="INIT")

	quit_id = WIDGET_BUTTON(sndrbase, VALUE = '  Quit  ', $
                        /FRAME, UVALUE = 'QUIT')

        WIDGET_CONTROL, sndrbase, /REALIZE, TLB_SET_XOFFSET=300, $
                        TLB_SET_YOFFSET=50

        xMANAGER,No_BLOCK=1, "pia_cal_ndrsel", sndrbase, GROUP=group
	
RETURN
END
