;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_CAL_PPSF
;
; PURPOSE:
;	Top level menu for PHT Point Spread Function File production, one of
;	the Calibration Files Derivation Procedures (CFDP)  
;
; CATEGORY:
;       PIA - graphics
;		
; CALLING SEQUENCE:
;       PIA_CAL_PPSF
;
; KEYWORD PARAMETERS:
;	GROUP=group: Group leader
;
; COMMON BLOCKS:
;	colour_indices
;	phtapert
;	phtfilter
;	phtppsf
;	pia_ppsf_cmn (internal)
;	cppsf_edit_cmn (internal)
;	cal_ppsf_cmn (nternal)
;
; PROCEDURES USED:
;	PIA LIB:
;		aperture_size_init
;		phtfilter_init
;		pia_multchoice
;		pia_write_author
;		pia_write_comment
;		pia_write_version
;		pia_xplot
;		pia_xsurface
;		read_asc_ppsf
;		read_ppsf
;		write_asc_ppsf
;		write_ppsf
;       ASTRO LIB:
;		fxread
;       INTERNAL:
;		ppsf_edit_event
;		ppsf_edit
;		cppsf_edit_event
;		cppsf_edit
;		clg_ppsf_edit_event
;		clg_ppsf_edit
;		pia_cal_ppsf_event
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel (ESA/ESTEC) 		March 1995
;	Modified (last) by: cg, wmt			September 1995
;	Oct 95 Version 3.5
;	Handling from export version possible (CG)	April 1997
;	V6.2
;	Re-initialize button added (CG)			November 1997
;	V6.6
;	/Modal use according to IDL >=5.0 (CG)		February 1999
;	V7.3.1
;
;-
; *********************************************************************
; *
; *********************************************************************
PRO PPSF_EDIT_event, event 

COMMON pia_ppsf_cmn, dets, detact, filts, filtact, allppsf, $
		ppsf, newppsf, ppsppsf, filt_id


	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.id, GET_VALUE=value
	CASE uvalue of
	'list': 
	'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
	ENDCASE
END

; *********************************************************************
; *
; *********************************************************************
PRO PPSF_EDIT 

@phtapert
COMMON pia_ppsf_cmn, dets, detact, filts, filtact, allppsf, $
		ppsf, newppsf, ppsppsf, filt_id

	edbase = WIDGET_BASE(TITLE =dets(detact)+' Actual PPSF Tables', $
			/column)

	cptlist = filts(filtact)
	typlist = ['Array', 'Pixel']

	IF STRMID(dets(detact),0,1) EQ 'P' THEN $
			naper = indgen(14) ELSE naper = [14,15]

	edvalbase = WIDGET_BASE(edbase, /row)
	
        edvalbas2 = WIDGET_BASE(edvalbase, /column)
	
	edval = WIDGET_TEXT(edvalbas2, XSIZE=10, YSIZE=1, $
	  VALUE = 'Filt\Aper')
	edval = WIDGET_TEXT(edvalbas2, XSIZE=10, YSIZE=10, $
	  VALUE = cptlist)

	loops = N_ELEMENTS(naper)-1   

	FOR III=0,loops < 6  DO BEGIN  
	 edvalbas3 = WIDGET_BASE(edvalbase, /column)
	 IF detact GE 3 THEN apval = typlist(III) ELSE $ 
	  apval = STRING(format='(f6.2)',p_diamy(III,0) )

	 edval = WIDGET_TEXT(edvalbas3, XSIZE=7, YSIZE=1, $
		VALUE = apval )
	 edval = WIDGET_TEXT(edvalbas3, XSIZE=7, YSIZE=10, $
		VALUE = STRING(FORMAT='(f7.3)',ppsf(III,*)),$
		UVALUE = 'list')
        ENDFOR

	IF loops GT 6 THEN BEGIN 

	edvalbase = WIDGET_BASE(edbase, /row)

        edvalbas2 = WIDGET_BASE(edvalbase, /column)
	
 	 edval = WIDGET_TEXT(edvalbas2, XSIZE=10, YSIZE=1, $
	  VALUE = 'Filt\Aper')
	 edval = WIDGET_TEXT(edvalbas2, XSIZE=10, YSIZE=10, $
	  VALUE = cptlist)

	 FOR III=7,loops  DO BEGIN  
	  edvalbas3 = WIDGET_BASE(edvalbase, /column)
	  IF detact GE 3 THEN apval = '   ' ELSE $ 
	  apval = STRING(format='(f6.2)',p_diamy(III,0) )

	  edval = WIDGET_TEXT(edvalbas3, XSIZE=7, YSIZE=1, $
		VALUE = apval )
	  edval = WIDGET_TEXT(edvalbas3, XSIZE=7, YSIZE=10, $
		VALUE = STRING(FORMAT='(f7.3)',ppsf(III,*)),$
		UVALUE = 'list')
         ENDFOR
        ENDIF


	quit = WIDGET_BUTTON(edbase, VALUE=' QUIT ', UVALUE='QUIT') 
	WIDGET_CONTROL, edbase, /REALIZE
	Xmanager,No_BLOCK=1, "PPSF_EDIT", edbase, GROUP=group 
	RETURN
END 

; *********************************************************************
; *
; *********************************************************************
PRO CPPSF_EDIT_event, event 

@phtapert
COMMON pia_ppsf_cmn, dets, detact, filts, filtact, allppsf, $
		ppsf, newppsf, ppsppsf, filt_id
COMMON cppsf_edit_cmn, edval_id 

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue of
	 'LIST': BEGIN
		CASE dets(detact) of
			'P1': indpp = indgen(10)
			'P2': indpp = [10,11]
			'P3': indpp = [12,13]
			ELSE: indpp = -1
		ENDCASE
		FOR III=0,N_ELEMENTS(edval_id) - 1 DO BEGIN
		 WIDGET_CONTROL, edval_id(III), GET_VALUE=value
		 IF N_ELEMENTS(value) EQ N_elements(filtact) THEN BEGIN
			newppsf(III,*) = float(value) 
                        IF III NE 14 AND indpp(0) NE -1 THEN $
                        	ppsppsf(III,indpp) = float(value)
		 ENDIF ELSE BEGIN
                  	XDISPLAYFILE, "", $
                    		TITLE = "Input not accepted", $
                    		WIDTH = 50, $
                    		HEIGHT = 4, $
                    	  TEXT = [" Wrong PPSF factors input  ", $]
                          	  "     ", $ ]
                          	  " Fix it and try again, please "]
			RETURN
		 ENDELSE	
		ENDFOR
	 END
	 'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
         ELSE: 
	ENDCASE

RETURN
END

; *********************************************************************
; *
; *********************************************************************
PRO CPPSF_EDIT, GROUP=group 

@phtapert
COMMON pia_ppsf_cmn, dets, detact, filts, filtact, allppsf, $
		ppsf, newppsf, ppsppsf, filt_id
COMMON cppsf_edit_cmn, edval_id 

	IF not KEYWORD_SET(group) THEN group = !PIA_TOP_WID
	edbase = WIDGET_BASE(TITLE =dets(detact)+' Computed PPSF Tables', $
			/column, /modal, group=group)


	cptlist = filts(filtact)

	IF STRMID(dets(detact),0,1) EQ 'P' THEN $
			naper = indgen(14) ELSE naper = 15

	edvalbase = WIDGET_BASE(edbase, /row)
	
        edvalbas2 = WIDGET_BASE(edvalbase, /column)
	
	edval = WIDGET_TEXT(edvalbas2, XSIZE=10, YSIZE=1, $
	  VALUE = 'Filt\Aper')
	edval = WIDGET_TEXT(edvalbas2, XSIZE=10, YSIZE=10, $
	  VALUE = cptlist)

	nele = N_ELEMENTS(naper)
	edval_id = lonarr(nele) 

	loops = N_ELEMENTS(naper) - 1  

	FOR III=0,loops < 6 DO BEGIN  
	 edvalbas3 = WIDGET_BASE(edvalbase, /column)
	 IF detact GE 3 THEN apval = ' ' ELSE $ 
	  apval = STRING(format='(f6.2)',p_diamy(III,0) )

	 edval = WIDGET_TEXT(edvalbas3, XSIZE=7, YSIZE=1, $
		VALUE =  apval )
	 edval_id(III) = WIDGET_TEXT(edvalbas3, /EDITABLE, XSIZE=7, YSIZE=10, $
		VALUE = STRING(FORMAT='(f7.3)',newppsf(III,*)),$
		UVALUE = 'list')
        ENDFOR

	IF loops GT 6 THEN BEGIN 

	edvalbase = WIDGET_BASE(edbase, /row)

        edvalbas2 = WIDGET_BASE(edvalbase, /column)
	
 	 edval = WIDGET_TEXT(edvalbas2, XSIZE=10, YSIZE=1, $
	  VALUE = 'Filt\Aper')
	 edval = WIDGET_TEXT(edvalbas2, XSIZE=10, YSIZE=10, $
	  VALUE = cptlist)

	 FOR III=7,loops  DO BEGIN  
	  edvalbas3 = WIDGET_BASE(edvalbase, /column)
	  IF detact GE 3 THEN apval = '   ' ELSE $ 
	  apval = STRING(format='(f6.2)',p_diamy(III,0) )

	  edval = WIDGET_TEXT(edvalbas3, XSIZE=7, YSIZE=1, $
		VALUE = apval )
	  edval_id(III) = WIDGET_TEXT(edvalbas3, /EDITABLE, XSIZE=7, YSIZE=10, $
		VALUE = STRING(FORMAT='(f7.3)',newppsf(III,*)),$
		UVALUE = 'list')
         ENDFOR
        ENDIF

	edconbase = WIDGET_BASE(edbase, /row)
	ok = WIDGET_BUTTON(edconbase, VALUE='  ACCEPT  ', UVALUE='LIST')
	quit = WIDGET_BUTTON(edconbase, VALUE=' QUIT ', UVALUE='QUIT') 

	WIDGET_CONTROL, edbase, /REALIZE

	Xmanager,No_BLOCK=1, "CPPSF_EDIT", edbase, GROUP=group 
	RETURN
END 

; *********************************************************************
; *
; *********************************************************************
PRO CLG_PPSF_EDIT_event, event 

COMMON pia_ppsf_cmn, dets, detact, filts, filtact, allppsf, $
		ppsf, newppsf, ppsppsf, filt_id
COMMON cal_ppsf_cmn, calg_ppsf, calu_ppsf, calg_ppsf_buf


	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.id, GET_VALUE=value
	CASE uvalue of
	'list': 
	'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
	ENDCASE
END

; *********************************************************************
; *
; *********************************************************************
PRO CLG_PPSF_EDIT 

@phtapert
COMMON pia_ppsf_cmn, dets, detact, filts, filtact, allppsf, $
		ppsf, newppsf, ppsppsf, filt_id
COMMON cal_ppsf_cmn, calg_ppsf, calu_ppsf, calg_ppsf_buf

	edbase = WIDGET_BASE(TITLE =dets(detact)+' CALG PPSF Tables', $
			/column)

	cptlist = filts(filtact)

	IF STRMID(dets(detact),0,1) EQ 'P' THEN $
			naper = indgen(14) ELSE naper = 15

	edvalbase = WIDGET_BASE(edbase, /row)
	
        edvalbas2 = WIDGET_BASE(edvalbase, /column)
	
	tysize = n_elements(calg_ppsf(0, *))
	edval = WIDGET_TEXT(edvalbas2, XSIZE=10, YSIZE=1, $
	  VALUE = 'Filt\Aper')
	edval = WIDGET_TEXT(edvalbas2, XSIZE=10, YSIZE=tysize, $
	  VALUE = cptlist)

	loops = N_ELEMENTS(naper)-1   

	FOR III=0,loops < 6  DO BEGIN  
	 edvalbas3 = WIDGET_BASE(edvalbase, /column)
	 IF detact GE 3 THEN apval = '   ' ELSE $ 
	  apval = STRING(format='(f6.2)',p_diamy(III,0) )

	 edval = WIDGET_TEXT(edvalbas3, XSIZE=7, YSIZE=1, $
		VALUE = apval )
	 edval = WIDGET_TEXT(edvalbas3, XSIZE=7, YSIZE=tysize, $
		VALUE = STRING(FORMAT='(f7.4)',calg_ppsf(III,*)),$
		UVALUE = 'list')
        ENDFOR

	IF loops GT 6 THEN BEGIN 

	edvalbase = WIDGET_BASE(edbase, /row)

        edvalbas2 = WIDGET_BASE(edvalbase, /column)
	
 	 edval = WIDGET_TEXT(edvalbas2, XSIZE=10, YSIZE=1, $
	  VALUE = 'Filt\Aper')
	 edval = WIDGET_TEXT(edvalbas2, XSIZE=10, YSIZE=tysize, $
	  VALUE = cptlist)

	 FOR III=7,loops  DO BEGIN  
	  edvalbas3 = WIDGET_BASE(edvalbase, /column)
	  IF detact GE 3 THEN apval = '   ' ELSE $ 
	  apval = STRING(format='(f6.2)',p_diamy(III,0) )

	  edval = WIDGET_TEXT(edvalbas3, XSIZE=7, YSIZE=1, $
		VALUE = apval )
	  edval = WIDGET_TEXT(edvalbas3, XSIZE=7, YSIZE=tysize, $
		VALUE = STRING(FORMAT='(f7.4)',calg_ppsf(III,*)),$
		UVALUE = 'list')
         ENDFOR
        ENDIF

        edconbase = WIDGET_BASE(edbase, /row)
        quit = WIDGET_BUTTON(edconbase, /frame, VALUE=' QUIT ', UVALUE='QUIT')
 
	WIDGET_CONTROL, edbase, /REALIZE
	Xmanager,No_BLOCK=1, "CLG_PPSF_EDIT", edbase, GROUP=group
	RETURN
END 

; *********************************************************************
; *
; *********************************************************************
PRO PIA_CAL_PPSF_EVENT, event

@phtppsf
@phtapert
@colour_indices

COMMON pia_ppsf_cmn, dets, detact, filts, filtact, allppsf, $
		ppsf, newppsf, ppsppsf, filt_id
COMMON cal_ppsf_cmn, calg_ppsf, calu_ppsf, calg_ppsf_buf


	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	i = WHERE(dets EQ uvalue, n)
	i = i(0)
	IF n NE 0 THEN uvalue = 'DET'

	CASE uvalue of

	   'DET': BEGIN
			detact = i
			det = STRMID(dets(detact),0,2)
			CASE det of
			  'P1': BEGIN 
				filtact = indgen(10)
				ppsf = phtppsf(0:13,filtact)
				calg_ppsf = calg_ppsf_buf(0:13,filtact)
			  END
			  'P2': BEGIN
				filtact = indgen(2) + 10
				ppsf = phtppsf(0:13,filtact)
				calg_ppsf = calg_ppsf_buf(0:13,filtact)
			  END
			  'P3': BEGIN
				filtact = indgen(2) + 12
				ppsf = phtppsf(0:13,filtact)
				calg_ppsf = calg_ppsf_buf(0:13,filtact)
			  END
			  'C1': BEGIN
				filtact = indgen(7) + 14
		; take care of first position invalid
				ppsf = phtppsf(14:15,filtact-13)
				calg_ppsf = calg_ppsf_buf(14,filtact-13)
			  END
			  'C2': BEGIN
				filtact = indgen(5) + 21
		; take care of first position invalid
				ppsf = phtppsf(14:15,filtact-13)
				calg_ppsf = calg_ppsf_buf(14,filtact-13)
			  END
			ENDCASE
			newppsf = ppsf
			det_id = WIDGET_INFO(event.id, /parent)
	   		WIDGET_CONTROL, det_id, SET_VALUE=dets(detact)
	   END	  

	   'PLOTACT': BEGIN 
		 title=dets(detact)+' actual PPSF Tables ' 
		 IF N_ELEMENTS(ppsf(*,0)) EQ 1 THEN BEGIN
			MESSAGE, /INFO, 'Not 2-dimensional, just plotting'
			GOTO, JUST_PLOT
                 ENDIF
                 pia_xsurface, ppsf, wlego=1, xtitle = 'Aperture', $
                        ytitle= 'Filter position', charsize=2, $
                        ztitle= ' PPSF factor  ', title=title, $
                        group=event.top  

		END

	   'PLOTACTPROJ': BEGIN
JUST_PLOT:

                list = filtact

		elnames = 'Filter ' + filts(list)
		nfil = N_ELEMENTS(elnames)

		IF detact GE 3 THEN BEGIN
		 list = nfil
		 elemn = ['Array','Pixel'] 
		 pia_multchoice, listi, ELEMNAMES=elemn   		 
                 apstr = elemn(listi)
		 posi = listi 
		ENDIF ELSE BEGIN   
		 elnames = [elnames, 'Apert '+ STRTRIM(STRING(p_diamy(*,0)),2)] 
		 pia_multchoice, list, ELEMNAMES = elnames   		 		
		 IF list GE nfil THEN $
		  apstr = STRTRIM(STRING(p_diamy(list-nfil,0)),2)
		 posi = 0
		ENDELSE

                IF list GE nfil THEN BEGIN 
 		  title = dets(detact)+' actual   PPSF - Aperture '+apstr
		  ytitle = STRMID(title,11,45) + ' factors'
		  x = indgen(N_ELEMENTS(ppsf(0,*))) + 1 
                  pia_xplot, x, ppsf(list-nfil+posi,*), psym=4, $
			title= title, xtitle=' Filter Position ', $
			ytitle = ytitle, annotation = title, legend = ytitle
		ENDIF ELSE BEGIN
 		  title = dets(detact)+' actual   PPSF - Filter '+$
				filts(list)

		 ytitle = STRMID(title,11,45) + ' factors'

		 x = indgen(N_ELEMENTS(ppsf(*,0))) + 1 
                 pia_xplot, x, ppsf(*,list), psym=4, $
			title= title, xtitle=' Aperture Position ', $
			ytitle = ytitle, annotation = title, legend = ytitle
		ENDELSE
           END

	   'OPLOTACTPROJ': BEGIN

                list = filtact

		elnames = 'Filter ' + filts(list)
		nfil = N_ELEMENTS(elnames)

		IF detact GE 3 THEN BEGIN
		 list = nfil
		 elemn = ['Array','Pixel'] 
		 pia_multchoice, listi, ELEMNAMES=elemn   		 
                 apstr = elemn(listi)
		 posi = listi 
		ENDIF ELSE BEGIN   
		 elnames = [elnames, 'Apert '+ STRTRIM(STRING(p_diamy(*,0)),2)] 
		 pia_multchoice, list, ELEMNAMES = elnames   		 		
		 IF list GE nfil THEN $
 		  apstr = STRTRIM(STRING(p_diamy(list-nfil,0)),2)
		 posi=0
		ENDELSE

                IF list GE nfil THEN BEGIN 
 		  title = dets(detact)+' actual   PPSF - Aperture '+ apstr
		 ytitle = STRMID(title,11,45) + ' factors'
		 x = indgen(N_ELEMENTS(ppsf(0,*))) + 1 
                 pia_xplot, x, ppsf(list-nfil+posi,*), psym=4, $
			title= title, color=yellow, overplot=99, $
			ytitle = ytitle, annotation = title, legend = ytitle
		ENDIF ELSE BEGIN
 		  title = dets(detact)+' actual   PPSF - Filter '+$
				filts(list)

		 ytitle = STRMID(title,11,45) + ' factors'

		 x = indgen(N_ELEMENTS(ppsf(*,0))) + 1 
                 pia_xplot, x, ppsf(*,list), psym=4, $
			title= title, color=yellow, overplot=99, $
			ytitle = ytitle, annotation = title, legend = ytitle
		ENDELSE
           END
	   'PLOTCOM': BEGIN 
		 title=dets(detact)+' actual PPSF Tables ' 
		 IF N_ELEMENTS(newppsf(*,0)) EQ 1 THEN BEGIN
			MESSAGE, /INFO, 'Not 2-dimensional, just plotting'
			GOTO, JUST_PLOT2
                 ENDIF
                 pia_xsurface, newppsf, wlego=1, xtitle = 'Aperture position', $
                        ytitle= 'Filter position', charsize=2, $
                        ztitle= ' PPSF factor  ', title=title, $
                        group=event.top  

		END

	   'PLOTCOMPROJ': BEGIN
JUST_PLOT2:

                list = filtact

		elnames = 'Filter ' + filts(list)
		nfil = N_ELEMENTS(elnames)

		IF detact GE 3 THEN BEGIN
		 list = nfil
		 elemn = ['Array','Pixel'] 
		 pia_multchoice, listi, ELEMNAMES=elemn   		 
                 apstr = elemn(listi)
		 posi = listi 
		ENDIF ELSE BEGIN   
		 elnames = [elnames, 'Apert '+ STRTRIM(STRING(p_diamy(*,0)),2)] 
		 pia_multchoice, list, ELEMNAMES = elnames   		 		
		 IF list GE nfil THEN $
		  apstr = STRTRIM(STRING(p_diamy(list-nfil,0)),2)
		 posi=0
		ENDELSE

                IF list GE nfil THEN BEGIN 
 		  title = dets(detact)+' computed   PPSF - Aperture '+apstr
		 ytitle = STRMID(title,13,45) + ' factors'
		 x = indgen(N_ELEMENTS(newppsf(0,*))) + 1 
                 pia_xplot, x, newppsf(list-nfil+posi,*), psym=4, $
			title= title, xtitle=' Filter Position ', $
			ytitle = ytitle, annotation = title, legend = ytitle
		ENDIF ELSE BEGIN
 		  title = dets(detact)+' computed   PPSF - Filter '+$
				filts(list)

		 ytitle = STRMID(title,13,45) + ' factors'

		 x = indgen(N_ELEMENTS(newppsf(*,0))) + 1 
                 pia_xplot, x, ppsf(*,list), psym=4, $
			title= title, xtitle=' Aperture Position ', $
			ytitle = ytitle, annotation = title, legend = ytitle
		ENDELSE
           END

	   'OPLOTCOMPROJ': BEGIN

                list = filtact

		elnames = 'Filter ' + filts(list)
		nfil = N_ELEMENTS(elnames)

		IF detact GE 3 THEN BEGIN
		 list = nfil
		 elemn = ['Array','Pixel'] 
		 pia_multchoice, listi, ELEMNAMES=elemn   		 
                 apstr = elemn(listi)
		 posi = listi 
		ENDIF ELSE BEGIN   
		 elnames = [elnames, 'Apert '+ STRTRIM(STRING(p_diamy(*,0)),2)] 
		 pia_multchoice, list, ELEMNAMES = elnames   		 		
		 IF list GE nfil THEN $
		  apstr = STRTRIM(STRING(p_diamy(list-nfil,0)),2)
		 posi = 0
		ENDELSE

                IF list GE nfil THEN BEGIN 
 		  title = dets(detact)+' computed   PPSF - Aperture '+apstr
		 ytitle = STRMID(title,13,45) + ' factors'
		 x = indgen(N_ELEMENTS(newppsf(0,*))) + 1 
                 pia_xplot, x, newppsf(list-nfil+posi,*), psym=4, $
			title= title, color=yellow, overplot=99, $
			ytitle = ytitle, annotation = title, legend = ytitle
		ENDIF ELSE BEGIN
 		  title = dets(detact)+' computed   PPSF - Filter '+$
				filts(list)

		 ytitle = STRMID(title,13,45) + ' factors'

		 x = indgen(N_ELEMENTS(newppsf(*,0))) + 1 
                 pia_xplot, x, ppsf(*,list), psym=4, $
			title= title, color=yellow, overplot=99, $
			ytitle = ytitle, annotation = title, legend = ytitle
		ENDELSE
           END

	   'PLOTCLG': BEGIN 
		 title=dets(detact)+' CLAG PPSF Tables ' 
		 IF N_ELEMENTS(calg_ppsf(*,0)) EQ 1 THEN BEGIN
			MESSAGE, /INFO, 'Not 2-dimensional, just plotting'
			GOTO, JUST_PLOT3
                 ENDIF
                 pia_xsurface, calg_ppsf, wlego=1, xtitle = 'Aperture', $
                        ytitle= 'Filter position', charsize=2, $
                        ztitle= ' PPSF factor  ', title=title, $
                        group=event.top  

		END

	   'PLOTCLGPROJ': BEGIN
JUST_PLOT3:

                list = filtact

		elnames = 'Filter ' + filts(list)
		nfil = N_ELEMENTS(elnames)

		IF detact GE 3 THEN BEGIN
		 list = nfil  		 
                 apstr = 'unique'
		ENDIF ELSE BEGIN   
		 elnames = [elnames, 'Apert '+ STRTRIM(STRING(p_diamy(*,0)),2)] 
		 pia_multchoice, list, ELEMNAMES = elnames   		 		
		 IF list GE nfil THEN $
		  apstr = STRTRIM(STRING(p_diamy(list-nfil,0)),2)
		ENDELSE

                IF list GE nfil THEN BEGIN 
 		  title = dets(detact)+' CALG  PPSF - Aperture '+apstr
		  ytitle = STRMID(title,11,45) + ' factors'
		  x = indgen(N_ELEMENTS(calg_ppsf(0,*))) + 1 
                  pia_xplot, x, calg_ppsf(list-nfil,*), psym=4, $
			title= title, xtitle=' Filter Position ', $
			ytitle = ytitle, annotation = title, legend = ytitle
		ENDIF ELSE BEGIN
 		  title = dets(detact)+' CALG  PPSF - Filter '+$
				filts(list)

		 ytitle = STRMID(title,11,45) + ' factors'

		 x = indgen(N_ELEMENTS(calg_ppsf(*,0))) + 1 
                 pia_xplot, x, calg_ppsf(*,list), psym=4, $
			title= title, xtitle=' Aperture Position ', $
			ytitle = ytitle, annotation = title, legend = ytitle
		ENDELSE
           END

	   'OPLOTCLGPROJ': BEGIN

                list = filtact

		elnames = 'Filter ' + filts(list)
		nfil = N_ELEMENTS(elnames)

		IF detact GE 3 THEN BEGIN
		 list = nfil 		 
                 apstr = 'unique'
		ENDIF ELSE BEGIN   
		 elnames = [elnames, 'Apert '+ STRTRIM(STRING(p_diamy(*,0)),2)] 
		 pia_multchoice, list, ELEMNAMES = elnames   		 		
		 IF list GE nfil THEN $
 		  apstr = STRTRIM(STRING(p_diamy(list-nfil,0)),2)
		ENDELSE

                IF list GE nfil THEN BEGIN 
 		  title = dets(detact)+' CALG   PPSF - Aperture '+ apstr
		 ytitle = STRMID(title,11,45) + ' factors'
		 x = indgen(N_ELEMENTS(calg_ppsf(0,*))) + 1 
                 pia_xplot, x, calg_ppsf(list-nfil,*), psym=4, $
			title= title, color=yellow, overplot=99, $
			ytitle = ytitle, annotation = title, legend = ytitle
		ENDIF ELSE BEGIN
 		  title = dets(detact)+' CALG  PPSF - Filter '+$
				filts(list)

		 ytitle = STRMID(title,11,45) + ' factors'

		 x = indgen(N_ELEMENTS(calg_ppsf(*,0))) + 1 
                 pia_xplot, x, calg_ppsf(*,list), psym=4, $
			title= title, color=yellow, overplot=99, $
			ytitle = ytitle, annotation = title, legend = ytitle
		ENDELSE
           END

	   'PROC': MESSAGE, /INFO, 'not yet implemented	

	   'EDACTVAL': PPSF_EDIT

	   'EDCOMVAL': CPPSF_EDIT, GROUP=event.top

	   'EDCLGVAL': CLG_PPSF_EDIT

	   'WRICOM': BEGIN
			CASE STRMID(dets(detact),0,1) of
			  'P': phtppsf(0:13,filtact) = newppsf
			  'C': phtppsf(14:15,filtact-13) = newppsf
			ENDCASE
			ppsf = newppsf
		END

	   'WRICALG': BEGIN
			CASE STRMID(dets(detact),0,1) of
			  'P': phtppsf(0:13,filtact) = newppsf
			  'C': phtppsf(14:15,filtact-13) = newppsf
			ENDCASE
                 pia_write_comment, comment
                 comm = ''
                 FOR I=0,N_ELEMENTS(comment)-1 DO comm = comm+comment(i)
                 pia_write_version, version
                 vers = ''
                 FOR I=0,N_ELEMENTS(version)-1 DO vers = vers+version(i)

                 filnam = !CALSAVE + 'PIA_PPSF'
		 WRITE_PPSF, 'PIA_PPSF', phtppsf, $
			comment=comm, version=vers

                 XDISPLAYFILE, "", $
                                TITLE = "Cal G file written", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" Cal G file written under ", $
                                  filnam+'.FITS' ]

		END

	   'WRICALU': BEGIN
                 pia_write_author, author
                 auth = ''
                 FOR I=0,N_ELEMENTS(author)-1 DO auth = auth+author(i)

                 pia_write_version, version
                 vers = ''
                 FOR I=0,N_ELEMENTS(version)-1 DO vers = vers+version(i)


                 filnam = !CALSAVE+'PIA_PPSF.TAB'
		 WRITE_ASC_PPSF, filnam, ppsppsf, $
			author=auth, version=vers

                 XDISPLAYFILE, "", $
                                TITLE = "Uplink file written", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" Uplink file written under ", $
                                  filnam ]

		END

	   'QUIT': WIDGET_CONTROL, event.top, /DESTROY
		
	   'INIT': BEGIN
	        read_pcpsf
		IF filtact(0) LT 14 THEN $ 
		 ppsf = phtppsf(0:13,filtact) ELSE $
		 ppsf = phtppsf(14:15,filtact-13)
		newppsf = ppsf
	   END
	        
	   ELSE: 
	ENDCASE
RETURN
END

; *********************************************************************
; *
; *
; *
; *********************************************************************
PRO PIA_CAL_PPSF, GROUP=group

@phtppsf
@phtfilter
@phtapert

COMMON pia_ppsf_cmn, dets, detact, filts, filtact, allppsf, $
		ppsf, newppsf, ppsppsf, filt_id
COMMON cal_ppsf_cmn, calg_ppsf, calu_ppsf, calg_ppsf_buf

	export = '(e)'
	posi = STRPOS(!PIA_VERSION,export)

	IF posi EQ -1 THEN ext_version=0 ELSE ext_version=1 

; Are the common filled up?
	IF N_ELEMENTS(phtppsf) EQ 0 THEN read_pcpsf

	IF N_ELEMENTS(c1filters) EQ 0 THEN PHTFILTER_INIT

	IF N_ELEMENTS(P_diamy) EQ 0 THEN READ_OMEGA

; Initial choices: P1  

	dets = ['P1','P2', 'P3', 'C100', 'C200'] 

	detact = 0

	filts = [p1filters, p2filters, p3filters, c1filters, c2filters]

	filtact = WHERE(STRMID(filts,0,2) EQ 'P1') 

; Initial ppsf and newppsf (changeable) corresponding to P1 
	ppsf = phtppsf(0:13,filtact)
	newppsf = ppsf
; Initial the calg and calu ppsf value
	fxread, !CALG+'PPSF.FITS', calg_ppsf_buf
	read_asc_ppsf, calu_ppsf, inputfile = !CALU+'p_ppsf.txt'
	calg_ppsf = calg_ppsf_buf(0:13, filtact)

; ppsppsf = phtppsf for P's (to be used for updating the uplink table)
	ppsppsf = phtppsf(0:13,*)


	ppsfbase = WIDGET_BASE(TITLE = 'PIA PPSF Table CFDP Menu', $
                                /COLUMN)

        choicebase = WIDGET_BASE(ppsfbase, /ROW)

	det_id = WIDGET_BUTTON(choicebase, VALUE = dets(detact), /MENU)

	FOR I=0,4 DO id_0 = WIDGET_BUTTON(det_id, $
		VALUE=dets(i),UVALUE=dets(i))
  
        plot_id = WIDGET_BUTTON(choicebase, VALUE = ' Plot ', /MENU)
        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' Actual Values ', /MENU)
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Lego Plot ', $
				UVALUE='PLOTACT' )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Plot Projection ', $
				UVALUE='PLOTACTPROJ' )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' OverPlot Projection ', $
				UVALUE='OPLOTACTPROJ' )
        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' Computed Values ', /MENU)
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Lego Plot ', $
				UVALUE='PLOTCOM' )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Plot Projection ', $
				UVALUE='PLOTCOMPROJ' )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' OverPlot Projection ', $
				UVALUE='OPLOTCOMPROJ' )
        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' CALG Values ', /MENU)
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Lego Plot ', $
				UVALUE='PLOTCLG' )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Plot Projection ', $
				UVALUE='PLOTCLGPROJ' )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' OverPlot Projection ', $
				UVALUE='OPLOTCLGPROJ' )

	proc_id = WIDGET_BUTTON(choicebase, VALUE= ' Process ', UVALUE='PROC')
	IF ext_version THEN WIDGET_CONTROL, proc_id, sensitive=0

	edit_id = WIDGET_BUTTON(choicebase, VALUE= ' Edit Values ', /MENU)
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'Actual Values', $
				UVALUE = 'EDACTVAL')
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'Computed Values', $
				UVALUE = 'EDCOMVAL')
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'CALG Values', $
				UVALUE = 'EDCLGVAL')

	write_id = WIDGET_BUTTON(choicebase, VALUE = ' Write Values ', /MENU)
	id_1 = WIDGET_BUTTON(write_id, VALUE = 'to internal common', $
				UVALUE = 'WRICOM')
	wricalg_id = WIDGET_BUTTON(write_id, VALUE = 'to Cal G file', $
				UVALUE = 'WRICALG')
	wricalu_id = WIDGET_BUTTON(write_id, VALUE = 'to Cal U file', $
				UVALUE = 'WRICALU')

	init_id = WIDGET_BUTTON(choicebase, VALUE = ' Re-initialize ', $
			UVAL="INIT")

	quit_id = WIDGET_BUTTON(ppsfbase, VALUE = '  Quit  ', $
                        /FRAME, UVALUE = 'QUIT')

        WIDGET_CONTROL, ppsfbase, /REALIZE, TLB_SET_XOFFSET=300, $
                        TLB_SET_YOFFSET=50

        Xmanager,No_BLOCK=1, "pia_cal_ppsf", ppsfbase, GROUP=group
	
RETURN
END
