;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;
; NAME:
;       PIA_CAL_RESPCHK
;
; PURPOSE:
;       Top level menu for Responsivity check analysis
;
; CATEGORY:
;       PIA - calibration
;
; CALLING SEQUENCE:
;       PIA_CAL_RESPCHK
;
; COMMON BLOCKS:
;       colour_indices
;       pia_calrespchk_cmn (internal)
;       pia_varselected_cmn (internal)
;       pia_dspchz_cmn (internal)
;       
; PROCEDURES USED:
;       PIA LIB:
;               get_respchk_str
;               pia_multchoice
;               pia_select_var
;               pia_showstr
;               pia_xplot
;               write_respchkstr
;       ASTRO LIB:
;               avg
;               boost_array
;               date_conv
;               fxhread
;               fxpar
;               match
;       INTERNAL:
;               rchk_struct_val_choice
;               rchkstr_show
;               pia_cal_respchk_event
;
; MODIFICATION HISTORY:
;       Written by: J.Acosta (Vilspa)                   May 1997
;
;-


; *************************************************************
; ***************  choice menu for structure elements
; *************************************************************

PRO RCHK_STRUCT_VAL_CHOICE

COMMON pia_calrespchk_cmn, dets, dets_phys, detact, newstruct, det_id, rchkstruct 
;;COMMON pia_varselected_cmn, vars

	data_names = ['Flag ', 'Date ', 'Julian Date', 'Rev. Number', $ 
	  'Orb. pos.','FCS No.','FCS heating', 'Temperature']
	  
	data_str = ['flag','date','jdate','rev','orbpos','fcsn','fcspow',$ 
	             'treset','temp']
	nele_data = N_ELEMENTS(data_str)
	data_tag = STRUPCASE(TAG_NAMES(rchkstruct))
	data_type = [0,2,0,0,0,1,0,1,0]
	data_pos = intarr(nele_data) 
	FOR I=0, nele_data-1 DO BEGIN
	  ind = where(data_tag eq strupcase(data_str(i)),nc)
	  IF nc eq 0 THEN BEGIN
	    print,string(7b),'Error in structure tag_names' 
	    RETURN
	  ENDIF  
	  data_pos(i) = ind(0)
	ENDFOR	  
	  
	data_exa = STRARR(nele_data)
	FOR itag=0, nele_data-1 DO data_exa(itag) = $  
	            STRING(rchkstruct(0).(data_pos(itag)))
	  
	  
; get variables limits
	pia_select_var, data_exa, lim_vars, VARNAMES=data_names, GROUP=group, $
	  VARTYP = data_type, STOP = choi_cancel
	  
	IF choi_cancel THEN RETURN
	
	vars = lim_vars
	indnot = WHERE(vars(0,*) EQ '',nnot)

	nelem = N_ELEMENTS(rchkstruct)
	indall = indgen(nelem)

; look first for absolute choices
 
        indch = WHERE(vars(0,*) NE '' AND data_type EQ 1, count)
 
        IF count GT 0 THEN BEGIN
          FOR I=0,count-1 DO BEGIN
                filt = [vars(0,indch(i))]
 
                indfilt = WHERE(STRTRIM(rchkstruct.(data_pos(indch(i))),2) EQ $ 
                        STRTRIM(filt(0),2), nfilt)
 
                IF nfilt EQ 0 THEN BEGIN
 
                        text = 'No ' + data_names(indch(i)) + $
                                ' corresponding to selection'
                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = text
                        RETURN
                ENDIF
                                          
                match, indall, indfilt, suba, subb, count=count
                IF count EQ 0 THEN GOTO, nocomb
                indall = indall(suba)
           ENDFOR
          ENDIF
 
; and then for chosen ranges
 
        indch = WHERE(vars(0,*) NE '' AND data_type EQ 0, count)
 
        IF count GT 0 THEN BEGIN
          FOR I=0,count-1 DO BEGIN
                IF vars(1,indch(i)) EQ '' THEN BEGIN
                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" Incomplete Spec found, returning  "]
                        RETURN
                ENDIF
 
                filt = [vars(0,indch(i)),vars(1,indch(i))]
                indfilt = WHERE(rchkstruct.(data_pos(indch(i))) GE filt(0) AND $
                                rchkstruct.(data_pos(indch(i))) LE filt(1), nfilt)
 
                IF nfilt EQ 0 THEN BEGIN
 
                        text = 'No ' + data_names(indch(i)) + $

                                ' corresponding to selection'
                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = text
                        RETURN
                ENDIF
                                          
                match, indall, indfilt, suba, subb, count=count
                IF count EQ 0 THEN GOTO, NOCOMB
                indall = indall(suba)
          ENDFOR
        ENDIF
 
; and then for chosen ranges which need date conversion
 
        indch = WHERE(vars(0,*) NE '' AND data_type EQ 2, count)
 
        IF count GT 0 THEN BEGIN
          FOR I=0,count-1 DO BEGIN
                IF vars(1,indch(i)) EQ '' THEN BEGIN
                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" Incomplete Spec found, returning  "]
                        RETURN
                ENDIF
 
                filt = [date_conv(vars(0,indch(i))),date_conv(vars(1,indch(i)))]
                NEL2CONV = N_ELEMENTS(rchkstruct.(data_pos(indch(i))))
                dat_conv = dblarr(NEL2CONV)
                FOR IDAT = 0,NEL2CONV-1 DO $
                 dat_conv(IDAT) = $
                   date_conv(rchkstruct(IDAT).(data_pos(indch(i))))
 
                indfilt = WHERE(dat_conv GE filt(0) AND $
                                dat_conv LE filt(1), nfilt)
 
                IF nfilt EQ 0 THEN BEGIN
 
                        text = 'No ' + data_names(indch(i)) + $
                                ' corresponding to selection'
                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = text
                        RETURN
                ENDIF
                                          
                match, indall, indfilt, suba, subb, count=count
                IF count EQ 0 THEN GOTO, NOCOMB
                indall = indall(suba)
          ENDFOR
        ENDIF
 
        acc_indices = indall
        nacc = N_ELEMENTS(indall)
        Text =  ["A total of "+ STRTRIM(STRING(nacc),2) + " observations", $
                 "correspond to the combination selected"]
        XDISPLAYFILE, "", $
                TITLE = "New Responsivity check selection", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [text]      
 
        RETURN
NOCOMB: 
        XDISPLAYFILE, "", $
            TITLE = "Input not accepted", $
            WIDTH = 50, $
            HEIGHT = 4, $
            TEXT = [" Combined selection discards all elements "]
        RETURN

END 

; *************************************************************
; shows a dark current structure
; *************************************************************
PRO RCHKSTR_SHOW, rchkstr, GROUP=group

	data_names = ['Flag ', 'ADMN', 'Date ', 'Julian Date', $
		      'Rev. number', 'Temperature', 'FCS no.', 'FCS heating', $
			'Orb. pos.','t_reset','treset correction','Signals ', $
			'Uncertainties ', 'Signal flags','Processing date']  
	
	pia_showstr, rchkstr, VALNAMES=data_names

END 


; *************************************************************
; *
; *************************************************************
PRO PIA_CAL_RESPCHK_EVENT, event

@colour_indices

COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
COMMON pia_calrespchk_cmn, dets, dets_phys, detact, newstruct, det_id, rchkstruct  


	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	i = WHERE(dets EQ uvalue, n)
	i = i(0)
	IF n NE 0 THEN uvalue = 'DET'

	CASE uvalue of
	   'DET': BEGIN
			WIDGET_CONTROL, det_id, SET_VALUE=dets(i)
			detact = dets(i)
			get_respchk_str, detact, rchkstruct
			newstruct = rchkstruct
		  END   
		  
	   'PLOTACT': BEGIN 
			xind = indgen(N_ELEMENTS(darkcurr)) + 1
			PIA_XPLOT, xind, darkcurr, psym=4, $
				title= detact + ' default Dark Current', $
				xtitle = ' Pixel ', $
				ytitle = 'Responsivity      [V/s]', $
				legend = title   

		      END

	   'OPLOTACT': BEGIN 
			xind = indgen(N_ELEMENTS(darkcurr)) + 1

			IF N_ELEMENTS(zoom_color) EQ 0 THEN zoom_color=-1
			IF zoom_color EQ -1 THEN zoom_color = green ELSE $
				zoom_color = zoom_color + 1
			IF zoom_color EQ 9 then zoom_color = 2

			IF N_ELEMENTS(zoom_psymch) EQ 0 THEN zoom_psymch=-1
			IF zoom_psymch EQ -1 THEN zoom_psymch = 2 ELSE $
				zoom_psymch = zoom_psymch + 1
			IF zoom_psymch EQ 8 then zoom_psymch = 2


			PIA_XPLOT, xind, darkcurr, psym = zoom_psymch, $
				color = zoom_color, $
				title= detact + ' default Dark Current', $
				xtitle = ' Pixel ', $
				ytitle = 'Dark Current      [V/s]', $
				legend = title, overplot = 99           
		      END


	   'PLOTCOM': BEGIN 
			IF N_ELEMENTS(newdarkcurr) NE 0 THEN BEGIN
			 xind = indgen(N_ELEMENTS(newdarkcurr(*,0))) + 1
			 PIA_XPLOT, xind, newdarkcurr(*,0), GROUP=event.top, $
				newdarkcurr(*,1), psym=4, $
				title= detact + ' computed Dark Current', $
				xtitle = ' Pixel ', $
				ytitle = 'Dark Current      [V/s]', $
				legend = title   
			ENDIF ELSE MESSAGE, /INFO, $
				'Sorry, no new dark current computed'
		      END

	   'OPLOTCOM': BEGIN 
			IF N_ELEMENTS(newdarkcurr) NE 0 THEN BEGIN
			 xind = indgen(N_ELEMENTS(newdarkcurr(*,0))) + 1
			 IF N_ELEMENTS(zoom_color) EQ 0 THEN zoom_color=-1
			 IF zoom_color EQ -1 THEN zoom_color = green ELSE $
				zoom_color = zoom_color + 1
			 IF zoom_color EQ 9 then zoom_color = 2

			 IF N_ELEMENTS(zoom_psymch) EQ 0 THEN zoom_psymch=-1
			 IF zoom_psymch EQ -1 THEN zoom_psymch = 2 ELSE $
				zoom_psymch = zoom_psymch + 1
			 IF zoom_psymch EQ 8 then zoom_psymch = 2

			 PIA_XPLOT, xind, newdarkcurr(*,0), GROUP=event.top, $
				newdarkcurr(*,1), psym = zoom_psymch, $
				color = zoom_color, $
				title= detact + ' computed Dark Current', $
				xtitle = ' Pixel ', $
				ytitle = 'Dark Current      [V/s]', $
				legend = title, overplot = 99           
			ENDIF ELSE MESSAGE, /INFO, $
				'Sorry, no new dark current computed'
		      END

	   'PROC_ERD': $
		PIA_CAL_RESPCHK_PROC, STRMID(detact,0,2), newstruct

	   'PROC_SRD': $
		PIA_CAL_RESPCHK_PROC, STRMID(detact,0,2), newstruct,   $ 
			/FROM_SRD

	   'PROC_SCP': $
	        PIA_CAL_RESPCHK_PROC, STRMID(detact,0,2), newstruct, $
			/FROM_SCP

	   'PROC_STR': BEGIN
; choose the parameters to be used and calculate newdarkcurr from them
		RCHK_STRUCT_VAL_CHOICE
	   END

	   'EDACTSTR': BEGIN
		RCHKSTR_SHOW, rchkstruct, GROUP=event.top  
	   END

	   'EDCOMSTR': BEGIN
		RCHKSTR_SHOW, newstruct, GROUP=event.top  
	   END


	   'ADDSTR': BEGIN
		 write_respchkstr, detact, newstruct
		 rchkstruct = [rchkstruct,newstruct]
		END

	   'WRICOM': BEGIN
		 ; copy newstruct to rchkstruct
		 rchkstruct = newstruct
		END

	   'WRISTR': BEGIN
		 ; Ask for confirmation of rewriting 
		 write_respchkstr, detact, newstruct,/REPLACE
		 rchkstruct = newstruct
		END

	   'WRIAFILN': BEGIN   ; write ASCII file 
		 ; ask for name
		 filename = !INTDIR + strmid(detact,0,2) + '_respchk.dat'
;		 write_rchkafil, filename, detact, newstruct
		PRINT, "I should write an ascii file, but I can't"
		END

	   'WRIAFILC': BEGIN   ; write ASCII file 
		 ; ask for name
		 filename = !INTDIR + strmid(detact,0,2) + '_respchk.dat'
;		 write_rchkafil, filename, detact, rchkstruct
		PRINT, "I should write an ascii file, but I can't"
		END


	   'QUIT': WIDGET_CONTROL, event.top, /DESTROY
		
	   ELSE: 
	ENDCASE
RETURN
END

; *************************************************************
; *
; *
; *
; *************************************************************
PRO PIA_CAL_RESPCHK, GROUP=group

COMMON pia_calrespchk_cmn, dets, dets_phys, detact, newstruct, det_id, rchkstruct
       
        ; dets_ref is used as the reference name for detector, SS will 
        ; be responsivity check using smaller FCS power.
	dets = ['P1','P2', 'P3', 'C100', 'C200', 'SS', 'SL']  
	dets_phys = ['P1','P2', 'P3', 'C100', 'C200', 'SL', 'SL'] 

; take C100 as initial choice
	detact = dets(0)

; write rchkstructure into the local structure  -  use initially for new old 
	 get_respchk_str, detact, rchkstruct
         newstruct = rchkstruct

	rchkbase = WIDGET_BASE(TITLE = 'Responsivity Check Analysis Menu', $
				/COLUMN)

	choicebase = WIDGET_BASE(rchkbase, /ROW)

	det_id = WIDGET_BUTTON(choicebase, VALUE = detact, /MENU)

	FOR I=0,N_ELEMENTS(dets)-1 DO $   
	   id_0 = WIDGET_BUTTON(det_id, VALUE=dets(i),UVALUE=dets(i))
  
	plot_id = WIDGET_BUTTON(choicebase, VALUE = ' Plot ', /MENU)
	id_1 = WIDGET_BUTTON(plot_id, VALUE = ' Actual Values ', /MENU )
	id_2 = WIDGET_BUTTON(id_1, VALUE = ' New Plot ', UVALUE='PLOTACT')
	id_2 = WIDGET_BUTTON(id_1, VALUE = ' Overplot ', UVALUE='OPLOTACT')
	id_1 = WIDGET_BUTTON(plot_id, VALUE = ' Computed Values ', /MENU)
	id_2 = WIDGET_BUTTON(id_1, VALUE = ' New Plot ', UVALUE='PLOTCOM')
	id_2 = WIDGET_BUTTON(id_1, VALUE = ' Overplot ', UVALUE='OPLOTCOM')

	proc_id = WIDGET_BUTTON(choicebase, VALUE= ' Process ', /MENU)
	id_1 = WIDGET_BUTTON(proc_id, $
		VALUE= 'New values and new Table Records from ERD measurements ', $
				UVALUE='PROC_ERD')
	id_1 = WIDGET_BUTTON(proc_id, $
		VALUE= 'New values and new Table Records from SRD measurements ', $
				UVALUE='PROC_SRD')
	id_1 = WIDGET_BUTTON(proc_id, $
		VALUE= 'New values and new Table Records from SCP measurements ', $
				UVALUE='PROC_SCP')
	id_1 = WIDGET_BUTTON(proc_id, $
		VALUE= 'New values from Cumulated Table ', $
				UVALUE='PROC_STR')

	edit_id = WIDGET_BUTTON(choicebase, $
		VALUE= 'Results Cumulated Table', /MENU)
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'Actual Values', $
				UVALUE = 'EDACTSTR')
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'Computed Values', $
				UVALUE = 'EDCOMSTR')

	write_id = WIDGET_BUTTON(choicebase, VALUE = ' Write Values ', /MENU)
	id_1 = WIDGET_BUTTON(write_id, $
		VALUE = 'Set new Records to internal common', $
				UVALUE = 'WRICOM')
	id_1 = WIDGET_BUTTON(write_id, $
		VALUE = 'Add New Records to Cumulated Table', $
				UVALUE = 'ADDSTR')
	id_1 = WIDGET_BUTTON(write_id, $
		VALUE = 'New Records to New Cumulated Table', $
				UVALUE = 'WRISTR')
	wrifile_id = WIDGET_BUTTON(write_id, $
		VALUE = 'New Values to ASCII file', $
				UVALUE = 'WRIAFILN')
	wricalu_id = WIDGET_BUTTON(write_id, $
		VALUE = 'Current Values to ASCII file', $
				UVALUE = 'WRIAFILC')

	quit_id = WIDGET_BUTTON(rchkbase, VALUE = '  Quit  ', $
			/FRAME, UVALUE = 'QUIT')

	WIDGET_CONTROL, rchkbase, /REALIZE, TLB_SET_XOFFSET=300, $
			TLB_SET_YOFFSET=50

	xMANAGER,No_BLOCK=1, "pia_cal_respchk", rchkbase, GROUP=group
	
RETURN
END
