;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_CAL_RESPONS
;
; PURPOSE:
;	Top level menu for Response File production, one of
;	the Calibration Files Derivation Procedures (CFDP)  
;
; CATEGORY:
;       PIA - graphics
;
; CALLING SEQUENCE:
;       PIA_CAL_RESPONS
;
; KEYWORD PARAMETERS:
;	GROUP=group: Group leader
;
; COMMON BLOCKS:
;	colour_indices
;	phtresdef
;	resp2calu_cmn (internal)
;	pia_respons_cmn (internal)
;	pia_varselected_cmn (internal)
;	cresp_edit_cmn (internal)
;	cal_resp_cmn (internal)
;
; PROCEDURES USED:
;	PIA LIB:
;		get_respstr
;		pia_select_var
;		pia_showstr
;		pia_write_author
;		pia_write_comment
;		pia_write_version
;		pia_xplot
;		read_asc_pdetect
;		read_resp
;		weight_mean
;		write_asc_pdetect
;		write_resp
;		write_respstr
;       ASTRO LIB:
;		boost_array
;		date_conv
;		fxhread
;		fxpar
;		match
;       INTERNAL:
;		resp2calu_weight_event
;		resp2calu_weight
;		respstruct_val_choice
;		respstr_show
;		respons_edit_event
;		respons_edit
;		crespons_edit_event
;		crespons_edit
;		cluresp_edit_event
;		cluresp_edit
;		clgresp_edit_event
;		clgresp_edit
;		pia_cal_respons_event
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel (ESA/ESTEC) 		March 1995
;	Modified (last) by: cg, wmt			Sept 1995
;	Oct 95 Version 3.5
;	Processing from measurements not allowed (CG)	January 1996
;	Replacing of accumulated structures added (CG)	January 1996
;	Handling from export version possible (CG)	April 1997
;	V6.2
;	Showing PHT-S responsivities also (CG)		September 1997
;	V6.5
;	Re-initialize button added (CG)			November 1997
;	V6.6
;	/Modal use according to IDL >=5.0 (CG)		February 1999
;	V7.3.1
;
;-
; *********************************************************************
; *
; *********************************************************************
PRO resp2calu_weight_event, event

COMMON resp2calu_cmn, edval_id, pixels
COMMON pia_respons_cmn, dets, detact, respons, newrespons, $
	wrical_id, det_id, pixl_weight, respstruct, newstruct, eta


        WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

        CASE uvalue of
         'LIST': BEGIN
		IF STRMID(detact,0,1) EQ 'S' THEN BEGIN
		 WIDGET_CONTROL, edval_id(0), GET_VALUE=value
		 WIDGET_CONTROL, edval_id(1), GET_VALUE=valu2
		 WIDGET_CONTROL, edval_id(2), GET_VALUE=valu3
		 WIDGET_CONTROL, edval_id(3), GET_VALUE=valu4
		 value = [value,valu2,valu3,valu4]
		ENDIF ELSE $
                 WIDGET_CONTROL, edval_id, GET_VALUE=value

                IF N_ELEMENTS(value) EQ pixels THEN $
                        pixl_weight = float(value) ELSE BEGIN
                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" Wrong responses weighting input  ", $]
                                  "     ", $ ]
                                  " Fix it and try again, please "]
                        RETURN
                ENDELSE
         END
         'QUIT': WIDGET_CONTROL, event.top, /DESTROY
         ELSE:
        ENDCASE
END

; *********************************************************************
; * Menu for weighting dark currents
; *********************************************************************
PRO resp2calu_weight, group=group

COMMON resp2calu_cmn, edval_id, pixels
COMMON pia_respons_cmn, dets, detact, respons, newrespons, $
	wrical_id, det_id, pixl_weight, respstruct, newstruct, eta


        nelem = N_ELEMENTS(pixl_weight)
        pixels = N_ELEMENTS(newrespons(*,0))

        IF nelem NE pixels THEN $
                pixl_weight = fltarr(pixels) + 1.

	IF not KEYWORD_SET(group) THEN group = !PIA_TOP_WID
        edbase = WIDGET_BASE(TITLE =detact+' Responses weighting', $
                        /column, /modal, group=group)

        edvalbase = WIDGET_BASE(edbase, /row)
        pixlist = STRTRIM(STRING(indgen(pixels) + 1),2)
        pixlist = 'Pixel ' + pixlist
	if STRMID(detact, 0, 1) EQ 'S' then begin
	  edval_id = LONARR(4)
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(0:31))
	  edval_id(0) = WIDGET_TEXT(edvalbase, /editable, XSIZE=18, YSIZE=32, $
		VALUE = STRTRIM(STRTRIM(STRING(pixl_weight(0:31)),2)), $
		UVALUE='JUNK')
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(32:63))
	  edval_id(1) = WIDGET_TEXT(edvalbase, /editable, XSIZE=18, YSIZE=32, $
		VALUE = STRTRIM(STRTRIM(STRING(pixl_weight(32:63)),2)),$
		 UVALUE='JUNK')
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(64:95), UVALUE='JUNK')
	  edval_id(2) = WIDGET_TEXT(edvalbase, /editable, XSIZE=18, YSIZE=32, $
		VALUE = STRTRIM(STRTRIM(STRING(pixl_weight(64:95)),2)),$
		UVALUE='JUNK')
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(96:127), UVALUE='JUNK')
	  edval_id(3) = WIDGET_TEXT(edvalbase, /editable, XSIZE=18, YSIZE=32, $
		VALUE = STRTRIM(STRTRIM(STRING(pixl_weight(96:127)),2)), $
		UVALUE='JUNK')
	ENDIF ELSE BEGIN
          edval = WIDGET_TEXT(edvalbase, XSIZE=8, YSIZE=pixels, $
           VALUE = pixlist, /SCROLL)
          edval_id = WIDGET_TEXT(edvalbase, /editable, XSIZE=18, YSIZE=pixels, $
           VALUE = STRTRIM(STRING(pixl_weight),2), /SCROLL, UVALUE='JUNK')
	ENDELSE
	
        edconbase = WIDGET_BASE(edbase, /row)
        ok = WIDGET_BUTTON(edconbase, VALUE='  OK  ', UVALUE='LIST')
        quit = WIDGET_BUTTON(edconbase, VALUE=' QUIT ', UVALUE='QUIT')
        WIDGET_CONTROL, edbase, /REALIZE
        xMANAGER,No_BLOCK=1, "RESP2CALU_WEIGHT", edbase, GROUP=group
        RETURN
END

; *********************************************************************
; * choice menu for structure elements
; *********************************************************************
PRO RESPS_STRUCT_CALC

COMMON pia_varselected_cmn, vars
COMMON pia_respons_cmn, dets, detact, respons, newrespons, $
	wrical_id, det_id, pixl_weight, respstruct, newrespstruct, eta 

	pia_resps_struct_val_choice, respstruct, indall 

	IF indall(0) EQ -1 THEN RETURN
	
	npix = N_ELEMENTS(respons)
	
	eta = fltarr(npix)
	erreta = eta
	FOR I=0, npix-1 DO BEGIN 			
		indok = WHERE(respstruct(indall).sflg(i) EQ 0, n)
		IF n GT 0 THEN BEGIN
		  	WEIGHT_MEAN, respstruct(indall(indok)).resps(i), $
				respstruct(indall(indok)).respu(i), avr, sig, $
				stdev  
			newrespons(i,0) = avr
			newrespons(i,1) = stdev
		  	WEIGHT_MEAN, respstruct(indall(indok)).eta(i), $
				respstruct(indall(indok)).err_eta(i), avr, sig, $
				stdev 
			eta(i) = avr
			erreta(i) = stdev
		ENDIF ELSE BEGIN 
		  	indok = WHERE(respstruct(indall).sflg(i) EQ 1, n)
			IF n GT 0 THEN BEGIN
		  		WEIGHT_MEAN, respstruct(indall(indok)).resps(i), $
				  respstruct(indall(indok)).respu(i), avr, sig,  $
				  stdev  
				newrespons(i,0) = avr
				newrespons(i,1) = stdev
		  	WEIGHT_MEAN, respstruct(indall(indok)).eta(i), $
				respstruct(indall(indok)).err_eta(i), avr, sig, $
				stdev 
			eta(i) = avr
			erreta(i) = stdev 
			        MESSAGE, /INFO, 'Pixel'+STRING(I+1)+$
					' has only warning flags'
			ENDIF ELSE BEGIN   
				newrespons(i,0) = 0.
				newrespons(i,1) = 0.
			        MESSAGE, /INFO, 'Pixel'+STRING(I+1)+$
					' has only bad flags'
			ENDELSE
		ENDELSE
	ENDFOR
	
	newrespstruct = respstruct(indall)

	text = ['Results from Responsivity accu tables extraction', $
		'================================================', ' ', $
		'Responsivities:', '--------------', $
		'Pixel ' + STRTRIM(STRING(indgen(N_ELEMENTS(eta))+1),2)+': '+$
		STRTRIM(STRING(newrespons(*,0)),2) + ' +/- ' + $
		STRTRIM(STRING(newrespons(*,1)),2), ' ', $
		'Quantum Efficiency:', '--------------', $
		'Pixel ' + STRTRIM(STRING(indgen(N_ELEMENTS(eta))+1),2)+': '+$
		STRTRIM(STRING(eta),2) + ' +/- ' + $
		STRTRIM(STRING(erreta),2) ]	
		
		PIA_disp_print_file, $
				"Resp_from_table", $
			 	TEXT=text, $
			 	TITLE = "PIA Responsivity extraction"

	RETURN

END 

; *********************************************************************
; * 
; *********************************************************************
PRO RESPSTR_SHOW, respstr, GROUP=group
; shows a responsivity structure
	data_names = ['General Flag ', 'Date ', 'Source ID',  $ 
	              'TDTNR', 'Orbital Pos.', 'Filter ID ', $
                      'In-Band Power [W] ', 'IBP Uncertainty [W]', $
                      'Number of photons ', $
                      'Responsivity [A/W]', 'R Uncertainty [A/W]',$
                      'Quantum Efficiency ', 'QE Uncertainty', $
                      'Noise Equivalent Power ', 'NEP Uncertainty', $
                      'Signal flags', 'Processing time ', 'SED file', $
                      'Lambda C' ]  
	
        ind_fil = where (tag_names(respstr) eq 'FILTER_ID')
	CASE STRMID(respstr(0).(ind_fil(0)),0,2) OF
		'C2': detpix=4
		'C1': detpix=9
		ELSE: detpix=1
	ENDCASE
	tmpstr = {FLAG:0, date:'', source: '',tdtnr:'', $
            orbpos:0.0, filter_id: '', $
            f_star: 0., f_star_unc: 0.0, qb_star: 0., $
            resps:fltarr(detpix), respu:fltarr(detpix), $
            eta:fltarr(detpix), err_eta:fltarr(detpix), $
            nep:fltarr(detpix), err_nep:fltarr(detpix), $
            sflg: intarr(detpix), Proc_time:'', SED_file:STRARR(2), clam:0.}

        tmpstr = REPLICATE(tmpstr, N_ELEMENTS(respstr))
        tmp_ntag = n_tags(tmpstr) -1
        FOR I=0,tmp_ntag-1 DO tmpstr.(i) = respstr.(i)
        ind_fil = where (tag_names(respstr) eq 'FILTER_ID')
        tmpstr.(tmp_ntag) = FLOAT(STRMID(respstr.(ind_fil(0)),3,5))
        
        
         
        pia_showstr, tmpstr, VALNAMES=data_names

END 


; *********************************************************************
; * 
; *********************************************************************
PRO RESPONS_EDIT_event, event 

COMMON pia_respons_cmn, dets, detact, respons, newrespons, $
	wrical_id, det_id, pixl_weight, newstruct, respstruct

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.id, GET_VALUE=value
	CASE uvalue of
	'list': PRINT, event.id, value
	'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
	ENDCASE
END

; *********************************************************************
; * 
; *********************************************************************
PRO RESPONS_EDIT 

COMMON pia_respons_cmn, dets, detact, respons, newrespons, $
	wrical_id, det_id, pixl_weight, newstruct, respstruct

	edbase = WIDGET_BASE(TITLE =detact+' Actual Responses', $
			/column)
	edvalbase = WIDGET_BASE(edbase, /row)
	pixels = N_ELEMENTS(respons(*,0))
	pixlist = STRTRIM(STRING(indgen(pixels) + 1),2)
	pixlist = 'Pixel ' + pixlist 
	if strmid(detact, 0, 1) EQ 'S' then begin
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(0:31))
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
		VALUE = STRTRIM(STRING(respons(0:31))))
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(32:63))
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
		VALUE = STRTRIM(STRING(respons(32:63))))
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(64:95))
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
		VALUE = STRTRIM(STRING(respons(64:95))))
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(96:127))
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
		VALUE = STRTRIM(STRING(respons(96:127))))
	endif else begin
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=pixels, $
	        VALUE = pixlist)
	  edval = WIDGET_TEXT(edvalbase, XSIZE=18, YSIZE=pixels, $
		VALUE = STRTRIM(STRING(respons)),uvalue='list')
	endelse
	quit = WIDGET_BUTTON(edbase, VALUE=' QUIT ', UVALUE='QUIT') 
	WIDGET_CONTROL, edbase, /REALIZE
	xMANAGER,No_BLOCK=1, "RESPONS_EDIT", edbase, GROUP=group 
	RETURN
END 

; *********************************************************************
; * 
; *********************************************************************
PRO CRESPONS_EDIT_event, event 

COMMON cresp_edit_cmn, edval_id, pixels 
COMMON pia_respons_cmn, dets, detact, respons, newrespons, $
	wrical_id, det_id, pixl_weight, newstruct, respstruct


	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue of
	 'LIST': BEGIN
		IF STRMID(detact,0,1) EQ 'S' THEN BEGIN
		 WIDGET_CONTROL, edval_id(0), GET_VALUE=value
		 WIDGET_CONTROL, edval_id(1), GET_VALUE=valu2
		 WIDGET_CONTROL, edval_id(2), GET_VALUE=valu3
		 WIDGET_CONTROL, edval_id(3), GET_VALUE=valu4
		 value = [value,valu2,valu3,valu4]
		ENDIF ELSE $
		 WIDGET_CONTROL, edval_id, GET_VALUE=value

		IF N_ELEMENTS(value) EQ pixels THEN $
			newrespons(*,0) = float(value) ELSE BEGIN
                  	XDISPLAYFILE, "", $
                    		TITLE = "Input not accepted", $
                    		WIDTH = 50, $
                    		HEIGHT = 4, $
                    	  TEXT = [" Wrong respons input  ", $]
                          	  "     ", $ ]
                          	  " Fix it and try again, please "]
			RETURN
		ENDELSE
	 END
	 'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
         ELSE: 
	ENDCASE
END

; *********************************************************************
; * 
; *********************************************************************
PRO CRESPONS_EDIT 

COMMON cresp_edit_cmn, edval_id, pixels 
COMMON pia_respons_cmn, dets, detact, respons, newrespons, $
	wrical_id, det_id, pixl_weight, newstruct, respstruct


	edbase = WIDGET_BASE(TITLE =detact+' Computed Responses', $
			/column)

	edvalbase = WIDGET_BASE(edbase, /row)
	pixels = N_ELEMENTS(newrespons(*,0))
	pixlist = STRTRIM(STRING(indgen(pixels) + 1),2)
	pixlist = 'Pixel ' + pixlist 
	if strmid(detact, 0, 1) EQ 'S' then begin
	  edval_id = LONARR(4)
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(0:31))
	  edval_id(0) = WIDGET_TEXT(edvalbase, /editable, XSIZE=10, YSIZE=32, $
		VALUE = STRTRIM(STRING(newrespons(0:31,0))), UVALUE='JUNK')
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(32:63))
	  edval_id(1) = WIDGET_TEXT(edvalbase, /editable, XSIZE=10, YSIZE=32, $
		VALUE = STRTRIM(STRING(newrespons(32:63,0))), UVALUE='JUNK')
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(64:95))
	  edval_id(2) = WIDGET_TEXT(edvalbase, /editable, XSIZE=10, YSIZE=32, $
		VALUE = STRTRIM(STRING(newrespons(64:95,0))), UVALUE='JUNK')
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(96:127))
	  edval_id(3) = WIDGET_TEXT(edvalbase, /editable, XSIZE=10, YSIZE=32, $
		VALUE = STRTRIM(STRING(newrespons(96:127,0))), UVALUE='JUNK')
	endif else begin
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=pixels, $
	    VALUE = pixlist)
	  edval_id = WIDGET_TEXT(edvalbase, /editable, XSIZE=18, YSIZE=pixels, $
	    VALUE = STRTRIM(STRING(newrespons(*,0)),2), UVALUE='JUNK')
	endelse
	edconbase = WIDGET_BASE(edbase, /row)
	ok = WIDGET_BUTTON(edconbase, VALUE='  OK  ', UVALUE='LIST')
	quit = WIDGET_BUTTON(edconbase, VALUE=' QUIT ', UVALUE='QUIT') 
	WIDGET_CONTROL, edbase, /REALIZE
	xMANAGER,No_BLOCK=1, "CRESPONS_EDIT", edbase, GROUP=group
	RETURN
END 

; *********************************************************************
; * 
; *********************************************************************
PRO CLURESP_EDIT_event, event 

COMMON pia_respons_cmn, dets, detact, respons, newrespons, $
	wrical_id, det_id, pixl_weight, newstruct, respstruct
COMMON cal_resp, calu_resp, calg_resp, calg_respons_p1, calg_respons_p2, calg_respons_p3, $
		 calg_respons_c1, calg_respons_c2, calg_respons_sssl

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.id, GET_VALUE=value
	CASE uvalue of
	'list': PRINT, event.id, value
	'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
	ENDCASE
END

; *********************************************************************
; * 
; *********************************************************************
PRO CLURESP_EDIT 

COMMON pia_respons_cmn, dets, detact, respons, newrespons, $
	wrical_id, det_id, pixl_weight, newstruct, respstruct
COMMON cal_resp, calu_resp, calg_resp, calg_respons_p1, calg_respons_p2, calg_respons_p3, $
		 calg_respons_c1, calg_respons_c2, calg_respons_sssl

	edbase = WIDGET_BASE(TITLE =' CALU Uplink Responsivity Table', $
			/column)
	edvalbase = WIDGET_BASE(edbase, /row)
        detlist = ['P1', 'P2', 'P3', 'C1', 'C2', 'SS', 'SL']
        detlist = 'Detector ' + detlist
        xsize = strlen(detlist(0))
        edval = WIDGET_TEXT(edvalbase, XSIZE=xsize, YSIZE=7, $
          VALUE = detlist)
        edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=7, $
          VALUE = STRING(format='(f10.4)', calu_resp), uvalue= 'list')

        edconbase = WIDGET_BASE(edbase, /row)
        quit = WIDGET_BUTTON(edconbase, /frame, VALUE=' QUIT ', UVALUE='QUIT')

	WIDGET_CONTROL, edbase, /REALIZE
	xMANAGER,No_BLOCK=1, "RESPONS_EDIT", edbase, GROUP=group 
	RETURN
END 

; *********************************************************************
; * 
; *********************************************************************
PRO CLGRESP_EDIT_event, event 
COMMON pia_respons_cmn, dets, detact, respons, newrespons, $
	wrical_id, det_id, pixl_weight, newstruct, respstruct
COMMON cal_resp, calu_resp, calg_resp, calg_respons_p1, calg_respons_p2, calg_respons_p3, $
		 calg_respons_c1, calg_respons_c2, calg_respons_sssl

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.id, GET_VALUE=value
	CASE uvalue of
	'list': PRINT, event.id, value
	'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
	ENDCASE
END

; *********************************************************************
; * 
; *********************************************************************
PRO CLGRESP_EDIT 
COMMON pia_respons_cmn, dets, detact, respons, newrespons, $
	wrical_id, det_id, pixl_weight, newstruct, respstruct
COMMON cal_resp, calu_resp, calg_resp, calg_respons_p1, calg_respons_p2, calg_respons_p3, $
		 calg_respons_c1, calg_respons_c2, calg_respons_sssl


	edbase = WIDGET_BASE(TITLE =detact+' CalG Responsivity', $
			/column)
	edvalbase = WIDGET_BASE(edbase, /row)
	pixels = N_ELEMENTS(calg_resp)
	pixlist = STRTRIM(STRING(indgen(pixels) + 1),2)
	pixlist = 'Pixel ' + pixlist 
	if strmid(detact, 0, 1) EQ 'S' then begin
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(0:31))
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
		VALUE = STRTRIM(STRING(calg_resp(0:31))))
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(32:63))
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
		VALUE = STRTRIM(STRING(calg_resp(32:63))))
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(64:95))
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
		VALUE = STRTRIM(STRING(calg_resp(64:95))))
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	        VALUE = pixlist(96:127))
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
		VALUE = STRTRIM(STRING(calg_resp(96:127))))
	endif else begin
	  edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=pixels, $
	        VALUE = pixlist)
	  edval = WIDGET_TEXT(edvalbase, XSIZE=18, YSIZE=pixels, $
		VALUE = STRTRIM(STRING(calg_resp)),uvalue='list')
	endelse

        edconbase = WIDGET_BASE(edbase, /row)
        quit = WIDGET_BUTTON(edconbase, /frame, VALUE=' QUIT ', UVALUE='QUIT')

	WIDGET_CONTROL, edbase, /REALIZE
	xMANAGER,No_BLOCK=1, "CLGRESP_EDIT", edbase, GROUP=group 
	RETURN
END 


; *********************************************************************
; * 
; *********************************************************************
PRO PIA_CAL_RESPONS_EVENT, event

@phtresdef
@phtw2jy
@colour_indices
COMMON pia_respons_cmn, dets, detact, respons, newrespons, $
	wrical_id, det_id, pixl_weight, respstruct, newstruct, eta
COMMON cal_resp, calu_resp, calg_resp, calg_respons_p1, calg_respons_p2, calg_respons_p3, $
		 calg_respons_c1, calg_respons_c2, calg_respons_sssl
COMMON pia_cal_respons_proc_res_cmn, resp, dresp, allres, alldres, $
	resp_str, proc_status 
COMMON ext_version, ext_version

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	i = WHERE(dets EQ uvalue, n)
	i = i(0)
	IF n NE 0 THEN uvalue = 'DET'

	CASE uvalue of
	   'DET': BEGIN
	   		WIDGET_CONTROL, det_id, SET_VALUE=dets(i)
			detact = dets(i)
			CASE STRMID(detact,0,2) OF
				'P1': BEGIN
				   respons = p1resp
				   calg_resp = calg_respons_p1
				end
				'P2': BEGIN
				   respons = p2resp
				   calg_resp = calg_respons_p2
				end
				'P3': BEGIN
				   respons = p3resp
				   calg_resp = calg_respons_p3
				end
				'C1': BEGIN
				   respons = c1resp
				   calg_resp = calg_respons_c1
				end
				'C2': BEGIN
				   respons = c2resp
				   calg_resp = calg_respons_c2
				end
				'SS': BEGIN
				   respons = slresp
				   calg_resp = calg_respons_sssl
				end
				'SL': BEGIN
				   respons = slresp
				   calg_resp = calg_respons_sssl
				end
                        ENDCASE
			eta = -1
			newrespons = respons
			boost_array, newrespons, newrespons * 0.
; IF SS/SL give a warning and avoid the structure search
			IF NOT ext_version THEN BEGIN
			 IF strmid(detact,0,1) NE 'S' THEN BEGIN
                          get_respstr, detact, respstruct  
                          newstruct = respstruct
                         ENDIF ELSE $
			  MESSAGE, /info, $
			   'No table use and no processing possible for S'
                        ENDIF
		  END	
	   	  
	   'PLOTACT': BEGIN 
			xind = indgen(N_ELEMENTS(respons)) + 1
			PIA_XPLOT, xind, respons, psym=4, $
				title= detact + ' default Response', $
				xtitle = ' Pixel ', $
				ytitle = 'Response      [A/W]', $
				legend = title   

		      END

	   'OPLOTACT': BEGIN 
			xind = indgen(N_ELEMENTS(respons)) + 1
			PIA_XPLOT, xind, respons, psym = 6, color = yellow, $
				title= detact + ' default Response', $
				xtitle = ' Pixel ', $
				ytitle = 'Response      [A/W]', $
				legend = title, overplot = 99		
		      END

	   'PLOTCOM': BEGIN 
			IF N_ELEMENTS(newrespons) NE 0 THEN BEGIN
			 xind = indgen(N_ELEMENTS(newrespons(*,0))) + 1
			 PIA_XPLOT, xind, newrespons(*,0), $
				newrespons(*,1), psym=4, $
				title= detact + ' computed Response', $
				xtitle = ' Pixel ', $
				ytitle = 'Response      [A/W]', $
				legend = title   
                        ENDIF ELSE MESSAGE, /INFO, $
				'Sorry, no new responses computed'
		      END

	   'OPLOTCOM': BEGIN 
			IF N_ELEMENTS(newrespons) NE 0 THEN BEGIN
			 xind = indgen(N_ELEMENTS(newrespons(*,0))) + 1
			 PIA_XPLOT, xind, newrespons(*,0), $
				newrespons(*,1), psym = 6, color = yellow, $
				title= detact + ' computed Response', $
				xtitle = ' Pixel ', $
				ytitle = 'Response      [A/W]', $
				legend = title, overplot = 99		
                        ENDIF ELSE MESSAGE, /INFO, $
				'Sorry, no new responses computed'
		      END

	   'PLOTETA': BEGIN
			IF ETA(0) EQ -1 THEN BEGIN
                           XDISPLAYFILE, "", $
                                TITLE = " missing ETA", $
                                WIDTH = 30, $
                                HEIGHT = 4, $
                                TEXT = ["ETA was not yet calculated  "]
			   RETURN
			ENDIF
			xind = indgen(N_ELEMENTS(eta)) + 1
			PIA_XPLOT, xind, eta, $
				psym = 6, $
				title= detact + ' computed ETA', $
				xtitle = ' Pixel ', $
				ytitle = 'Quantum efficiency ', $
				legend = title		
		END
			
	   'PLOTCLU': BEGIN
                xind = indgen(7) + 1
                title = 'CalU Responsivity values from p_detect.txt'
                xtitle = 'PHT Detectors: (P1, P2, P3, C1, C2, SS, SL)'
		ytitle = 'Response	[A/W]'
 
                pia_xplot, xind, calu_resp, psym=4, $
                     title=title, xtitle=xtitle, $
                     ytitle = ytitle, $
                     annotation = title, legend=ytitle
	   END

	   'OPLOTCLU': BEGIN
                xind = indgen(7) + 1
                title = 'CalU Responsivity values from p_detect.txt'
                xtitle = 'PHT Detectors: (P1, P2, P3, C1, C2, SS, SL)'
		ytitle = 'Response	[A/W]'
 
                pia_xplot, xind, calu_resp, psym=6, $
                     color=yellow, overplot=99, $
                     title=title, xtitle=xtitle, $
                     ytitle = ytitle, $
                     annotation = title, legend=ytitle
	   END

           'PLOTCALG': BEGIN
                        IF N_ELEMENTS(calg_resp) NE 0 THEN BEGIN
                         xind = indgen(N_ELEMENTS(calg_resp)) + 1
                         PIA_XPLOT, xind, calg_resp, GROUP=event.top, $
                                newrespons(*,1), psym=4, $
                                title= detact + ' CalG Responsivity ', $
                                xtitle = ' Pixel ', $
                                ytitle = 'Responsivity    [A/W]', $
                                legend = title
                        ENDIF ELSE MESSAGE, /INFO, $
                                'Sorry, no responsivity'
                      END

	   'PROC_PRERED': BEGIN 
	   	pia_cal_respons_proc, detact, /from_table
		IF N_ELEMENTS(resp_str) EQ 0 THEN RETURN
		newstruct = resp_str
		newrespons(*,0) = resp
		newrespons(*,1) = dresp
	   END

	   'PROC': BEGIN
              if strmid(detact, 0, 1) ne 'S' then begin
; Note that the pia_write_comment would return an array rather than
; single value.
               pia_write_comment, instcom="SOURCE", source
                source = source(0)
               pia_write_comment, instcom="In-band-power (W)", inbpower
                inbpower = FLOAT(STRTRIM(inbpower(0),2))
               pia_write_comment, $
                instcom="In-band-power uncertainty (W)", inbpowun
                inbpowun = FLOAT(STRTRIM(inbpowun(0),2))
                case strmid(detact, 0, 2) of
                  'C1': crespon = fltarr(9)
                  'C2': crespon = fltarr(4)
                  else: crespon = fltarr(1)
                endcase
                crespun = crespon
                PIA_CAL_RESPONS_PROC, STRMID(detact,0,2), source=source, $
                        ibpower=inbpower, ibpowun = inbpowun
		newstruct = resp_str
                newrespons(*,0) = resp
                newrespons(*,1) = dresp
               endif else message, /INFO, $
                  'Sorry, Processing for SS/SL is not implemented'

           END

           'PROC_STR': RESPS_STRUCT_CALC 

	   'EDACTVAL': RESPONS_EDIT

	   'EDCOMVAL': CRESPONS_EDIT

	   'EDCLUVAL': CLURESP_EDIT

	   'EDCLGVAL': CLGRESP_EDIT

           'EDACTSTR': RESPSTR_SHOW, respstruct, GROUP=event.top

           'EDCOMSTR': RESPSTR_SHOW, newstruct, GROUP=event.top

	   'WRICOM': BEGIN
			CASE STRMID(detact,0,2) OF
				'P1': p1resp = newrespons(*,0)
				'P2': p2resp = newrespons(*,0)
				'P3': p3resp = newrespons(*,0)
				'C1': c1resp = newrespons(*,0)
				'C2': c2resp = newrespons(*,0)
				'SS': slresp = newrespons(*,0)
				'SL': slresp = newrespons(*,0)
                        ENDCASE
                 respons = newrespons
		END

           'WRISTR' : BEGIN
                 write_respstr, detact, newstruct
                 respstruct = [respstruct, newstruct]
           END

           'WRISTR_REPL' : BEGIN
                 write_respstr, detact, newstruct, /replace
                 respstruct = newstruct
           END

	   'WRICALG': BEGIN
		 pia_write_comment, comment
		 comm = ''
		 FOR I=0,N_ELEMENTS(comment)-1 DO comm = comm+comment(i)
		 pia_write_version, version
		 vers = ''
		 FOR I=0,N_ELEMENTS(version)-1 DO vers = vers+version(i)
		 write_resp, 'PIA_RESPONSE', $
			p1resp, p2resp, p3resp, c1resp,$
			c2resp, slresp, comment=comm, version=vers 
		END

           'WRICALU': BEGIN

; get the pixel weights
                IF STRMID(detact,0,1) NE 'P' THEN $
                        resp2calu_weight, group=event.top ELSE pixl_weight = 1.

                IF STRMID(detact,0,1) EQ 'S' THEN detu='SS' ELSE detu=detact

                pia_write_author, author
                auth = ''
                FOR I=0,N_ELEMENTS(author)-1 DO auth = auth+author(i)

                pia_write_version, version
                vers = ''
                FOR I=0,N_ELEMENTS(version)-1 DO vers = vers+version(i)

                INPUT = !CALSAVE + 'pdetect_pia.txt'
                OUTPUT = !CALSAVE + 'pdetect_pia.txt'

                IF detu EQ 'SS' THEN BEGIN
                 iresp = fltarr(2)
                 iresp(0) = TOTAL(newrespons(0:63,0) * pixl_weight(0:63)) $
                            / TOTAL(pixl_weight(0:63))
                 iresp(1) = TOTAL(newrespons(64:127,0) * pixl_weight(64:127)) $
                            / TOTAL(pixl_weight(64:127))
                ENDIF ELSE $
                 iresp = TOTAL(newrespons(*,0) * pixl_weight) $
                                / TOTAL(pixl_weight)

                write_asc_pdetect, detu, respons = iresp(0), version=vers, $
                        author=auth, inputfile=input, outputfile=output

                IF detu EQ 'SS' THEN BEGIN
                        detu = 'SL'
                  write_asc_pdetect, detu, respons = iresp(1), version=vers, $
                         author=auth, inputfile=output, outputfile=output
                ENDIF

           END

           'WRICALU_ETA': BEGIN

		IF eta(0) EQ -1 THEN BEGIN
                        XDISPLAYFILE, "", $
                                TITLE = " missing ETA", $
                                WIDTH = 30, $
                                HEIGHT = 4, $
                          TEXT = ["ETA was not yet calculated  "]
			RETURN
		END
; get the pixel weights
                IF STRMID(detact,0,1) NE 'P' THEN $
                        resp2calu_weight ELSE pixl_weight = 1.

                IF STRMID(detact,0,1) EQ 'S' THEN detu='SS' ELSE detu=detact

                pia_write_author, author
                auth = ''
                FOR I=0,N_ELEMENTS(author)-1 DO auth = auth+author(i)

                pia_write_version, version
                vers = ''
                FOR I=0,N_ELEMENTS(version)-1 DO vers = vers+version(i)

                INPUT = !CALSAVE + 'pdetect_pia.txt'
                OUTPUT = !CALSAVE + 'pdetect_pia.txt'

                IF detu EQ 'SS' THEN BEGIN
                 ieta = fltarr(2)
                 ieta(0) = TOTAL(eta(0:63) * pixl_weight(0:63)) $
                            / TOTAL(pixl_weight(0:63))
                 ieta(1) = TOTAL(eta(64:127) * pixl_weight(64:127)) $
                            / TOTAL(pixl_weight(64:127))
                ENDIF ELSE $
                 ieta = TOTAL(eta * pixl_weight) $
                                / TOTAL(pixl_weight)

                write_asc_pdetect, detu, eta = ieta(0), version=vers, $
                        author=auth, inputfile=input, outputfile=output

                IF detu EQ 'SS' THEN BEGIN
                        detu = 'SL'
                  write_asc_pdetect, detu, eta = ieta(1), version=vers, $
                         author=auth, inputfile=output, outputfile=output
                ENDIF

           END

           'WRICALU_PSSSL': BEGIN

                IF STRMID(detact,0,1) NE 'S' THEN BEGIN
                        XDISPLAYFILE, "", $
                                TITLE = "Detector not accepted", $
                                WIDTH = 30, $
                                HEIGHT = 4, $
                          TEXT = ["This menu is only valid for PHT-S "]
			RETURN
		ENDIF               	

                pia_write_author, author
                auth = ''
                FOR I=0,N_ELEMENTS(author)-1 DO auth = auth+author(i)

                pia_write_version, version
                vers = ''
                FOR I=0,N_ELEMENTS(version)-1 DO vers = vers+version(i)

                INPUT = !CALSAVE + 'p_ss_sl_pia.txt'
		pia_write_anything, 'the input file name', inppro, $
			proposal = INPUT
		IF inppro(0) NE '' THEN INPUT = inppro(0)
                OUTPUT = !CALSAVE + 'p_ss_sl_pia.txt'

		write_asc_psssl, rrespons = newrespons(*,0), inputfile=INPUT, $
			outputfile = OUTPUT, version=vers, author=auth
           END

	   'INIT': BEGIN
	       read_resp
	       slresp = v2jy_s / w2jy_s
	       slresu = v2jyunc_s / w2jy_s
		CASE STRMID(detact,0,2) OF
				'P1': newrespons(*,0) = p1resp 
				'P2': newrespons(*,0) = p2resp
				'P3': newrespons(*,0) = p3resp
				'C1': newrespons(*,0) = c1resp
				'C2': newrespons(*,0) = c2resp
				'SS': newrespons(*,0) = slresp
				'SL': newrespons(*,0) = slresp
                ENDCASE
                newrespons(*,1) = newrespons(*,0) * 0.
                respons = newrespons
	   END
	       
	   'QUIT': WIDGET_CONTROL, event.top, /DESTROY
		
	   ELSE: 
	ENDCASE
RETURN
END

; *********************************************************************
; * 
; *
; *
; *********************************************************************
PRO PIA_CAL_RESPONS, GROUP=group

@phtresdef
@phtw2jy

COMMON pia_respons_cmn, dets, detact, respons, newrespons, $
	wrical_id, det_id, pixl_weight, respstruct, newstruct, eta 
COMMON cal_resp, calu_resp, calg_resp, calg_respons_p1, calg_respons_p2, calg_respons_p3, $
		 calg_respons_c1, calg_respons_c2, calg_respons_sssl
COMMON ext_version, ext_version

; include SLRESP taking it from its actual place into the "old" one
	slresp = v2jy_s / w2jy_s
	slresu = v2jyunc_s / w2jy_s


	dets = ['P1','P2', 'P3', 'C100', 'C200', 'SS/SL'] 
; default startup detector id is C100
	detact = dets(4)
	IF N_ELEMENTS(c2resp) EQ 0 THEN read_resp
	respons = C2RESP

	newrespons = respons
; the newrespons * 0 is the uncertainty
	boost_array, newrespons, newrespons * 0.

; restore the structure/table from the save file
	export = '(e)'
	posi = STRPOS(!PIA_VERSION,export)

	IF posi EQ -1 THEN BEGIN

 	 filename = !CALSAVE+ 'C2' + 'CALRESP_STR.SAV'
	 res = findfile(filename, count=count) 	 
	 
	 IF count NE 0 THEN BEGIN
          get_respstr, detact, respstruct
          newstruct = respstruct
	  ext_version = 0
	 ENDIF ELSE BEGIN
	  XDISPLAYFILE, "", $
              TITLE = "File not found", $
              WIDTH = 80, $
              HEIGHT = 4, $
              TEXT = ["File " + filename + " not found " , $
		      "... will continue without processing possibility"]
	  ext_version = 1    
	 ENDELSE
	ENDIF ELSE ext_version=1

; initialize eta in the common block to -1
	eta = -1
; initialize the calu respons common block
	temp = fltarr(4, 7)
	read_asc_pdetect, temp, inputfile=!CALU+'p_detect.txt'
	calu_resp = transpose(temp(2, *))
; initialize the calg respons common block
	openr, unit, !CALG+'PRESPONSE.FITS', /block, /get_lun
	fxhread, unit, hdr
        calg_respons_p1 = fxpar(hdr, 'P1RESP')
        calg_respons_p2 = fxpar(hdr, 'P2RESP')
        calg_respons_p3 = fxpar(hdr, 'P3RESP')
        calg_respons_c1 = fxpar(hdr, 'C1RESP*')
        calg_respons_c2 = fxpar(hdr, 'C2RESP*')
        calg_respons_sssl = fxpar(hdr, 'SRESP*')
        calg_resp = calg_respons_c2
	free_lun, unit

	respbase = WIDGET_BASE(TITLE = 'PIA Responses CFDP Menu', $
                                /COLUMN)

        choicebase = WIDGET_BASE(respbase, /ROW)

	det_id = WIDGET_BUTTON(choicebase, VALUE = detact, /MENU)

	FOR I=0,5 DO id_0 = WIDGET_BUTTON(det_id, VALUE=dets(i),UVALUE=dets(i))
  
        plot_id = WIDGET_BUTTON(choicebase, VALUE = ' Plot ', /MENU)
        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' Actual Values ', /MENU )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' New Plot ', UVALUE='PLOTACT')
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Overplot ', UVALUE='OPLOTACT')

        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' Computed Values ', /MENU)
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' New Plot ', UVALUE='PLOTCOM')
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Overplot ', UVALUE='OPLOTCOM')

        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' ETA (Quantum efficiency) ', $
        		UVALUE= 'PLOTETA')

        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' CALU Values ', /MENU)
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' New Plot ', UVALUE='PLOTCLU')
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Overplot ', UVALUE='OPLOTCLU')
        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' CALG Values ',UVALUE='PLOTCALG')

	proc_id = WIDGET_BUTTON(choicebase, VALUE= ' Process ', /MENU )
	IF ext_version THEN WIDGET_CONTROL, proc_id, sensitive=0
        id_1 = WIDGET_BUTTON(proc_id, $
        	VALUE= 'Values and Table Records from Pre-reduced Signal Table', $
                                UVALUE='PROC_PRERED')
        id_1 = WIDGET_BUTTON(proc_id, $
        	VALUE= 'Values and Table Records from measurements ', $
                                UVALUE='PROC')
	WIDGET_CONTROL, id_1, sensitive=0
        id_1 = WIDGET_BUTTON(proc_id, $
        	VALUE= 'Responses from Response Cumulated Table', $
                                UVALUE='PROC_STR')


	edit_id = WIDGET_BUTTON(choicebase, VALUE= ' Edit Values ', /MENU)
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'Actual Values', $
				UVALUE = 'EDACTVAL')
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'Computed Values', $
				UVALUE = 'EDCOMVAL')
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'CALU Values', $
				UVALUE = 'EDCLUVAL')
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'CALG Values', $
				UVALUE = 'EDCLGVAL')

        edit_id = WIDGET_BUTTON(choicebase, $
        	VALUE= 'Results Cumulated Table', /MENU)
	IF ext_version THEN WIDGET_CONTROL, edit_id, sensitive=0
        id_1 = WIDGET_BUTTON(edit_id, VALUE = 'Actual Values', $
                                UVALUE = 'EDACTSTR')
        id_1 = WIDGET_BUTTON(edit_id, VALUE = 'Computed Values', $
                                UVALUE = 'EDCOMSTR')

	write_id = WIDGET_BUTTON(choicebase, VALUE = ' Write Values ', /MENU)
	id_1 = WIDGET_BUTTON(write_id, $
		VALUE = 'New values to internal common', $
				UVALUE = 'WRICOM')
        id_1 = WIDGET_BUTTON(write_id, $
        	VALUE = 'ADD new Table Records to Cumulated Table', $
                                UVALUE = 'WRISTR')
	IF ext_version THEN WIDGET_CONTROL, id_1, sensitive=0

        id_1 = WIDGET_BUTTON(write_id, $
        	VALUE = 'REPLACE Cumulated Table through new Table Records', $
                                UVALUE = 'WRISTR_REPL')
	IF ext_version THEN WIDGET_CONTROL, id_1, sensitive=0

	wrical_id = WIDGET_BUTTON(write_id, $
		VALUE = 'New Responses to Cal G file', $
				UVALUE = 'WRICALG')

	wricalu_id = WIDGET_BUTTON(write_id, $
		VALUE = 'New Responses to Cal U file (pdetect.txt)', $
				UVALUE = 'WRICALU')
	wricalu_id = WIDGET_BUTTON(write_id, $
		VALUE = 'New Mean Responses to Cal U file (p_ss_sl.txt)', $
				UVALUE = 'WRICALU_PSSSL')
	wricalu_id = WIDGET_BUTTON(write_id, $
		VALUE = 'New ETA (Quantum eff) to Cal U file ', $
				UVALUE = 'WRICALU_ETA')

	init_id = WIDGET_BUTTON(choicebase, VALUE = ' Re-initialize ', $
			UVAL="INIT")

	quit_id = WIDGET_BUTTON(respbase, VALUE = '  Quit  ', $
                        /FRAME, UVALUE = 'QUIT')

        WIDGET_CONTROL, respbase, /REALIZE, TLB_SET_XOFFSET=300, $
                        TLB_SET_YOFFSET=50

        xMANAGER,No_BLOCK=1, "pia_cal_respons", respbase, GROUP=group
	
RETURN
END
