;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_CAL_SWAVL
;
; PURPOSE:
;	Top level menu for SS-SL central wavelengths file production, one of
;	the Calibration Files Derivation Procedures (CFDP53201)  
;
; CATEGORY:
;       PIA - graphics
;
; CALLING SEQUENCE:
;       PIA_CAL_SWAVL
;
; KEYWORD PARAMETERS:
;	GROUP=group: Group leader
;
; COMMON BLOCKS:
;	colour_indices
;	phtslwavlen
;	pia_swavl_cmn (internal)
;	cswavl_edit_cmn (internal)
;	pia_cal_swavl_cmn (intenral)
;	pia_cal_swavl_data (internal)
;
; PROCEDURES USED:
;	PIA LIB:
;		pia_cal_swavl_comp
;		pia_multchoice
;		pia_multi_fit
;		pia_write_author
;		pia_write_version
;		pia_xplot
;		read_asc_psssl
;		set_slwavelen
;		write_asc_psssl
;       INTERNAL:
;		swavl_edit_event
;		swavl_edit
;		cswavl_edit_event
;		cswavl_edit
;		clu_swavl_edit_event
;		clu_swavl_edit
;		pia_cal_swavl_event
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel (ESA/ESTEC)		June 1995
;	Modified (last) by: cg, wmt			September 1995
;	Oct 95 Version 3.5
;	Handling from export version possible (CG)	April 1997
;	V6.2
;	Re-initialize button added (CG)			November 1997
;	V6.6
;	/Modal use according to IDL >=5.0 (CG)		February 1999
;	V7.3.1
;	Code bug (not accepted by IDL5.3) corrected(CG)	March 2000
;	V8.2
;
;-
; *********************************************************************
; *
; *********************************************************************
PRO SWAVL_EDIT_event, event 

COMMON pia_swavl_cmn, swavl, newswavl

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.id, GET_VALUE=value
	CASE uvalue of
	'list': 
	'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
	ENDCASE
END

; *********************************************************************
; *
; *********************************************************************
PRO SWAVL_EDIT 

COMMON pia_swavl_cmn, swavl, newswavl

	pixels = N_ELEMENTS(swavl)
	pixlist = STRTRIM(STRING(indgen(pixels) + 1),2)
	pixlist = 'Pixel ' + pixlist

	edbase = WIDGET_BASE(TITLE =' Actual SS/SL Central Wavelenghts', $
			/column)

	edvalbase = WIDGET_BASE(edbase, /row)
	
	edval = WIDGET_TEXT(edvalbase, XSIZE=8, YSIZE=32, $
	  VALUE = pixlist(0:63), /scroll)
	edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	  VALUE = STRTRIM(STRING(swavl(0:63)),2), /scroll ) 
	edval = WIDGET_TEXT(edvalbase, XSIZE=8, YSIZE=32, $
	  VALUE = pixlist(64:*), /scroll)
	edval = WIDGET_TEXT(edvalbase, XSIZE=10, YSIZE=32, $
	  VALUE = STRTRIM(STRING(swavl(64:*)),2), /scroll )


	quit = WIDGET_BUTTON(edbase, VALUE=' QUIT ', UVALUE='QUIT') 
	WIDGET_CONTROL, edbase, /REALIZE
	xMANAGER,No_BLOCK=1, "SWAVL_EDIT", edbase, GROUP=group 
	RETURN
END 

; *********************************************************************
; *
; *********************************************************************
PRO CSWAVL_EDIT_event, event 

COMMON pia_swavl_cmn, swavl, newswavl
COMMON cswavl_edit_cmn, edval_id1, edval_id2 

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue of
	 'LIST': BEGIN
		 WIDGET_CONTROL, edval_id1, GET_VALUE=value
		 WIDGET_CONTROL, edval_id2, GET_VALUE=value2
		 value = [value, value2]
	 	 IF N_ELEMENTS(value) EQ N_ELEMENTS(newswavl) THEN $
			newswavl = float(value)  ELSE BEGIN
                  	XDISPLAYFILE, "", $
                    		TITLE = "Input not accepted", $
                    		WIDTH = 50, $
                    		HEIGHT = 4, $
                    	  TEXT = [" Wrong S-Wavelenghts input  ", $]
                          	  "     ", $ ]
                          	  " Fix it and try again, please "]
			RETURN
		 ENDELSE	
	  END
	 'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
         ELSE: 
	ENDCASE

RETURN
END

; *********************************************************************
; *
; *********************************************************************
PRO CSWAVL_EDIT, group=group 

COMMON pia_swavl_cmn, swavl, newswavl
COMMON cswavl_edit_cmn, edval_id1, edval_id2 

	pixels = N_ELEMENTS(newswavl)
	pixlist = STRTRIM(STRING(indgen(pixels) + 1),2)
	pixlist = 'Pixel ' + pixlist

	IF not KEYWORD_SET(group) THEN group = !PIA_TOP_WID
	edbase = WIDGET_BASE(TITLE =' Computed SS/SL Central Wavelenghts', $
			/column, /modal, group=group)

	edvalbase = WIDGET_BASE(edbase, /row)  
	
	edval = WIDGET_TEXT(edvalbase, XSIZE=8, YSIZE=32, $
	  VALUE = pixlist(0:63), /scroll)
	edval_id1 = WIDGET_TEXT(edvalbase, /editable, XSIZE=10, YSIZE=32, $
	  VALUE = STRTRIM(STRING(newswavl(0:63)),2), /scroll, UVALUE='junk' )
	edval = WIDGET_TEXT(edvalbase, XSIZE=8, YSIZE=32, $
	  VALUE = pixlist(64:*), /scroll)
	edval_id2 = WIDGET_TEXT(edvalbase, /editable, XSIZE=10, YSIZE=32, $
	  VALUE = STRTRIM(STRING(swavl(64:*)),2), /scroll, UVALUE='junk' )

	edconbase = WIDGET_BASE(edbase, /row)  
	ok = WIDGET_BUTTON(edconbase, VALUE=' OK ', UVALUE='LIST') 
	quit = WIDGET_BUTTON(edconbase, VALUE=' QUIT ', UVALUE='QUIT') 
	WIDGET_CONTROL, edbase, /REALIZE
	xMANAGER,No_BLOCK=1, "CSWAVL_EDIT", edbase, GROUP=group 
	RETURN
	RETURN
END 

; *********************************************************************
; *
; *********************************************************************
PRO CLU_SWAVL_EDIT_event, event 

COMMON pia_swavl_cmn, swavl, newswavl
COMMON pia_cal_swavl_cmn, calu_swavl

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.id, GET_VALUE=value
	CASE uvalue of
	'list': 
	'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
	ENDCASE
END

; *********************************************************************
; *
; *********************************************************************
PRO CLU_SWAVL_EDIT 

COMMON pia_swavl_cmn, swavl, newswavl
COMMON pia_cal_swavl_cmn, calu_swavl

	pixels = N_ELEMENTS(calu_swavl)
	pixlist = STRTRIM(STRING(indgen(pixels) + 1),2)
	pixlist = 'Pixel ' + pixlist

	edbase = WIDGET_BASE(TITLE =' Actual SS/SL Central Wavelenghts', $
			/column)

	edvalbase = WIDGET_BASE(edbase, /row)
	
	edval = WIDGET_TEXT(edvalbase, XSIZE=8, YSIZE=43, $
	  VALUE = pixlist(0:42))
	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=43, $
	  VALUE = STRTRIM(STRING(calu_swavl(0:42)),2)) 
	edval = WIDGET_TEXT(edvalbase, XSIZE=8, YSIZE=43, $
	  VALUE = pixlist(43:85))
	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=43, $
	  VALUE = STRTRIM(STRING(calu_swavl(43:85)),2))
	edval = WIDGET_TEXT(edvalbase, XSIZE=9, YSIZE=43, $
	  VALUE = pixlist(86:*))
	edval = WIDGET_TEXT(edvalbase, XSIZE=12, YSIZE=43, $
	  VALUE = STRTRIM(STRING(calu_swavl(86:*)),2))

        edconbase = WIDGET_BASE(edbase, /row)
        quit = WIDGET_BUTTON(edconbase, /frame, VALUE=' QUIT ', UVALUE='QUIT')

	WIDGET_CONTROL, edbase, /REALIZE
	xMANAGER,No_BLOCK=1, "CLU_SWAVL_EDIT", edbase, GROUP=group
	RETURN
END 

; *********************************************************************
; *
; *********************************************************************
PRO PIA_CAL_SWAVL_EVENT, event

@colour_indices
@phtslwavlen
COMMON pia_swavl_cmn, swavl, newswavl
COMMON pia_cal_swavl_cmn, calu_swavl
COMMON pia_cal_swavl_data, mnpw, mnpu

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue of

	   'PLOTACT': BEGIN 
		 title=' Actual S-Central Wavelengts ' 

		 ytitle = ' Wavelenght '

		 x = findgen(N_ELEMENTS(swavl)) + 1 
                 pia_xplot, x, swavl, psym=4, $
			title= title, xtitle=' Pixel ', $
			ytitle = ytitle, annotation = title, legend = ytitle
           END

	   'OPLOTACT': BEGIN

		 title=' Actual S-Central Wavelengts ' 

		 ytitle = ' Wavelenght '

		 x = findgen(N_ELEMENTS(swavl)) + 1 

                 pia_xplot, x, swavl, psym=4, $
			title= title, color=yellow, overplot=99, $
			ytitle = ytitle, annotation = title, legend = ytitle
           END

	   'PLOTCOM': BEGIN 
		 title=' Computed S-Central Wavelengts ' 

		 ytitle = ' Wavelenght '

		 x = findgen(N_ELEMENTS(newswavl)) + 1 
                 pia_xplot, x, newswavl, psym=4, $
			title= title, xtitle=' Pixel ', $
			ytitle = ytitle, annotation = title, legend = ytitle
           END

	   'OPLOTCOM': BEGIN

		 title=' Computed S-Central Wavelengts ' 

		 ytitle = ' Wavelenght '

		 x = findgen(N_ELEMENTS(newswavl)) + 1 

                 pia_xplot, x, newswavl, psym=4, $
			title= title, color=yellow, overplot=99, $
			ytitle = ytitle, annotation = title, legend = ytitle
           END

	   'PLOTCLU': BEGIN 
		 title=' CALU S-Central Wavelengts ' 

		 ytitle = ' Wavelenght '

		 x = findgen(N_ELEMENTS(calu_swavl)) + 1 
                 pia_xplot, x, calu_swavl, psym=4, $
			title= title, xtitle=' Pixel ', $
			ytitle = ytitle, annotation = title, legend = ytitle
           END

; menu for processing measurements
	   'PROC': pia_cal_swavl_proc, mnpw, mnpu	
	   	
; menu for computing wavelengths
	   'COMPWL': BEGIN
		IF N_ELEMENTS(mnpw) EQ 0 THEN BEGIN
		        XDISPLAYFILE, "", $
                    		TITLE = "Non-existing input", $
                    		WIDTH = 50, $
                    		HEIGHT = 4, $
                    	  	TEXT = [" No data to compute new wavelengths",$
                          	  "     ", $ 
                          	  " Process measurements and try again "]
			
			RETURN
		ENDIF
		
	   	numlist = N_ELEMENTS(mnpw(0,*))

		IF numlist GT 1 THEN BEGIN
			list = STRTRIM(STRING(indgen(numlist)+1),2)
			list = 'Raster position ' + list
			pia_multchoice, list, elemnames=list
			actmnpw = mnpw(*,list)
			actmnpu = mnpu(*,list)
			pia_cal_swavl_comp
			pia_multi_fit_nomodal, indgen(128)+1, actmnpw, $
				weight=1./actmnpu^2, psym=4 
		ENDIF ELSE BEGIN
			actmnpw = mnpw(*,0)
			actmnpu = mnpu(*,0)
			pia_cal_swavl_comp			
			pia_multi_fit_nomodal, indgen(128)+1, actmnpw, $
				weight=1./actmnpu^2, psym=4
		ENDELSE
 
	   END
				 
	   'EDACTVAL': SWAVL_EDIT

	   'EDCOMVAL': CSWAVL_EDIT, GROUP=event.top

	   'EDCLUVAL': CLU_SWAVL_EDIT

	   'WRICOM': BEGIN
		SLWAVELEN = newswavl
		swavl = newswavl
	   END

	   'WRICALU': BEGIN               
	   	pia_write_author, author
                auth = ''
                FOR I=0,N_ELEMENTS(author)-1 DO auth = auth+author(i)

                pia_write_version, version
                vers = ''
                FOR I=0,N_ELEMENTS(version)-1 DO vers = vers+version(i)

                INPUT = !CALSAVE + 'p_ss_sl.txt'
                OUTPUT = !CALSAVE + 'p_ss_sl_pia.txt'

                write_asc_psssl, lc = newswavl, version=vers, $
                        author=auth, inputfile=input, outputfile=output

           END


	   'QUIT': WIDGET_CONTROL, event.top, /DESTROY
	   
	   'INIT': BEGIN
	     	set_slwavelen
		swavl = slwavelen
		newswavl = swavl
	   END
		
	   ELSE: 
	ENDCASE
RETURN
END

; *********************************************************************
; *
; *
; *
; *********************************************************************
PRO PIA_CAL_SWAVL, GROUP=group

@phtslwavlen
COMMON pia_swavl_cmn, swavl, newswavl
COMMON pia_cal_swavl_cmn, calu_swavl
COMMON pia_cal_swavl_data, mnpw, mnpu

	export = '(e)'
	posi = STRPOS(!PIA_VERSION,export)

	IF posi EQ -1 THEN ext_version=0 ELSE ext_version=1 


; set inital data to nothing
;	IF N_ELEMENTS(mnpw) GT 0 THEN mnpw = 0
;	IF N_ELEMENTS(mnpw) GT 0 THEN mnpu = 0
; Is the common filled up?
	IF N_ELEMENTS(slwavelen) EQ 0 THEN set_slwavelen

; Initialize swavl and newswavl 
	swavl = slwavelen
	newswavl = swavl
; Initialize the calu_swavl
	read_asc_psssl, temp, inputfile=!CALU+'p_ss_sl.txt'
	calu_swavl = transpose(temp(1,*))

	swavlbase = WIDGET_BASE(TITLE='PIA S-central wavelengths CFDP Menu',$
                                /COLUMN)

        choicebase = WIDGET_BASE(swavlbase, /ROW)

        plot_id = WIDGET_BUTTON(choicebase, VALUE = ' Plot ', /MENU)
        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' Actual Values ', /MENU)
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' New Plot ', $
				UVALUE='PLOTACT' )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' OverPlot ', $
				UVALUE='OPLOTACT' )
        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' Computed Values ', /MENU)
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' New Plot ', $
				UVALUE='PLOTCOM' )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' OverPlot ', $
				UVALUE='OPLOTCOM' )
        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' CALU Values ', $
				UVALUE='PLOTCLU')

	proc_id = WIDGET_BUTTON(choicebase, VALUE= ' Process ', /menu)
	IF ext_version THEN WIDGET_CONTROL, proc_id, sensitive=0

	id_1 = WIDGET_BUTTON(proc_id, VALUE= 'Measurements to spectra', $
				UVALUE='PROC')
	id_1 = WIDGET_BUTTON(proc_id, UVALUE= 'COMPWL', $
				VALUE='Compute new central wavelengths')

	edit_id = WIDGET_BUTTON(choicebase, VALUE= ' Edit Values ', /MENU)
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'Actual Values', $
				UVALUE = 'EDACTVAL')
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'Computed Values', $
				UVALUE = 'EDCOMVAL')
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'CALU Values', $
				UVALUE = 'EDCLUVAL')

	write_id = WIDGET_BUTTON(choicebase, VALUE = ' Write Values ', /MENU)
	id_1 = WIDGET_BUTTON(write_id, VALUE = 'to internal common', $
				UVALUE = 'WRICOM')
	wricalu_id = WIDGET_BUTTON(write_id, VALUE = 'to Cal U file', $
				UVALUE = 'WRICALU')

	init_id = WIDGET_BUTTON(choicebase, VALUE = ' Re-initialize ', $
			UVAL="INIT")

	quit_id = WIDGET_BUTTON(swavlbase, VALUE = '  Quit  ', $
                        /FRAME, UVALUE = 'QUIT')

        WIDGET_CONTROL, swavlbase, /REALIZE, TLB_SET_XOFFSET=300, $
                        TLB_SET_YOFFSET=50

        xMANAGER,No_BLOCK=1, "pia_cal_swavl", swavlbase, GROUP=group
	
RETURN
END
