;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_CAL_SWAVL_COMP
;
; PURPOSE:
;	Compute new central PHT SS/SL wavelengths fitting lines positions.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_CAL_SWAVL_COMP
;
; COMMON BLOCKS:
;	phtslwavlen
;	pia_cal_swavl_comp_cmn (internal)
;	
; CALLED ROUTINES:
;	PIA LIB:
;		pia_disp_print_file
;		pia_xplot
;       INTERNAL:
;		pia_cal_swavl_comp_event
;	
; MODIFICATION HISTORY:
;	Written by C.Gabriel (ESA/ESTEC)		August 1995
;	Modified (last) by: cg				September 1995
;	Oct 95 Version 3.5
;
;-

; ****************************************************************************
; *  PIA_CAL_SWAVL_COMP  - menu definition procedure
; ****************************************************************************
PRO PIA_CAL_SWAVL_COMP_event, event 

COMMON pia_cal_swavl_comp_cmn, edlist_id, edlisun_id, wavelen
@colour_indices

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue of
	 'FIT1': BEGIN
	 	WIDGET_CONTROL, edlist_id, GET_VALUE=values
	 	WIDGET_CONTROL, edlisun_id, GET_VALUE=valunc
		values = FLOAT(values)
		valunc = FLOAT(valunc)
	 	indvalss = WHERE(values GT 0.5 AND values LT 64., ns)
		indvalsl = WHERE(values GT 0.5 AND values GT 64., nl)

		overplot = 0
		IF ns GT 1 THEN BEGIN
			actval = values(indvalss)
			actunc = valunc(indvalss)
			weights = 1./actunc^2
			actwavlen = wavelen(indvalss)

			resfit = polyfitw(actval, actwavlen, weights, 1)

			pixval = resfit(0) + resfit(1) * indgen(64)
			pixtxt = ""
			FOR I=0,63 DO pixtxt = [pixtxt, "Pixel "+$
				STRTRIM(STRING(i+1),2) + ": " + $
				STRTRIM(STRING(pixval(i)),2)]

			pia_disp_print_file, "sscwavl_lin", $
                    	   TITLE = "Fit results (lin): PHT-SS central WL", $
                    	   WIDTH = 30, $
                    	   HEIGHT = 40, $
                    	   TEXT = [" Wavelengths for SS are computed as"+ $
                          	STRTRIM(STRING(resfit(0)),2)+" + Pix.nr * " +$
                          	STRTRIM(STRING(resfit(1)),2), $ 
                          	"  ", pixtxt]
			  
			pia_xplot, indgen(64)+1, pixval, $
				title="SS central wavelengths results",$
				xtitle="Pixels", ytitle=' !4k 	   [l!3m]',$
				psym = 4, color=white		
			overplot = 1
		ENDIF			

		IF nl GT 1 THEN BEGIN
			actval = values(indvalsl)
			actunc = valunc(indvalsl)
			weights = 1./actunc^2
			actwavlen = wavelen(indvalsl)

			resfit = polyfitw(actval, actwavlen, weights, 1)

			pixval = resfit(0) + resfit(1) * (indgen(64)+64) 
			pixtxt = ""
			FOR I=0,63 DO pixtxt = [pixtxt, "Pixel "+$
				STRTRIM(STRING(i+65),2) + ": " + $
				STRTRIM(STRING(pixval(i)),2)]

			pia_disp_print_file, "slcwavl_lin", $
                    	   TITLE = "Fit results (lin): PHT-SL central WL", $
                    	   WIDTH = 30, $
                    	   HEIGHT = 40, $
                    	   TEXT = [" Wavelengths for SL are computed as"+ $
                          	STRTRIM(STRING(resfit(0)),2)+" + Pix.nr * " +$
                          	STRTRIM(STRING(resfit(1)),2), $ 
                          	"  ", pixtxt]
			  
			pia_xplot, indgen(64)+65, pixval, $
				title="SL central wavelengths results",$
				xtitle="Pixels", ytitle=' !4k 	   [l!3m]',$
				psym = 4, overplot=overplot, color=white		
		ENDIF			
	 END						

	 'FIT2': BEGIN
	 	WIDGET_CONTROL, edlist_id, GET_VALUE=values
	 	WIDGET_CONTROL, edlisun_id, GET_VALUE=valunc
		values = FLOAT(values)
		valunc = FLOAT(valunc)
	 	indvalss = WHERE(values GT 0.5 AND values LT 64., ns)
		indvalsl = WHERE(values GT 0.5 AND values GT 64., nl)

		overplot = 0
		IF ns GT 2 THEN BEGIN
			actval = values(indvalss)
			actunc = valunc(indvalss)
			weights = 1./actunc^2
			actwavlen = wavelen(indvalss)

			resfit = polyfitw(actval, actwavlen, weights, 2)

			pixval = resfit(0) + resfit(1) * indgen(64) + $
					     resfit(2) * indgen(64)^2 
			pixtxt = ""
			FOR I=0,63 DO pixtxt = [pixtxt, "Pixel "+$
				STRTRIM(STRING(i+1),2) + ": " + $
				STRTRIM(STRING(pixval(i)),2)]

			pia_disp_print_file, "sscwavl_lin", $
                    	   TITLE = "Fit results (pol.2): PHT-SS central WL", $
                    	   WIDTH = 35, $
                    	   HEIGHT = 40, $
                    	   TEXT = [" Wavelengths for SS are computed as "+ $
                          	STRTRIM(STRING(resfit(0)),2)+" + Pix.nr * " +$
                          	STRTRIM(STRING(resfit(1)),2) + $
                          	" + Pix.nr^2 * " + $ 
                          	STRTRIM(STRING(resfit(2)),2), $ 
                          	"  ", pixtxt]
			  
			pia_xplot, indgen(64)+1, pixval, $
				title="SS central wavelengths results",$
				xtitle="Pixels", ytitle=' !4k 	   [l!3m]',$
				psym = 4, color=white		
			overplot = 1
		ENDIF			

		IF nl GT 2 THEN BEGIN
			actval = values(indvalsl)
			actunc = valunc(indvalsl)
			weights = 1./actunc^2
			actwavlen = wavelen(indvalsl)

			resfit = polyfitw(actval, actwavlen, weights, 2)

			pixval = resfit(0) + resfit(1) * (indgen(64)+64) + $
					     resfit(2) * (indgen(64)+64) ^ 2
			pixtxt = ""
			FOR I=0,63 DO pixtxt = [pixtxt, "Pixel "+$
				STRTRIM(STRING(i+65),2) + ": " + $
				STRTRIM(STRING(pixval(i)),2)]

			pia_disp_print_file, "slcwavl_lin", $
                    	   TITLE = "Fit results (2-pol): PHT-SL central WL", $
                    	   WIDTH = 35, $
                    	   HEIGHT = 40, $
                    	   TEXT = [" Wavelengths for SL are computed as "+ $
                          	STRTRIM(STRING(resfit(0)),2)+" + Pix.nr * " +$
                          	STRTRIM(STRING(resfit(1)),2) + $
                          	" + Pix.nr^2 * "+$ 
                          	STRTRIM(STRING(resfit(2)),2), $ 
                          	"  ", pixtxt]
			  
			pia_xplot, indgen(64)+65, pixval, $
				title="SL central wavelengths results",$
				xtitle="Pixels", ytitle=' !4k 	   [l!3m]',$
				psym = 4, overplot=overplot, color=white		
		ENDIF			
	 END						

	 'FWHM': BEGIN
	 	WIDGET_CONTROL, edlist_id, GET_VALUE=values
	 	WIDGET_CONTROL, edlisun_id, GET_VALUE=valunc
		values = FLOAT(values)
		valunc = FLOAT(valunc)
	 	indvalss = WHERE(values GT 0.5 AND values LT 64., ns)
		indvalsl = WHERE(values GT 0.5 AND values GT 64., nl)

; take the positive values times ratio (fwhm/sigma_gauss) times def pixel width
		text = ''
		IF ns GT 0 THEN BEGIN
			FOR I=0,N_ELEMENTS(indvalss)-1 DO BEGIN
				fwhm = valunc(indvalss(i)) * 1.177 * 0.0383
			 	text = [text,$
			'Pixel '+STRTRIM(STRING(round(values(indvalss(i)))))+$
				  ':' + '    FWHM(SS)='+STRING(fwhm)]
			ENDFOR
		ENDIF
		IF nl GT 0 THEN BEGIN
			FOR I=0,N_ELEMENTS(indvalsl)-1 DO BEGIN
				fwhm = valunc(indvalsl(i)) * 1.177 * 0.0922
			 	text = [text,$
			'Pixel '+STRTRIM(STRING(round(values(indvalsl(i)))))+$
			 	  ':' + '    FWHM(SL)='+STRING(fwhm)]
			ENDFOR
		ENDIF
		IF N_ELEMENTS(text) GT 1 THEN $
			PIA_DISP_PRINT_FILE, "slcwavl_FWHM", $
                    	   TITLE = "Fit results: PHT-S FWHM", $
                    	   WIDTH = 30, $
                    	   HEIGHT = N_ELEMENTS(text)+3, $
                    	   TEXT = text
             END  
		 	 
	 'QUIT': WIDGET_CONTROL, event.top, /DESTROY 

         ELSE: 

	ENDCASE
END


; *********************************************************************
; *
; *
; *
; *********************************************************************
PRO pia_CAL_SWAVL_COMP

@phtslwavlen

COMMON pia_cal_swavl_comp_cmn, edlist_id, edlisun_id, wavelen

	IF Xregistered("PIA_CAL_SWAVL_COMP") NE 0 THEN RETURN

	NGC7027_lines = [2.6252, 2.826, 2.873, 3.039, 3.093, 3.297, 3.740, $
			4.0512, 4.485, 4.654, 4.765, 5.608, 6.949, 6.985, $
			7.457, 8.992, 9.715, 10.524, 12.814] 

	wavelen = NGC7027_lines
	
	NGC7027_names = ['HI 4-6', 'HeII 7-9', 'HI 5-11', 'HI 5-10', $
			 'HeII 6-7', 'HI 5-9', 'HI 5-8', $
			 'HI 4-5', '[MgIV]', 'HI 5-7', 'HeII 7-8', '[MgV]', $
			 'He II 8-9', '[ArII]', $
			 'HI 5-6', '[ArIII]', 'HeII 9-10', '[SIV]', '[NeII]'] 

	edbase = WIDGET_BASE(TITLE = 'Computation of S central wavelengths', $
			/column)

	edvalbase = WIDGET_BASE(edbase, /row)
; Names
	edvalbas2 = WIDGET_BASE(edvalbase, /column)
	edval_id = WIDGET_TEXT(edvalbas2, XSIZE=10, YSIZE=1, VALUE='Sp.Line',$
		UVALUE='junk')
	edval_id = WIDGET_TEXT(edvalbas2, XSIZE=10, YSIZE=20, $
	  VALUE = NGC7027_names, UVALUE='JUNK')

; Lambda Positions
	edvalbas2 = WIDGET_BASE(edvalbase, /column)
	edval_id = WIDGET_TEXT(edvalbas2, XSIZE=10, YSIZE=1, VALUE=' Lambda ',$
		UVALUE='junk')
	edval_id = WIDGET_TEXT(edvalbas2, XSIZE=10, YSIZE=20, $
	  VALUE = STRTRIM(string(NGC7027_lines),2), UVALUE='JUNK')

; Pixel Positions
	pixpos = interpol(indgen(128),reform(slwavelen),ngc7027_lines)
	edvalbas2 = WIDGET_BASE(edvalbase, /column)
	edval_id = WIDGET_TEXT(edvalbas2, XSIZE=10, YSIZE=1, $
		VALUE='Pix expct',$
		UVALUE='junk')
	edval_id = WIDGET_TEXT(edvalbas2, XSIZE=10, YSIZE=20, $
	  VALUE = STRTRIM(STRING(pixpos+1),2), UVALUE='JUNK')

; Positions found
	edvalbas2 = WIDGET_BASE(edvalbase, /column)
	edval_id = WIDGET_TEXT(edvalbas2, XSIZE=10, YSIZE=1, VALUE='Pix found',$
		UVALUE='junk')
	edlist_id = WIDGET_TEXT(edvalbas2, /editable, XSIZE=10, YSIZE=20, $
	  VALUE = STRTRIM(string(pixpos*0.),2), UVALUE='JUNK')

; Uncertainties on Positions found
	edvalbas2 = WIDGET_BASE(edvalbase, /column)
	edval_id = WIDGET_TEXT(edvalbas2, XSIZE=10, YSIZE=1, VALUE=' Sigma ',$
		UVALUE='junk')
	edlisun_id = WIDGET_TEXT(edvalbas2, /editable, XSIZE=10, YSIZE=20, $
	  VALUE = STRTRIM(string(pixpos*0.+1),2), UVALUE='JUNK')

	edconbase = WIDGET_BASE(edbase, /row)
	fit = WIDGET_BUTTON(edconbase, VALUE='Fit Values ( > 0 )', /menu )
	fit1 = WIDGET_BUTTON(fit, VALUE='linear', UVALUE='FIT1')
	fit2 = WIDGET_BUTTON(fit, VALUE='quadratic', UVALUE='FIT2')
	fwhm = WIDGET_BUTTON(edconbase, VALUE='Calculate FWHM', UVALUE='FWHM')
	quit = WIDGET_BUTTON(edconbase, VALUE=' QUIT ', UVALUE='QUIT') 

	WIDGET_CONTROL, edbase, /REALIZE
	xMANAGER,No_BLOCK=1, "PIA_CAL_SWAVL_COMP", edbase, GROUP=group 
	RETURN
END 
