;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_CAL_VIGNET
;
; PURPOSE:
;	Top level menu for PHT Vignetting Files production, one of
;	the Calibration Files Derivation Procedures (CFDP)  
;
; CATEGORY:
;       PIA - graphics
;
; CALLING SEQUENCE:
;       PIA_CAL_VIGNET
;
; KEYWORD PARAMETERS:
;	GROUP=group: Group leader
;
; COMMON BLOCKS
;	colour_indices
;	phtfilter
;	phtvignet
;	pia_vign_cmn (internal)
;	cvign_edit_cmn (internal)
;	cal_vignet_cmn (internal)
;
; PROCEDURES USED:
;	PIA LIB:
;		phtfilter_init
;		pia_multchoice
;		pia_xplot
;		pia_xsurface
;		vignet_tables_read
;		write_vign
;       ASTRO LIB:
;		fxread
;       INTERNAL:
;		vignet_edit_event
;		vignet_edit
;		cvignet_edit_event
;		cvignet_edit
;		clgvignet_edit_event
;		clgvignet_edit
;		pia_cal_vignet_event
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel (ESA/ESTEC)		March 1995
;	Modified (last) by: cg, wmt                     Jul 1995
;	Oct 95 Version 3.5
;	Handling from export version possible (CG)	April 1997
;	V6.2
;	Re-initialize button added (CG)			November 1997
;	V6.6
;	/Modal use according to IDL >=5.0 (CG)		February 1999
;	V7.3.1
;-
; *********************************************************************
; *
; *********************************************************************
PRO VIGNET_EDIT_event, event 

COMMON pia_vign_cmn, dets, detact, filts, filtact, detfilt, $
		avignet, newvignet, wricalg_id, filt_id


	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.id, GET_VALUE=value
	CASE uvalue of
	'list': 
	'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
	ENDCASE
END

; *********************************************************************
; *
; *********************************************************************
PRO VIGNET_EDIT 

COMMON pia_vign_cmn, dets, detact, filts, filtact, detfilt, $
		avignet, newvignet, wricalg_id, filt_id

	edbase = WIDGET_BASE(TITLE =detact+' Actual Vignet Tables', $
			/column)

	cptlist = STRTRIM(STRING(indgen(25)*15-180),2) + ' arcsec'

	pixels = N_ELEMENTS(avignet(*,0,0))

	pixlist = ''

	IF STRMID(detact,0,1) EQ 'C' THEN pixchar = 'Pix ' ELSE $
					  pixchar = 'Ap.'  

	edvalbase = WIDGET_BASE(edbase, /row)
	
        edvalbas2 = WIDGET_BASE(edvalbase, /column)
	
	edval = WIDGET_TEXT(edvalbas2, XSIZE=12, YSIZE=1, $
	  VALUE = 'ChopperThrow')
	edval = WIDGET_TEXT(edvalbas2, XSIZE=12, YSIZE=25, $
	  VALUE = cptlist)

	FOR III=0,N_ELEMENTS(avignet(*,0,0))-1 DO BEGIN  
	 edvalbas3 = WIDGET_BASE(edvalbase, /column)
	 edval = WIDGET_TEXT(edvalbas3, XSIZE=5, YSIZE=1, $
		VALUE = pixchar+STRTRIM(STRING(III+1),2))
	 edval = WIDGET_TEXT(edvalbas3, XSIZE=5, YSIZE=25, $
		VALUE = STRMID(STRTRIM(STRING(avignet(III,*,detfilt)),2),0,5),$
		UVALUE = 'list')
        ENDFOR

	quit = WIDGET_BUTTON(edbase, VALUE=' QUIT ', UVALUE='QUIT') 
	WIDGET_CONTROL, edbase, /REALIZE
	xMANAGER,No_BLOCK=1, "VIGNET_EDIT", edbase, GROUP=group 
	RETURN
END 

; *********************************************************************
; *
; *********************************************************************
PRO CVIGNET_EDIT_event, event 

COMMON pia_vign_cmn, dets, detact, filts, filtact, detfilt, $
		avignet, newvignet, wricalg_id, filt_id
COMMON cvign_edit_cmn, edval_id 

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue of
	 'LIST': BEGIN
		FOR III=0,N_ELEMENTS(edval_id) - 1 DO BEGIN
		 WIDGET_CONTROL, edval_id(III), GET_VALUE=value
		 IF N_ELEMENTS(value) EQ 25 THEN $
			newvignet(III,*,detfilt) = float(value) ELSE BEGIN
                  	XDISPLAYFILE, "", $
                    		TITLE = "Input not accepted", $
                    		WIDTH = 50, $
                    		HEIGHT = 4, $
                    	  TEXT = [" Wrong vignetting factors input  ", $]
                          	  "     ", $ ]
                          	  " Fix it and try again, please "]
			RETURN
		 ENDELSE	
		ENDFOR
	 END
	 'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
         ELSE: 
	ENDCASE

RETURN
END

; *********************************************************************
; *
; *********************************************************************
PRO CVIGNET_EDIT, group=group 

COMMON pia_vign_cmn, dets, detact, filts, filtact, detfilt, $
		avignet, newvignet, wricalg_id, filt_id
COMMON cvign_edit_cmn, edval_id 

	IF not KEYWORD_SET(group) THEN group = !PIA_TOP_WID
	edbase = WIDGET_BASE(TITLE =detact+' Computed Vignet Tables', $
			/column, /modal, group=group)

	cptlist = STRTRIM(STRING(indgen(25)*15-180),2) + ' arcsec'

	pixels = N_ELEMENTS(avignet(*,0,0))

	pixlist = ''

	IF STRMID(detact,0,1) EQ 'C' THEN pixchar = 'Pix ' ELSE $
					  pixchar = 'Ap.'  

	edvalbase = WIDGET_BASE(edbase, /row)
	
        edvalbas2 = WIDGET_BASE(edvalbase, /column)
	
	edval = WIDGET_TEXT(edvalbas2, XSIZE=12, YSIZE=1, $
	  VALUE = 'ChopperThrow')
	edval = WIDGET_TEXT(edvalbas2, XSIZE=12, YSIZE=25, $
	  VALUE = cptlist)

	nele = N_ELEMENTS(newvignet(*,0,0))
	edval_id = lonarr(nele) 

	FOR III=0,N_ELEMENTS(avignet(*,0,0))-1 DO BEGIN  
	 edvalbas3 = WIDGET_BASE(edvalbase, /column)
	 edval = WIDGET_TEXT(edvalbas3, XSIZE=5, YSIZE=1, $
		VALUE = pixchar+STRTRIM(STRING(III+1),2))
	 edval = WIDGET_TEXT(edvalbas3, /EDITABLE, XSIZE=5, YSIZE=25, $
		VALUE = STRMID(STRTRIM(STRING(newvignet(III,*,detfilt)),2),0,5),$
		UVALUE = 'list')
	 edval_id(III) = edval
        ENDFOR

	edconbase = WIDGET_BASE(edbase, /row)
	ok = WIDGET_BUTTON(edconbase, VALUE='  ACCEPT  ', UVALUE='LIST')
	quit = WIDGET_BUTTON(edconbase, VALUE=' QUIT ', UVALUE='QUIT') 

	WIDGET_CONTROL, edbase, /REALIZE

	xMANAGER,No_BLOCK=1, "CVIGNET_EDIT", edbase, GROUP=group 
	RETURN
END 

; *********************************************************************
; *
; *********************************************************************
PRO CLGVIGNET_EDIT_event, event 

COMMON pia_vign_cmn, dets, detact, filts, filtact, detfilt, $
		avignet, newvignet, wricalg_id, filt_id
COMMON cal_vignet_cmn, calg_vignet, calg_vignet_p1, calg_vignet_p2, calg_vignet_p3, $
       calg_vignet_c1, calg_vignet_c2


	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.id, GET_VALUE=value
	CASE uvalue of
	'list': 
	'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
	ENDCASE
END

; *********************************************************************
; *
; *********************************************************************
PRO CLGVIGNET_EDIT 

COMMON pia_vign_cmn, dets, detact, filts, filtact, detfilt, $
		avignet, newvignet, wricalg_id, filt_id
COMMON cal_vignet_cmn, calg_vignet, calg_vignet_p1, calg_vignet_p2, calg_vignet_p3, $
       calg_vignet_c1, calg_vignet_c2

	edbase = WIDGET_BASE(TITLE =detact+' CALG Vignet Tables', $
			/column)

	cptlist = STRTRIM(STRING(indgen(25)*15-180),2) + ' arcsec'

	pixels = N_ELEMENTS(calg_vignet(*,0,0))

	pixlist = ''

	IF STRMID(detact,0,1) EQ 'C' THEN pixchar = 'Pix ' ELSE $
					  pixchar = 'Ap.'  

	edvalbase = WIDGET_BASE(edbase, /row)
	
        edvalbas2 = WIDGET_BASE(edvalbase, /column)
	
	edval = WIDGET_TEXT(edvalbas2, XSIZE=12, YSIZE=1, $
	  VALUE = 'ChopperThrow')
	edval = WIDGET_TEXT(edvalbas2, XSIZE=12, YSIZE=25, $
	  VALUE = cptlist)

	FOR III=0,N_ELEMENTS(calg_vignet(*,0,0))-1 DO BEGIN  
	 edvalbas3 = WIDGET_BASE(edvalbase, /column)
	 edval = WIDGET_TEXT(edvalbas3, XSIZE=5, YSIZE=1, $
		VALUE = pixchar+STRTRIM(STRING(III+1),2))
	 edval = WIDGET_TEXT(edvalbas3, XSIZE=5, YSIZE=25, $
		VALUE = STRMID(STRTRIM(STRING(calg_vignet(III,*,detfilt)),2),0,5),$
		UVALUE = 'list')
        ENDFOR

	quit = WIDGET_BUTTON(edbase, VALUE=' QUIT ', UVALUE='QUIT') 
	WIDGET_CONTROL, edbase, /REALIZE
	xMANAGER,No_BLOCK=1, "VIGNET_EDIT", edbase, GROUP=group
	RETURN
END 

; *********************************************************************
; *
; *********************************************************************
PRO PIA_CAL_VIGNET_EVENT, event

@phtvignet
@colour_indices

COMMON pia_vign_cmn, dets, detact, filts, filtact, detfilt, $
		avignet, newvignet, wricalg_id, filt_id
COMMON cal_vignet_cmn, calg_vignet, calg_vignet_p1, calg_vignet_p2, calg_vignet_p3, $
       calg_vignet_c1, calg_vignet_c2


	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	i = WHERE(filts EQ uvalue, n)
	i = i(0)
	IF n NE 0 THEN uvalue = 'FILT'

	CASE uvalue of

	   'FILT': BEGIN
			filtact = i
			det = STRMID(filts(filtact),0,2)
			detact = det
			CASE det of
			  'P1': BEGIN 
				avignet = pp1vign
				detfilt = filtact
				calg_vignet = calg_vignet_p1
			  END
			  'P2': BEGIN
				avignet = pp2vign
				detfilt = filtact - 10 
				calg_vignet = calg_vignet_p2
			  END
			  'P3': BEGIN
				avignet = pp3vign
				detfilt = filtact - 12 
				calg_vignet = calg_vignet_p3
			  END
			  'C1': BEGIN
				avignet = pc1vign
				detfilt = filtact - 14
				detact = 'C100'
				calg_vignet = calg_vignet_c1
			  END
			  'C2': BEGIN
				avignet = pc2vign
				detfilt = filtact - 21
				detact = 'C200'
				calg_vignet = calg_vignet_c2
			  END
			ENDCASE
			newvignet = avignet
	   		WIDGET_CONTROL, filt_id, SET_VALUE=filts(filtact)
	   END	  

	   'PLOTACT': BEGIN 
		 title=detact+' actual vignetting - Filter '+filts(filtact) 
                 pia_xsurface, avignet(*,*,detfilt), wlego=1, xtitle = 'Pixel #', $
                        ytitle= 'Chopper Throw', charsize=2, $
                        ztitle= ' Vignetting factor  ', title=title, $
                        group=event.top  

		END

	   'PLOTACTPROJ': BEGIN
	        IF STRMID(detact,0,1) EQ 'C' THEN pixchar = 'Pixel ' ELSE $
					          pixchar = 'Aperture '  
                list = indgen(N_ELEMENTS(avignet(*,0,0)))
		elnames = pixchar + STRING(list+1)
		pia_multchoice, list, ELEMNAMES = elnames   
		 		
		title = detact+' actual vignetting - Filter '+filts(filtact)
		ytitle = pixchar+STRTRIM(STRING(list+1),2)+ ' factors'
		x = findgen(25) * 15. - 180.
                pia_xplot, x, avignet(list,*,detfilt), psym=4, $
			title= title, xtitle=' Chopper throw   [arcsec]', $
			ytitle = ytitle, annotation = title, legend = ytitle
           END

	   'OPLOTACTPROJ': BEGIN
	        IF STRMID(detact,0,1) EQ 'C' THEN pixchar = 'Pixel ' ELSE $
					          pixchar = 'Aperture '  
                list = indgen(N_ELEMENTS(avignet(*,0,0)))
		elnames = pixchar + STRING(list+1)
		pia_multchoice, list, ELEMNAMES = elnames   
		 		
		title = detact+' actual vignetting - Filter '+filts(filtact)
		ytitle = pixchar+STRTRIM(STRING(list+1),2)+ ' factors'
		x = findgen(25) * 15. -180.
                pia_xplot, x, avignet(list,*,detfilt), psym=6, $
			title= title, overplot=99, color = yellow, $
			ytitle = ytitle, annotation = title, legend = ytitle
           END

	   'PLOTCOM': BEGIN 

		 title=detact+' computed vignetting - Filter '+filts(filtact) 
                 pia_xsurface, newvignet(*,*,detfilt), wlego=1, xtitle = 'Pixel #', $
                        ytitle= 'Chopper Throw', charsize=2, $
                        ztitle= ' Vignetting factor  ', title=title, $
                        group=event.top  

		END


	   'PLOTCOMPROJ': BEGIN
	        IF STRMID(detact,0,1) EQ 'C' THEN pixchar = 'Pixel ' ELSE $
					          pixchar = 'Aperture '  
                list = indgen(N_ELEMENTS(newvignet(*,0,0)))
		elnames = pixchar + STRING(list+1)
		pia_multchoice, list, ELEMNAMES = elnames   
		 		
		title = detact+' computed vignetting - Filter '+filts(filtact)
		ytitle = pixchar+STRTRIM(STRING(list+1),2)+ ' factors'
		x = findgen(25) * 15. - 180.
                pia_xplot, x, newvignet(list,*,detfilt), psym=4, $
			title= title, xtitle=' Chopper throw   [arcsec]', $
			ytitle = ytitle, annotation = title, legend = ytitle
           END

	   'OPLOTCOMPROJ': BEGIN
	        IF STRMID(detact,0,1) EQ 'C' THEN pixchar = 'Pixel ' ELSE $
					          pixchar = 'Aperture '  
                list = indgen(N_ELEMENTS(newvignet(*,0,0)))
		elnames = pixchar + STRING(list+1)
		pia_multchoice, list, ELEMNAMES = elnames   
		 		
		title = detact+' computed vignetting - Filter '+filts(filtact)
		ytitle = pixchar+STRTRIM(STRING(list+1),2)+ ' factors'
		x = findgen(25) * 15. - 180.
                pia_xplot, x, newvignet(list,*,detfilt), psym=6, $
			title= title, overplot=99, color = yellow, $
			ytitle = ytitle, annotation = title, legend = ytitle
           END

	   'PLOTCLG': BEGIN 
		 title=detact+' CALG vignetting - Filter '+filts(filtact) 
                 pia_xsurface, calg_vignet(*,*,detfilt), wlego=1, xtitle = 'Pixel #', $
                        ytitle= 'Chopper Throw', charsize=2, $
                        ztitle= ' Vignetting factor  ', title=title, $
                        group=event.top  

		END

	   'PLOTCLGPROJ': BEGIN
	        IF STRMID(detact,0,1) EQ 'C' THEN pixchar = 'Pixel ' ELSE $
					          pixchar = 'Aperture '  
                list = indgen(N_ELEMENTS(calg_vignet(*,0,0)))
		elnames = pixchar + STRING(list+1)
		pia_multchoice, list, ELEMNAMES = elnames   
		 		
		title = detact+' CALG vignetting - Filter '+filts(filtact)
		ytitle = pixchar+STRTRIM(STRING(list+1),2)+ ' factors'
		x = findgen(25) * 15. - 180.
                pia_xplot, x, calg_vignet(list,*,detfilt), psym=4, $
			title= title, xtitle=' Chopper throw   [arcsec]', $
			ytitle = ytitle, annotation = title, legend = ytitle
           END

	   'OPLOTCLGPROJ': BEGIN
	        IF STRMID(detact,0,1) EQ 'C' THEN pixchar = 'Pixel ' ELSE $
					          pixchar = 'Aperture '  
                list = indgen(N_ELEMENTS(calg_vignet(*,0,0)))
		elnames = pixchar + STRING(list+1)
		pia_multchoice, list, ELEMNAMES = elnames   
		 		
		title = detact+' CALG vignetting - Filter '+filts(filtact)
		ytitle = pixchar+STRTRIM(STRING(list+1),2)+ ' factors'
		x = findgen(25) * 15. - 180.
                pia_xplot, x, calg_vignet(list,*,detfilt), psym=6, $
			title= title, overplot=99, color = yellow, $
			ytitle = ytitle, annotation = title, legend = ytitle
           END

	   'PROC': MESSAGE, /INFO, 'not yet implemented	

	   'EDACTVAL': VIGNET_EDIT

	   'EDCOMVAL': CVIGNET_EDIT, group=event.top

	   'EDCLGVAL': CLGVIGNET_EDIT

	   'WRICOM': BEGIN
			CASE STRMID(detact,0,2) of
			  'P1': pp1vign = newvignet
			  'P2': pp2vign = newvignet
			  'P3': pp3vign = newvignet
			  'C1': pc1vign = newvignet
			  'C2': pc2vign = newvignet
			ENDCASE
			avignet = newvignet
		 WIDGET_CONTROL, wricalg_id, /sensitive
		END

	   'WRICALG': BEGIN
		deta = strmid(detact,0,2)
		write_vign, 'PIA_'+detact+'_VIGNET', deta, newvignet
		END

	   'QUIT': WIDGET_CONTROL, event.top, /DESTROY
		
	   'INIT': BEGIN
		vignet_tables_read
		CASE STRMID(detact,0,2) of
			 'P1': newvignet = pp1vign
			 'P2': newvignet = pp2vign 
			 'P3': newvignet = pp3vign
			 'C1': newvignet = pc1vign
			 'C2': newvignet = pc2vign
			ENDCASE
			avignet = newvignet
	   END

	   ELSE: 
	ENDCASE
RETURN
END

; *********************************************************************
; *
; *
; *
; *********************************************************************
PRO PIA_CAL_VIGNET, GROUP=group

@phtvignet
@phtfilter

COMMON pia_vign_cmn, dets, detact, filts, filtact, detfilt, $
		avignet, newvignet, wricalg_id, filt_id
COMMON cal_vignet_cmn, calg_vignet, calg_vignet_p1, calg_vignet_p2, calg_vignet_p3, $
       calg_vignet_c1, calg_vignet_c2


	export = '(e)'
	posi = STRPOS(!PIA_VERSION,export)

	IF posi EQ -1 THEN ext_version=0 ELSE ext_version=1 


; Are the common filled up?
	IF N_ELEMENTS(pc1vignet) EQ 0 THEN vignet_tables_read

	IF N_ELEMENTS(c1filters) EQ 0 THEN PHTFILTER_INIT

; Initial choices: C100 - C1_100 

	dets = ['P1','P2', 'P3', 'C100', 'C200', 'SS/SL'] 

	detact = dets(3)

	filts = [p1filters, p2filters, p3filters, c1filters, c2filters]

	filtact = 18
	detfilt = filtact - 14

	avignet = PC1VIGN

	newvignet = avignet

;init the calg common block
	FXREAD, !CALG+'PP1VIGN.FITS', calg_vignet_p1 
        FXREAD, !CALG+'PP2VIGN.FITS', calg_vignet_p2 
        FXREAD, !CALG+'PP3VIGN.FITS', calg_vignet_p3 
        FXREAD, !CALG+'PC1VIGN.FITS', calg_vignet_c1
        FXREAD, !CALG+'PC2VIGN.FITS', calg_vignet_c2 
	calg_vignet = calg_vignet_c1

	vignbase = WIDGET_BASE(TITLE = 'PIA Vignet Table CFDP Menu', $
                                /COLUMN)

        choicebase = WIDGET_BASE(vignbase, /ROW)

	filt_id = WIDGET_BUTTON(choicebase, VALUE = filts(filtact), /MENU)

	FOR I=0,25 DO id_0 = WIDGET_BUTTON(filt_id, $
		VALUE=filts(i),UVALUE=filts(i))
  
        plot_id = WIDGET_BUTTON(choicebase, VALUE = ' Plot ', /MENU)
        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' Actual Values ', /MENU)
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Lego Plot ', $
				UVALUE='PLOTACT' )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Plot Projection ', $
				UVALUE='PLOTACTPROJ' )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' OverPlot Projection ', $
				UVALUE='OPLOTACTPROJ' )
        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' Computed Values ', /MENU)
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Plot Projection ', $
				UVALUE='PLOTCOMPROJ' )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' OverPlot Projection ', $
				UVALUE='OPLOTCOMPROJ' )
        id_1 = WIDGET_BUTTON(plot_id, VALUE = ' CALG Values ', /MENU)
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Lego Plot ', $
				UVALUE='PLOTCLG' )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' Plot Projection ', $
				UVALUE='PLOTCLGPROJ' )
        id_2 = WIDGET_BUTTON(id_1, VALUE = ' OverPlot Projection ', $
				UVALUE='OPLOTCLGPROJ' )

	proc_id = WIDGET_BUTTON(choicebase, VALUE= ' Process ', UVALUE='PROC')
	IF ext_version THEN WIDGET_CONTROL, proc_id, sensitive=0

	edit_id = WIDGET_BUTTON(choicebase, VALUE= ' Edit Values ', /MENU)
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'Actual Values', $
				UVALUE = 'EDACTVAL')
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'Computed Values', $
				UVALUE = 'EDCOMVAL')
	id_1 = WIDGET_BUTTON(edit_id, VALUE = 'CALG Values', $
				UVALUE = 'EDCLGVAL')

	write_id = WIDGET_BUTTON(choicebase, VALUE = ' Write Values ', /MENU)
	id_1 = WIDGET_BUTTON(write_id, VALUE = 'to internal common', $
				UVALUE = 'WRICOM')
	wricalg_id = WIDGET_BUTTON(write_id, VALUE = 'to Cal G file', $
				UVALUE = 'WRICALG')
	WIDGET_CONTROL, wricalg_id, SENSITIVE=0	

	init_id = WIDGET_BUTTON(choicebase, VALUE = ' Re-initialize ', $
			UVAL="INIT")

	quit_id = WIDGET_BUTTON(vignbase, VALUE = '  Quit  ', $
                        /FRAME, UVALUE = 'QUIT')

        WIDGET_CONTROL, vignbase, /REALIZE, TLB_SET_XOFFSET=300, $
                        TLB_SET_YOFFSET=50

        xMANAGER,No_BLOCK=1, "pia_cal_vignet", vignbase, GROUP=group
	
RETURN
END
