;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
   PRO write_fxisoheader, filename, phdr, data, username = username, $
   			  comment = comment, version = version, $,
   			  extension=extension
;+
; NAME:
;     	WRITE_FXISOHEADER
; PURPOSE:
;		Write a PHT primary FITS header for a FITS file.
; CATEGORY:
;		PIA - I/O
; CALLING SEQUENCE:
;       WRITE_FXISOHEADER, FILENAME, HEADER, DATA, 
;     USERNAME=USERNAME, COMMENT=COMMENT, VERSION=VERSION,EXTENSION=EXTENSION 
;
; INPUT:
;		FILENAME: filename for the output file without extension
;       
;
; OPTIONAL INPUT:
;       PIPELINENAME: 	string type, default is the pipeline product name
;       USERNAME : 	the username line in the fits header, string type.
;                  	the maximum character length is 8.
;       COMMENT : 	the comment line in the fits header, string type
;       VERSION : 	the version number, string type, less than 8 chars
;                 	default is 0001
;	EXTENSION:	for binary extension files
;
; OUTPUT:
;		HEADER: string array containing the new header
;
; PROCEDURES USED: 
;		ASTROLIB:
;			fxhmake
;			fxaddpar
;
; MODIFICATION HISTORY:
;       Written by: I. Heinrichsen			Jan. 1997
;-
;
  on_error, 2

; Check the number of parameters
;
  	if n_params() lt 2 then message, $
   		'Syntax: WRITE_FXISOHEADER, FILENAME, HEADER [, DATA]'+$
   ' USERNAME = USERNAME, COMMENT=COMMENT, VERSION=VERSION, EXTENSION=EXTENSION'

; test keywords and set defaults
;
	if keyword_set(comment) then com=comment else com='File created with PIA'
	if keyword_set(extension) then ext=1 else ext=0
	if keyword_set(version) then ver=version else ver='0001'
	if keyword_set(username) then begin
	 	if strlen(username) > 8 then begin
      		message, 'Maximum length for username is 8'+$
      				 ' characters long'
      		return
    	endif
    	user=username
    endif else begin
    	user='PIDT'
	endelse

; Create the ISO/PHT Primary Header
;
	IF n_params() EQ 3 THEN $  
	 fxhmake,  hdr, data, extend=ext,/date ELSE $
	 fxhmake,  hdr, extend=ext, /date 
	

;	Add the ISO/PHT specific parameters
;
	fxaddpar, hdr, 'ORIGIN','ESA',' European Space Agency'
	fxaddpar, hdr, 'TELESCOP','ISO',' Infrared Space Observatory'
	fxaddpar, hdr, 'INSTRUME','PHT',' Instrument used'
	fxaddpar, hdr, 'COMMENT',com,''
	fxaddpar, hdr, 'FILENAME', filename,' File name assigned in ISO archive'
	fxaddpar, hdr, 'FILEVERS',ver,' File version assigned by ISO archive'
	fxaddpar, hdr, 'PIA_VERS', !pia_version, ' Internal (user) PIA-CAL Version'
	fxaddpar, hdr, 'USERNAME', user
	phdr=hdr
RETURN
END
