;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  PRO write_respchkstr, det, newrchkstr, REPLACE=replace
;+
; NAME:
;       WRITE_DARKCSTR
; PURPOSE:
;       Append a new structure to the dark current structure corresponding 
;	to det 
; CATEGORY:
;	PIA - I/O
; CATEGORY:
;       
; CALLED SEQUENCE:
;       WRITE_RESPCHKSTR, DETECTOR_NAME, newrchkstr [,/REPLACE]
; INPUTS:
;       DETECTOR_NAME: ONE OF THESE STRINGS -- P1, P2, P3, C1, C2, SL
;       newrchkstr: the corresponding new responsivity check structure
; OPTIONAL INPUTS:
;       NONE
; KEYWORD PARAMETERS:
;       NONE
; PROCEDURE:
; MODIFICATION HISTORY:
;       WRITTEN BY: Jose Acosta
;	MAy 97 Version 6.4
;-
ON_ERROR, 2

	detind = STRMID(STRUPCASE(det),0,2)

	CASE detind of 
		'SL': respchk_str = {SLRESPCHKSTR_typ}
		'C2': respchk_str = {C2RESPCHKSTR_typ}
		'C1': respchk_str = {C1RESPCHKSTR_typ}
		ELSE: respchk_str = {PRESPCHKSTR_typ}
	ENDCASE

	filename = !CALSAVE+ detind + 'CALRECHK_STR.SAV'
	res = findfile(filename, count = count)
 
        IF count NE 0 THEN RESTORE, filename ELSE replace = 1

	if keyword_set (replace) then respchk_str = newrchkstr $
	   else respchk_str = [respchk_str, newrchkstr]
	
	SAVE, respchk_str, FILE=filename, /XDR
END

