;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	CHANGE_TMPHDR
;
; PURPOSE:
;	Replaces in a temporary PHT PIA structure the element hdr
;
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;	change_tmphdr, tmpdata, type, newhdr, tmpout
;
; INPUTS:
;	tmpdata: The (ERD,SRD,SCP,SPD) temporary structure
;	type:	 Reduction level (ERD, SRD, ...)
;	newhdr:	 The header for replacing tmpdata.hdr
;
;	
; OUTPUTS:
;	tmpout:  The new structure with the updated header
;	
; SIDE EFFECTS:
;	
; PROCEDURES USED:
;	INTERNAL: 
;	PIA_LIB:
;		fill_erd, fill_srd, fill_scp, fill_spd, fill_aap
;		pia_load_ierd, pia_load_isrd, pia_load_iscp, pia_load_ispd, 
;		pia_load_iaap, pia_load_idynresp, dynresp_init, fill_dynresp, 
;		dyncal_clear
;
; COMMON BLOCKS:
;	pia_on_line	all internal buffers
;	
; MODIFICATION HISTORY:
;	Written by:	C.Gabriel (ESA/VILSPA)			January 1997
;	V6.3
;	Types dyncal added                  	(JAcosta-VILSPA) October 1998
;	Type DYNR added 		    	(JAcosta-IAC)	 February 2000
;	V8.2
;-
PRO change_tmphdr, tmpdata, type, newhdr, tmpout

@pia_on_line

	ON_ERROR, 2

	CASE type OF
	
	'ERD': BEGIN
	    pos = N_ELEMENTS(phterd)
	    FILL_ERD, tmpdata, newhdr
	    PIA_LOAD_IERD, phterd(pos), tmpout
	    erd_init, index=pos
	 END	
	'SRD': BEGIN
	    pos = N_ELEMENTS(phtsrd)
	    FILL_SRD, tmpdata, newhdr
	    PIA_LOAD_ISRD, phtsrd(pos), tmpout
	    srd_init, index=pos
	 END	
	'SCP': BEGIN
	    pos = N_ELEMENTS(phtscp)
	    FILL_SCP, tmpdata, newhdr
	    PIA_LOAD_ISCP, phtscp(pos), tmpout
	    scp_init, index=pos
	 END	
	 'SPD': BEGIN
	    pos = N_ELEMENTS(phtspd)
	    FILL_SPD, tmpdata, newhdr
	    PIA_LOAD_ISPD, phtspd(pos), tmpout
	    spd_init, index=pos
	 END
	 'AAP': BEGIN
	    pos = N_ELEMENTS(phtaap)
	    FILL_AAP, tmpdata, newhdr
	    PIA_LOAD_IAAP, phtaap(pos), tmpout
	    aap_init, index=pos
	 END
	 'DYNCAL': BEGIN
	    pos = N_ELEMENTS(phtdyncal)
	    FILL_DYNCAL, tmpdata, newhdr
	    PIA_LOAD_IDYNCAL, phtdyncal(pos), tmpout
	    dyncal_clear, index=pos
	 END
	 'DYNR': BEGIN
	    pos = N_ELEMENTS(phtdynresp)
	    FILL_DYNRESP, tmpdata, newhdr
	    PIA_LOAD_IDYNRESP, phtdynresp(pos), tmpout
	    dynresp_init, index=pos
	 END
	 ELSE: tmpout=tmpdata
	 
	 ENDCASE
	 
	 RETURN
	 END
	 
	 
