;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	CHECK_CHOP
;
; PURPOSE:	
;	Correct chopper position by signals which have bad flagged
;	chopper information 
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	CHECK_CHOP, CHOP, CFLAG, NCHANGED
;
; INPUT PARAMETERS:
;	chop:	The chopper positions of the ramps (SRD level)
;	cflag:	The corresponding chopper flags
;	
;
; OUTPUT:
;	nchanged: the number of changed elements in input/output "chop" array 
;
; RESTRICTIONS:  
;
; METHOD:
;	Chopper bad flagged signals get the chopper position of the 
;	immediately following signal, if its information is reliable
;	(normal reason for bad flag is given by problems with the update
;	 in the readout chopper information) 
;
; MODIFICATION HISTORY:
;	Written by: C. Gabriel (ESA/VILSPA)		September 1997
;	V6.5
;-
PRO check_chop, chop, cflag, nchanged

	indbad = WHERE(cflag NE 0, nbad)
	CASE 1 OF
	nbad GT 1: IF N_ELEMENTS(cflag)-1 EQ indbad(nbad-1) THEN BEGIN
	            indbad=indbad(0:nbad-2) 
	            nbad = nbad - 1
	           ENDIF
	nbad EQ 1: IF indbad(0) EQ N_ELEMENTS(cflag)-1 THEN nbad = 0
	ELSE:
	ENDCASE

	nchanged = 0
	FOR I=0,nbad-1 DO BEGIN
	  IF cflag(indbad(i)+1) EQ 0 THEN BEGIN
	    IF chop(indbad(i)) NE chop(indbad(i)+1) THEN $
	     nchanged = nchanged + 1
	    chop(indbad(i)) = chop(indbad(i)+1)
	    cflag(indbad(i)) = 0
	  ENDIF
	ENDFOR

	RETURN
	END	
	
