;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       CHOP_FRCORR_FCT
;
; PURPOSE:
;       Return the correction factors and uncertainties corresponding to a
;	given detector and chopper dwelltime, for the correction of signal
;	losses due to chopping 
;
; CATEGORY:
;       PIA - processing
;
; CALLING SEQUENCE:
;       res = CHOP_FRCORR_FCT(det, dwelltime)
;
; INPUT PARAMETERS:
;	DET:		String for detector used (eg. 'P1', 'C1' or 'C100')
;	DWELLTIME:	Time spent on each chopper plateau (integer in sec.)
;        
; OUTPUT:
;       Returns a float array RES(npixel,2) with 
;					RES(npixel,0)=Corr.factor for det pixels 
;					RES(npixel,1)=Uncertainty 
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel - ESA/VILSPA-SAI		January 1998
;       Version 7.0
;-
FUNCTION chop_frcorr_fct, det, dwelltime

@phtchopcor


	IF N_ELEMENTS(CHOPCORR_STR) EQ 0 THEN READ_CHOPCOR

	ind_timechop = WHERE(chopcorr_str.inchop_time EQ dwelltime, ntime)
	IF ntime NE 1 THEN BEGIN 
   		info = 'Not adequate chopper frequency'
   		MESSAGE, info
   		RETURN, -1
	ENDIF

	CASE STRMID(det,0,2) OF
   		'P1': corrsig_tab = chopcorr_str.p1corr
   		'P2': corrsig_tab = chopcorr_str.p2corr
   		'P3': corrsig_tab = chopcorr_str.p3corr
   		'C1': corrsig_tab = chopcorr_str.c1corr
   		'C2': corrsig_tab = chopcorr_str.c2corr
   		'SL': corrsig_tab = chopcorr_str.slcorr
	ENDCASE   

	corrval = REFORM(corrsig_tab(*,ind_timechop(0),*))
	
	RETURN, corrval
	END
