;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO Chop_Param_Init
;+
; NAME:
;	CHOP_PARAM_INIT
;
; PURPOSE:
;	This proceude initialises the chop_param common block with 
;       the TM constants
;
; CATEGORY:
;	PIA - initialisation
;
; CALLING SEQUENCE:
;	CHOP_PARAM_INIT
;
; INPUTS:
;	None
;
; OUTPUTS:
;	None
;
; COMMON BLOCKS
;	chop_param
;
; SIDE EFFECTS:
;	Alters the values defined in the chop_param common block
;
; PROCEDURES USED:
;	None
;
; MODIFICATION HISTORY:
;	Written by:	Huw Morris
;	Modified by:	C. Gabriel
;	Oct 95 Version 3.5
;
;-

@chop_param

; Note that these are all FM constants

        C = 1.0               ; Parameters for initial conversion
        P = 4096              ; of TMDATA word to a voltage
        Q = 20.0
        R = 10.0

;  a :== U_GRADE (calibration language)
;  b :== U_OFFSET    (  "         "  )

        A = 9.862622            	; Coefficients for the
        B = -20.0057               	; line approximation

;  Line deviation tables
        Ang_Dev = [-180.0, -162.0, -144.0, -126.0, -108.0, -90.0, -72.0, $
                    -54.0,  -36.0,  -18.0,    0.0,   18.0,  36.0,  54.0, $
                     72.0,   90.0,  108.0,  126.0,  144.0, 162.0, 180.0 ]

        DU_DC = [ -17.6, -18.8, -20.5, -21.9, -22.3, -22.0, -20.0, $
                  -16.0, -10.9,  -4.5,   0.0,   0.0,   0.0,   0.0, $
                    0.0,   0.0,   0.0,   0.0,   0.0,   0.0,   0.0 ]

;  Correction tables
        Norm_Ang = [ -1.0, -0.9, -0.8, -0.7, -0.6, -0.5, -0.4, $
                     -0.3, -0.2, -0.1,  0.0,  0.1,  0.2,  0.3, $
                      0.4,  0.5,  0.6,  0.7,  0.8,  0.9,  1.0 ]

        DU_ACD = [  -0.1,  -1.9,  -5.4,  -7.6,  -8.6,  -8.8,  -8.8, $
                    -6.8,  -4.1,  -1.0,   2.4,   6.0,   9.6,  13.0, $
                    15.6,  15.4,  14.4,  12.5,  10.0,   7.7,   3.4 ]

        DU_ACI = [  -0.1,  -8.0, -14.5, -20.9, -24.3, -26.1, -27.8, $
                   -28.9, -28.7, -27.5, -25.5, -22.7, -18.3, -13.5, $
                   -10.6,  -6.6,  -3.9,  -1.7,   0.8,   2.0,   3.4 ]

;  Parameters for FCS
        DCF1 = 660.0 + 3578.
        DCF2 = -710.0 - 3578
        OF1 = 131.
        OF2 = 239.
        ACF1 = 660.0 + 3578.


	END
