;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
pro conv_analog,idb,idb_f_bounds,hkdat,hkout

;+
; NAME:
;       CONV_ANALOG
;
; PURPOSE:
;       This procedure converts the analog part of an array hkdat of 
;       an existing GEHK?.FITS into an string array hkout 
;       containing the converted analog data
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       CONV_ANALOG, Idb, Idb_f_bounds, Hkdat, Hkout 
;
; INPUTS:
;       Idb         :database array
;       Idb_f_bounds:boundaries of STS and ANA block in the idb
;       Hkdat       :array containing the fits data
;
; OUTPUTS:
;       Hkout       :array, in which to store the converted data
;
; RESTRICTIONS:
;       The part of this program dealing with action routines 
;       isn't written yet
; 
; PROCEDURE:
;       Extract the relevant data for analog parameters from
;       the input arrays and give it to the conv_curve function
;
; PROCEDURES USED:
;       PIA LIB: conv_curve
;
; MODIFICATION HISTORY:
;       Written by:	Andreas Karch
;	Oct 95 Version 3.5
;-
 
dummy1=strarr(7)
dummy2=strarr(32)
dummy3=strarr(16,4)

;loop over all analog values
for i=idb_f_bounds(2),idb_f_bounds(3) do begin

;read conv_ar  and conv_table
 handle_value,idb(18,i),data


if data.analog3 ne 0 then begin

  handle_value,data.analog1,dummy1
  handle_value,data.analog2,dummy2
  handle_value,data.analog3,dummy3
  
endif else begin 

;if conv flag not set give a signal to int_to_text
dummy2(31)='conv flag not set'

endelse

; if conversion method is 0
 if strcompress(dummy1(0),/remove_all) eq '' then begin
 hkout(i,*)=conv_curve(idb,dummy2,hkdat,i) 
 endif else begin

; else call action routine (this part isn't workink yet !!!!)
  print, 'sorry, please add this part of the program as a homework'
 endelse
 

endfor 

end
