;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
function conv_curve,idb,c_tab,hkdat,i

;+
; NAME:
;       CONV_CURVE
;
; PURPOSE:
;       This function converts idb element number i of the analog part  
;       into an string array hkout containing the converted
;       analog data
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       CONV_CURVE, Idb, C_tab, Hkdat, I 
;
; INPUTS:
;       Idb         :database array
;       I           :idb element number (must be in ANA part)
;       Hkdat       :array containing the fits data
;       C_tab       :conversion tables for element i
;                    first part considers x-values, second part y
;
; OUTPUTS:
;       None
; 
; PROCEDURE:
;       Add two one byte words to one two byte word, look
;       for the bits dtermined by length and offset in the
;       idb with the idb and function.
;       Search for the two neighbours in the x part of the
;       conversion table and find the right value by
;       linear interpolation.        
;
; PROCEDURES USED:
;       None
;
; MODIFICATION HISTORY:
;       Written by:	Andreas Karch
;	Oct 95 Version 3.5
;-

;read a whole  two -byte word

  rawvalue=256*hkdat(idb(15,i)-628,*)+hkdat(idb(15,i)-627,*)
 
;check offset and length of required bits
 bitnums=long(indgen(idb(17,i))+idb(16,i))

; calculate proper value
 value=0l
 for j=0l,n_elements(bitnums)-1 do begin
  junk=rawvalue and 2l^bitnums(j)
  value=value+junk/(2l^bitnums(j))*(2l^j)
 endfor


 neighbour=byte(value)

; return value if this hk should not be converted
if c_tab(31) eq 'conv flag not set' then begin 
   return, value


endif else begin
 index=where(strcompress(c_tab) eq ' ')
    if index(0) ne -1 then c_tab(index)=0
   c_tab=double(c_tab)

;find the two nearest x-values
 for j=15,1,-1 do  begin  
  n=where(value le c_tab(j) and value ge c_tab(j-1))
  if n(0) ne -1 then neighbour(n)=j
 endfor

 ; right neighbour, left neighbour at x-index = neighbour - 1


 ; return value of linear interpolation
    

   converted=(value-c_tab(neighbour-1))*(c_tab(neighbour+16)-c_tab(neighbour+15))
   converted=converted/(c_tab(neighbour)-c_tab(neighbour-1))
   converted=converted+c_tab(neighbour+15)
   return, converted
 
endelse

end
