;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
pro conv_hk,idb,hkout,hkdat,timestep,idb_ar_table,idb_ar_image

;+
; NAME:
;       CONV_HK
;
; PURPOSE:
;       This procedure converts the housekeeping part of an GEHK?.FITS file
;       into an string array hkout containing the converted data.
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       CONV_HK, Tdtnum, Idb, Hkout, Hkdat, Timestep, Idb_ar_table, $
;	         Idb_ar_image
;
; INPUTS:
;	Tdtnum      :TDT number corresponging to the housekeeping file
;       Idb         :database array
;
; OUTPUTS:
;       Hkout       :strarr(hk,x) containing converted data for each 
;                    hk-parameter and each measurement
;       Hkdat       :array containing the fits data
;       Idb=starr(18,hk)  containing the 18 values of interest for each
;                   hk-parameter from the idb_def table
;           0:de_number 1:de_name 2:de_type 3:subcom_flag 4:modeflag
;           5:monitor 6:max_slots 7:decomp 8:conv 9:limsel 10:limit
;           11:memver 12:qlagen 13:extr_source 14:extr_ar
;           15:location 16:offset 17:length
;           18: handle with corresponding data
;       Timestep(x) containing the time for each measurement
;       Idb_ar_table and Idb_ar_image with informations about 
;              action routines
;
; PROCEDURE:
;       Read in fits data, find boundaries of analog part and status
;       part and convert both parts in different subroutines        
;
; PROCEDURES USED:
;       PIA LIB: get_boundaries
;                conv_status
;                conv_analog
;
; MODIFICATION HISTORY:
;       Written by:	Andreas Karch
;	Modified by:	C. Gabriel
;	Oct 95 Version 3.5
;-

; read idb_def in array idb
; if this is not done yet, please enter the following line
; read_idb_def,header,idb,idb_ar_table,idb_ar_image

;get boundaries of STS and ANA block

 get_boundaries,idb,idb_f_bounds

;convert status-values, define hkout

 conv_status,idb,idb_f_bounds,hkdat,hkout
 
;convert analog values

 conv_analog,idb,idb_f_bounds,hkdat,hkout

; in your running idl session should now exist:

; ( hk=number of housekeeping parameters  x=number of measurements)
; ( bn=number of bytes in the fits file, containing hk data       ) 

; ATTENTION: WHILE I WAS WORKING, HK AND NB WERE BOTH 66
; DON'T MIX THEM UP

; idb=starr(18,hk)  containing the 18 values of interest for each
;                   hk-parameter from the idb_def table
;           0:de_number 1:de_name 2:de_type 3:subcom_flag 4:modeflag
;           5:monitor 6:max_slots 7:decomp 8:conv 9:limsel 10:limit
;           11:memver 12:qlagen 13:extr_source 14:extr_ar
;           15:location 16:offset 17:length
;           18: handle with corresponding data
; hkdat=lonarr(nb,x) is directly the fits data
; hkout=strarr(hk,x) containing converted data for each hk-parameter
;                    and each measurement
; timestep(x) containing the time for each measurement
; idb_ar_table and idb_ar_image with informations about 
;              action routines
end 
