;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
pro conv_status,idb,idb_f_bounds,hkdat,hkout

;+
; NAME:
;       CONV_STATUS
;
; PURPOSE:
;       This procedure converts the status part of an array hkdat of 
;       an existing GEHK?.FITS into an string array hkout 
;       containing the converted status data
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       CONV_STATUS, Idb, Idb_f_bounds, Hkdat, Hkout 
;
; INPUTS:
;       Idb         :database array
;       Idb_f_bounds:boundaries of STS and ANA block in the idb
;       Hkdat       :array containing the fits data
;
; OUTPUTS:
;       Hkout       :array, in which to store the converted data
;
; RESTRICTIONS:
;       The part of this program dealing with action routines 
;       isn't written yet
; 
; PROCEDURE:
;       Extract the relevant data for status parameters from
;       the input arrays and give it to the int_to_text function
;
; PROCEDURES USED:
;       PIA LIB: int_to_text
;
; MODIFICATION HISTORY:
;       Written by:	Andreas Karch
;	Oct 95 Version 3.5
;-

;the highest index of hkout is reserved for later use
;it shall contain the measurement name
hkout=strarr(idb_f_bounds(3)+2,n_elements(hkdat(0,*)))
dummy=strarr(17)

;loop over all stat values
for i=idb_f_bounds(0),idb_f_bounds(1) do begin

;read conv_ar  and conv_table
 handle_value,idb(18,i),data


if data.status ne 0 then begin
  handle_value,data.status,dummy
   
endif else begin 

;if conv flag not set give a signal to int_to_text
dummy(16)='conv flag not set'

endelse

; if conversion method is 0
 if strcompress(dummy(0),/remove_all) eq '' then begin
  hkout(i,*)=int_to_text(idb,dummy,hkdat,i) 
 endif else begin

; else call action routine (this part isn't workink yet !!!!)
  print, 'sorry, please add this part of the program as a homework'
 endelse
 

endfor 

end
