;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        FUNCTION CONV_SUBS, SUBS
;+
; NAME:
;       CONV_SUBS
;
; PURPOSE:
;       Convert the PHT subsystem number into the detector identifier string
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       Result = CONV_SUBS(Subs)
;
; INPUTS:
;       Subs	: Subsystem number
;
; OUTPUTS:
;       Returns a 2-character string as PHT detector identifier
;
; PROCEDURES USED:
;       None
;
; MODIFICATION HISTORY:
;       Written by:	C. Gabriel
;	Oct 95 Version 3.5
;-
;
        ON_ERROR, 2
	
	FOR i = 0, N_ELEMENTS(SUBS)-1 DO BEGIN
           CASE SUBS(i) of
		0: D = 'P1'
		1: D = 'P2'
		2: D = 'P3'
		3: D = 'SL'
		6: D = 'C1'
		7: D = 'C2'
		ELSE: BEGIN
		 Message, /info, ' Not identified Subsystem
		 D = ''
		END
	   ENDCASE
	   IF i EQ 0 THEN DET = D ELSE DET = [DET,D]
	ENDFOR
        RETURN, DET
        END
