;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  PRO darkcur, isignal, det, osignal
;+
; NAME:
;       DARKCUR
;
; PURPOSE:
;	This routine subtracts the darkcurrent given in the signal array.
;
; CATEGORY:
;       PIA - processing
;
; CALLING SEQUENCE:
;       DARKCUR, Input_signal, Detector_name, Output_signal
;
; INPUTS:
;       Input_signal: A 2-dim array. The first dim is the number of pixels
;                     The pixel dim is {1, 1, 1, 9, 4, 64} for
;                     detector {P1, P2, P3, C1, C2, SL}
;                     Second dim is the number of signals
;       Detector_name: One of these strings -- P1, P2, P3, C1, C2, SL
;
; OUTPUTS:
;       Output_signal: Same dim as the input signal with the darkcurrent
;                      correction
;
; COMMON BLOCKS:
;       phtdarkcur
;
; RESTRICTIONS:
;       The input detector string must be in upper case, or you get nothing!
;
; PROCEDURE:
;       Use FXPAR to extract the keyword info
;
; PROCEDURES USED:
;	ASTRO LIB: fxpar
;
; MODIFICATION HISTORY:
;       Written by:	Wai-Ming Tai
;	Modified by:	C. Gabriel
;	Oct 95 Version 3.5 
;-

@phtdarkcur
ON_ERROR, 2

; NOTE THAT FOR SOME REASON THE FXPAR WOULD NOT ACCEPT THE STRING VAR
; THAT MEANS THE INPUT KEYWORD HAS TO BE SPECIFIED AT THE FXPAR CALLING
; LEVEL, A BIT OF PAIN. WMT, OCT 94

OSIGNAL = ISIGNAL
CASE DET OF
'P1': BEGIN
        DARKC = FXPAR(DARKCURHDR, 'DARKP1')
        OSIGNAL(0,*) = ISIGNAL(0, *) - DARKC
      ENDCASE
'P2': BEGIN
        DARKC = FXPAR(DARKCURHDR, 'DARKP2')
        OSIGNAL(0,*) = ISIGNAL(0, *) - DARKC
      ENDCASE
'P3': BEGIN
        DARKC = FXPAR(DARKCURHDR, 'DARKP3')
        OSIGNAL(0,*) = ISIGNAL(0, *) - DARKC
      ENDCASE
'C1': BEGIN
        DARKC = FXPAR(DARKCURHDR, 'DARK1C*')
        FOR I = 0, 8 DO OSIGNAL(I,*) = ISIGNAL(I, *) - DARKC(I)
      ENDCASE
'C2': BEGIN
        DARKC = FXPAR(DARKCURHDR, 'DARK2C*')
        FOR I = 0, 3 DO OSIGNAL(I,*) = ISIGNAL(I, *) - DARKC(I)
      ENDCASE
'SL': BEGIN
        DARKC = FXPAR(DARKCURHDR, 'DARKS*')
        FOR I = 0, 127 DO OSIGNAL(I,*) = ISIGNAL(I, *) - DARKC(I)
      ENDCASE 
END
END

