;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	DARKCUR_TIME
;
; PURPOSE:
;	Performs dark current subtraction on a measurement at SRD or SCP levels.
;
; CATEGORY:
;	PIA - algorithms
;
; CALLING SEQUENCE:
;	DARKCUR_ORB, tmpdata, DARK = dark, SCP = scp, NEWHEADER = newheader 
;	
;INPUTS
;
; KEYWORD PARAMETERS:
;	DARK:		The dark current value subtracted
;       SCP:    	If selected tmpdata is expected to be a SCP temporary 
;			structure; if not it will be SRD
;	NEWHEADER: Header of the measurement where info will be added. 
;	PRO_RASTER:	Perform subtraction per raster point
;	PRO_MEAS:	Same per whole measurement 
;
; COMMON BLOCKS:
;	phtdarkorb
;
; MODIFICATION HISTORY:
;	Written by Jose ACOSTA (IAC/PIDT) 			August 1998
;	V7.2
;-
PRO DARKCUR_TIME, det, indarkc, outdarkc, obstime

@phtdarkorb

IF N_PARAMS() NE 4 THEN BEGIN
   print,'Syntax: darkcur_time, det, indarkc, outdarkc, obstime
   RETURN
ENDIF

IF det NE 'SL' THEN BEGIN 
   print,'Dark current depending on observing time is only valid for detector SL'
   RETURN
ENDIF

   
npix = pixel_det(det)
darktime = SLDARKTIME

nele = N_ELEMENTS(indarkc(0,*))
outdarkc = indarkc

FOR ipix=0,npix-1 DO BEGIN
   corr = darktime.ampl(ipix)*exp(-obstime/darktime.tau(ipix))
   FOR iele=0, nele-1 DO outdarkc(ipix,iele) = indarkc(ipix,iele) + corr      
ENDFOR



RETURN
END   
