;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
FUNCTION dec_admn, admn, decstr_sh=decstr_sh

;+
; NAME:
;	DEC_ADMN
;
; PURPOSE:
;	Function to decode the PHT-IA administration name returning 
;	a string.
;
; CATEGORY:
;	PIA - processing  
;
; CALLING SEQUENCE:
;       decstr = DEC_ADMN(Admn, decstr_sh=decstr_sh)
;
; INPUTS:
;       Admn  : An administration name as in pht###.admn                
;
; OUTPUTS:
;       Decstr: A string containing the decoded explanation 
;
; KEYWORDS:
;	Decstr_sh: A short version of the string
;
; PROCEDURES USED:
;	None
;
; MODIFICATION HISTORY:
;       Written by:	Carlos Gabriel (ESA/SAI)	September 1997
;	V6.5
;	Returning same string if no correspondence
;	 with expectations (CG)				October 1997
;	V6.6
;	Adding concatenation info (CG)			July 1998
;	V7.2
;-

        ON_ERROR, 2

	pos_strings = ['P1','P2','P3','C1','C2','SS','SL']
	IF admn(0) EQ '' THEN BEGIN 
	  decstr = ''
	  RETURN, decstr
	ENDIF
	ind = WHERE(pos_strings EQ STRMID(admn(0),0,2), ncount)
	IF ncount EQ 0 THEN RETURN, admn

	decstr = ''
	decstr_sh = ''

	FOR I = 0, N_ELEMENTS(admn) - 1 DO BEGIN

	 detsh = STRMID(admn(I),0,2)
	 if STRMID(detsh,0,1) EQ 'C' THEN det = detsh+'00' ELSE det = detsh

	 pos = STRMID(admn(I),2,2)
	 pos = FIX(pos) + 1

	 tdt = STRMID(admn(I),4,8)
	 decstr1 = det+'-TDT '+tdt+'-Meas.'+STRTRIM(STRING(pos),2) 
	 decstr_sh1 = detsh + '-' + tdt + '-' + STRTRIM(STRING(pos),2)

	 IF STRLEN(admn(I)) GT 12 THEN BEGIN
	 	IF STRUPCASE(STRMID(admn(I),12,1)) EQ 'S' THEN BEGIN
	 	   decstr1 = decstr1 + ' Subtracted' 
	 	   decstr_sh1 = decstr_sh1 + 'S'
	 	ENDIF
	 	IF STRUPCASE(STRMID(admn(I),12,1)) EQ 'G' THEN BEGIN
	 	   decstr1 = decstr1 + ' Conc.' 
	 	   decstr_sh1 = decstr_sh1 + 'C'
	 	ENDIF
	 	IF STRUPCASE(STRMID(admn(I),12,4)) EQ '_LEG' THEN $
	 	   decstr1 = decstr1 + ' Raster leg '+ STRMID(admn(I),16,2) 
	 	IF STRUPCASE(STRMID(admn(I),12,4)) EQ '_CST' THEN $
	 	   decstr1 = decstr1 + ' Chop step '+ STRMID(admn(I),18,5) 
	 	IF STRUPCASE(STRMID(admn(I),12,2)) EQ '_Y' THEN $
	 	   decstr1 = decstr1 + ' Raster '+ STRMID(admn(I),12,8) 
	 	IF STRUPCASE(STRMID(admn(I),12,4)) EQ 'GLUE' THEN BEGIN
	 	   decstr1 = decstr1 + ' Concatenated ' 
	 	   decstr_sh1 = decstr_sh1 + 'C'
	 	ENDIF
	 ENDIF

         IF decstr(0) EQ '' THEN decstr = decstr1 ELSE decstr = [decstr,decstr1]
         IF decstr_sh(0) EQ '' THEN decstr_sh = decstr_sh1 ELSE $
             decstr_sh = [decstr_sh,decstr_sh1]
	ENDFOR	

        RETURN, decstr
	END
