;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
PRO decode_admn, admn, decstr, decstr_sh = decstr_sh

;+
; NAME:
;	DECODE_ADMN
;
; PURPOSE:
;	This procedure decodes the PHT-IA administration name returning 
;	a string.
;
; CATEGORY:
;	PIA - processing  
;
; CALLING SEQUENCE:
;       DECODE_ADMN, Admn, Decstr
;
; INPUTS:
;       Admn  : An administration name as in pht###.admn                
;
; OUTPUTS:
;       Decstr: A string containing the decoded explanation 
;
; KEYWORDS:
;	Decstr_sh: A short version of the string
;
; PROCEDURES USED:
;	None
;
; MODIFICATION HISTORY:
;       Written by:	Carlos Gabriel
;	Oct 95 Version 3.5
;	Decoding also S for subtracted in admn
;	Decoding also _LEG for raster leg
;	Decoding also _CSTEP for chopper step
;	Decoding also _y_z for Raster point separation case
;	Keyword DECSTR_SH added (CG)				July 1997
;	V6.4
;	Extension for measurements' concatenations (CG)		November 1997
;	V6.6
;	Adding concatenation info (CG)				July 1998
;	V7.2
;-

        ON_ERROR, 2

;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 2 THEN MESSAGE, $
          'Syntax:  decode_admn, admn, decstr'

	IF admn(0) EQ '' THEN BEGIN 
	  decstr = ''
	  RETURN
	ENDIF

	decstr = ''
	decstr_sh = ''

	FOR I = 0, N_ELEMENTS(admn) - 1 DO BEGIN

	 detsh = STRMID(admn(I),0,2)
	 if STRMID(detsh,0,1) EQ 'C' THEN det = detsh+'00' ELSE det = detsh

	 pos = STRMID(admn(I),2,2)
	 pos = FIX(pos) + 1

	 tdt = STRMID(admn(I),4,8)
	 decstr1 = det+'-TDT '+tdt+'-Meas.'+STRTRIM(STRING(pos),2) 
	 decstr_sh1 = detsh + '-' + tdt + '-' + STRTRIM(STRING(pos),2)

	 IF STRLEN(admn(I)) GT 12 THEN BEGIN
	 	IF STRUPCASE(STRMID(admn(I),12,1)) EQ 'S' THEN BEGIN
	 	   decstr1 = decstr1 + ' Subtracted' 
	 	   decstr_sh1 = decstr_sh1 + 'S'
	 	ENDIF
	 	IF STRUPCASE(STRMID(admn(I),12,1)) EQ 'G' THEN BEGIN
	 	   decstr1 = decstr1 + ' Concatenated' 
	 	   decstr_sh1 = decstr_sh1 + 'C'
	 	ENDIF
	 	IF STRUPCASE(STRMID(admn(I),12,4)) EQ '_LEG' THEN $
	 	   decstr1 = decstr1 + ' Raster leg '+ STRMID(admn(I),16,2) 
	 	IF STRUPCASE(STRMID(admn(I),12,4)) EQ '_CST' THEN $
	 	   decstr1 = decstr1 + ' Chop step '+ STRMID(admn(I),18,5) 
	 	IF STRUPCASE(STRMID(admn(I),12,2)) EQ '_Y' THEN $
	 	   decstr1 = decstr1 + ' Raster '+ STRMID(admn(I),12,8) 
	 	IF STRUPCASE(STRMID(admn(I),12,4)) EQ 'GLUE' THEN BEGIN
	 	   decstr1 = decstr1 + ' Concatenated ' 
	 	   decstr_sh1 = decstr_sh1 + 'C'
	 	ENDIF
	 ENDIF

         IF decstr(0) EQ '' THEN decstr = decstr1 ELSE decstr = [decstr,decstr1]
         IF decstr_sh(0) EQ '' THEN decstr_sh = decstr_sh1 ELSE $
             decstr_sh = [decstr_sh,decstr_sh1]
	ENDFOR	

        RETURN
	END
