;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       DECODE_CS2MEA
;
; PURPOSE:
;       This is part of the pia_control panel support routines.
; 	And therefore is designed entirely with the pia_control,
;	pia_read_ext and pia_man_mea in mind.
;	It is used for converting the compact information to
;	the measurement information.
;
; CATEGORY:
;       PIA - utilities
;
; CALLING SEQUENCE:
;       DECODE_CS2MEA, meaname, string
;
; INPUT:
;	meaname: the measurement name
;	
; OUTPUT:
;	string: the decoded string
;
; COMMON BLOCKS:
;       phtcs
;
; PROCEDURES USED:
;       PIA LIB:
;	Astronomical Library:
; MODIFICATION HISTORY:
;	Written by: Wai-Ming Tai (DIAS)			March 1996
;	String bug fixed (pstafile) (CG)		July 1996
;	Avoiding crash in case of record not found (CG) March 1998
;	V7.1
;	Confusing message avoided (CG)			September 1999
;	V8.1
;
;-
pro decode_cs2mea, meaname, str
@phtcs


  str = ' '
  chopper_mode=['Scan sawtooth','Scan sawtooth','Scan triangular',$
                'Scan triangular',$
                'Rectangular','Rectangular','Rectangular','Rectangular',$
                'FCS1<->FCS2','COFOV<->FCS1','COFOV<->FCS2','NOTUSED',$
                'Staring -Offset','Staring +Offset',$
                'Staring FCS1','Staring FCS2']

 ;polarisers, apertures and filters on the wheels
 wheel1_position=['UNKNOWN','P_POL000','P_POL120','P_POL240',$
                  'P_NO_POL','PHT_S','C_RETICL','C_FREE1 ',$
                  'C_FREE2','C_FREE3','S_REDUND','C_POL000',$
                  'C_POL120','C_POL240','C_NO_POL','NOTUSED']
 wheel2_positi_s=['UNKNOWN','52_SEC','79_SEC','99_SEC',$
                  '120_SEC','127X127_SEC2','180_SEC','180_SEC_XBLK',$
                  '5_SEC','7P6_SEC','10_SEC','13P8_SEC',$
                  '18_SEC','20X32_SEC2','23_SEC','NOTUSED']
 wheel2_positi_c=['UNKNOWN','OPEN','90_RED','50_UM',$
                  '60_UM','70_UM','100_UM','105_UM',$
                  '90_UM','160_UM','200_UM','180_UM',$
                  '135_UM','120_UM','RETICLE','NOTUSED']
 wheel3_position=['UNKNOWN',$
                  '3P29_UM','3P6_UM',$
                  '4P85_UM','7P3_UM',$
                  '7P7_UM','10_UM',$
                  '11P3_UM','12P8_UM',$
                  '16P0_UM','11P5_UM',$
                  '20_UM','25_UM',$
                  '60_UM','100_UM',$
                  'NOTUSED']
  wheel2_position=[wheel2_positi_s,wheel2_positi_c]    

  subsystems=['P1     ','P2     ','P3     ','SL  ','NOTUSED',$
             'NOTUSED','C100   ','C200   ']

  psta_file = strmid(meaname,4,8)
  mea_pos = fix(strmid(meaname, 2, 2))
  cs_unit = phtcs.unit
  ind = where(cs_unit EQ psta_file, count)

  if count NE 0 then begin
    handle_value, phtcs(ind(0)).handle, cst
    detshort = STRMID(meaname,0,2)
    IF detshort EQ 'SS' THEN detshort = 'SL'

    subs = subsystems(cst.subs)

    index_arr=where(strmid(subs,0,2) eq detshort,count)
    IF count NE 0 THEN BEGIN 
     in = index_arr(mea_pos)
     chop_mode = chopper_mode(cst.cmod(in))
     wheel1 = wheel1_position(cst.c1ps(in))
     wheel2 = wheel2_position(cst.c2ps(in)+16*((cst.subs(in) eq 6) or (cst.subs(in) eq 7)))
     wheel3 = wheel3_position(cst.c3ps(in))
     str = chop_mode + ', ' + wheel1 +'/' + wheel2 + '/' + wheel3
    ENDIF ELSE message, /info, 'Problems with detector record, no info but continuing'
  endif else message, /info, 'Compact status ' + psta_file + ' not found!'
  
end
