;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       DECODE_FILETYPE
;
; PURPOSE:
;       This is part of the pia_control panel support routines.
; 	And therefore is designed entirely with the pia_control,
;	pia_read_ext and pia_man_mea in mind.
;	It is used for converting the file name to
;	a more informatve information.
;
; CATEGORY:
;       PIA - utilities
;
; CALLING SEQUENCE:
;       DECODE_FILETYPE, FILENAME, OUTPUT-STRING
;
; INPUT:
;	filename: the filename for decoding
;
; OUTPUT:
;	output-string: the decoded string
;
; COMMON BLOCKS:
;
; PROCEDURES USED:
;       PIA LIB:
;	Astronomical Library:
; MODIFICATION HISTORY:
;	Written by: Wai-Ming Tai (DIAS)			March 1996
;
;-
pro decode_filetype, filename, strl

  filetype = strmid(filename, 0, 4)
  case filetype of
  'PSTA': strl = 'Compact Status file'
  'PSTI': strl = 'Serendipity mode Compact Status file'
  'P1ER': strl = 'PHT-C100 Edited Raw Data'
  'P2ER': strl = 'PHT-C200 Edited Raw Data'
  'PPER': strl = 'PHT-P Edited Raw Data'
  'PSER': strl = 'PHT-S Edited Raw Data'
  'P2ES': strl = 'PHT-C200 Serendipity Edited Raw Data'
  'PC1S': strl = 'PHT-C100 Standard Processed Data'
  'PC2S': strl = 'PHT-C200 Standard Processed Data'
  'PP1S': strl = 'PHT-P1 Standard Processed Data'
  'PP2S': strl = 'PHT-P2 Standard Processed Data'
  'PP3S': strl = 'PHT-P3 Standard Processed Data'
  'PSLS': strl = 'PHT-SL Standard Processed Data'
  'PSSS': strl = 'PHT-SS Standard Processed Data'
  'PC1A': strl = 'PHT-C100 cal A file'
  'PC2A': strl = 'PHT-C200 cal A file'
  'PP1A': strl = 'PHT-P1 Cal A file'
  'PP2A': strl = 'PHT-P2 Cal A file'
  'PP3A': strl = 'PHT-P3 Cal A file'
  'PPAP': strl = 'PHT-P Point Source Photometry data'
  'PPAE': strl = 'PHT-P Extended Source Photometry data'
  'PPAS': strl = 'PHT-P Scan & Slew Photometry data'
  'PLAP': strl = 'PHT-SL Point Source Spectroscopy data'
  'PLAE': strl = 'PHT-SL Extended Source Spectroscopy data'
  'PLAS': strl = 'PHT-SL Raster Mode Spectroscopy data'
  'PSAP': strl = 'PHT-SS Point Source Spectroscopy data'
  'PSAE': strl = 'PHT-SS Extended Source Spectroscopy data'
  'PSAS': strl = 'PHT-SS Raster Mode Spectroscopy data'
  'PCAP': strl = 'PHT-C Point Source Photometry data'
  'PCAE': strl = 'PHT-C Extended Source Photometry data'
  'PCAS': strl = 'PHT-C Scan & Slew Photometry data'
  'PGAI': strl = 'PHT Photometric Image data'
  'PGAU': strl = 'PHT Uncertainty Image data'
  'PGAT': strl = 'PHT Exposure Image data'
  ELSE: strl = 'File'
  endcase
end
