;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       DECODE_HDR2MEA
;
; PURPOSE:
;       This is part of the pia_control panel support routines.
; 	And therefore is designed entirely with the pia_control,
;	pia_read_ext and pia_man_mea in mind.
;	It is used for converting the fits header to
;	a more infromative information.
;	It decodes the AOT name, the Object name and the ATTTYPE
;	name ( pointing, tracking or raster).
;
; CATEGORY:
;       PIA - utilities
;
; CALLING SEQUENCE:
;       DECODE_HDR2MEA, HEADER, OUTPUT-STRING, PIA_NAME
;
; INPUT:
;	header: the FITS header for decoding
;
; OUTPUT:
;	output-string: the decoded string
;	pia_name: name assigned by PIA, it can be modified by users.
;
; COMMON BLOCKS:
;
; PROCEDURES USED:
;       PIA LIB:
;	Astronomical Library:
; MODIFICATION HISTORY:
;	Written by: Wai-Ming Tai (DIAS)			March 1996
;	Measname added (CG)				May 1997
;	V6.3
;
;-
pro decode_hdr2mea, hdr, str, measname, ADMN = admn

  aotname = strtrim(sxpar(hdr, 'EOHAAOTN'), 2)
  obj = strtrim(sxpar(hdr, 'OBJECT'), 2)
;  ra = strtrim(string(sxpar(hdr, 'ATTRA')), 2)
;  dec = strtrim(string(sxpar(hdr, 'ATTDEC')), 2)
  type = strtrim(sxpar(hdr, 'ATTTYPE'), 2)
  ; get the PIA_name from the header, if not present then write it
  measname = strtrim(sxpar(hdr, 'PIA_MNAM'), 2)
  IF measname eq '0' AND KEYWORD_SET(admn) THEN BEGIN 
    measname = admn
    FXADDPAR, hdr, 'PIA_MNAM', measname, $ 
        "Name chosen for measurement by PIA user", BEFORE='XTENSION'
  ENDIF
     
  case type of
  'P': type = 'pointing'
  'T': type = 'tracking'
  'R': begin
       type = 'raster'
       npts = strtrim(string(sxpar(hdr, 'ATTRNPTS')), 2)
       nlns = strtrim(string(sxpar(hdr, 'ATTRNLNS')), 2)
       type = type + '=' + npts + 'x' + nlns 
       end
   ELSE:
   endcase
   
;   str = aotname + ', ' + obj + ', ' + type + ', (' + ra + ', ' + dec + ')'
   str = obj + ', ' + aotname + ', ' + type 

; add chosen name for measurement
   ;IF measname NE '0' THEN str = str + ', ' + measname
end
