;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       DECODE_TDT2MEA
;
; PURPOSE:
;       This is part of the pia_control panel support routines.
; 	And therefore is designed entirely with the pia_control,
;	pia_read_ext and pia_man_mea in mind.
;	It is used for converting the tdt measurement information
;	a more infromative measurement information.
;
; CATEGORY:
;       PIA - utilities
;
; CALLING SEQUENCE:
;       DECODE_TDT2MEA, MEANAME, OUTPUT-STRING
;
; INPUT:
;	MEANAME: the TDT measurement for decoding
;
; OUTPUT:
;	output-string: the decoded string
;
; COMMON BLOCKS:
;
; PROCEDURES USED:
;       PIA LIB:
;	Astronomical Library:
; MODIFICATION HISTORY:
;	Written by: Wai-Ming Tai (DIAS)			March 1996
;	Special info added (CG)				July 1996
;	Concatenated info added (CG)			November 1997
;	V6.6
;	Change for new concatenation nomenclature (CG)	July 1998
;	V7.2
;
;-
pro decode_tdt2mea, meaname, str

  meapos = fix(strmid(meaname, 2, 2)) + 1
; we just take the first two character, for P or S detector is okay, and
; as for C100 or C200, it becomes C1 or C2
  str = strmid(meaname, 0, 2) + '-' + strmid(meaname, 4, 8) + '-' + $
        strtrim(string(meapos), 2)

; add the special cases 
	 IF STRLEN(meaname) GT 12 THEN BEGIN
	 	IF STRUPCASE(STRMID(meaname,12,1)) EQ 'S' THEN $
	 	   str = str + '-Subtr' 
	 	IF STRUPCASE(STRMID(meaname,12,1)) EQ 'G' THEN $
	 	   str = str + '-Conc' 
	 	IF STRUPCASE(STRMID(meaname,12,4)) EQ '_LEG' THEN $
	 	   str = str + '-R_leg'+ STRMID(meaname,16,2) 
	 	IF STRUPCASE(STRMID(meaname,12,4)) EQ '_CST' THEN $
	 	   str = str + '-ChopS'+ STRMID(meaname,18,5) 
	 	IF STRUPCASE(STRMID(meaname,12,2)) EQ '_y' THEN $
	 	   str = str + '-Rast '+ STRMID(meaname,12,8) 
	 	IF STRUPCASE(STRMID(meaname,12,4)) EQ 'GLUE' THEN $
	 	   str = str + '-Concat' 
	 ENDIF
end
