;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO DEGL_RAMPS, XALL, YALL, ERD_DISC, RAMPEND, DEGLFLAG, DEGLINFO
;+
; NAME:
;	DEGL_RAMPS
;
; PURPOSE:
;	Deglitch ramps of a measurement returning 
;	the corrected ramps
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	DEGL_RAMPS, XALL, YALL, ERD_DISC, RAMPEND, DEGLFLAG, DEGLINFO
;
; INPUTS:
;	Xall	: Array containing the independent variable [t]  (same size)
;	Yall	: Array containing values of read-outs from a measurement [V]
;	Erd_disc: Array containing flags (0=to be used, 1=not to be used)
;	Rampend	: Array containing the end of integration ramps (before ramp
;		   splitting)
;	Tint	: On chip integration time applied in the measurement
;	
;
; OUTPUTS:
;	Degflag	: Array containing flags (0=undisturbed signal, 5=glitch)
;
; RESTRICTIONS:
;	Yall, Xall, ERD_DISC must have the same number of elements
;
; PROCEDURES USED:
;	PIA source:
;		deglitch_basic
;
; COMMON BLOCKS:
;	degl_ramps_cmn
;
; MODIFICATION HISTORY:
;	Written by:	Carlos Gabriel (ESA/VILSPA-SAI)	        December 1995
;	Modifications by I.Heinrichsen (MPIK) and CG
;	Version 5.0					        August 1996
;	Flag coding included and use of rampend (JAcosta)	May 1999
;	V7.4
;-
;
COMMON degl_ramps_cmn, fsig, niter, minp


 On_ERROR,2                                          ;Return to caller
;
; Check the number of parameters
;
	IF N_PARAMS() LT 5 THEN MESSAGE, $
          'Syntax: DEGL_RAMPS, XALL, YALL, ERD_DISC, RAMPEND, DEGLFLAG, ' + $
	  ' DEGLINFO '
;
deglinfo = ''
;
	IF N_ELEMENTS(fsig) EQ 0 THEN degl_ramps_init


	SUM = N_ELEMENTS(XALL)
	IF SUM NE N_ELEMENTS(YALL) THEN BEGIN
	  MESSAGE, /info,'Xall and Yall must have same number of elements, back'
	  RETURN
	ENDIF

deglflag = erd_disc*0


; Now proceed ramp per ramp
nramp = N_ELEMENTS(rampend)

iramp0 = 0
FOR iramp=0, nramp-1 DO BEGIN   ;starts loop over ramps 
  npt_ramp = rampend(iramp)-iramp0+1
  ind_ramp = INDGEN(npt_ramp) + iramp0
  xxt = xall(ind_ramp)
  yyt = yall(ind_ramp)
  fyt = erd_disc(ind_ramp)
  indok = WHERE(fyt EQ 0, nok)
  IF nok GT 1 THEN BEGIN
  	 deglitch_basic, xxt(indok), yyt(indok), accdegl, $
		      	degltext, fsig=fsig, iter=niter, minp=minp
			
    IF N_ELEMENTS(degltext) GT 1 THEN deglinfo = [deglinfo, degltext(1:*)]

    deglflag(ind_ramp(indok)) = accdegl
  ENDIF 
  iramp0 = rampend(iramp)+1
ENDFOR     ;close loop over ramps

RETURN
END










