;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	DEGLITCH2
;
; PURPOSE:
;	Look for positive jumps in a ramp of a measurement returning 
;	the ramp with jumps removed
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	DEGLITCH2, xin, yin, ydegl, FSIG=FSIG, ITER=ITER, MINP=MINP
;
; INPUTS:
;	xin	: Array containing an x axis (e.g. time, position, etc) 
;	Yin	: Array containing a ramp of read-outs 
;
; KEYWORDS:
;	FSIG	: Sigmas' threshold for determining a jump
;	ITER	: Number of iterations 
;	MINP	: Minimum of points for applying the algorithm
;
; OUTPUTS:
;	Ydegl	: Array containing the corrected y
;
; COMMON BLOCKS:
;	degl_string
; RESTRICTIONS:
;
; PROCEDURES USED:
;	None
;
; MODIFICATION HISTORY:
;	Written by:	Carlos Gabriel (ESA/VILSPA-SAI)		December 1995
;		(based partially on a routine by J.Acosta, IAC)
;	Modified (last) by CG:
;	Normalization fixed (CG)				February 1997
;	Version 6.1
;	Position within ramp info added to degltext (CG)	Januuary 1998
;	V6.6
;-
PRO deglitch2, xin, yin, ydegl, FSIG=FSIG, ITER=ITER, MINP=MINP

COMMON degl_string, degltext

	IF NOT KEYWORD_SET(ITER) THEN ITER=4
	IF NOT KEYWORD_SET(FSIG) THEN FSIG=4.5
	IF NOT KEYWORD_SET(MINP) THEN MINP=25
	
	pos_in_ramp = 0
	
	x = xin
	y=yin

	nit = 0
	nall = N_ELEMENTS(y)
	IF nall LT minp THEN BEGIN 
		ydegl = y
		RETURN
	ENDIF
		
	
	WHILE nit LT iter DO BEGIN

	 dify = y(1:nall-1) - y(0:nall-2)
	 difx = x(1:nall-1) - x(0:nall-2)
	 dify_norm = dify / difx 
	 difabs = y(1:nall-1) - y(0)
	
	 indmin = WHERE(dify NE max(dify), nn)
	 IF nn GT 1 THEN BEGIN
	  stdv = stdev(dify_norm(indmin), meandif_norm)
	  stdvn = stdev(dify(indmin), meandif)

	  IF meandif EQ 0. THEN meandif = 1.e-08
	  
	  n_out = $
	    WHERE(ABS(dify_norm) GT ABS(meandif_norm+stdv*fsig), ncount) 
	
	  IF ncount EQ 0 THEN nit = 99 ELSE BEGIN
	 
		FOR I=0,ncount-1 DO BEGIN
		   
		   difabs(n_out(I):*) = difabs(n_out(I):*) - $
					dify(n_out(I)) + meandif 
		 pos_in_ramp = pos_in_ramp + 1
	         s=string(x(n_out(i)))+'     '+string(dify(n_out(i))) + $
	         	'     '+string(meandif)+ '    '+$
	         	string(dify(n_out(i))/meandif) + '           ' + $
	         	STRTRIM(pos_in_ramp,2)
	         
		   degltext=[degltext,s]
		   IF N_ELEMENTS(difabs) GT n_out(I)+1 THEN BEGIN 
		   	difabs(n_out(I)+1:*) = difabs(n_out(I)+1:*) - $
					dify(n_out(I)+1) + meandif 
			dify(n_out(i)+1) = meandif
		   ENDIF
	 	   y = [y(0), y(0)+difabs]
		ENDFOR
		
	 	nit = nit+1

	   ENDELSE
	  ENDIF ELSE nit=99
	ENDWHILE

	ydegl = y


	RETURN
	END	 













