;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	DEGLITCH_BASIC
;
; PURPOSE:
;	Look for positive jumps in a ramp of a measurement returning 
;	the ramp with jumps removed
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	DEGLITCH_BASIC, xin, yin, ydegl, FSIG=FSIG, ITER=ITER, MINP=MINP
;
; INPUTS:
;	xin	: Array containing an x axis (e.g. time, position, etc) 
;	Yin	: Array containing a ramp of read-outs 
;
; KEYWORDS:
;	FSIG	: Sigmas' threshold for determining a jump
;	ITER	: Number of iterations 
;	MINP	: Minimum of points for applying the algorithm
;
; OUTPUTS:
;	Ydegl	: Array containing the corrected y
;
; COMMON BLOCKS:
;	degl_string
; RESTRICTIONS:
;
; PROCEDURES USED:
;	None
;
; MODIFICATION HISTORY:
;	Original routine "deglitch2.pro"
;	Written by:	Carlos Gabriel (ESA/VILSPA-SAI)		December 1995
;		(based partially on a routine by J.Acosta, IAC)
;	Modified (last) by CG:
;	Normalization fixed (CG)				February 1997
;	Version 6.1
;	Position within ramp info added to degltext (CG)	Januuary 1998
;	V6.6
;	
;	Renamed to deglitch_basic after simplification by
;	Jose Acosta (IAC)					May 1999
;	V7.4
;	Preventing for a case with all differences equal (CG)	July 1999
;	V8.0 
;-
PRO deglitch_basic, xin, yin, degl_acc, degltext, FSIG=FSIG, ITER=ITER, $
   MINP=MINP

degltext = ''

	IF NOT KEYWORD_SET(ITER) THEN ITER=4
	IF NOT KEYWORD_SET(FSIG) THEN FSIG=4.5
	IF NOT KEYWORD_SET(MINP) THEN MINP=25
		
	degl_acc = FIX(yin)*0

	nit = 0
	nall = N_ELEMENTS(yin)
	IF nall LT minp THEN RETURN
		
	 dify = yin(1:nall-1) - yin(0:nall-2)
	 difx = xin(1:nall-1) - xin(0:nall-2)
	 dify_norm = dify / difx 
	 
	 indtaken = INDGEN(nall-1)
	 
	 difytaken = dify_norm
	 ncount = nall-1
	
	WHILE nit LT iter AND ncount GT 0 DO BEGIN
	 difytaken = difytaken(indtaken)
	 ; perform min MAX clipping
	 indclip = WHERE(difytaken NE MAX(difytaken) AND $ 
	     difytaken NE MIN(difytaken), nn)
	 
	 CASE 1 OF 
	    nn GT 1: BEGIN
	               stdv = STDEV(difytaken(indclip), meandif_norm)
		       meandif = AVG(difytaken(indclip))
		     END  
	    nn LE 1: BEGIN
	               stdv = STDEV(difytaken)
		       meandif = AVG(difytaken)
		     END  
	    ELSE:
	 ENDCASE   
	 
	  tol =  stdv*fsig
	 
	
	 indtaken = WHERE(ABS(difytaken-meandif) LE tol, ncount)
	 nit = nit+1
	ENDWHILE 
	 	  
	indout = WHERE(ABS(dify_norm-meandif) GT tol, nout) 
	
	FOR i=0, nout-1 DO BEGIN 
	    degl_acc(indout(i)+1) = 5
	    s=string(xin(indout(i)+1))+'     '+string(dify(indout(i))) + $
	         	'     '+string(meandif)+ '    '+$
	         	string(dify(indout(i))/meandif) + '           ' ; + $
	         	;STRTRIM(pos_in_ramp,2)
	         
	    degltext=[degltext,s]
	ENDFOR
		

	RETURN
	END	 













