;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the Acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO Deglitch_Change_Event, event
;+
;  NAME:
;	DEGLITCH_CHANGE
;
;  PURPOSE:
;	Event handler for Deglitch_Change
;
;  CATEGORY:
;	PIA - graphics
;
;  MODIFICATION HISTORY
;	Written by:	Huw Morris
;	Modified by:	C. Gabriel
;	Oct 95 Version 3.5
;	Deglitching taking into account RPID!  (CG)	      June 1996
;	Discarded signals are not considered for 
;	deglitching, added input another argument  (JA)       March 1997
;	No upper limit for local distribution (CG)	      June 1997
;	V6.3
;	Shows in red former discarded points, in blue 
;		new ones (CG)				      January 1998
;	V6.6
;	Use of /modal as prescribed for IDL >=5.0 (CG)	      January 1999
;	V7.3
;-

@deglitch_param
@colour_indices

; Get the information from the widget that caused the event
	Widget_Control, event.id, Get_Value=Value, Get_UValue=UValue

; The user value of the base widget points to another base widget, where
; all the necessary information is stored.
	Degparbase = WIDGET_INFO(event.id, /parent)
	Widget_Control, Degparbase, Get_UValue=realbase
	Widget_Control, realbase, Get_UValue=info

	CASE UValue OF

; Number of times to iterate
	  'ITER': BEGIN
	    IF (Value LT 1 OR Value GT 10) THEN BEGIN
	      Acknowledge, group=event.top, Text='   Iterations must be in range [1, 10]    '
	      Widget_Control, event.id, Set_Value=info.Iter
	    ENDIF ELSE BEGIN
	      Widget_Control, event.id, Set_Value=Value
	    ENDELSE
	    Widget_Control, info.BadID, Get_Value=Bad
	    IF (Value LT Bad) THEN Widget_Control, info.BadID, Set_Value=Value
	  END

; Number of times a pixel has to be flagged bad in order to be rejected
	  'BAD': BEGIN
	    Widget_Control, info.IterID, Get_Value=Iter
	    IF (Value LT 1 OR Value GT Iter) THEN BEGIN
	      Acknowledge, group=event.top, $
	        Text='   Bad count must be in range [1, Iterations]   '
	      Widget_Control, event.id, Set_Value=info.Bad
	    ENDIF ELSE BEGIN
	      Widget_Control, event.id, Set_Value=Value
	    ENDELSE
	  END

; The size of the local distribution
	  'LOCAL': BEGIN
	    IF (Value LT 5 ) THEN BEGIN
	      Acknowledge, group=event.top, $
	        Text='   Local distribution must be > 4   '
	      Widget_Control, event.id, Set_Value=info.Local
	    ENDIF ELSE BEGIN
	      Widget_Control, event.id, Set_Value=Value
	    ENDELSE
	  END
	
; The number of standard deviations from the median a point must be in
; order to be marked as bad
	  'SIG': BEGIN
	    IF (Value LT 0.1 OR Value GT 5.0) THEN BEGIN
	      Acknowledge, group=event.top, $
	        Text = '   Sigma range must be [0.1, 5.0]   '
	      Widget_Control, event.id, Set_Value=info.Sigma
	    ENDIF ELSE BEGIN
	      Widget_Control, event.id, Set_Value=Value
	    ENDELSE
	  END  

; The increment in each local istribution
	  'STEP': BEGIN
	    IF (Value LT 1 OR Value GT 5) THEN BEGIN
	      Acknowledge, group=event.top, $
	        Text =    'Local distribution jump must be in range [1, 5]   '
	      Widget_Control, event.id, Set_Value=info.Step
	    ENDIF ELSE BEGIN
	      Widget_Control, event.id, Set_Value=Value
	    ENDELSE
	  END

; If using individually chopper plateaux or per step
	  'PERCHOP': BEGIN 
	         Widget_Control, info.PerChopID, Get_Value=perchop
	          INFO.PERCHOP = perchop
	  END	          
	  
; If using raster individually
	  'PERRAST': BEGIN 
	         Widget_Control, info.PerRastID, Get_Value=perrast
	          INFO.PERRAST = perrast
	  END	          
	  
; If using clipping
	  'CLIP': BEGIN 
	         Widget_Control, info.DeglClipID, Get_Value=clip
	          INFO.Degl_Clip = clip
		 Degl_Clip = clip
	  END	          
	  
; Put all the widget values back into the top level widget and exit
	  'EXIT': BEGIN
	    info.Iter = info.IterDef
	    info.Bad = info.BadDef
	    info.Local = info.LocalDef
	    info.Sigma = info.SigDef
	    info.Step = info.StepDef
	    info.Perchop = info.PerchopDef
	    info.Perrast = info.PerrastDef
	    info.Degl_clip = info.DeglclipDef
	    Widget_Control, realbase, Set_UValue=info 
	    Widget_Control, event.top, /destroy
	  END

; Put all the widget values back into the top level widget and exit
; changing the elements in the common block with the deglitch parameters
	  'EXIT_CH': BEGIN
	    Widget_Control, info.IterID, Get_Value=Iter
	    info.Iter=Iter
	    Widget_Control, info.BadID, Get_Value=Bad
	    info.Bad=Bad
	    Widget_Control, info.LocalID, Get_Value=Local
	    info.Local=Local
	    Widget_Control, info.SigID, Get_Value=Sigma
	    info.Sigma=Sigma
	    Widget_Control, info.StepID, Get_Value=Step
	    info.Step=Step
	    Widget_Control, info.PerChopID, Get_Value=Perchop
	    info.Perchop = perchop
	    Widget_Control, info.PerRastID, Get_Value=Perraster
	    info.Perrast = perraster
	    Widget_Control, info.DeglClipID, Get_Value=Clip
	    info.Degl_clip = clip

	    max_iter = iter
	    num_bad = bad
	    num_local = local
	    num_sigma = sigma
	    num_step = step
	    per_chop = perchop
	    per_raster = perraster
	    degl_clip = clip	    
	    Widget_Control, realbase, Set_UValue=info 
	    Widget_Control, event.top, /destroy
	  END
; Replace all the widget values with the values they held on entering this
; procedure 
          'ORIG': BEGIN
	    info.Iter = info.IterDef
	    info.Bad = info.BadDef
	    info.Local = info.LocalDef
	    info.Sigma = info.SigDef
	    info.Step = info.StepDef
	    info.Perchop = info.PerchopDef
	    info.Perrast = info.PerrastDef
	    info.Degl_clip = info.DeglclipDef
	    Degl_clip = info.Degl_clip
	    Widget_Control, info.IterID, Set_Value=info.IterDef
	    Widget_Control, info.BadID, Set_Value=info.BadDef
	    Widget_Control, info.LocalID, Set_Value=info.LocalDef
	    Widget_Control, info.SigID, Set_Value=info.SigDef
	    Widget_Control, info.StepID, Set_Value=info.StepDef
	    Widget_Control, info.PerChopID, Set_Value=info.PerChopDef
	    Widget_Control, info.PerRastID, Set_Value=info.PerRastDef
	    Widget_Control, info.DeglClipID, Set_Value=info.DeglClipDef
	    Widget_Control, realbase, Set_UValue=info
	  END

; Perform the deglitching and display the results in a seperate window
	  'DEGLITCH': BEGIN
	    Widget_Control, event.top, /hourglass
	    Widget_Control, info.IterID, Get_Value=Iter
; Iter
	    IF (Iter LT 1 OR Iter GT 10) THEN BEGIN
	      Acknowledge, group=event.top, Text='   Iterations must be in range [1, 10]    '
	      Widget_Control, info.IterID, Set_Value=info.Iter
	      Iter = info.Iter
	    ENDIF 
	    Widget_Control, info.BadID, Get_Value=Bad
	    IF (Iter LT Bad) THEN Widget_Control, info.BadID, Set_Value=Iter
	    Max_Iter=Iter

; Bad counts
	    Widget_Control, info.BadID, Get_Value=Bad
	    IF (Bad LT 1 OR Bad GT Iter) THEN BEGIN
	      Acknowledge, group=event.top, $
	        Text='   Bad count must be in range [1, Iterations]   '
	      Widget_Control, info.BadId, Set_Value=info.Bad
	      Bad = info.Bad
	    ENDIF 

	    Num_Bad=Bad

; Local
	    Widget_Control, info.LocalID, Get_Value=Local
	    IF (Local LT 5) THEN BEGIN
	      Acknowledge, group=event.top, $
	        Text='   Local distribution must be > 4   '
	      Widget_Control, info.LocalID, Set_Value=info.Local
	      Local = info.Local
	    ENDIF 
	    Num_Local=Local

; Sigma
	    Widget_Control, info.SigID, Get_Value=Sigm
	    IF (Sigm LT 0.1 OR Sigm GT 5.0) THEN BEGIN
	      Acknowledge, group=event.top, $
	        Text = '   Sigma range must be [0.1, 5.0]   '
	      Widget_Control, info.SigID, Set_Value=info.Sigma
	      sigm = info.sigma
	    ENDIF 
	    Num_Sigma=Sigm

; Step
	    Widget_Control, info.StepID, Get_Value=Step
	    IF (Step LT 1 OR Step GT 5) THEN BEGIN
	      Acknowledge, group=event.top, $
	        Text =    'Local distribution jump must be in range [1, 5]   '
	      Widget_Control, info.StepID, Set_Value=info.Step
	      Step = info.Step
	    ENDIF 
	    Num_Step=Step

; Per/chop
	    Widget_Control, info.PerChopID, Get_Value=perchop

; Per/rast
	    Widget_Control, info.PerRastID, Get_Value=perrast

	    Deglitch_all, info.Slope, info.ChopStep, info.rpid, $
	    	info.Error, info.Sgdisc, accept, slice_chop=perchop, $
		noslice_raster=1-perrast

	    Info.accept = accept

; Plot the deglitch points in a large window. 
	    xindex = findgen(N_ELEMENTS(info.Slope))
	    pia_xplot, info.time, info.Slope, info.Error, color=white, $
		group=event.top, psym=4

	    form_disc = WHERE(info.sgdisc NE 0, nfd)
	    IF nfd GT 0 THEN pia_xplot, info.time(form_disc), $
	       info.slope(form_disc), color=red, psym=4, $
	       legend='Former discarded', /overplot


	    Badpoints=WHERE(info.Accept NE 0, BadCount)
	    IF (Badcount GT 0) THEN BEGIN
	      IF (Badcount EQ 1) THEN BEGIN
	        BadSlopes=FltArr(1)
	        Badtimes=FltArr(1)
	        BadSlopes(0)=info.Slope(Badpoints)
		Badtimes(0) = info.time(Badpoints)
	      pia_xplot, Badtimes, BadSlopes, $
	        psym=7, color=1, /overplot 
	        Acknowledge, group=event.top, $
	          Text =    'One slope has been discarded '
	      ENDIF ELSE BEGIN
		Badtimes = info.time(Badpoints)
	        BadSlopes=info.Slope(Badpoints)
	      pia_xplot, Badtimes, BadSlopes, $
	        psym=7, color=magenta, /overplot, symsize=1.5 
	        Acknowledge, group=event.top, $
	          Text =  STRTRIM(STRING(N_ELEMENTS(BadSlopes)),2) + $
				 ' slopes have been discarded '
	      ENDELSE
	    ENDIF ELSE $
	        Acknowledge, group=event.top, $
	          Text =  'All slopes have been accepted '
	  END

	ENDCASE

	END

;-----------------------------------------------------------------------

	PRO Deglitch_Change, Time, Slope, ChopStep, RPID, Error, Sgdisc, $
	   Accept, NO_data=no_data, modal=modal, group=group
;+
;
;  NAME:
;	DEGLITCH_CHANGE
;
;  PURPOSE:
;	Allows the user to interactively alter the deglitching parameters
;
;  CATEGORY:
;	PIA - graphics
;
;  CALLING SEQUENCE:
;	DEGLITCH_CHANGE, Time, Slope, Chopstep, RPID, Error, Sgdisc, Accept
;
;  INPUTS:
;	Time	: Array of input times (corresponding to slope)
;	Slope   : Array of input slopes
;	Chopstep: Corresponding array of chopper steps
;	RPID	: Corresponding array (2 BYTE-Arr) of Raster Points ID
;	Error   : Corresponding array of slope errors
;	Sgdisc  : Corresponding array with discarded signals 
;
;  OUTPUTS:
;	Accept  : Array of the status of each slope:
;	  0 - Accept
;	  1 - Reject
;
;  COMMON BLOCKS:
;	deglitch_param
;
;  SIDE EFFECTS:
;	Values in the deglitch_param common block are altered.
;
;  PROCEDURES USED:
;	PIA LIB:  Acknowledge
;	          pia_plot
;	          pia_xplot
;	INTERNAL: deglitch_change_event
;
;  MODIFICATION HISTORY:
;	Written by:	Huw Morris
;	Modified by:	C. Gabriel
;	Oct 95 Version 3.5
;	Accept & quit implemented (CG)			December 1995
;	Time = input parameter -> time x-axis (CG)	January 1996
;
;-

@deglitch_param
@colour_indices
                            
	IF KEYWORD_SET(no_data) THEN BEGIN
		IF not KEYWORD_SET(modal) THEN modal = 0
	ENDIF ELSE BEGIN
	 modal = 0
	ENDELSE
	IF not KEYWORD_SET(group) THEN group=''

	N_Dim=N_Elements(Slope)
;	Error=FltArr(N_Dim)

; Look first if deglitch parameters are present - If not initialize
	IF N_ELEMENTS(min_deglitch) EQ 0 THEN deglitch_param_init

; Make sure that the deglitching has been carried out first
	IF not KEYWORD_SET(NO_DATA) THEN $
	Deglitch_All, Slope, ChopStep, RPID, Error, Sgdisc, Accept, $
	   slice_chopp=per_chop, noslice_raster=per_raster $
	 ELSE begin
	   time=0.
	   slope=0.
	   chopstep=0
	   rpid=[0b,0b]
	   error=0.
	   sgdisc=0.
	   accept=0
	ENDELSE

; This is the base widget that will contain the structure passed back from
; the event handler. It will remain unrealized
	VBase = Widget_Base()	

; This is the apparent base widget. The User Value will point to the
; real base widget. In this way, destroying all the realized widgets does
; not delete the data.
	DegparBase = Widget_Base(Title='Deglitching Parameters', $
	  Event_Pro='Deglitch_Change_Event', Column=1, modal=modal, group=group)


	font='-*-courier-bold-*-*-*-14-*'
; A widget that holds Max_Iter: the number of iterations to perform on
; the data  
	Iter = CW_Field(DegparBase, font=font, $
		Title='Number of Iterations               ', $
		Value=Max_Iter, $
	  UValue='ITER', /return_events, /integer, xsize=4)

; A widget that holds Num_Bad: the number of times a slope has to be
; flagged bad before it is rejected.
	Bad = CW_Field(DegparBase, font=font,$
		Title='Times a pixel has to be flagged bad', $
	  Value=Num_Bad, UValue='BAD', /return_events, /integer, xsize=4)

; A widget that holds Num_Local: the size of the local distribution
	Local = CW_Field(DegparBase, font=font,$
		Title='Size of local distribution         ', $
	  Value=Num_Local, UValue='LOCAL', /return_events, /integer, xsize=4)

; A widget that holds Num_Sigma: the number of standard deviations away
; from the median of the local distribution for a slope to be flagged bad.
; Changing this value has the greatest effect on the deglitching. 
	Sig = CW_Field(DegparBase, font=font,$
		Title='Number of sigmas range          ', $
		Value=Num_Sigma, $
	  	UValue='SIG', /return_events, /floating, xsize=7)

; A widget that holds Num_Step: the increment applied to the local 
; distribution
	Step= CW_Field(DegparBase, font=font,$
		Title='Size of jump in local distribution ', $
	  Value=Num_Step, UValue='STEP', /return_events, /integer, xsize=4)

; A widget that holds Num_Step: the increment applied to the local 
; distribution
	
	CHOP= cw_bgroup(DegparBase, /NONexclusive,$
		SET_VALUE=[PER_CHOP], FONT=font, UVAL='PERCHOP', $
		['USE chopper plateaux / step individually']) 

	RAST= cw_bgroup(DegparBase, /NONexclusive,$
		SET_VALUE=[PER_RASTER], FONT=font, UVAL='PERRAST', $
		['USE raster steps individually']) 

	DeglClipID= cw_bgroup(DegparBase, /NONexclusive,$
		SET_VALUE=[Degl_Clip], FONT=font, UVAL='CLIP', $
		['USE max/min clipping']) 


; A button widget to perform the deglitching with the current parameters
; and to display the results on a large plot
	IF NOT KEYWORD_SET(NO_DATA) THEN $
	Draw = Widget_Button(DegparBase, Value='Perform Deglitching', $
	  UValue='DEGLITCH') ELSE DRAW=-1

; A button widget to restore the deglitching parameters to the values
; they had on entry to the event handler
	Orig = Widget_Button(DegparBase, Value='Get original parameters', $
	  UValue='ORIG')

; A button widget to take the original values of the deglitching
; parameters ,and exit
	Exit = Widget_Button(DegparBase, $
		Value='Original parameters & Exit', UValue='EXIT')

; A button widget to accept the changed values of the deglitching
; parameters ,and exit
	Exit = Widget_Button(DegparBase, $
		Value='New parameters & Exit', UValue='EXIT_CH')

; A widget to hold a small plot, which shows the rejected slopes using
; the original parameters
	IF NOT KEYWORD_SET(NO_DATA) THEN $
	Graph = Widget_Draw(DegparBase, xsize=256, ysize=256) ELSE graph=-1

; Create an anonymous structure containing all the information the event
; handler might need.
; That is, the deglitch input/output parameters, the deglitch common
; block parameters, and default values for the common block parameters
	Info = {Time:time, Slope:slope, Chopstep:chopstep, RPID:rpid, $ 
	   Error:error, Sgdisc: sgdisc, $
	   Accept:accept, Iter:Max_Iter, Bad:Num_Bad, Local:Num_Local, $
	   Sigma:Num_Sigma, Step:Num_Step, Perchop: Per_chop, $
	   perrast:per_raster, IterID:Iter, BadID:Bad, LocalID:Local, $
	   SigID:Sig, StepID:Step, PerChopID:Chop, PerRastID:Rast, $
	   IterDef:Max_Iter, BadDef:Num_Bad, LocalDef:Num_Local, $
	   SigDef:Num_Sigma, StepDef:Num_Step, PerChopDef: Per_Chop, $
	   PerRastDef: Per_raster, $
	   Degl_clip: degl_clip, DeglclipID: DeglclipID, Deglclipdef:degl_clip}

; Use the base widget to point to this structure
	Widget_Control, vbase, Set_UValue=info

; Use the realized base to point to the base widget and realize it
	Widget_Control, Degparbase, Set_UValue=VBase
	Widget_Control, Degparbase, /realize

; Plot the current deglitching parameters in the small draw widget
	IF NOT KEYWORD_SET(NO_DATA) THEN BEGIN
	 Widget_Control, graph, Get_Value=wid
	 WSet, wid

 	 xind = findgen(N_ELEMENTS(slope)) + 1
         PIA_PLOT, Time, Slope, yerr=error, color=white, psym=4

	 form_disc = WHERE(sgdisc NE 0, fdn)
	 IF fdn GT 0 THEN OPLOT, time(form_disc), slope(form_disc), color=red, $
	    psym=4
	
         Bad = WHERE(Accept NE 0, Bad_count)
         IF (Bad_count GT 0) THEN OPLOT, time(Bad), Slope(Bad), color=blue, psym=7
	ENDIF


	xMANAGER,No_BLOCK=1, 'Deglitch_Change', DegparBase

; Retrive the information from the base widget
; These common variables have not necessarily been set in the event handler,
; and thus must be set here, just to make sure.
	Widget_Control, VBase, Get_UValue=info
	Max_Iter = info.Iter
	Num_Bad = info.Bad
	Num_Local = info.Local
	Num_Sigma = info.Sigma
	Num_Step = info.Step
	Degl_Clip = info.Degl_clip

	Accept = info.Accept
	
; Destroy the base widget - not possible, problems when running from other 
; widgets (CG)
;	Widget_Control, VBase, /destroy
	END
