;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO DER_SCPHDR, SRDHDR, SCPHDR, USRMSG = USRMSG
;+
; NAME:
;       DER_SCPHDR
;
; PURPOSE:
;	Derive a SCP Header file, adding to the SRD header (SRDHDR) 
;	keywords indicating signal selection criteriae for SCP derivation.
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       DER_SCPHDR, Srdhdr, Scphdr
;
; INPUTS:
;       Srdhdr 	: SRD-header
;
; OUTPUTS:
;       Scphdr 	: SCP-header
;
; COMMON BLOCKS:
;	phtacc
;
; PROCEDURES USED: 
;	None
;
; MODIFICATION HISTORY:
;	Written by:	Carlos Gabriel
;	Modified by: 	Wai-Ming Tai
;	Oct 95 Version 3.5
;	Comment changed to indicate SCP level (CG)		March 1996
;
;-
;
@phtacc
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 2 THEN MESSAGE, $
          'Syntax:  DER_SCPHDR, SRDHDR, SCPHDR'

	LINE = 'PRS_FS  =                    '+STRTRIM(string(sig1acc),2)+$
                        ' / using 1st signal/ch.plateau (0=taken,1=not)'
	junk = string(replicate(32b, 80))
	strput, junk, line, 0
	TMPHDR = [JUNK]

	IF N_ELEMENTS(signacc) GT 1 or signacc(0) NE 0 THEN BEGIN
	   FOR i=0,N_ELEMENTS(signacc)-1 DO BEGIN
		nr = signacc(i)
		IF nr le 9 THEN $
		LINE = 'PRS_'+STRTRIM(STRING(nr),2)+'S  =             '+ $
			string(nr)+                                   $
                        ' / # of Signal/Ch.Pl. deselected ' $
		ELSE LINE = 'PRS_'+STRTRIM(STRING(nr),2)+'S =             '+  $
			string(nr)+                                   $
                        ' / # of Signal/Ch.Pl. deselected ' 
	        junk = string(replicate(32b, 80))
	        strput, junk, line, 0
		TMPHDR = [TMPHDR,JUNK]
	   ENDFOR
	ENDIF

	LINE = 'PRS_FSIG=             '+string(minsig+1)+$
                        ' / First signal taken for processing '
	junk = string(replicate(32b, 80))
	strput, junk, line, 0
	TMPHDR = [TMPHDR,JUNK]
	
	LINE = 'PRS_LSIG=             '+string(maxsig-1)+$
                        ' / Last signal taken for processing '
	junk = string(replicate(32b, 80))
	strput, junk, line, 0
	TMPHDR = [TMPHDR,JUNK]
	
	IF N_ELEMENTS(anysig) GT 1 or anysig(0) NE 0 THEN BEGIN
	   FOR i=0,N_ELEMENTS(anysig)-1 DO BEGIN
		nr = anysig(i)
		IF nr le 9 THEN $
		LINE = 'PRS_'+STRTRIM(STRING(nr),2)+'A  =             '+ $
		    string(nr)+                                   $
                    ' / # of Signal deselected  ' ELSE IF nr le 99 THEN $
		LINE = 'PRS_'+STRTRIM(STRING(nr),2)+'A =             '+  $
		    string(nr)+                                   $
                    ' / # of Signal deselected  ' ELSE IF nr le 999 THEN $
		LINE = 'PRS_'+STRTRIM(STRING(nr),2)+'A=             '+   $
		    string(nr)+                                   $
                    ' / # of Signal deselected  ' 
	        junk = string(replicate(32b, 80))
	        strput, junk, line, 0
		TMPHDR = [TMPHDR,JUNK]
	   ENDFOR
	ENDIF
	
	IF KEYWORD_SET(usrmsg) THEN BEGIN
	  junk = string(replicate(32b,80))
	  strput, junk, 'PRS_USRM=', 0
	  strput, junk, usrmsg, 10
	  tmphdr = [TMPHDR,junk]
	endif
	
	keyword = strmid(srdhdr, 0, 8)
	xtension = where(keyword eq 'XTENSION')
	hdrlen = n_elements(srdhdr)
	scphdr = [ srdhdr( 0: xtension(0) - 1), tmphdr, $
		   srdhdr( xtension(0) : hdrlen - 1)]


	fxaddpar, scphdr, 'PRS_FDCH', sigtnacc.chop_meas, $
		'Disc. fraction / ch.plateau - chopped case', BEFORE='XTENSION'  
	fxaddpar, scphdr, 'PRS_FDNC', sigtnacc.star_meas, $
		'Disc. fraction(/CP) - staring & raster case', BEFORE='XTENSION'  

	COMMENT = WHERE(KEYWORD EQ 'COMMENT ')
	posi = STRPOS(SCPHDR(COMMENT(0)),'Ramp')
	IF posi NE -1 THEN BEGIN 
	  tmpline = SCPHDR(COMMENT(0))
	  STRPUT, tmpline, 'Chopper Plateau Data', posi
	  SCPHDR(COMMENT(0)) = tmpline
	ENDIF

	FXADDPAR, scphdr, 'PIA_VERS', !PIA_VERSION, $
	  ' PHT-Interactive Analysis version used', BEFORE='XTENSION'	     


        RETURN
        END
