;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO DER_SHDR, ERDHDR, NDEG, SRDHDR, USRMSG = USRMSG
;+
; NAME:
;       DER_SHDR
;
; PURPOSE:
;	Derive a SRD Header file, adding to the ERD header (ERDHDR) 
;	keywords indicating read-out selection criteriae for SRD derivation.
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       DER_SHDR, Erdhdr, Srdhdr
;
; INPUTS:
;       Erdhdr 	: ERD-header
;	Ndeg	: Degree of the polynomial used to perform ramp fitting
;
; OUTPUTS:
;       Srdhdr 	: SRD-header
;
; COMMON BLOCKS:
;	phtacc
;
; PROCEDURES USED: 
;	None
;
; MODIFICATION HISTORY:
;       Written by:	Carlos Gabriel
;	Modification history: 
;	ERD keywords taken out (CG) - December 1996
;	V5.5	
;	Ramp subdivision info added (CG)	March 1997
;	V6.2
;	Bug for first NDR acc fixed (CG)	September 1997
;	V6.5
;	Bug on type caused by new comment lines in ERD
;	 original files fixed	(CG)		September 1999
;	V8.0
;
;-
;
@phtacc
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 3 THEN MESSAGE, $
          'Syntax:  DER_SHDR, ERDHDR, NDEG, SRDHDR'


	IF !subd_ramp NE 0 THEN $
	 FXADDPAR, erdhdr, 'PR_SEPAR', !subd_ramp, $
	  ' Number of read-outs used for pseudo-ramp', BEFORE='XTENSION'
 
	LINE = 'PR_PDEG =             '+string(ndeg)+$
                        ' / Degree of polynomial used to fit ramps'
	JUNK = STRING(REPLICATE(32B, 80))
	STRPUT, JUNK, LINE, 0
	TMPHDR = [JUNK]
 
	LINE = 'PR_DR   =             '+string(drnacc)+$
                        ' / Processed using DR (0=taken,1=not)'
	JUNK = STRING(REPLICATE(32B, 80))
	STRPUT, JUNK, LINE, 0
	TMPHDR = [TMPHDR, JUNK]

	LINE = 'PR_FNDR =             '+string(ndr1nac)+$
                        ' / Processed using first NDR (0=taken,1=not)'
	JUNK = STRING(REPLICATE(32B, 80))
	STRPUT, JUNK, LINE, 0
	TMPHDR = [TMPHDR, JUNK]

	IF N_ELEMENTS(ndrnacc) GT 1 or ndrnacc(0) NE 0 THEN BEGIN
	   FOR i=0,N_ELEMENTS(ndrnacc)-1 DO BEGIN
		nr = fix(ndrnacc(i))
		IF nr le 9 THEN $
		LINE = 'PR_'+STRTRIM(STRING(nr),2)+'NDR =             '+ $
			string(nr)+                                   $
                        ' / # of NDR deselected ' $
		ELSE LINE = 'PR_'+STRTRIM(STRING(nr),2)+'NDR=             '+  $
			string(nr)+                                   $
                        ' / # of NDR deselected  ' 
	        JUNK = STRING(REPLICATE(32B, 80))
	        STRPUT, JUNK, LINE, 0
	        TMPHDR = [TMPHDR, JUNK]
	   ENDFOR
	ENDIF

	LINE = 'PR_FRAMP=             '+string(minr(0)+1)+$
                        ' / First ramp taken for processing '
	JUNK = STRING(REPLICATE(32B, 80))
	STRPUT, JUNK, LINE, 0
	TMPHDR = [TMPHDR, JUNK]
	
	IF maxr(0) GT 0 THEN strmax=string(maxr(0)-1) ELSE strmax='       L'
	LINE = 'PR_LRAMP=             '+strmax+$
                        ' / Last ramp taken for processing '
	JUNK = STRING(REPLICATE(32B, 80))
	STRPUT, JUNK, LINE, 0
	TMPHDR = [TMPHDR, JUNK]
	
	IF N_ELEMENTS(anyr) GT 1 or anyr(0) NE 0 THEN BEGIN
	   FOR i=0,N_ELEMENTS(anyr)-1 DO BEGIN
		nr = anyr(i)
		IF nr le 9 THEN $
		LINE = 'PR_'+STRTRIM(STRING(nr),2)+'A   =             '+ $
		    string(nr)+                                   $
                    ' / # of Read-out deselected  ' ELSE IF nr le 99 THEN $
		LINE = 'PR_'+STRTRIM(STRING(nr),2)+'A  =             '+  $
		    string(nr)+                                   $
                    ' / # of Read-out deselected  ' ELSE IF nr le 999 THEN $
		LINE = 'PR_'+STRTRIM(STRING(nr),2)+'A =             '+   $
		    string(nr)+                                   $
                    ' / # of Read-out deselected  ' 
	        JUNK = STRING(REPLICATE(32B, 80))
	        STRPUT, JUNK, LINE, 0
	        TMPHDR = [TMPHDR, JUNK]
	   ENDFOR
	ENDIF
	
	LINE = 'PR_FVOLT=        '+string(minvolt)+$
                        ' / Minimum Voltage accepted        '
	JUNK = STRING(REPLICATE(32B, 80))
	STRPUT, JUNK, LINE, 0
	TMPHDR = [TMPHDR, JUNK]
	
	LINE = 'PR_LVOLT=        '+string(maxvolt)+$
                        ' / Maximum Voltage accepted       '
	JUNK = STRING(REPLICATE(32B, 80))
	STRPUT, JUNK, LINE, 0
	TMPHDR = [TMPHDR, JUNK]
	
	IF KEYWORD_SET(usrmsg) THEN BEGIN
	  JUNK = STRING(REPLICATE(32B, 80))
	  STRPUT, JUNK, 'PR_USRM =', 0
	  STRPUT, JUNK, USRMSG, 10
	  TMPHDR = [TMPHDR,JUNK]
	ENDIF 
	JUNK = STRING(REPLICATE(32B, 80))
	STRPUT, JUNK, 'END     ', 0
	
	KEYWORD = STRMID(ERDHDR, 0, 8)
	XTENSION = WHERE(KEYWORD EQ 'XTENSION')
	HDRLEN = N_ELEMENTS(ERDHDR)
	SRDHDR = [ ERDHDR( 0 : XTENSION(0) - 1), TMPHDR, $
		   ERDHDR( XTENSION(0))]

	JUNK = STRING(REPLICATE(32B, 80))
	STRPUT, JUNK, 'END     ', 0
	SRDHDR = [SRDHDR,JUNK]

; change different keywords to adapt them to an IA product
	COMMENT = WHERE(KEYWORD EQ 'COMMENT ')
	posis = STRPOS(srdhdr(comment), 'Edited')
	ind = WHERE(posis NE -1, n)
	IF n EQ 0 THEN BEGIN
	  posis = STRPOS(srdhdr(comment), 'ERD')
  	  ind = WHERE(posis NE -1, n)
	ENDIF
	IF n GT 0 THEN BEGIN
		tmpline = SRDHDR(COMMENT(ind(0)))
		STRPUT, tmpline, 'Signal per Ramp Data', posis(ind(0))
		SRDHDR(COMMENT(ind(0))) = tmpline
	ENDIF ELSE BEGIN
		JUNK = STRING(REPLICATE(32B, 80))
		STRPUT, junk, 'COMMENT    Signal per Ramp Data', 0
		SRDHDR = [junk, SRDHDR]
	ENDELSE
	
	FILENAME= WHERE(KEYWORD EQ 'FILENAME')
; *** Following line changed (SB, 22/08/96)
;	posi = STRPOS(SRDHDR(FILENAME(0)), 'in ISO')
	posi = 43
	tmpline = SRDHDR(FILENAME(0))
	STRPUT, tmpline, 'of original ERD file in ISO archive',posi
	SRDHDR(FILENAME(0)) = tmpline
	
	DATE= WHERE(KEYWORD EQ 'DATE    ')
	posi = STRPOS(SRDHDR(DATE(0)), 'date')
	tmpline = SRDHDR(DATE(0))
	STRPUT, tmpline, 'of original ERD file', posi + 5
	SRDHDR(DATE(0)) = tmpline
	
	FILEVERS= WHERE(KEYWORD EQ 'FILEVERS')
; *** Following line changed (SB, 22/08/96)
;	posi = STRPOS(SRDHDR(FILEVERS(0)), 'in ISO')
	posi = 44
	tmpline = SRDHDR(FILEvers(0))	
	STRPUT, tmpline, 'for ERD file in ISO archive ', posi
	SRDHDR(FILEvers(0)) = tmpline 
	FXADDPAR, srdhdr, 'PIA_VERS', !PIA_VERSION, $
	  ' PHT-Interactive Analysis version used', BEFORE='XTENSION'	     
	
        RETURN
        END
