;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO DER_SPDHDR, SCPHDR, SPDHDR, USRMSG = USRMSG
;+
; NAME:
;       DER_SPDHDR
;
; PURPOSE:
;	Derive a SPD Header file, adding to the SCP header (SCPHDR) 
;	keywords indicating signal selection criteriae for SPD derivation.
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       DER_SPDHDR, Scphdr, Spdhdr
;
; INPUTS:
;       Scphdr 	: SCP-header
;
; KEYWORD PARAMETERS:
;	USRMSG	: Set this for a user message
;
; OUTPUTS:
;       Spdhdr 	: SPD-header
;
; COMMON BLOCKS:
;	phtacc
;
; PROCEDURES USED:
;	None 
;
; MODIFICATION HISTORY:
;       Written by Carlos Gabriel
;	Oct 95 Version 3.5
;	Comment changed indicating SPD level (CG)		March 1996
;
;-
;
@phtacc
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 2 THEN MESSAGE, $
          'Syntax:  DER_SPDHDR, SCPHDR, SPDHDR'


	LINE = 'PRC_FCHP=             '+string(minscp+1)+$
                        ' / First Ch.Plateau taken for processing '
	junk = string(replicate(32b, 80))
	strput, junk, line, 0
	TMPHDR = JUNK
	
	LINE = 'PRC_LCHP=             '+string(maxscp-1)+$
                        ' / Last Ch.Plateau taken for processing '
	junk = string(replicate(32b, 80))
	strput, junk, line, 0
	TMPHDR = [TMPHDR,JUNK]
	
	IF N_ELEMENTS(scpnacc) GT 1 or scpnacc(0) NE 0 THEN BEGIN
	   FOR i=0,N_ELEMENTS(scpnacc)-1 DO BEGIN
		nr = scpnacc(i)
		IF nr le 9 THEN $
		LINE = 'PRC_'+STRTRIM(STRING(nr),2)+'S  =             '+ $
			string(nr)+                                   $
                        ' / # of deselected Chopper Plateau' $
		ELSE LINE = 'PRC_'+STRTRIM(STRING(nr),2)+'S =             '+  $
			string(nr)+                                   $
                        ' / # of deselected Chopper Plateau ' 
	        junk = string(replicate(32b, 80))
	        strput, junk, line, 0
		tmphdr = [tmphdr,junk]
	   ENDFOR
	ENDIF

	IF N_ELEMENTS(anyscp) GT 1 or anyscp(0) NE 0 THEN BEGIN
	   FOR i=0,N_ELEMENTS(anyscp)-1 DO BEGIN
		nr = anyscp(i)
		IF nr le 9 THEN $
		LINE = 'PRC_'+STRTRIM(STRING(nr),2)+'A  =             '+ $
		    string(nr)+                                   $
                    ' / # of deselected Ch.Plateau  ' ELSE IF nr le 99 THEN $
		LINE = 'PRC_'+STRTRIM(STRING(nr),2)+'A =             '+  $
		    string(nr)+                                   $
                    ' / # of deselected Ch.Plateau ' ELSE IF nr le 999 THEN $
		LINE = 'PRC_'+STRTRIM(STRING(nr),2)+'A=             '+   $
		    string(nr)+                                   $
                    ' / # of deselected Ch.Plateau ' 
	        junk = string(replicate(32b, 80))
	        strput, junk, line, 0
		TMPHDR = [TMPHDR,JUNK]
	   ENDFOR
	ENDIF
	
	IF KEYWORD_SET(usrmsg) THEN BEGIN
	  junk = string(replicate(32b,80))
	  strput, junk, 'PRC_USRM=', 0
	  strput, junk, usrmsg, 10
	  tmphdr = [tmphdr,junk]
	endif
	
	keyword = strmid(scphdr, 0, 8)
	xtension = where(keyword eq 'XTENSION')
	hdrlen = n_elements(scphdr)
	spdhdr = [ scphdr( 0: xtension(0) - 1), tmphdr, $
		   scphdr( xtension(0) : hdrlen - 1)]


	COMMENT = WHERE(KEYWORD EQ 'COMMENT ')
	posi = STRPOS(SPDHDR(COMMENT(0)),'Signal')
	IF posi NE -1 THEN BEGIN 
	  tmpline = SPDHDR(COMMENT(0))
	  STRPUT, tmpline, 'In-band power per Chopper Plateau Data', posi
	  SPDHDR(COMMENT(0)) = tmpline
	ENDIF

	FXADDPAR, spdhdr, 'PIA_VERS', !PIA_VERSION, $
	  ' PHT-Interactive Analysis version used', BEFORE='XTENSION'	     



        RETURN
        END
