;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

PRO det_calfile, orig_name, meas_time, tmp_name, error=error

;+
; NAME:
;	DET_CALFILE
;
; PURPOSE:
;	Determines which Calibration File has to be used according to the
;	measurement time
;
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;	det_calfile, orig_name, meas_time, tmp_name, error=error
;
; INPUT PARAMETERS:
;	orig_name: The original calibration filename without extension
;	meas_time: The measurement time for which calibration numbers are needed
;
;
; OUTPUT PARAMETERS:
;	tmp_name:  The actual calibration file to be used
;
; RESTRICTIONS:
;
; METHOD:
;
; PROCEDURES USED:
;       Astronomical Library:
;		date_conv
;		fxbopen
;               fxbread
;
; MODIFICATION HISTORY:
;	Written by: C. Gabriel - ESA-SAI	September 96
;-

	error = 0
	
	junk = findfile(!CALG + 'PTIMEDEP.FITS', count=count)

	IF count EQ 0 THEN BEGIN
	   error=1
	   PRINT, 'Warning: No Time Dependance CAL file found'
	   RETURN
	ENDIF
	
	FXBOPEN, unit, !CALG + 'PTIMEDEP.FITS', 1, hdr
	
	fxbread, unit, orig, 'CALGROOT'
	
	ind = WHERE(STRTRIM(orig,2) EQ STRTRIM(orig_name,2), n )

	IF n GT 0 THEN BEGIN
		date = date_conv(meas_time, 'VECTOR')
		date = (date(0)-1900)*1e9 + date(1)*1e6 + date(2)*1e4 + $
			date(3)*1e2 + date(4)
		FXBREAD, unit, calgtime, 'CALGTIME'
		FXBREAD, unit, calgfile, 'CALGFILE'
		indt = WHERE(FLOAT(calgtime(ind)) LT date, nt)
		IF nt GT 0 THEN BEGIN
		   tmp_name = STRTRIM(calgfile(ind(indt(nt-1))),2) + '.FITS'
		ENDIF ELSE BEGIN
		   ERROR=1
		   PRINT, 'Wrong times computation with calfiles, returning' 
		ENDELSE 
	ENDIF ELSE tmp_name = orig_name + '.FITS'
	
	fxbclose, unit
	free_lun, unit
	
	RETURN
	END
