;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO DIE_TRANS_INIT
;+
; NAME:
;	DIE_TRANS_INIT
;
; PURPOSE:
;	To put the relevant parameters for CRE conversion into the
;	common block phtdietrans
;
; CATEGORY:
;	PIA - initialisation
;
; CALLING SEQUENCE:
;	DIE_TRANS_INIT
;
; INPUTS:
;	None
;
; OUTPUTS:
;	None
;
; COMMON BLOCKS:
;	phtdietrans
;
; PROCEDURE:
;	The calibration G files PDIE1TRANS and PDIE2TRANS are used 
;	together with the compact status to put 4 of the 5 parameters
;	needed for the CRE conversion into the common PHTDIETRANS. 
;	This way simplifies applying different numbers for converting,
;	then just the common has to be changed.
;
; PROCEDURES USED:
;	ASTRO LIB: fxbopen
;	           fxbread
;	           fxbclose
;	           boost_array
;
; MODIFICATION HISTORY:
;	Written by Carlos Gabriel
;	Oct 95 Version 3.5
;
;-
@phtdietrans
;
 On_ERROR,2                                          ;Return to caller

; 
; Read Die1 unit 
;
 FXBOPEN, UNIT, !CALG+'PDIE1TRANS.FITS',1
 FXBREAD, UNIT, D1FIX, 'PDIE1FIX'
 FXBREAD, UNIT, D1UOF, 'PDIE1UOF'
 FXBREAD, UNIT, D1GN1, 'PDIE1GN1'
 FXBREAD, UNIT, D1GN2, 'PDIE1GN2'
 FXBCLOSE, UNIT
;
; Read Die2 unit - Provisory change for using new FM Cal G files 
;
 FXBOPEN, UNIT, !CALG+'PDIE2TRANS.FITS',1
 FXBREAD, UNIT, D2FIX, 'PDIE2FIX'
 FXBREAD, UNIT, D2UOF, 'PDIE2UOF'
 FXBREAD, UNIT, D2GN1, 'PDIE2GN1'
 FXBREAD, UNIT, D2GN2, 'PDIE2GN2'
 FXBCLOSE, UNIT
;
; Put the values into the common
;
 PDIEFIX = D1FIX
 PDIEUOF = D1UOF
 PDIEGN1 = D1GN1
 PDIEGN2 = D1GN2
 BOOST_ARRAY, PDIEFIX, D2FIX
 BOOST_ARRAY, PDIEUOF, D2UOF
 BOOST_ARRAY, PDIEGN1, D2GN1
 BOOST_ARRAY, PDIEGN2, D2GN2
;
 RETURN
 END
