;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO DO_DEGLITCH, tmpdata, sig_disc, tmphdr, degl_acc, $ 
	 ENCODE_FLAG = encode_flag, GROUP=group
;+
; NAME:
;	DO_DEGLITCH
;
; PURPOSE:
;	Apply deglitching procedure to a phtsrd structure 
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	DO_DEGLITCH, Tmpdata, Tmphdr, sig_disc, Degl_acc [,/ENCODE_FLAG] $ 
;              [,GROUP=group]
;
; INPUTS:
;	Tmpdata:  A PHTsrd temporary structure
;	Sig_disc: Array with discarding flags
;	Tmphdr:	  The temporary header
;	
; OUTPUTS:
;	Tmphdr:	  The updated temporary header 
;	Degl_acc: A 2-dim index array of deglitched signals
;	
; COMMON BLOCKS:
;	deglitch_param
;
; RESTRICTIONS:
;	tmpdata must be a temporary PHT SRD structure
;	
; PROCEDURES CALLED:
;	PIA LIB: deglitch_param_init
;	         deglitch_all
;	Astrolib: FXADDPAR
;	
; MODIFICATION HISTORY:
;	Written by:	Carlos Gabriel
;	Oct 95 Version 3.5
;	Not initializing the deglitch_param common if already existent (CG)
;								December 1995
;	Call to deglitch_all including RPID
;	Sig_disc array included as input to avoid discarded
;	signals	(JA)						March 1997
;	Use of FXADDPAR (CG)					July 1997
;	V6.4
;	tmpdata.flag is not modified, degl. flag is 
;       in degl_acc (JA)  					February 1998
;	V7.1
;-
@deglitch_param
        ON_ERROR, 2

;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 3 THEN MESSAGE, $
          'Syntax:  DO_DEGLITCH, TMPDATA, SIG_DISC, TMPHDR, DEGL_ACC ' + $
               '[,/ENCODE_FLAG] [,GROUP=group]'

	degl_acc = tmpdata.flag * 0

;  At the moment we just use always default values - In the future this
;  should become an interactive choose

	IF N_ELEMENTS(min_deglitch) EQ 0 THEN deglitch_param_init
	
	noslice_raster = 1 -per_raster

	npix = pixel_det(tmpdata.det)
	
	FOR I = 0, npix - 1 DO BEGIN 
		  deglitch_all, tmpdata.slop(i,*), $
			tmpdata.step, tmpdata.rpid, tmpdata.slun(i,*), $
			sig_disc(i,*), degacc, slice_chopp=PER_CHOP, $
			noslice_raster = noslice_raster
		  degl_acc(i,*) = degacc
	ENDFOR
	   
; if selected -> encode flag 
       IF KEYWORD_SET(ENCODE_FLAG) THEN BEGIN 
          encode_piaflag, 'SRD', 'GLITCH', tmpdata.flag, newflag, degl_acc, $
              DET = tmpdata.det, /ALLPIX
          tmpdata.flag = newflag    
       ENDIF    
           

; include information in header
	FXADDPAR, tmphdr, 'PRS_DEGL', 1, ' Deglitching correction applied',$
		BEFORE='XTENSION'

 	RETURN
	END
