;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	CHECK_LIMITS_DFPAR
;
; PURPOSE:
;	Check the limits of fitting parameters for drift model functions
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	CHECK_LIMITS_DFPAR, par0, drift_par, flag
;
; INPUT:
;	par0:		Array containing the initial values of parameters
;	drift_par:	Structure containing the fitted parameters and their 
;			limits
;
; KEYWORD PARAMETERS:
;	MULTI_PIX:	For non-interactive use. Performing loop over different
;			pixels.
;	
; OUTPUT:
;	flag:		Array wit flags for each parameter:
;				 (0=within limits,1=outside)
;			
;	
; COMMON BLOCKS:
;	pia_drift_par 
;		
; RESTRICTIONS:
;	The structure fit_par_str has to be defined prior to access this routine
;
; PROCEDURES USED:
;	PIA LIB:
;
; MODIFICATION HISTORY:
;	Written by: J. Acosta (IAC)		   November 1996 
;	Version 5.x - Aug.96
;			
;-
PRO CHECK_LIMITS_DFPAR, par0, drift_par, flag

;look for parameters which are free
ind_var = where(drift_par.a_var, nvar) 

if nvar eq 0 then begin
   flag = 0 
   RETURN
endif

flag = 0*drift_par.a_var

for ivar = 0, nvar-1 do begin
  iivar = ind_var(ivar)
  constr =  drift_par.p_range(2,iivar)
  fval0 = par0(iivar) 
  fval = drift_par.p_field(iivar) 

  case fix(constr) of   
      0: 
      1: BEGIN
           if fval lt drift_par.p_range(0,iivar) or  $
              fval gt drift_par.p_range(1,iivar) then flag(ivar) = 1
         END
      2: BEGIN
      	   if fval lt (drift_par.p_range(0,iivar)*fval0) or $
      	      fval gt (drift_par.p_range(1,iivar)*fval0) then $
      	      flag(ivar) = 1         
         END
      else: flag(ivar) = 1
  endcase
         	 
endfor       
         	 

RETURN 

END   

