;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
PRO dffunct_info
;+
; NAME:
;       dffunct_info
; PURPOSE:
;       Initializes the common blcck DFFUNCT_INFO which contains the information
;	for the differente fitting functions. In principle this should be the
;	only place where specific information for each function is contained.
;	The rest of routines used in the drifting modelling will work
;	independently of any function. 
;
; CATEGORY:
;	PIA - initialization
;
; CALLING SEQUENCE:
;       DFFUNCT_INFO
;
; INPUT PARAMETERS:
;	None       
;
; OUTPUT PARAMETERS: 
;	None
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               dffunct_info
;
; MODIFICATION HISTORY:
;       Written by: J.Acosta
;	Oct 96 Version 5.x
;	Include Fouks for Triangular and sawtooth chopp. (Jacosta)  May 97
;-


COMMON DFFUNCT_INFO, funct_info   

; create a string array containing the name of function [funct_lst(0,#)] 
; and its  corresponding routine [funct_lst(1,#)] 

NFUNCT = 11

weightm = ['NONE','SIGMA','TIME','SIGNAL']

maxnpar = 10

minp_ext = 5

chisqtol = 2.5

use_mintime = 1

funct_npar = intarr(NFUNCT)

funct_lst = strarr(4,NFUNCT)


funct_lst(0,*) = ['     Fouks     ',' Fouks chopped ', ' Thermal Fouks ', $
		  'Ther_Fouks chop','  Offset exp   ', ' Offset invexp ', $
		  ' Num. differ.  ',' 3 Offset exp  ', 'Fouks rectchopp', $
		  'Fouks triachopp','Fouks sawtchopp']
funct_lst(1,*) = ['FOUKSC_DRIFT','FOUKSC_CHOP_DRIFT','FOUKST_DRIFT',       $
	'FOUKST_CHOP_DRIFT', 'OFFEXP_DRIFT','INVEXP_DRIFT','NUMDIF_DRIFT', $
	'OFFEXP3_DRIFT','FOUKSC_RTCHO_DRIFT','FOUKSC_TTCHO_DRIFT',	   $
	'FOUKSC_STCHO_DRIFT']

funct_lst(2,*) = $
['S(t)=b*S_i+{[(1.-b)(S_0-b*S_i)S_i]/[S_0-b*S_i+(S_i-S_0)exp(-(t-t0)/teta)]}', 	$
 'Same as plain Fouks - used pairwise for chopper plateaux',			$
 'Similar to Fouks, but including temperature dependence',			$
 'Similar to Fouks, with temperature dependence & pairwise for chopper plateau',$
 'S(t) = S_infty + (S_0-S_infty)*exp[-(t-t0)/Tau]); Tau=E/S_infty^p',		$
 'S(t) = A0 * (1. + beta / {1.+ alpha*exp[-(t-t0)/Tau]}', 			$
 'Numerical solution of equation: dS/dt = S_inf * C - S(t) * a', 		$
 'S(t) = S_inf*(1+a1*exp(-t/Tau1)+a2*exp(-t/Tau2))' 				$
     + '+(S_0-S_inf*(1+a1+a2)*exp(-t/Tau3))', 					$
 'Fouks function for rectangular chopping', 					$
 'Fouks function for triangular chopping ', 					$
 'Fouks function for sawtooth  chopping ' ]
 
funct_lst(3,*) = ['fouks_start_par','fouks_chop_start_par','foukst_start_par',$ 
 'foukst_chop_start_par','offexp_start_par','invexp_start_par',               $
 'numdif_start_par', 'offexp3_start_par','fouksc_rtcho_start_par',            $
 'fouksc_ttcho_start_par','fouksc_stcho_start_par']
 
funct_parlabel = {func0:['S_infty', 'S_0', 'beta', 'E_j'],    	$   
		func1:['S_inf_low', 'S_0_low', 'beta', 'E_j', 	$
                                'S_inf_high', 'S_0_high'],    	$
		func2:['S_infty', 'S_0', 'beta', 'E_j','T_j'],  $
		func3:['S_inf_low', 'S_0_low', 'beta', 'E_j',   $
			  'T_j','S_inf_high', 'S_0_high'],	$
                func4:['S_infty', 'S_0', 'E','p'],	      	$             
		func5:['A0', 'beta', 'alpha', 'Tau'],		$
		func6:['S_inf', 'S_0', 'C'],			$
		func7:['S_inf','S_0','lambda','beta', 		$
			'E1','E2','E3','p1','p2','p3'],		$
		func8:['S_infty1', 'S_infty2', 'beta', 'E_j1', 	$
                                'E_j2', 'S_ini0'],		$
		func9:['S_infty1', 'S_infty2', 'S_infty3',      $
		       'beta', 'E_j1', 'E_j2', 'E_j3', 		$
                       'S_ini0'],				$
		func10:['S_infty1', 'S_infty2', 'S_infty3',     $
		       'beta', 'E_j1', 'E_j2', 'E_j3', 		$
                       'S_ini0']    } 

for ifunct = 0, NFUNCT-1 do  $ 
       funct_npar(ifunct) = n_elements(funct_parlabel.(ifunct))

funct_avar = {avar0:[1,1,0,0],				$
              avar1:[1,1,0,0,1,1],			$
              avar2:[1,1,0,0,0],			$
              avar3:[1,1,0,0,0,1,1],			$
              avar4:[1,1,0,0],				$
              avar5:[1,1,1,1],				$
              avar6:[1,1,1],				$
              avar7:[1,1,0,1,0,0,0,0,0,0],		$
              avar8:[1,1,0,0,0,1],			$
              avar9:[1,1,1,0,0,0,0,1],			$
              avar10:[1,1,1,0,0,0,0,1]   }

funct_fractleft= [2.,2.,2.,2.,5.,5.,5.,2.,2.,2.,2.]

funct_mintime = [1.,1.,1.,1.,3.,3.,3.,1.,1.,1.,1.]

; prange = fltarr(3,npars): 
;	prange(0,ipar) = lower limit; 
; 	prange(1,ipar) = upper limit, 
; 	prange(2,ipar)=[0:no limits,1:absolute,2:relative] 
i = 0
; FOUKSC_DRIFT
prang0 = fltarr(3,funct_npar(i))
prang0(2,0) = 0 & prang0(0,0)= 0.3 & prang0(1,0) = 3.
prang0(2,1) = 2 & prang0(0,1) = 0.1 & prang0(1,1) = 10.
prang0(2,2) = 1 & prang0(0,2) = 0. & prang0(1,2) = 1.
prang0(2,3) = 1 & prang0(0,3) = 0. & prang0(1,3) = 1.e5

i= i+1 
; FOUKSC_CHOP_DRIFT
prang1 = fltarr(3,funct_npar(i))
prang1(2,0) = 0 & prang1(0,0) = 0.3 & prang1(1,0) = 3.
prang1(2,1) = 2 & prang1(0,1) = 0.1 & prang1(1,1) = 10.
prang1(2,2) = 1 & prang1(0,2) = 0. & prang1(1,2) = 1.
prang1(2,3) = 1 & prang1(0,3) = 0. & prang1(1,3) = 1.e5
prang1(2,4) = 0 & prang1(0,4) = 0.3 & prang1(1,4) = 3. 
prang1(2,5) = 2 & prang1(0,5) = 0.1 & prang1(1,5) = 10.

i= i+1 
; FOUKST_DRIFT 
prang2 = fltarr(3,funct_npar(i))
prang2(2,0) = 0 & prang2(0,0)= 0.3 & prang2(1,0) = 3.
prang2(2,1) = 2 & prang2(0,1) = 0.1 & prang2(1,1) = 10.
prang2(2,2) = 1 & prang2(0,2) = 0. & prang2(1,2) = 1.
prang2(2,3) = 1 & prang2(0,3) = 0. & prang2(1,3) = 1.e5
prang2(2,4) = 1 & prang2(0,4) = 0. & prang2(1,4) = 100.

i= i+1 
; FOUKST_CHOP_DRIFT
prang3 = fltarr(3,funct_npar(i))
prang3(2,0) = 0 & prang3(0,0) = 0.3 & prang3(1,0) = 3.
prang3(2,1) = 2 & prang3(0,1) = 0.1 & prang3(1,1) = 10.
prang3(2,2) = 1 & prang3(0,2) = 0. & prang3(1,2) = 1.
prang3(2,3) = 1 & prang3(0,3) = 0. & prang3(1,3) = 1.e5
prang3(2,4) = 1 & prang3(0,4) = 0. & prang3(1,4) = 100.
prang3(2,5) = 0 & prang3(0,5) = 0.3 & prang3(1,5) = 3. 
prang3(2,6) = 2 & prang3(0,6) = 0.1 & prang3(1,6) = 10.

i= i+1 
; OFFEXP_DRIFT
prang4 = fltarr(3,funct_npar(i))
prang4(2,0) = 0 & prang4(0,0) = 0.3 & prang4(1,0) = 3.
prang4(2,1) = 2 & prang4(0,1) = 0.1 & prang4(1,1) = 10.
prang4(2,2) = 1 & prang4(0,2) = 0. & prang4(1,2) = 1.e5
prang4(2,3) = 1 & prang4(0,2) = 0. & prang4(1,2) = 1.e5

i= i+1 
; INVEXP_DRIFT
prang5 = fltarr(3,funct_npar(i))

i= i+1 
; NUMDIF_DRIFT
prang6 = fltarr(3,funct_npar(i))

i= i+1 
; OFFEXP3_DRIFT
prang7 = fltarr(3,funct_npar(i))
j = 0   ; S_inf
prang7(2,j) = 0 & prang7(0,j)= 0.3 & prang7(1,j) = 3.
j = j+ 1   ; S_0
prang7(2,j) = 2 & prang7(0,j) = 0.1 & prang7(1,j) = 10.
j = j+ 1   ; lambda
prang7(2,j) = 1 & prang7(0,j) = -1.e3 & prang7(1,j) = 1.e3
j = j+ 1   ; beta
prang7(2,j) = 1 & prang7(0,j) = -1.e3 & prang7(1,j) = 1.e3
j = j+ 1   ; E1
prang7(2,j) = 2 & prang7(0,j) = 0. & prang7(1,j) = 10.
j = j+ 1   ; E2
prang7(2,j) = 2 & prang7(0,j) = 0. & prang7(1,j) = 100.
j = j+ 1   ; E3
prang7(2,j) = 2 & prang7(0,j) = 0. & prang7(1,j) = 100.
j = j+ 1   ; p1
prang7(2,j) = 2 & prang7(0,j) = -1.5 & prang7(1,j) = 1.5
j = j+ 1   ; p2
prang7(2,j) = 2 & prang7(0,j) = -1.5 & prang7(1,j) = 1.5
j = j+ 1   ; p3
prang7(2,j) = 2 & prang7(0,j) = -1.5 & prang7(1,j) = 1.5

i= i+1 
; FOUKSC_RTCHO_DRIFT
prang8 = fltarr(3,funct_npar(i))
prang8(2,0) = 0 & prang8(0,0) = 0.3 & prang8(1,0) = 3.
prang8(2,1) = 0 & prang8(0,1) = 0.3 & prang8(1,1) = 3.
prang8(2,2) = 1 & prang8(0,2) = 0. & prang8(1,2) = 1.
prang8(2,3) = 1 & prang8(0,3) = 0. & prang8(1,3) = 1.e5
prang8(2,4) = 1 & prang8(0,4) = 0  & prang8(1,4) = 1.e5
prang8(2,5) = 2 & prang8(0,5) = 0.1 & prang8(1,5) = 10.

i= i+1 
; FOUKSC_TTCHO_DRIFT
prang9 = fltarr(3,funct_npar(i))
prang9(2,0) = 0 & prang9(0,0) = 0.3 & prang9(1,0) = 3.
prang9(2,1) = 0 & prang9(0,1) = 0.3 & prang9(1,1) = 3.
prang9(2,2) = 0 & prang9(0,2) = 0.3 & prang9(1,2) = 3.
prang9(2,3) = 1 & prang9(0,2) = 0. & prang9(1,3) = 1.
prang9(2,4) = 1 & prang9(0,4) = 0. & prang9(1,4) = 1.e5
prang9(2,5) = 1 & prang9(0,5) = 0  & prang9(1,5) = 1.e5
prang9(2,6) = 1 & prang9(0,6) = 0  & prang9(1,6) = 1.e5
prang9(2,7) = 2 & prang9(0,7) = 0.1 & prang9(1,7) = 10.

i= i+1 
; FOUKSC_STCHO_DRIFT
prang10 = fltarr(3,funct_npar(i))
prang10(2,0) = 0 & prang10(0,0) = 0.3 & prang10(1,0) = 3.
prang10(2,1) = 0 & prang10(0,1) = 0.3 & prang10(1,1) = 3.
prang10(2,2) = 0 & prang10(0,2) = 0.3 & prang10(1,2) = 3.
prang10(2,3) = 1 & prang10(0,2) = 0. & prang10(1,3) = 1.
prang10(2,4) = 1 & prang10(0,4) = 0. & prang10(1,4) = 1.e5
prang10(2,5) = 1 & prang10(0,5) = 0  & prang10(1,5) = 1.e5
prang10(2,6) = 1 & prang10(0,6) = 0  & prang10(1,6) = 1.e5
prang10(2,7) = 2 & prang10(0,7) = 0.1 & prang10(1,7) = 10.


  
funct_prange = {prang0:prang0, 		$
		prang1:prang1, 		$
		prang2:prang2, 		$
		prang3:prang3, 		$
		prang4:prang4, 		$
		prang5:prang5, 		$
		prang6:prang6, 		$
		prang7:prang7, 		$
		prang8:prang8, 		$
		prang9:prang9, 		$
		prang10:prang10}

index = indgen(NFUNCT)
export = '(e)'
posi = STRPOS(!PIA_VERSION,export)
IF posi GT 0 THEN BEGIN
  index = [0,8,9,10,4,5,7]
  tmpparlabel = {func0:funct_parlabel.(index(0)),    	$   
		 func1:funct_parlabel.(index(1)),    	$
		 func2:funct_parlabel.(index(2)),    	$
		 func3:funct_parlabel.(index(3)),    	$
		 func4:funct_parlabel.(index(4)),    	$
		 func5:funct_parlabel.(index(5)),    	$
		 func6:funct_parlabel.(index(6))  } 
		 
  tmpavar = {func0:funct_avar.(index(0)),    	$   
		 func1:funct_avar.(index(1)),    	$
		 func2:funct_avar.(index(2)),    	$
		 func3:funct_avar.(index(3)),    	$
		 func4:funct_avar.(index(4)),    	$
		 func5:funct_avar.(index(5)),    	$
		 func6:funct_avar.(index(6))      } 
		 
  tmpprange = {func0:funct_prange.(index(0)),    	$   
		 func1:funct_prange.(index(1)),    	$
		 func2:funct_prange.(index(2)),    	$
		 func3:funct_prange.(index(3)),    	$
		 func4:funct_prange.(index(4)),    	$
		 func5:funct_prange.(index(5)),    	$
		 func6:funct_prange.(index(6))    } 
		 
  funct_parlabel = tmpparlabel
  funct_avar = tmpavar
  funct_prange = tmpprange
ENDIF

det_def = ['SL','P1','P2','P3','C1','C2']
det_deffunct = ['FOUKSC_DRIFT', 'FOUKSC_DRIFT', 'FOUKSC_DRIFT',$
		'OFFEXP_DRIFT','OFFEXP_DRIFT','OFFEXP_DRIFT']
	
funct_info = {	npar:funct_npar(index), 		$
		lst:funct_lst(*,index), 		$
		parlabel:funct_parlabel, 		$
                avar:funct_avar, 			$
                fractleft:funct_fractleft(index), 	$
                mintime:funct_mintime(index), 		$
                prange:funct_prange,			$
                minpext:minp_ext,			$
                maxnpar:maxnpar,			$
                weightm:weightm,			$
	        chisqtol:chisqtol,			$
	        use_mintime:use_mintime,		$
                det_def:det_def,			$
                det_deffunct:det_deffunct}

             
return
end
