;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
PRO dffunct_info
;+
; NAME:
;       dffunct_info
; PURPOSE:
;       Initializes the common blcck DFFUNCT_INFO which contains the information
;	for the differente fitting functions. In principle this should be the
;	only place where specific information for each function is contained.
;	The rest of routines used in the drifting modelling will work
;	independently of any function. 
;
; CATEGORY:
;	PIA - initialization
;
; CALLING SEQUENCE:
;       DFFUNCT_INFO
;
; INPUT PARAMETERS:
;	None       
;
; OUTPUT PARAMETERS: 
;	None
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               dffunct_info
;
; MODIFICATION HISTORY:
;       Written by: J.Acosta
;	Oct 96 Version 5.x
;-


COMMON DFFUNCT_INFO, funct_info   

; create a string array containing the name of function [funct_lst(0,#)] 
; and its  corresponding routine [funct_lst(1,#)] 

NFUNCT = 3

funct_npar = intarr(NFUNCT)

funct_lst = strarr(4,NFUNCT)


funct_lst(0,*) = ['  Offset exp   ', ' Offset invexp ', $
		  ' Num. differ.  ']
funct_lst(1,*) = ['OFFEXP_DRIFT','INVEXP_DRIFT','NUMDIF_DRIFT']

funct_lst(2,*) = $
[ 'S(t) = S_infty * (1.+ alpha*exp[-(t-t0)/Tau]',$
 'S(t) = A0 * (1. + beta / {1.+ alpha*exp[-(t-t0)/Tau]}', $
 'Numerical solution of equation: dS/dt = S_inf * C - S(t) * S_inf']
 
funct_lst(3,*) = ['offexp_start_par','invexp_start_par','numdif_start_par']
funct_parlabel = {func4:  ['S_infty', 'alpha', 'Tau'],	      	$             
		func5:  ['A0', 'beta', 'alpha', 'Tau'],		$
		func6:	['S_inf', 'S_0', 'C']	} 

for ifunct = 0, NFUNCT-1 do  $ 
       funct_npar(ifunct) = n_elements(funct_parlabel.(ifunct))

funct_avar = {avar4:[1,1,1],				$
              avar5:[1,1,1,1],				$
              avar6:[1,1,1]   }

funct_fractleft= [5.,5.,5.]

; prange = fltarr(3,npars): 
;	prange(0,ipar) = lower limit; 
; 	prange(1,ipar) = upper limit, 
; 	prange(2,ipar)=[0:no limits,1:absolute,2:relative] 
prang0 = fltarr(3,4)
prang0(2,0) = 2 & prang0(0,0)= 0.3 & prang0(1,0) = 3.
prang0(2,1) = 2 & prang0(0,1) = 0.3 & prang0(1,1) = 3.
prang0(2,2) = 1 & prang0(0,2) = 0. & prang0(1,2) = 1.
prang0(2,3) = 1 & prang0(0,3) = 0. & prang0(1,3) = 1.e5

prang1 = fltarr(3,6)
prang1(2,0) = 2 & prang1(0,0) = 0.3 & prang1(1,0) = 3.
prang1(2,1) = 2 & prang1(0,1) = 0.3 & prang1(1,1) = 3.
prang1(2,2) = 1 & prang1(0,2) = 0. & prang1(1,2) = 1.
prang1(2,3) = 1 & prang1(0,3) = 0. & prang1(1,3) = 1.e5
prang1(2,4) = 2 & prang1(0,4) = 0.3 & prang1(1,4) = 3. 
prang1(2,5) = 2 & prang1(0,5) = 0.3 & prang1(1,5) = 3.

prang2 = fltarr(3,5)

prang3 = fltarr(3,7)

prang4 = fltarr(3,3)

prang5 = fltarr(3,4)

prang6 = fltarr(3,3)

  
funct_prange = {prang4:prang4, 		$
		prang5:prang5, 		$
		prang6:prang6 	}

funct_info = {npar:funct_npar, lst:funct_lst, parlabel:funct_parlabel, $
               avar:funct_avar, fractleft:funct_fractleft, prange:funct_prange}

             
return
end
