;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	DRIFT_STD_SCP
;
; PURPOSE:
;	Derive a SCP level structure using the drift analysis cumulated 
;	information and the standard acceptance criteria
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	drift_std_scp, driftps, scppos, ACC_ALL=acc_all
;
; INPUT:
;	driftps:	Position of the drift info within the phtdrift array
;	scppos:		Position of the scp meas. within the phtscp array
;
; KEYWORD PARAMETERS:
;	ACC_ALL:	Ignore drift analysis acceptance criteria
;	
; OUTPUT:
;	(none)			
;	
; COMMON BLOCKS:
;	phtdrift
;	phtscp
;		
; RESTRICTIONS:
;
; PROCEDURES USED:
;	PIA LIB:
;		decode_flag
;
; MODIFICATION HISTORY:
;	Written by: C. Gabriel (ESA/VILSPA-SAI) 		February 1997
;	V6.1
;	Bug for all accepted by array detectors fixed (CG)	April 1997
;	V6.2		
;-
PRO drift_std_scp, driftps, scppos, ACC_ALL=acc_all

@phtdrift
@phtscp

	pia_load_idrift, phtdrift(driftps), tmpdrift
	pia_load_iscp, phtscp(scppos), tmpscp
	
	fit_par_str = tmpdrift.drift
	npix_eff = N_ELEMENTS(fit_par_str.signal(*,0))	

	IF KEYWORD_SET(acc_all) THEN BEGIN
            	tmpscp.aver(0:npix_eff-1,*) = fit_par_str.signal
            	tmpscp.avun(0:npix_eff-1,*) = fit_par_str.err
	    	tmpscp.flag(0:npix_eff-1,*) = fit_par_str.flag * 0
	ENDIF ELSE BEGIN
	
	
	
	  nflag = 5
	  FOR ipix=0,npix_eff-1 DO BEGIN
	    FOR istep=0,N_ELEMENTS(fit_par_str.signal(0,*))-1 DO BEGIN
	  
	  	decode_flag, fit_par_str.flag(ipix,istep), nflag, code
	  	
  		IF not code(1) AND not code(2) AND not code(3) THEN BEGIN  		    
            		tmpscp.aver(ipix,istep) = fit_par_str.signal(ipix,istep)
            		tmpscp.avun(ipix,istep) = fit_par_str.err(ipix,istep)
	    		tmpscp.flag(ipix,istep) = tmpscp.flag(ipix,istep)
  		ENDIF
	    ENDFOR
	  ENDFOR
	ENDELSE
	
	FILL_SCP, tmpscp, replace=scppos
	
	RETURN
	END
