;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO FILL_DRIFT, tmp, REPLACE=replace 
;+
; NAME:
;       FILL_DRIFT
;
; PURPOSE:
;	FILLS a temporary structure into the dynamical structure PHTDRIFT  
;
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;       FILL_DRIFT, tmp, REPLACE=replace
;
; INPUT:
;       tmp 	: PHTDRIFT like temporary structure
;
; OPTIONAL INPUT:
;	REPLACE : IF set (different to 0) put structure into this PHTDRIFT position
;
; RESTRICTIONS:
;       tmp must be a valid phtdrift like temporary structure
;
; PROCEDURES USED: 
;       Common Block(s) or @ procedure(s):
;               phtdrift
;
; MODIFICATION HISTORY:
;       Written by: J.Acosta  (MPIA/ESA/IAC)		October 1996
;	Updated by CG, including SLOP variation tag	February 1997
;	V6.1
;
;-
;
@phtdrift
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  FILL_DRIFT, tmp, [REPLACE=replace]'


;  Create the structures and the handles
        PHTDRIFT_T = {PHTDRIFT_TYPE}
        PHTDRIFT_T.STAB = HANDLE_CREATE()
        PHTDRIFT_T.DRIFT = HANDLE_CREATE()
        PHTDRIFT_T.SLOPV = HANDLE_CREATE()
        
;  Fill the temporary ERD structure
        PHTDRIFT_T.ADMN = tmp.ADMN
        PHTDRIFT_T.PROCT = tmp.proct

;  Fill the handles
        HANDLE_VALUE, PHTDRIFT_T.STAB, tmp.STAB, /SET  
        HANDLE_VALUE, PHTDRIFT_T.DRIFT, tmp.DRIFT, /SET  
        HANDLE_VALUE, PHTDRIFT_T.SLOPV, tmp.DRIFT, /SET  


;  Update the PHTDRIFT structure using the temporary structure
	IF KEYWORD_SET(REPLACE) THEN BEGIN
		IF N_ELEMENTS(phtdrift) LE replace THEN $
		  MESSAGE, /INFO, 'Non-existing position, returning' ELSE $
		  PHTDRIFT(REPLACE) = PHTDRIFT_T 
	ENDIF ELSE $
          PHTDRIFT = [PHTDRIFT,PHTDRIFT_T]

        RETURN
        END
