;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	FOUKSC_start_par
;
; PURPOSE:
;	Calculate start parameters for the fouks model 
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	FOUKSC_start_par, det, time, slop, flag, pixel, start_par, $
;		error=error
;
; INPUT:
;	det:	PHT detector ('P1', 'C2', ...)
;	slop:	Signal slopes array
;	pixel:	Pixel to be used
;
; KEYWORD PARAMETERS:
;	ERROR:	Results of computation
;	
; OUTPUT:
;	start_par: The start parameters
;	
; COMMON BLOCKS:
;	fouks_start_par 
;		
; PROCEDURES USED:
;       PIA LIB:
;               s_ini_final
;	Astrolib:
;		readcol
;
; MODIFICATION HISTORY:
;	Written by: C.Gabriel (ESA/VILSPA-SAI)	  August 1996
;	Added flag as input parameter (J.Acosta)  October 1996
;	Added time as input parameter (J.Acosta)  October 1996
;	Added t_zero as input keyword (J.Acosta)  November 1996
;	Set a dummy value for S_C(pixel) when 
;	argument of sqrt is negative  (J.Acosta)  January 1997	 
;	Version 5.0 - Aug.96
;			
;-
PRO fouks_start_par, det, time, slop, flag, pixel, start_par, ERROR=error, $
          T_ZERO = t_zero

COMMON fouks_start_par, s_beta, s_C, s_Nd, det_par

	error = 1	      
	start_par = fltarr(4)
	IF N_ELEMENTS(det_par) EQ 0 THEN det_par = det
; read data from driftpar file in case is not in
	IF N_ELEMENTS(s_beta) EQ 0 OR (det_par NE det) THEN BEGIN
	   CASE det OF 
	    'P2': filepar= !CALG+'fouks_P2_par.txt'
	    'SL': filepar = !CALG+'fouks_SL_par.txt'
	    ELSE: filepar= !CALG+'fouks_P2_par.txt'
	   ENDCASE        
	   det_par = det  
	   readcol, filepar,pix, s_beta, s_C, s_ND, f='i,f,d,d'       
	ENDIF

	
	; Set parameters according to selected detector
	CASE det of
	   'SL': BEGIN
	     tmp_ND = s_ND(pixel)
	     tmp_C = s_C(pixel)
	     tmp_beta = s_beta(pixel)
	     IF pixel LT 64 THEN  tmp_Z = 8.052  ELSE tmp_Z = 9.644
	    END
	    ELSE: BEGIN
	     tmp_ND = s_ND(0)
	     tmp_C = s_C(0)
	     tmp_beta = s_beta(0)
	     tmp_Z = 10.
	    END
	ENDCASE
	      A = 1.949e-11
	

	;;if not keyword_set(T_ZERO) then t_zero = time(0)

	s_ini_final, time, slop, flag, S_ini, S_final, error = err_ini  ;;, $ 
	    ;;T_zero = t_zero
	
	;avoid negative values for S_infty
	start_par(0) = max([1.e-4,S_final])
	
	error = 0	      
	start_par(1) = max([S_ini,start_par(0)*tmp_beta]) * 1.2
	
	start_par(2) = tmp_beta
	logarg = alog(tmp_Nd/start_par(0)/tmp_C)
	IF logarg GT 0. THEN  ej = sqrt(A*tmp_Nd/logarg(0))  $
	  ELSE BEGIN      ; set tmp_C = 1.013e13
	             logarg = alog(tmp_Nd/start_par(0)/1.013e13)
	             ej = sqrt(A*tmp_Nd/logarg)
	             print,'Using a dummy value for Ej '
	  ENDELSE
	start_par(3) = ej / tmp_Z
	 
	error = err_ini
	 
	RETURN
	
	END
