;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	FOUKST_start_par
;
; PURPOSE:
;	Calculate start parameters for the fouks thermal model 
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	FOUKSC_start_par, det, time, slop, flag, pixel, start_par, $
;		error=error
;
; INPUT:
;	det:	PHT detector ('P1', 'C2', ...)
;	time:   Time array
;	slop:	Signal slopes array
;	pixel:	Pixel to be used
;
; KEYWORD PARAMETERS:
;	ERROR:	Results of computation
;	
; OUTPUT:
;	start_par: The start parameters
;	
; COMMON BLOCKS:
;	fouks_start_par 
;		
; PROCEDURES USED:
;	Astrolib:
;		readcol
;
; MODIFICATION HISTORY:
;	Written by: J.Acosta (ESA/VILSPA-SAI)	  October 1996
;	Added flag as input parameter (J.Acosta)  October 1996
;	Added t_zero as input keyword (J.Acosta)  November 1996
;	Set a dummy value for S_C(pixel) when 
;	argument of sqrt is negative  (J.Acosta)  January 1997	 
;	Version 5.1 - Oct.96
;			
;-
PRO foukst_start_par, det, time, slop, flag, pixel, start_par, error=error, $
          T_ZERO = t_zero

COMMON fouks_start_par, s_beta, s_C, s_Nd, det_par

	error = 1	      
	start_par = fltarr(5)
; read data from driftpar file in case is not in
	IF N_ELEMENTS(s_beta) EQ 0 THEN $
	   readcol, !CALU+'fouks_dpar.txt', pix, s_beta, s_C, s_ND, f='i,f,d,d'

	s_ini_final, time, slop, flag, S_ini, S_final, error = err_ini
	
	CASE det of
	
	   'SL': BEGIN
	      
	      error = 0	      
	      nlast = N_ELEMENTS(slop) - 1
	      ;avoid negative values for S_infty
	      start_par(0) = max([1.e-4,S_final])
	      start_par(1) = max([S_ini,S_final*s_beta(pixel)*1.2])
	      start_par(2) = s_beta(pixel)
	      a = 1.949e-11
	      logarg = alog(s_Nd(pixel)/start_par(0)/s_C(pixel))
	      IF logarg GT 0. THEN ej = sqrt(A*s_Nd(pixel)/logarg)    $
	         ELSE BEGIN ; set s_C(pixel) = 1.013e13
	           ej =     $  
	             sqrt(A*s_Nd(pixel)/alog(s_Nd(pixel)/start_par(0)/1.013e13))
	           print,'Using a dummy value for Ej '
	         ENDELSE  
	         
	      IF pixel LT 64 THEN start_par(3) = ej / 8.052 $ 
	            ELSE start_par(3) = ej / 9.644
	      start_par(4) = 0.25
	    END
; other detectors just taking some numbers	 
	    ELSE: BEGIN
	      error = 0	      
	      nlast = N_ELEMENTS(slop) - 1
	      start_par(0) = S_final
	      start_par(1) = S_ini
; take s_beta as for pixel 30 PHT-S
	      start_par(2) = s_beta(30)
	      start_par(3) = 3.	
	      start_par(4) = 0.25        
	    END
	 ENDCASE
	 
	 error = err_ini
	 
	 RETURN
	 END
