;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	FUNCTION_2B_FITTED
;
; PURPOSE:
;	Interface function for drift modelling functions written
;	as procedures
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	Result = FUNCTION_2B_FITTED(var)
;
; INPUT:
;	var:	The dependant parameters
;	
;
; KEYWORD PARAMETERS:
;	(none)	          
;	
; OUTPUT:
;	Result: Chi-square corresponding to the distribution passed
;		by common F_2B_FIT, function passed by common PIA_DRIFT_PAR
;		 and the variables var.
;	
; COMMON BLOCKS:
;	F_2B_FIT  Containing x, y(x), w(x)=weight, r(x)=raster/chopper step 
;		
; PROCEDURES USED:
;
; MODIFICATION HISTORY:
;	Written by: C.Gabriel (ESA/VILSPA-SAI)	  February 1997
;	Version 6.1
;			
;-
FUNCTION FUNCTION_2B_FITTED, var


COMMON F_2B_FIT, x, y, w
COMMON PIA_DRIFT_PAR, pia_drift_par 

	par= var *1.D0
	
	CALL_PROCEDURE, pia_drift_par.ffunct, x, par, fct

	chisq = 0.
  	for i=0,N_ELEMENTS(fct)-1 DO chisq = chisq + (y(i)-fct(i))^2 * w(i)

  
  	chisq = chisq / (N_ELEMENTS(y)-N_ELEMENTS(var)+1) 
; 	print, chisq
  	RETURN, chisq
  	END
