;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	INVEXP_start_par
;
; PURPOSE:
;	Calculate start parameters for the 'offset inverse exponential' drift 
;	function 
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	GAUSSINV_start_par, det, time, slop, flag, pixel, start_par, $
;		error=error
;
; INPUT:
;	det:	PHT detector ('P1', 'C2', ...)
;	time:   Time array
;	slop:	Signal slopes array
;	pixel:	Pixel to be used
;
; KEYWORD PARAMETERS:
;	ERROR:	Results of computation
;	
; OUTPUT:
;	start_par: The start parameters
;	
; COMMON BLOCKS:
;	(none) 
;		
; PROCEDURES USED:
;       PIA LIB:
;               s_ini_final
;
; MODIFICATION HISTORY:
;	Written by: J. Acosta (IAC)	  August 1996
;	Added flag as input parameter (J.Acosta)  October 1996
;       Added time as input parameter J.Acosta    October 1996
;	Added t_zero as input keyword (J.Acosta)  November 1996
;	Version 5.0 - Aug.96
;			
;-
PRO invexp_start_par, det, time, slop, flag, pixel, start_par, error=error, $
	T_Zero = t_zero


	error = 0	      
	start_par = fltarr(4)

        
        s_ini_final, time, slop, flag, S_0, S_infty, error= err_ini

        beta = 0.3   
	start_par(0) = S_infty / (1.+beta) 
	start_par(1) = beta
	start_par(2) = (S_0 - S_infty) / (S_0 - start_par(0)) 
	start_par(3) = 64.
	
	error = err_ini 
	 
	 
 RETURN

END
