;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	NUMDIF_start_par
;
; PURPOSE:
;	Calculate start parameters for the 'Numerical differ' drift function 
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	NUMDIF_start_par, det, time, slop, flag, pixel, start_par, $
;		error=error
;
; INPUT:
;	det:	PHT detector ('P1', 'C2', ...)
;	slop:	Signal slopes array
;	pixel:	Pixel to be used
;
; KEYWORD PARAMETERS:
;	ERROR:	Results of computation
;	
; OUTPUT:
;	start_par: The start parameters
;	
; COMMON BLOCKS:
;	(none) 
;				
; PROCEDURES USED:
;       PIA LIB:
;               s_ini_final
;
; MODIFICATION HISTORY:
;	Written by: C. Gabriel (ESA/VILSPA-SAI)	  August 1996
;	Added flag as input parameter (J.Acosta)  October 1996
;	Added t_zero as input keyword (J.Acosta)  November 1996
;       Added time as input parameter J.Acosta    October 1996
;	Version 5.0 - Aug.96
;			
;-
PRO numdif_start_par, det, time, slop, flag, pixel, start_par, ERROR=error, $
        T_ZERO = t_zero

	error = 0	      
	start_par = fltarr(3)

	s_ini_final, time, slop, flag, S_ini, S_final

	start_par(2) = 1.
	;start_par(1) = (slop(0) + slop(1)) / 2.
	;start_par(0) = avg(slop)
	start_par(1) = S_ini
	start_par(0) = S_final

	 
	 
 RETURN

END
