;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	OFFEX2_start_par
;
; PURPOSE:
;	Calculate start parameters for the 'two offset exponential' drift 
;	function 
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	OFFEXP_start_par, det, time, slop, flag, pixel, start_par, $
;		error=error
;
; INPUT:
;	det:	PHT detector ('P1', 'C2', ...)
;	time:	Time array
;	slop:	Signal slopes array
;	pixel:	Pixel to be used
;
; KEYWORD PARAMETERS:
;	ERROR:	Results of computation
;	
; OUTPUT:
;	start_par: The start parameters
;	
; COMMON BLOCKS:
;	(none) 
;		
; PROCEDURES USED:
;       PIA LIB:
;               s_ini_final
;
; MODIFICATION HISTORY:
;	Written by: J. Acosta (IAC)	  November 1996
;	added prescription to estimate lambda (J.Acosta)  November 1996
;	Version 5.3 - Nov.96
;			
;-
PRO offexp2_start_par, det, time, slop, flag, pixel, start_par, ERROR=error, $
          T_ZERO = t_zero



	error = 0	      
	start_par = fltarr(6)
	

        if not keyword_set(t_zero) then t_zero = time(0)
	
	nlast = N_ELEMENTS(slop) - 1
	s_ini_final, time, reform(slop), reform(flag), S_ini, S_final, $
	  DerS_ini, ERROR = err_ini, T_ZERO = t_zero
	
	Taui = 40.
	lambda = 2.8
	
	error = err_ini
	start_par(0) = S_final
        start_par(1) = S_ini 
	 
	lim_der = (S_final - S_ini)/lambda / Taui 
	start_par(2) = min([DerS_ini, lim_der]) 	 
	 
	start_par(3) = 10.
	
	start_par(4) = Taui
	
	start_par(5) = lambda
	
	 
 RETURN

END
