;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	OFFEXP3_start_par
;
; PURPOSE:
;	Calculate start parameters for the 'two offset exponential' drift 
;	function 
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	OFFEXP_start_par, det, time, slop, flag, pixel, start_par, $
;		error=error
;
; INPUT:
;	det:	PHT detector ('P1', 'C2', ...)
;	time:	Time array
;	slop:	Signal slopes array
;	pixel:	Pixel to be used
;
; KEYWORD PARAMETERS:
;	ERROR:	Results of computation
;	
; OUTPUT:
;	start_par: The start parameters
;	
; COMMON BLOCKS:
;	(none) 
;		
; PROCEDURES USED:
;       PIA LIB:
;               s_ini_final
;
; MODIFICATION HISTORY:
;	Written by: J. Acosta (IAC)	  November 1996
;	added prescription to estimate lambda (J.Acosta)  November 1996
;	Version 5.3 - Nov.96
;			
;-
PRO offexp3_start_par, det, time, slop, flag, pixel, start_par, ERROR=error, $
          T_ZERO = t_zero

ON_ERROR, 2

COMMON offexp3_start_par_c, exp3_det, exp3_E1, exp3_p1, exp3_E2, exp3_p2, $
        exp3_E3, exp3_p3, exp3_scal, exp3_Shigh, det_cur 

	error = 0	      
	start_par = fltarr(10)

        IF N_ELEMENTS(det_cur) EQ 0 THEN det_cur = det
        IF N_ELEMENTS(exp3_det) EQ 0 OR (det_cur NE det) THEN BEGIN
           det_cur = det  
           filepar = !CALG + 'offexp3_Adet_par.txt'
           readcol, filepar, exp3_det, exp3_E1, exp3_p1, exp3_E2, exp3_p2, $
               exp3_E3, exp3_p3, exp3_scal, exp3_Shigh,  $ 
               f='A,f,f,f,f,f,f,f,f',skipline= 4 
        ENDIF 

        ind_det = where(exp3_det eq det,ndet)
        IF ndet eq 0 THEN BEGIN 
              print,'WARNING: Not calibrated detector' 
              ind_det = 0
        ENDIF 
          
        E1 = exp3_E1(ind_det(0))
        E2 = exp3_E2(ind_det(0))
        E3 = exp3_E3(ind_det(0))
	p1 = exp3_p1(ind_det(0))
	p2 = exp3_p2(ind_det(0))
	p3 = exp3_p3(ind_det(0))
	scal = exp3_scal(ind_det(0))
	Shigh = exp3_Shigh(ind_det(0))

	get_darkcur, det, darkcur
		
        if not keyword_set(t_zero) then t_zero = time(0)
	
	nlast = N_ELEMENTS(slop) - 1
	   
	;get estimate of s_0, S_final
	s_ini_final, time, reform(slop), reform(flag), S_0, S_final, $
	   ERROR = err_ini, T_ZERO = t_zero   
        error = err_ini
        IF error GT 0 THEN BEGIN 
                print,'Initialization error of exponential function '
                RETURN
        ENDIF 
	
	
	start_par(0) = max([S_final,darkcur(pixel)])
        start_par(1) = S_0 
	 
	; Assing beta according to values of Time constants 
	ind_val = where(reform(flag) le 1, nval)
	Tau3 = E3/start_par(0)^p3
	;beta1 = float(exp(-scal*double(max(time(ind_val)-t_zero)/Tau3)))
	beta2 = 1.-exp(-S_final/Shigh)
	
	;if beta1 gt beta2 then print,'Using maximum time for beta prescription' $
	;   ELSE print,'Using high signal for beta prescription'
	print,'Using high signal for beta prescription'

	start_par(2) = 0. 	 
	 
	;start_par(3) = max([beta1,beta2])
	start_par(3) = beta2	
	
	start_par(4) = E1
	
	start_par(5) = E2
	
	start_par(6) = E3
	
	start_par(7) = p1
	 
	start_par(8) = p2
	
	start_par(9) = p3 
		 
 RETURN

END
