;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	OFFEXP_start_par
;
; PURPOSE:
;	Calculate start parameters for the 'offset exponential' drift function 
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	OFFEXP_start_par, det, time, slop, flag, pixel, start_par, $
;		error=error
;
; INPUT:
;	det:	PHT detector ('P1', 'C2', ...)
;	time:	Time array
;	slop:	Signal slopes array
;	pixel:	Pixel to be used
;
; KEYWORD PARAMETERS:
;	ERROR:	Results of computation
;	
; OUTPUT:
;	start_par: The start parameters
;	
; COMMON BLOCKS:
;	(none) 
;		
; PROCEDURES USED:
;       PIA LIB:
;               s_ini_final
;
; MODIFICATION HISTORY:
;	Written by: J. Acosta (IAC)	  August 1996
;	Added flag as input parameter (J.Acosta)  October 1996
;       Added time as input parameter J.Acosta    October 1996
;	Added t_zero as input keyword (J.Acosta)  November 1996
;	handling error when initialization was not
;	succesful		      (J.Acosta)  June 1997
;	Version 5.0 - Aug.96
;	Change parameters for C100   (JAcosta)    January 1998
;	Version 6.6   
;			
;-
PRO offexp_start_par, det, time, slop, flag, pixel, start_par, ERROR=error, $
          T_ZERO = t_zero

COMMON offexp_start_par_c, exp_det, exp_E1, exp_p1, det_cur 


	error = 0	      
	start_par = fltarr(4)
	
	SHIFT_ELE = 5
	MIN_NPTS = 3

        IF N_ELEMENTS(det_cur) EQ 0 THEN det_cur = det
        IF N_ELEMENTS(exp_det) EQ 0 OR (det_cur NE det) THEN BEGIN
           det_cur = det  
           filepar = !CALG + 'offexp_Adet_par.txt'
           readcol, filepar, exp_det, exp_E1, exp_p1, f='A,F,F',skipline= 4, $
              /SILENT 
        ENDIF 
	
	nlast = N_ELEMENTS(slop) - 1
	s_ini_final, time, reform(slop), reform(flag), S_ini, S_final, $ 
	     ERROR = err_ini
	
	error = err_ini
	IF error GT 0 THEN BEGIN 
		print,'Initialization error of exponential function '
		RETURN
	ENDIF 
	
	start_par(0) = S_final
        start_par(1) = S_ini 
	 
        ind_det = where(exp_det eq det,ndet)
        IF ndet EQ 0 THEN BEGIN 
              print,'WARNING: Not calibrated detector' 
              ind_det = 0
	ENDIF
	
	start_par(2) = exp_E1(ind_det(0))
	start_par(3) = exp_p1(ind_det(0))
		 
	 
 RETURN

END
