;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_DISPDRIFT
;
; PURPOSE:
;	Menu for PIA Drift Analysis intermediate level.
;
;	This routine should only be called by the PIA Display Data routine
;	and should not be called directly from the command line.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_DISPDRIFT, driftps, data_srd, scpps
;
; INPUT PARAMETERS:
;	driftps:	Position within the phtdrift dynamycal structure
;	data_srd:	Temporary SRD level structure
;	scpps:		Position within the phtscp dynamycal structure
;
; KEYWORD PARAMETERS:
;	GROUP:	The group leader of the widget hirarchy
;       NV:	Number of Views (1 <= NV <= 4)
;
; COMMON BLOCKS:
;	adm
;	colour_indices
;	drift_not_acc
;	phtdrift
;	phtscp
;	pia_driftmod_out
;	pia_dispdrift_cmn (internal)
;	pia_dspchdr_cmn (internal)
;	pia_dspchz_cmn 
;	pia_widget_info 
;
; PROCEDURES USED:
;	PIA LIB:
;		drift_std_scp
;		pia_get_step
;		pia_get_rpid
;		pia_drift_mod
;		pia_xplot
;		pia_showstr
;		pia_disp_hdr 
;		pia_disp_cs
;		pia_disp_isr
;		pia_disp_stat
;		pia_dispscp
;       ASTRO LIB:
;       INTERNAL:
;		 drft_showpar
;		 pixbuteventd
;		 viewevent_drft
;		 zoomevent_drft
;		 zoomsync_drft
;		 zoomnsync_drft
;		 pia_resetview_drft
;		 pia_dispdrift_event
;		 reprocess_drft
;
; MODIFICATION HISTORY:
;       Written by: C.Gabriel (ESA/VILSPA-SAI)          February 1997
;	V6.1
;	Refreshing drift info before new actions 
;	 + bug with pixel change fixed +
;	 + saving capability 		(CG)		May 1997
;	V6.3
;	Calling sequence to pia_dispscp (JAc)   	October 1997
;	V6.6
;       Inconsistency in common block removed (CG)      April 1998
;       V7.1
;	Bug by pixel serial decrement fixed (CG)	August 1999
;	V8.0
;			
;-
; *********************************************************************
; * Show Parameters
; *********************************************************************
PRO drft_showdat, event
COMMON pia_driftmod_out, out_fitpar_str, out_fitacc 
COMMON pia_dispdrift_cmn, tmpdata, tmpsrd, tmp_scp, view, viewsize, nviews, $
	viewoptions, overid, drftdi1_wid, is_srd, is_scp  
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
COMMON pia_dspchdr_cmn, pixcho, psymch, pixcount
COMMON DFFUNCT_INFO, funct_info
@colour_indices

	IF out_fitacc GT 0 THEN BEGIN
	  reprocess_refresh
	  out_fitacc = 0
	ENDIF
	  
	WIDGET_CONTROL, event.id, GET_UVALUE = UVAL
	
	flabel = ["Fitted final Signals", "Standard Signals", $
		  "Jump predicted final Signals"]
	index = FIX(STRMID(UVAL,0,1)) - 1
	uval = STRMID(UVAL,1,5)

	CASE uval OF
	'NEW': overpl = 0
	'SYNC': overpl = 1
	'NSYNC': overpl = -1
	ENDCASE
	
        ytype = 0

	charsize = 1.10
	IF overpl NE 0 THEN BEGIN
		xstyle = 0
		ystyle = 0
		IF zoom_color EQ -1 THEN zoom_color = green ELSE $
			zoom_color = zoom_color + 1
		IF zoom_color EQ 9 then zoom_color = 4
		zoom_psymch = zoom_psymch + 1
		IF zoom_psymch EQ 8 then zoom_psymch = 1

		title = ''
	ENDIF ELSE BEGIN
		xstyle = 0
		ystyle = 0
		zoom_color = -1
		zoom_psymch = psymch
        ENDELSE

	
	IF index EQ 0 THEN $
	 dat = {sig:tmpdata.signal, err:tmpdata.err, lab:flabel(index(0))} $
	ELSE IF index EQ 1 THEN $
	 dat = {sig:tmp_scp.taver, err:tmp_scp.tavun, lab:flabel(index(0))} $
	ELSE BEGIN
	 dat = {sig:tmpdata.jump, err:tmpdata.err_jump,lab:flabel(index(0))} 
	ENDELSE
	
	rpid_chosen = [1B,1B]
	step = 1
	chop_system = 1
	max_rpid = [max(tmp_scp.trpid(0)),max(tmp_scp.trpid(1))]
	max_step = max(tmp_scp.tstep)
	max_chop = N_ELEMENTS(tmp_scp.tstep)


	IF max_step GT 1 THEN BEGIN
	    pia_mult_rp_chop, max_rpid, max_step, max_chop, rpc_choice
	    rpid_chosen = rpc_choice.rpid_chosen
	    chop_system = WHERE(rpc_choice.chop_chosen NE 0,nc)
	    step = rpc_choice.chop_chosen(chop_system)
	ENDIF ELSE IF max(max_rpid) GT 1 THEN BEGIN
	         pia_get_rpid, tmp_scp.trpid, rpid_chosen
	 
	ENDIF


        x = indgen(N_ELEMENTS(tmpdata.fract_left)) + 1
	yall = x * 0.
	yerr = x * 0.

	IF chop_system(0) EQ 0 THEN BEGIN
	  ind = WHERE(tmp_scp.trpid EQ rpid_chosen AND $
	     	tmp_scp.tstep EQ step,n)
	     
	  IF n EQ 0 THEN BEGIN
	        PRINT, 'Raster/Step combination NOT found'
	        RETURN
	  ENDIF
	  anntmp = 'RPID ' + STRTRIM(FIX(rpid_chosen),2) + '   ' + $
	     	      'STEP ' + STRTRIM(step,2) + ' average'
	     
	  FOR I=0,N_ELEMENTS(x)-1 DO BEGIN
	     	yall(i) = avg([dat.sig(i,ind)])
	     	yerr(i) = sigma([dat.sig(i,ind)])
	  ENDFOR
	ENDIF ELSE BEGIN
	  
	  anntmp = 'Absolute Chopper Plateau ' + STRTRIM(step,2) 
	     
	  yall = dat.sig(*,step-1)
	  yerr = dat.err(*,step-1)	
        ENDELSE
	decode_admn, tmpsrd.admn, adm_dec
	ytitle=dat.lab

	     PIA_XPLOT, x, yall, yerr, $   
		psym = zoom_psymch, xtitle=' Pixel Number ',  $
		ytitle=ytitle, $
		title=dat.lab + ' - '+ adm_dec, $
                legend=strmid(ytitle,0,20),     $
		overplot = overpl,  $
		charsize = charsize, color = zoom_color,         $       
		xstyle=xstyle, ystyle=ystyle, $
                annotation=anntmp                    


	RETURN
	END
; *********************************************************************
; * Show Parameters
; *********************************************************************
PRO drft_showpar, event
COMMON pia_driftmod_out, out_fitpar_str, out_fitacc 
COMMON pia_dispdrift_cmn, tmpdata, tmpsrd, tmp_scp, view, viewsize, nviews, $
	viewoptions, overid, drftdi1_wid, is_srd, is_scp  
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
COMMON pia_dspchdr_cmn, pixcho, psymch, pixcount
COMMON DFFUNCT_INFO, funct_info
@colour_indices

	IF out_fitacc GT 0 THEN BEGIN
	  reprocess_refresh
	  out_fitacc = 0
	ENDIF
	  

	WIDGET_CONTROL, event.id, GET_UVALUE = UVAL
	
	CASE uval OF
	'NEW': overpl = 0
	'SYNC': overpl = 1
	'NSYNC': overpl = -1
	ENDCASE
	
        ytype = 0

	charsize = 1.10
	IF overpl NE 0 THEN BEGIN
		xstyle = 0
		ystyle = 0
		IF zoom_color EQ -1 THEN zoom_color = green ELSE $
			zoom_color = zoom_color + 1
		IF zoom_color EQ 9 then zoom_color = 4
		zoom_psymch = zoom_psymch + 1
		IF zoom_psymch EQ 8 then zoom_psymch = 1

		title = ''
	ENDIF ELSE BEGIN
		xstyle = 0
		ystyle = 0
		zoom_color = -1
		zoom_psymch = psymch
        ENDELSE

	
	ind_funct = WHERE(STRTRIM(funct_info.lst(1,*),2) EQ  $
	  			STRTRIM(tmpdata.mod_func,2), nindf)
	ind_funct = ind_funct(0)
	flabel = [funct_info.parlabel.(ind_funct), 'Chi-square']
	     pia_multchoice, index, ELEMNAMES= flabel
	     
	max_step = tmpdata.neff_steps


	c_chosen = 1
	IF max_step GT 1 THEN $
		pia_simple_choice, max_step, c_chosen, $
		   label="Choose the corresponding position"

        x = indgen(N_ELEMENTS(tmpdata.fract_left)) + 1
	yall = x * 0.
	yerr = x * 0.


	anntmp = 'Parameter '+flabel(index)+ ': Position ' + STRTRIM(c_chosen,2)

	c_chosen = c_chosen - 1

	IF index EQ N_ELEMENTS(flabel)-1 THEN $
	 yall = tmpdata.chisq(*,c_chosen) ELSE $
	 yall = tmpdata.param(*,c_chosen,index)
	     
	decode_admn, tmpsrd.admn, adm_dec
	ytitle=flabel(index)

	PIA_XPLOT, x, yall, $   
		psym = zoom_psymch, xtitle=' Pixel Number ',  $
		ytitle=ytitle, $
		title='Fit parameter '+flabel(index) + ' - '+ adm_dec, $
                legend=strmid(ytitle,0,20),     $
		overplot = overpl,  $
		charsize = charsize, color = zoom_color,         $       
		xstyle=xstyle, ystyle=ystyle, $
                annotation=anntmp                    


	RETURN
	END
; *********************************************************************
; * Refresh reprocessed pixels
; *********************************************************************

pro reprocess_refresh

COMMON pia_dispdrift_cmn, tmpdata, tmpsrd, tmp_scp, view, viewsize, nviews, $
	viewoptions, overid, drftdi1_wid, is_srd, is_scp  
COMMON pia_dspchdr_cmn, pixcho, psymch, pixcount
COMMON pia_driftmod_out, out_fitpar_str, out_fitacc 
COMMON drift_not_acc, d_degl_acc, d_degl_set, d_sig_disc, d_disc_set 
@phtdrift

	pixch = out_fitacc - 1

	out_fitacc = 0
	
	tmpdata.jump(pixch,*) = out_fitpar_str.jump
	tmpdata.err_jump(pixch,*) = out_fitpar_str.err_jump
	tmpdata.signal(pixch,*) = out_fitpar_str.signal
	tmpdata.err(pixch,*) = out_fitpar_str.err
	tmpdata.slop(pixch,*) = out_fitpar_str.slop
	tmpdata.slop_flag(pixch,*) = out_fitpar_str.slop_flag
	tmpdata.flag(pixch,*) = out_fitpar_str.flag
	tmpdata.chisq(pixch,*) = out_fitpar_str.chisq
	tmpdata.A_VAR(pixch,*,*) = out_fitpar_str.A_VAR
   	tmpdata.FRACT_LEFT(pixch) = out_fitpar_str.FRACT_LEFT 
   	tmpdata.WEIGHTM(pixch) = out_fitpar_str.WEIGHTM   
   	tmpdata.PARAM(pixch,*,*) = out_fitpar_str.PARAM(0,*,*)     
   	tmpdata.SG_PARAM(pixch,*,*) = out_fitpar_str.SG_PARAM(0,*,*)     
   	tmpdata.PRANGE(pixch,*,*,*) = out_fitpar_str.PRANGE(0,*,*,*)     
	tmpdata.T_INI(pixch,*) = out_fitpar_str.T_INI
	tmpdata.TEMP_INI(pixch,*) = out_fitpar_str.TEMP_INI

	FOR I=0,NVIEWS-1 DO  pia_resetview_drft, i, view(i).controlid
	
	pia_load_idrift, phtdrift(tmp_scp.driftps), tmpdr
	tmpdr.drift = tmpdata
					
	fill_drift, tmpdr, replace=tmp_scp.driftps
	
	RETURN
	END	


; *********************************************************************
; * Reprocess single pixels
; *********************************************************************
pro reprocess_drft, event

COMMON pia_dispdrift_cmn, tmpdata, tmpsrd, tmp_scp, view, viewsize, nviews, $
	viewoptions, overid, drftdi1_wid, is_srd, is_scp  
COMMON pia_dspchdr_cmn, pixcho, psymch, pixcount
COMMON pia_driftmod_out, out_fitpar_str, out_fitacc 
COMMON drift_not_acc, d_degl_acc, d_degl_set, d_sig_disc, d_disc_set 
COMMON pia_driftmod_out, out_fitpar_str, out_fitacc 

	IF out_fitacc GT 0 THEN BEGIN
	  reprocess_refresh
	  out_fitacc = 0
	ENDIF
	  

	WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
	
	pixch = pixcho(windowindex)

	out_fitacc = 0
	
	PIA_DRIFT_MOD, tmpsrd, pixch, d_sig_disc, d_degl_acc, d_degl_set, $
		 GROUP=event.top, /FITRESULTS

	
	RETURN
	END	

; *********************************************************************
; *
; *********************************************************************
pro pixbuteventd, event

COMMON pia_dispdrift_cmn, tmpdata, tmpsrd, tmp_scp, view, viewsize, nviews, $
	viewoptions, overid, drftdi1_wid, is_srd, is_scp  
COMMON pia_dspchdr_cmn, pixcho, psymch, pixcount
COMMON dspdrf_widg, pixbut

        WIDGET_CONTROL, event.id, GET_UVALUE = new_pixbut

        ind = WHERE(pixcho eq new_pixbut(0))
        ind = ind(0)

        IF ind LT 0 or ind GE nviews THEN BEGIN

          pixcount = pixcount+1
          IF pixcount GE nviews THEN pixcount = 0

          old_pixcho = pixcho(pixcount)
          pixcho(pixcount) = new_pixbut(0)

          view(pixcount).viewtype = 0
          pia_resetview_drft, pixcount, view(pixcount).controlid

          txtval = STRTRIM(STRING(pixcount+1),2)
          WIDGET_CONTROL, pixbut(old_pixcho), $
                                SET_VALUE = ' '
          WIDGET_CONTROL, pixbut(pixcho(pixcount)), $
                        SET_VALUE = txtval
        ENDIF
END

; *********************************************************************
; *
; *********************************************************************
pro viewevent_drft, event

COMMON pia_dispdrift_cmn, tmpdata, tmpsrd, tmp_scp, view, viewsize, nviews, $
	viewoptions, overid, drftdi1_wid, is_srd, is_scp  
COMMON pia_dspchdr_cmn, pixcho, psymch, pixcount

	viewindexid = WIDGET_INFO(event.id, /PARENT)
	WIDGET_CONTROL, viewindexid, GET_UVALUE = viewindex
	WIDGET_CONTROL, event.id, GET_UVALUE = setting
	setting = setting(0)

	IF (view(viewindex(0)).viewtype NE setting) THEN BEGIN
		view(viewindex(0)).viewtype = setting
		pia_resetview_drft, viewindex, viewindexid
	ENDIF
END


; *********************************************************************
; *
; *********************************************************************
pro zoomevent_drft, event

COMMON pia_dispdrift_cmn, tmpdata, tmpsrd, tmp_scp, view, viewsize, nviews, $
	viewoptions, overid, drftdi1_wid, is_srd, is_scp  
COMMON pia_dspchdr_cmn, pixcho, psymch, pixcount
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices

	WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
	zoomitd, windowindex        
END


; *********************************************************************
; *
; *********************************************************************
pro zoomsync_drft, event

COMMON pia_dispdrift_cmn, tmpdata, tmpsrd, tmp_scp, view, viewsize, nviews, $
	viewoptions, overid, drftdi1_wid, is_srd, is_scp  
COMMON pia_dspchdr_cmn, pixcho, psymch, pixcount
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices

	WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
	zoomitd, windowindex, overplot = 1        

END

; *********************************************************************
; *
; *********************************************************************
pro zoomnsync_drft, event

COMMON pia_dispdrift_cmn, tmpdata, tmpsrd, tmp_scp, view, viewsize, nviews, $
	viewoptions, overid, drftdi1_wid, is_srd, is_scp  
COMMON pia_dspchdr_cmn, pixcho, psymch, pixcount
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices

	WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
	zoomitd, windowindex, overplot = -1        

END

; *********************************************************************
; *
; *********************************************************************
pro zoomitd, windowindex, overplot=overplot

COMMON pia_dispdrift_cmn, tmpdata, tmpsrd, tmp_scp, view, viewsize, nviews, $
	viewoptions, overid, drftdi1_wid, is_srd, is_scp  
COMMON pia_dspchdr_cmn, pixcho, psymch, pixcount
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices
COMMON pia_driftmod_out, out_fitpar_str, out_fitacc 


	IF out_fitacc GT 0 THEN BEGIN
	  reprocess_refresh
	  out_fitacc = 0
	ENDIF
	  
	
	
	IF (KEYWORD_SET(overplot)) THEN overplot = overplot ELSE overplot = 0

	xtitle = viewoptions(view(windowindex).viewtype).viewxlab
	ytitle = viewoptions(view(windowindex).viewtype).viewylab

	decode_admn, tmpdata.TDTNR, title
	title = title + '  ' + tmpsrd.unit

	IF is_srd THEN BEGIN 
         get_convwh, tmpsrd.admn, wheels, chmod, champ
         anntmp = title + $
		'  [' + wheels(0) + '  ' + wheels(1) + '  ' + $
		wheels(2) + ']  [' + chmod + '  ' + champ + ']'
         anntmp = anntmp+' (DRIFT subl.)'
        ENDIF 


        ytype = 0

	charsize = 1.10
	IF overplot NE 0 THEN BEGIN
		xstyle = 0
		ystyle = 0
		IF zoom_color EQ -1 THEN zoom_color = green ELSE $
			zoom_color = zoom_color + 1
		IF zoom_color EQ 9 then zoom_color = 4
		zoom_psymch = zoom_psymch + 1
		IF zoom_psymch EQ 8 then zoom_psymch = 1

		title = ''
	ENDIF ELSE BEGIN
		xstyle = 0
		ystyle = 0
		zoom_color = -1
		zoom_psymch = psymch
        ENDELSE


	CASE view(windowindex).viewtype OF

;Plot signals + fit
	  0: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Signal: Pixel '+str_pixch+'  [V/s]' 
		ytitle = str_pixch 

		ind_val = WHERE(tmpdata.slop_flag(pixch,*) LE 1, nval)

		; plot model fitting
		IF nval GT 0 THEN BEGIN
		 PIA_XPLOT, tmpdata.time, 				$
			tmpdata.slop(pixch,*), 				$
			psym = -3, color=orange,  			$
                        legend=' Fitted signal', xtitle=xtitle, 	$
			ytitle=ytitle, ytype=ytype, charsize=charsize,  $
			title=title, subtitle=subtitle,      		$
			overplot = overplot,                     	$       
			xstyle=xstyle, ystyle=ystyle 
	
		 n_sig = n_elements(tmpdata.time_sg)
		 time_sg = [tmpsrd.stim(0),tmpdata.time_sg]
		 signal =  tmpdata.signal
		 sz_tmp = size(signal)
		 if sz_tmp(0) eq 2 then signal = reform(signal(pixch,*)) ELSE $
		    signal = signal(pixch)
		 final_sg = 0. &  final_ti = 0.
		 for is = 0, n_sig-1 do begin
		        final_sg = [final_sg, signal(is), signal(is)]
		    	final_ti = [final_ti, time_sg(is),time_sg(is+1)]	
		 endfor
		 pia_xplot, final_ti(1:*), final_sg(1:*), color=green, $
		            legend = 'Final value ',psym=-3,/overplot
                 
		ENDIF
		
		; plot SRD data and discard signals
		IF is_srd THEN BEGIN 
		  pia_xplot, tmpsrd.stim, tmpsrd.slop(pixch,*), 	$
			tmpsrd.slun(pixch,*), 				$
			psym = zoom_psymch, color = zoom_color,  	$
                        legend=strmid(ytitle,0,20), 			$
                        annotation=anntmp, /overplot                   

		  ; discard signals, not used for model fitting
		  indno = WHERE(tmpdata.slop_flag(pixch,*) GT 1, nn)
                  IF nn GT 0 THEN $
			  PIA_XPLOT, tmpsrd.stim(indno), $
			  tmpsrd.slop(pixch,indno), $
			  psym = 7, color=red, overplot=1, $
                          legend=' discarded points'
                 ENDIF         


    	  END
;Plot flags
	  1: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Flags: Pixel '+str_pixch
		ytitle = str_pixch 

		
		pia_xplot, tmpsrd.stim, $
			tmpsrd.flag(pixch,*), $
			psym = zoom_psymch, xtitle=xtitle,  $
			ytitle=ytitle, ytype=ytype, $
			title=title, subtitle=subtitle, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,     $       
			xstyle=xstyle, ystyle=ystyle, $
                        legend=strmid(ytitle,0,20), $
                        annotation=anntmp                   

		

    	  END
;Plot derived signals
	  2: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Derived signals: Pixel '+str_pixch
		ytitle = str_pixch 

		pia_xplot, tmpdata.time_sg, tmpdata.signal(pixch,*), $
			tmpdata.err(pixch,*), psym = zoom_psymch, $
			xtitle=xtitle, ytitle = ytitle, $
			title=title, subtitle=subtitle, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,     $       
			xstyle=xstyle, ystyle=ystyle, ytype=ytype, $
                        legend=strmid(ytitle,0,20), $
                        annotation=anntmp             
          END
;Plot derived signals' flags
	  3: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Derived sig-flags: Pixel '+str_pixch
		ytitle = str_pixch 

		pia_xplot, tmpdata.time_sg, tmpdata.flag(pixch,*), $
			psym = zoom_psymch, $
			xtitle=xtitle, ytitle = ytitle, $
			title=title, subtitle=subtitle, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,     $       
			xstyle=xstyle, ystyle=ystyle, ytype=ytype, $
                        legend=strmid(ytitle,0,20), $
                        annotation=anntmp             
          END
;Plot Standard SCP values
	  4: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Standard signal/Ch.Pl.: Pixel '+str_pixch
		ytitle = str_pixch 

		pia_xplot, tmp_scp.ttime, tmp_scp.taver(pixch,*), $
			tmp_scp.tavun(pixch,*), $
			psym = zoom_psymch, $
			xtitle=xtitle, ytitle = ytitle, $
			title=title, subtitle=subtitle, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,     $       
			xstyle=xstyle, ystyle=ystyle, ytype=ytype, $
                        legend=strmid(ytitle,0,20), $
                        annotation=anntmp             
		
		indno = WHERE(tmp_scp.tflag(pixch,*) GT 1, nn)
		IF nn GT 0 THEN $
			PIA_XPLOT, tmp_scp.ttime(indno), $
			  tmp_scp.taver(pixch,indno), $
			  psym = 7, color=red, overplot=1, $
                          legend=' discarded points'



          END
;Plot Chi-square for this pixel
	  5: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = '"Normalized" Chi-square / DoF: Pix '+str_pixch
		ytitle = str_pixch 
		
		neffsteps = N_ELEMENTS(tmpdata.chisq(0,*))
		x = tmpdata.time_sg(0:neffsteps-1)
		
		pia_xplot, x, tmpdata.chisq(pixch,*), $
			psym = psymch, $
			xtitle=xtitle, ytitle = ytitle, $
			title=title, charsize=charsize, color = zoom_color,     $       
			xstyle=xstyle, ystyle=ystyle, ytype=ytype, $
                        legend=strmid(ytitle,0,20), $
                        annotation=anntmp    
		
          END

	  6: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Residuals: Pix '+str_pixch+'  [V/s]' 
		ytitle = str_pixch 

		ind_val = WHERE(tmpdata.slop_flag(pixch,*) EQ 0, ni)
		IF ni EQ 0 THEN RETURN
		
		resi = tmpdata.slop(pixch,ind_val) - tmpsrd.slop(pixch,ind_val)

		pia_xplot, tmpsrd.stim(ind_val), resi, $
			psym = zoom_psymch, $
			xtitle=xtitle, ytitle = ytitle, $
			title=title, subtitle=subtitle, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,     $       
			xstyle=xstyle, ystyle=ystyle, ytype=ytype, $
                        legend=strmid(ytitle,0,20), $
                        annotation=anntmp             

	  END


;Plot Jump method results
	  7: BEGIN

		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Exp. Signal ("Jump"): P.'+str_pixch+' [V/s]' 
		ytitle = str_pixch 

		pia_xplot, tmpdata.time_sg, tmpdata.jump(pixch,*), $
			tmpdata.err_jump(pixch,*), $
			psym = zoom_psymch, $
			xtitle=xtitle, ytitle = ytitle, $
			title=title, subtitle=subtitle, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,     $       
			xstyle=xstyle, ystyle=ystyle, ytype=ytype, $
                        legend=strmid(ytitle,0,20), $
                        annotation=anntmp             
	   

          END
	  ELSE: MESSAGE, /INFO, 'Unsupported View'
          ENDCASE

END

; *********************************************************************
; *
; *********************************************************************
pro pia_resetview_drft, windowindex, UPDATE_LABEL

COMMON pia_dispdrift_cmn, tmpdata, tmpsrd, tmp_scp, view, viewsize, nviews, $
	viewoptions, overid, drftdi1_wid, is_srd, is_scp  
COMMON pia_dspchdr_cmn, pixcho, psymch, pixcount
COMMON scp_nac, cps_disc, disc_set, vign_set 
COMMON tmpvalues3, tmprpid, tmprpid_name
@colour_indices
@phtdrift
COMMON pia_driftmod_out, out_fitpar_str, out_fitacc 


	IF out_fitacc GT 0 THEN BEGIN
	  reprocess_refresh
	  out_fitacc = 0
	ENDIF
	  

	wset, view(windowindex).windownum         ;set to draw in 

	ERASE, color = 100                        ;erase the view


	IF NOT (KEYWORD_SET(UPDATE_LABEL)) THEN $
	  UPDATE_LABEL = 0


        charsize = 0.8
        symsize = 0.5

        title = viewoptions(view(windowindex).viewtype).viewname
	xtitle = viewoptions(view(windowindex).viewtype).viewxlab
	ytitle = viewoptions(view(windowindex).viewtype).viewylab

	CASE view(windowindex).viewtype OF


;Plot averages of pixel signals
	  0: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Signal: Pixel '+str_pixch+'  [V/s]' 
		ytitle = str_pixch 

		
		; plot valid model fitting
		ind_val = WHERE(tmpdata.slop_flag(pixch,*) LE 1, nval)
		
		minxx = MIN(tmpdata.time,MAX=maxxx)
		yy = tmpdata.slop
		;if srd data are present, then take the minimum and 
		; maximum from there
		IF is_srd THEN minyy = MIN(tmpsrd.slop(pixch,*), MAX=maxyy) $
		ELSE $
		IF nval GT 1 THEN minyy = MIN(yy(pixch,ind_val), MAX=maxyy) $
		  ELSE minyy = MIN(yy(pixch,*),MAX=maxyy)   
		PIA_PLOT, [minxx, maxxx],[minyy, maxyy], /nodata, $
			  xtitle=xtitle, ytitle=ytitle, charsize = charsize  

		IF nval GT 0 THEN BEGIN
		 PIA_OPLOT, tmpdata.time(ind_val), tmpdata.slop(pixch,ind_val), $
			  linestyle=2, color=orange, thick=2.5
	
		; plot predicted final value
		 n_sig = n_elements(tmpdata.time_sg)
		 time_sg = [tmpdata.time(0),tmpdata.time_sg]
		 signal =  tmpdata.signal
		 sz_tmp = size(signal)
		 if sz_tmp(0) eq 2 then signal = reform(signal(pixch,*)) $
		   ELSE signal = signal(pixch)
		 final_sg = 0. &  final_ti = 0.
		 FOR is = 0, n_sig-1 do begin
		        final_sg = [final_sg, signal(is), signal(is)]
		    	final_ti = [final_ti, time_sg(is),time_sg(is+1)]	
		 ENDFOR

		 pia_oplot, final_ti(1:*), final_sg(1:*), color=green, $
		             linestyle=1, thick=2.5

		ENDIF
		
		 ; plot srd data, if present
		IF is_srd THEN BEGIN 
		 pia_oplot, tmpsrd.stim, tmpsrd.slop(pixch,*), $
			yerr=tmpsrd.slun(pixch,*), $
			psym = psymch, symsize=symsize                 


		 ; plot discard signals (SRD), ie. not used for model fitting
		 indno = WHERE(tmpdata.slop_flag(pixch,*) GT 1, nnval_srd)
                 IF nnval_srd GT 0 THEN $
			  PIA_OPLOT, tmpsrd.stim(indno), $
			  tmpsrd.slop(pixch,indno), $
			  psym = 7, color=red
		ENDIF	  




		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  
         
    	  END
;Plot  signal flags
	  1: BEGIN

		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Flags: Pixel '+str_pixch
		ytitle = str_pixch 

		
		pia_plot, tmpsrd.stim, $
			tmpsrd.flag(pixch,*), $
			psym = psymch, xtitle=xtitle,  $
			ytitle=ytitle,  $
			title=title,  $
			charsize = charsize, symsize=symsize              

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  
          
    	  END
;Plot derived signals
	  2: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Derived signals: Pixel '+str_pixch
		ytitle = str_pixch 

		pia_plot, tmpdata.time_sg, tmpdata.signal(pixch,*), $
			psym = psymch, $
			xtitle=xtitle, ytitle = ytitle, $
			title=title,  $
			charsize = charsize, symsize=symsize
   
		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  
          
          END
;Plot derived signals' flags
	  3: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Derived sig-flags: Pixel '+str_pixch
		ytitle = str_pixch 

		pia_plot, tmpdata.time_sg, tmpdata.flag(pixch,*), $
			psym = psymch, $
			xtitle=xtitle, ytitle = ytitle, $
			title=title, $
			charsize = charsize, symsize=symsize

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  
          
     
          END
;Plot standard SCP values
	  4: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Standard signal/Ch.Pl.: Pixel '+str_pixch
		ytitle = str_pixch 

		pia_plot, tmp_scp.ttime, tmp_scp.taver(pixch,*), $
			yerr=tmp_scp.tavun(pixch,*), $
			psym = psymch, $
			xtitle=xtitle, ytitle = ytitle, $
			title=title, charsize=charsize, symsize=symsize
		
		indno = WHERE(tmp_scp.tflag(pixch,*) GT 1, nn)
		IF nn GT 0 THEN $
			PIA_OPLOT, tmp_scp.ttime(indno), $
			  tmp_scp.taver(pixch,indno), $
			  psym = 7

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  
			  
		
          END
;Plot Chi-square for full array
	  5: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = '"Normalized" Chisq/DoF: Pix '+str_pixch
		ytitle = str_pixch 

		neffsteps = N_ELEMENTS(tmpdata.chisq(0,*))
		x = tmpdata.time_sg(0:neffsteps-1)
		
		pia_plot, x, tmpdata.chisq(pixch,*), $
			psym = psymch, $
			xtitle=xtitle, ytitle = ytitle, $
			title=title, charsize=charsize, symsize=symsize
		
		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  
			  
		

          END

	  6: BEGIN

		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Residuals: Pix '+str_pixch+'  [V/s]' 
		ytitle = str_pixch 

		ind_val = WHERE(tmpdata.slop_flag(pixch,*) EQ 0, ni)
		IF ni EQ 0 THEN RETURN
		
		resi = tmpdata.slop(pixch,ind_val) - tmpsrd.slop(pixch,ind_val)
		
		pia_plot, tmpsrd.stim(ind_val), resi, $
			psym = psymch, $
			xtitle=xtitle, ytitle = ytitle, $
			title=title,  $
			charsize = charsize, symsize=symsize      
		 		
		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  
			  
		

          END

	  7: BEGIN

		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Exp. Signal ("Jump"): Pix '+str_pixch+' [V/s]' 
		ytitle = str_pixch 

		pia_plot, tmpdata.time_sg, tmpdata.jump(pixch,*), $
			yerr=tmpdata.err_jump(pixch,*), $
			psym = psymch, $
			xtitle=xtitle, ytitle = ytitle, $
			title=title,  $
			charsize = charsize, symsize=symsize      
		 		
		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  
			  
		

          END

	  ELSE: WIDGET_CONTROL, UPDATE_LABEL, $
				set_value = 'Unsupported View'
          ENDCASE

END


; ***************************************************************************
;  Event handling routine for PIA display menu
; ****************************************************************************

PRO pia_dispdrift_event, event

@adm
@phtcs
@phtdrift
@phtsrd
@phtscp

COMMON pia_dispdrift_cmn, tmpdata, tmpsrd, tmp_scp, view, viewsize, nviews, $
	viewoptions, overid, drftdi1_wid, is_srd, is_scp  
COMMON pia_widget_info, extfil_wid, intfil_wid, buffil_wid, $
                        erddi1_wid, erddi2_wid, srddi1_wid, srddi2_wid, $
                        scpdi1_wid, scpdi2_wid, spddi1_wid, spddi2_wid, $
                        aapdi1_wid, aapdi2_wid
COMMON pia_dispdrift_results, drift_str_res
COMMON pia_driftmod_out, out_fitpar_str, out_fitacc 
COMMON pia_dspchdr_cmn, pixcho, psymch, pixcount
COMMON DFFUNCT_INFO, funct_info
COMMON dspdrf_widg, pixbut
COMMON dispcust_cmn, psym, line


	IF out_fitacc GT 0 THEN BEGIN
	  reprocess_refresh
	  out_fitacc = 0
	ENDIF
	  
	
	WIDGET_CONTROL, event.id, get_uvalue = uvalue
        WIDGET_CONTROL, event.top, /HOURGLASS

	CASE uvalue OF


; 	  "EXIT":  BEGIN
;		    WIDGET_CONTROL, event.top, /DESTROY 
;		    PIA_DISPSCP, data= tmp_scp.scpps
;		  END


          "HELP":   BEGIN
	   	IF !VERSION.OS NE 'vms' THEN $
		spawn, '$w3net $PIA_HTML/um/drift_mod.html &' ELSE $
		spawn, 'w3net /pia_dsk/pia/html/um/drift_mod.html'
		END


	  "CUST": BEGIN
			pia_dispcust, GROUP=event.top
			psymch = psym
			 FOR I=0,NVIEWS-1 DO BEGIN
			    pia_resetview_drft, i, view(i).controlid
			 ENDFOR
          END

	  "LOAD": BEGIN
; search for same file and detector type
		    newdata = pickmeas(FTYPE="DRIFT", DTYPE=tmpdata.det, $ 
		                   POSI=posi)
		    IF newdata NE '' THEN BEGIN



                     datind2 = WHERE(phtdsrd.admn eq newdata, count2)
                     datind3 = WHERE(phtdscp.admn eq newdata, count3)
                    
                     IF count2 GE 1 THEN BEGIN
                        srdlist = phtsrd(dataind2).admn
                        pia_multmeas, scplist
                        dataind2 = datind2(srdlist)
                        pia_load_isrd, phtsrd(dataind2(0)), data_srd
                        tmpsrd = data_srd
		     ENDIF ELSE BEGIN 
		        MESSAGE, /INFO, 'SRD level not found, please load it!!' 
		        RETURN
		     ENDELSE   

                     IF count3 GE 1 THEN BEGIN
			scplist = phtscp(datind3).admn
			pia_multmeas, scplist
                        datind3 = datind3(scplist)
                        pia_load_iscp, phtscp(dataind3(0)), tmpscp
		     ENDIF ELSE BEGIN 
		        MESSAGE, /INFO, 'SCP level not found, please load it!!' 
		        RETURN
		     ENDELSE   

                     IF count NE 0 THEN BEGIN 
			pia_load_idrift, phtdrift(datind(posi(0))), tmpdrift

	                txt = "PIA Drift Analysis Window -"
	                decode_admn, tmpdata.admn, dattext
	                dattext = txt+dattext
	
	                WIDGET_CONTROL, dattext_id, SET_VALUE = dattext  
			
		        ; refresh all screens
			FOR I=0,NVIEWS-1 DO pia_resetview_drft, i,  $ 
			      view(i).controlid                        
                     ENDIF

		    ENDIF
		  END	                  	


	  "SAVE": BEGIN
		pia_load_idrift, phtdrift(tmp_scp.driftps), tmpall
		tmpall.drift = tmpdata
	  	PCONT_SAVEINT, junk, 'DRIFT', tmpdata=tmpall
	  END

	  "SHOWD": PIA_showstr, tmpdata,  GROUP=event.top 
                   
          "HDR": pia_disp_hdr, tmpsrd.hdr, tmpsrd.admn, 'PHTSRD'


          "CS": PIA_DISP_CS, tmpsrd.admn

	  "ISREP": PIA_disp_isr,STRMID(tmpsrd.admn,4,8)

	  "ISMANN": PIA_DISP_stat, tmpsrd.admn, /STAB

	  "ISDRIFT": PIA_DISP_stat, tmpsrd.admn, /DRIFT
	   
	  "ISSLOPV": PIA_DISP_stat, tmpsrd.admn, /SLOPV

	  "ACCEPT_STD": BEGIN
		drift_std_scp, tmp_scp.driftps, tmp_scp.scpps
		WIDGET_CONTROL, event.top, /DESTROY 
		PIA_DISPSCP, data= tmp_scp.scpps
	  END

	  "ACCEPT_ALL": BEGIN
		drift_std_scp, tmp_scp.driftps, tmp_scp.scpps, /ACC_ALL
		WIDGET_CONTROL, event.top, /DESTROY 
		IF is_scp THEN PIA_DISPSCP, data= tmp_scp.scpps
	  END

	  "DISCARD_ALL": BEGIN
		WIDGET_CONTROL, event.top, /DESTROY 
		IF is_scp THEN PIA_DISPSCP, data= tmp_scp.scpps
	  END

	  "CANCEL": BEGIN
		WIDGET_CONTROL, event.top, /DESTROY 
	  END

	  
	  "PIXCH": BEGIN
			old_pixcho = pixcho
			new_pixc = pia_pixchoice(GROUP=event.top, PIXC=pixcho)
			maxpix = max(new_pixc)
                        minpix = min(new_pixc)
			junk = 0
			IF (tmpdata.det EQ 'C1' AND maxpix gt 8) OR $
			   (tmpdata.det EQ 'C2' AND maxpix gt 3) OR $
			   (tmpdata.det EQ 'SS' AND maxpix gt 127) OR $
			   (tmpdata.det EQ 'SL' AND maxpix gt 127) OR $
			   (minpix lt 0)  THEN BEGIN
		    		XDISPLAYFILE, "", $
                    		GROUP = event.top, $
                    		TITLE = "Warning ", $
                    		WIDTH = 30, $
                    		HEIGHT = 6, $
                    		TEXT = [" Your pixel choice is not valid ", $
                                        " and will not be taken "]
		                junk = 1
			ENDIF
			IF junk NE 1 THEN BEGIN  			
			 FOR I=0,NVIEWS-1 DO BEGIN
			  IF new_pixc(i) NE old_pixcho(i) THEN BEGIN
			    pixcho(i) = new_pixc(i)
			    WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
			    view(i).windownum = temp
			    pia_resetview_drft, i, view(i).controlid
                            IF STRMID(tmpdata.det,0,1) EQ 'C' THEN BEGIN
                              txtval = STRTRIM(STRING(i+1),2)
                              junk = where(new_pixc eq old_pixcho(i), count)
                              IF count EQ 0 THEN $
                                 WIDGET_CONTROL, pixbut(old_pixcho(i)), $
                                        SET_VALUE = ' '
                              WIDGET_CONTROL, pixbut(pixcho(i)), $
                                        SET_VALUE = txtval
                            ENDIF
                          ENDIF
			 ENDFOR
			ENDIF
          END

	  "PIXCHSER": BEGIN
			old_pixcho = pixcho
			new_pixc = old_pixcho + nviews
			CASE STRMID(tmpdata.det,0,2) OF
				'C1': npix = 9
				'C2': npix = 4
				'SL': npix = 128
				'SS': npix = 128
				'P1': RETURN
				'P2': RETURN
				'P3': RETURN
			ENDCASE  
			new_pixc = new_pixc mod npix
			
			FOR I=0,NVIEWS-1 DO BEGIN
			  IF new_pixc(i) NE old_pixcho(i) THEN BEGIN
			    pixcho(i) = new_pixc(i)
			    WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
			    view(i).windownum = temp
			    pia_resetview_drft, i, view(i).controlid
			    IF STRMID(tmpdata.det,0,1) EQ 'C' THEN BEGIN 
			      txtval = STRTRIM(STRING(i+1),2)
			      junk = where(new_pixc eq old_pixcho(i), count)
			      IF count EQ 0 THEN $
			         WIDGET_CONTROL, pixbut(old_pixcho(i)), $
					SET_VALUE = ' '
			      WIDGET_CONTROL, pixbut(pixcho(i)), $
					SET_VALUE = txtval
			    ENDIF 
                          ENDIF
			ENDFOR
          END

	  "PIXCHSERD": BEGIN
			old_pixcho = pixcho
			new_pixc = old_pixcho - nviews
			CASE STRMID(tmpdata.det,0,2) OF
				'C1': npix = 9
				'C2': npix = 4
				'SL': npix = 128
				'SS': npix = 128
				'P1': RETURN
				'P2': RETURN
				'P3': RETURN
			ENDCASE  
			ind=WHERE(new_pixc LT 0,nind)
			IF nind GT 0 THEN new_pixc(ind) = npix+new_pixc(ind)  
			
			FOR I=0,NVIEWS-1 DO BEGIN
			  IF new_pixc(i) NE old_pixcho(i) THEN BEGIN
			    pixcho(i) = new_pixc(i)
			    WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
			    view(i).windownum = temp
			    pia_resetview_drft, i, view(i).controlid
			    IF STRMID(tmpdata.det,0,1) EQ 'C' THEN BEGIN 
			      txtval = STRTRIM(STRING(i+1),2)
			      junk = where(new_pixc eq old_pixcho(i), count)
			      IF count EQ 0 THEN $
			         WIDGET_CONTROL, pixbut(old_pixcho(i)), $
					SET_VALUE = ' '
			      WIDGET_CONTROL, pixbut(pixcho(i)), $
					SET_VALUE = txtval
			    ENDIF 
                          ENDIF
			ENDFOR
          END

        "NVIEWS": BEGIN

            newviews = event.value + 1
            IF newviews NE nviews THEN BEGIN
                WIDGET_CONTROL, drftdi1_wid, /DESTROY
                pia_dispdrift, tmp_scp.driftps, tmpsrd, tmp_scp.scpps, $
                   NV = newviews
            ENDIF
         END

	 "REFRESH":  FOR I=0,NVIEWS-1 DO pia_resetview_drft, i, view(i).controlid


	ENDCASE
	
RETURN
END

; ****************************************************************************
;  PIA Dispdrft - menu definition procedure
; ****************************************************************************

PRO pia_dispdrift, driftps, data_srd, scpps, NV = NV, GROUP=group


COMMON pia_dispdrift_cmn, tmpdata, tmpsrd, tmp_scp, view, viewsize, nviews, $
	viewoptions, overid, drftdi1_wid, is_srd, is_scp  
COMMON pia_dspchdr_cmn, pixcho, psymch, pixcount
COMMON drfattext, dattext_id, newheader
COMMON dspdrf_widg, pixbut
COMMON pia_widget_info, extfil_wid, intfil_wid, buffil_wid, $
                        erddi1_wid, erddi2_wid, srddi1_wid, srddi2_wid, $
                        scpdi1_wid, scpdi2_wid, spddi1_wid, spddi2_wid, $
                        aapdi1_wid, aapdi2_wid
COMMON pia_dispdrift_results, drift_str_res
COMMON not_acc, degl_acc, degl_set, sig_disc, disc_set 
COMMON drift_not_acc, d_degl_acc, d_degl_set, d_sig_disc, d_disc_set 
@phtscp
@phtdrift
COMMON pia_driftmod_out, out_fitpar_str, out_fitacc 

; If already registered, return

        IF Xregistered("pia_dispdrift") NE 0 THEN BEGIN
                RETURN
        END

	IF N_PARAMS() LT 1 THEN BEGIN
	  MESSAGE, 'Syntax: PIA_DISPDRIFT, FIT_STR [,DATA_SRD] [,DATA_SCP], NV=NV
	  RETURN
 	ENDIF
	      
	   
	pia_load_idrift, phtdrift(driftps), tmpdata
	tmpdata = tmpdata.drift	
	
	; set npixel
	npix = pixel_det(tmpdata.det)
	
	IF N_PARAMS() GE 2 THEN BEGIN 
         	tmpsrd = data_srd 
         	IS_SRD = 1
        ENDIF ELSE IS_SRD = 0
        
        IF N_PARAMS() EQ 3 THEN BEGIN 
                pia_load_iscp, phtscp(scpps), tmpscp
	        tmp_scp = {ttime:tmpscp.time, taver:tmpscp.aver(0:npix-1,*), $
		     tavun:tmpscp.avun(0:npix-1,*),$
		     tflag:tmpscp.flag(0:npix-1,*), scpps:scpps, $
		     driftps:driftps, trpid:tmpscp.rpid, tstep:tmpscp.step}
                IS_SCP = 1
        ENDIF  ELSE IS_SCP = 0      
                 	

	out_fitacc = 0
	
	
	IF N_ELEMENTS(degl_acc) EQ 0 THEN BEGIN
	  degl_acc = 0
	  degl_set = 0
	ENDIF

	d_degl_acc = degl_acc
	d_degl_set = degl_set
	d_sig_disc = sig_disc
	d_disc_set = d_disc_set
; initialize views and pixels chosen

        IF KEYWORD_SET(NV) THEN NVIEWS = nv ELSE nviews = 4
        IF nviews GT 4 THEN nviews = 4
        pixcount = -1


	psymch = 4	

	CASE STRMID(tmpdata.det, 0,1) of 
          'P': BEGIN 
		pixcho = [0,0,0,0]
	  END
          ELSE: BEGIN  
	         CASE STRMID(tmpdata.det,0,2) of
	           'C1': BEGIN
			pixcho = [0,2,4,6]
		   END
	           'C2': BEGIN
			pixcho = [1,2,3,0]
		   END
	           'SS': BEGIN
			pixcho = [10,40,90,120]
		   END
	           'SL': BEGIN
			pixcho = [10,40,90,120]
		   END
		  ELSE: BEGIN
			pixcho = [10,40,90,120]
		   END
	 	  ENDCASE		
	  END
        ENDCASE

	viewsize = 220
	xsize = viewsize * 4 / nviews
	ysize = viewsize

	viewinstance = {vinstd, viewtype:0b, 	$	;structure for   
				controlid:0L,	$       ;each view	
				windowid:0L,	$
				windownum:0}	

        view = REPLICATE(viewinstance, NVIEWS)		; array of view struct.

	IF IS_SRD EQ 0 THEN viewtype_p = [0,2,3,5] $ 
	   ELSE viewtype_p = INDGEN(4) 
        IF STRMID(tmpdata.det, 0,1) eq 'P' THEN $
                FOR i=0,nviews-1 DO view(i).viewtype = viewtype_p(i)

	instance = {vopt3, viewname:'', $
                  viewid:0, viewxlab:'', $
		  viewylab:'' }                     	;structures describing
	NVIEWOPTS = 8                           	;each type of view 

	viewoptions = REPLICATE(instance, NVIEWOPTS)    

        ; Use only drift structure, optionally SRD
        viewoptions(0).viewname = "Signal  [V/sec]"
        viewoptions(0).viewid = 0
        viewoptions(0).viewylab = "Signal Values       [V/s]"
        viewoptions(0).viewxlab = "Time       [s]"
        viewoptions(2).viewname = "Final signals "
        viewoptions(2).viewid = 2
        viewoptions(2).viewylab = "Derived signals"
        viewoptions(2).viewxlab = "Time       [s]"
        viewoptions(3).viewname = "Final flags     "
        viewoptions(3).viewid = 3
        viewoptions(3).viewylab = "Derived signals' Flags "
        viewoptions(3).viewxlab = "Time       [s]"
        viewoptions(5).viewname = "Chi-square value "
        viewoptions(5).viewid = 5
        viewoptions(5).viewylab = "Normalized Chi-square / DoF"
        viewoptions(5).viewxlab = "Time       [s]    "
        viewoptions(7).viewname = "Expected signal (from jumps)"
        viewoptions(7).viewid = 7
        viewoptions(7).viewylab = "'Jumps' expected signal diff "
        viewoptions(7).viewxlab = "Time       [s]"
        
        ; SRD needed
        viewoptions(1).viewname = "Signal Flags "
        viewoptions(1).viewid = 1
        viewoptions(1).viewylab = "Signal Flags           "
        viewoptions(1).viewxlab = "Time       [s]"
        viewoptions(6).viewname = "Residuals (model-signal) "
        viewoptions(6).viewid = 6
        viewoptions(6).viewylab = "Residuals (model-signal) "
        viewoptions(6).viewxlab = "Time       [s]"

	; SCP needed
        viewoptions(4).viewname = "Signal per Chopper Plateau"
        viewoptions(4).viewid = 4
        viewoptions(4).viewylab = "Standard averages/ch.pl "
        viewoptions(4).viewxlab = "Time       [s]"

	IF STRPOS(tmpdata.mod_func, 'TCHO') EQ -1 THEN NVIEWOPTS=7  

; top base

	wid = WIDGET_BASE( TITLE="PIA Drift Analysis Data Display", $
		/COLUMN, XPAD = 20, YPAD = 20, SPACE = 20)
	drftdi1_wid = wid
; control windows

	control = WIDGET_BASE(drftdi1_wid, /ROW)

	control_exit = WIDGET_BUTTON(control, VALUE="    Exit    ",$
					 /MENU)
        id_2 = WIDGET_BUTTON(control_exit, $
        		VALUE=' Accept modelling in standard way',  $
                               UVALUE='ACCEPT_STD' )
        IF IS_SCP EQ 0 THEN WIDGET_CONTROL, id_2, sensitive=0                       
                               
        id_2 = WIDGET_BUTTON(control_exit, $
        		VALUE=' Accept all values from modelling',  $
                               UVALUE='ACCEPT_ALL' )
        ;IF IS_SCP EQ 0 THEN WIDGET_CONTROL, id_2, sensitive=0                       
                               
        id_2 = WIDGET_BUTTON(control_exit, $
        		VALUE=' Discard all values from modelling',  $
                               UVALUE='DISCARD_ALL' )
        IF IS_SCP EQ 0 THEN WIDGET_CONTROL, id_2, sensitive=0  
                             
        id_2 = WIDGET_BUTTON(control_exit, VALUE=' Cancel',  $
                               UVALUE='CANCEL' )
                              


	control_help = WIDGET_BUTTON(control, VALUE="    Help    ",$
					 UVALUE="HELP")
	control_cust = WIDGET_BUTTON(control, VALUE="  Customize ",$
					 UVALUE="CUST")


	junk = WIDGET_LABEL(control, VALUE = '     ')

	txt = "PIA Drift Analysis Window -"
	decode_admn, tmpdata.tdtnr, dattext
	dattext = txt+dattext
	
	dattext_id = WIDGET_LABEL(control, VALUE = dattext)  

;------------------- the C mapping windows -------------------------
	
	pad_empty = string('',$ 
	  format='(A'+STRTRIM(MAX([1,100-strlen(dattext)]),2)+')')
        
        junk = WIDGET_LABEL(control, $ 
              VALUE = pad_empty)

        IF STRMID(tmpdata.det, 0,1) eq 'C' THEN BEGIN

        pixver = WIDGET_BASE(control, /COLUMN)
	junk = WIDGET_LABEL(pixver, VALUE='^ +Z')

        pixhor = WIDGET_BASE(pixver,/ROW)

          IF STRMID(tmpdata.det, 1,1) eq '1' THEN BEGIN
                pixbut = intarr(9)
                FOR i=0,2 DO pixbut(i*3+2) = $
                        WIDGET_BUTTON(pixhor, VALUE=' ',$
                                XOFFSET=3*i, $,
                                UVALUE=i*3+2,$
                                EVENT_PRO = 'pixbuteventd')
                pixhor = WIDGET_BASE(pixver,/ROW,YOFFSET=10)
                FOR i=0,2 DO pixbut(i*3+1) = $
                        WIDGET_BUTTON(pixhor, VALUE=' ',$
                                XOFFSET=3*i, $
                                UVALUE=i*3+1,$
                                EVENT_PRO = 'pixbuteventd')
                pixhor = WIDGET_BASE(pixver,/ROW,YOFFSET=10)
                FOR i=0,2 DO pixbut(i*3) = $
                        WIDGET_BUTTON(pixhor, VALUE=' ',$
                                XOFFSET=3*i, $
                                UVALUE=i*3,$
                                EVENT_PRO = 'pixbuteventd')
          ENDIF ELSE $
          IF STRMID(tmpdata.det, 1,1) eq '2' THEN BEGIN
                pixbut = intarr(4)
                FOR i=0,1 DO pixbut(i+2) = $
                        WIDGET_BUTTON(pixhor, VALUE=' ',$
                                XOFFSET=3*i, $
                                UVALUE=i+2,$
                                EVENT_PRO = 'pixbuteventd')
                pixhor = WIDGET_BASE(pixver,/ROW,YOFFSET=10)
                FOR i=1,0,-1 DO pixbut(i) = $
                        WIDGET_BUTTON(pixhor, VALUE=' ',$
                                XOFFSET=3*i, $
                                UVALUE=i,$
                                EVENT_PRO = 'pixbuteventd')
          ENDIF
	junk = WIDGET_LABEL(pixhor, VALUE='> +Y')
        ENDIF

;----------------- the View windows are defined ------------------

	viewbase = WIDGET_BASE(drftdi1_wid, /ROW, SPACE=20)

	viewstorageids = LONARR(NVIEWS)
	overid = lonarr(NVIEWS)	   
	
        FOR viewindex = 0, NVIEWS - 1 DO BEGIN
	  tempbase = WIDGET_BASE(viewbase, /FRAME, /COLUMN, $
				EVENT_PRO = 'viewevent_drft')
	  view(viewindex).controlid = WIDGET_BUTTON(tempbase, VALUE="   ",$
				MENU = 2, UVALUE = viewindex, $
				EVENT_PRO = 'viewevent_drft')
	  view(viewindex).windowid = WIDGET_DRAW(tempbase, $
				XSIZE = xsize, YSIZE = ysize, $
				RETAIN = 2) 
		FOR i = 0, NVIEWOPTS - 1 DO BEGIN
     			dummy = WIDGET_BUTTON(view(viewindex).controlid, $
                	VALUE = viewoptions(i).viewname, $
                	UVALUE = i)
		ENDFOR

	  zoombase = WIDGET_BASE(tempbase, /FRAME, /ROW)
          zoom = WIDGET_BUTTON(zoombase, $
                        VALUE = "Zoom & Print", $
                        UVALUE = viewindex, MENU = 2)

          dummy = WIDGET_BUTTON(zoom, $
                        VALUE = "New  ", $
                        UVALUE = viewindex, EVENT_PRO = 'zoomevent_drft')

          synch = WIDGET_BUTTON(zoom, $
                        VALUE = "Overplot, same y-axis  ", $
                        UVALUE = viewindex, EVENT_PRO = 'zoomsync_drft')
          nsynch = WIDGET_BUTTON(zoom, $
                        VALUE = "Overplot, new y-axis", $
                        UVALUE = viewindex, EVENT_PRO = 'zoomnsync_drft')


          repr = WIDGET_BUTTON(zoombase, $
                        VALUE = " Reprocess Pixel ", $
                        UVALUE = viewindex, EVENT_PRO = 'reprocess_drft')




        ENDFOR

	controlbase = WIDGET_BASE(drftdi1_wid, $
                /ROW, $
                SPACE = 40)


;----------------- the Data controls are defined ------------------

        datcont = WIDGET_BUTTON(controlbase, VALUE='    Data    ', /MENU )

        id_2 = WIDGET_BUTTON(datcont, VALUE='Load', UVALUE='LOAD' )
        id_2 = WIDGET_BUTTON(datcont, VALUE='Show Data', UVALUE='SHOWD' )
        id_2 = WIDGET_BUTTON(datcont, VALUE='Save', UVALUE='SAVE' )

        	
;---------------- the View controls are defined -----------------

        viewcont = WIDGET_BUTTON(controlbase, VALUE='  View  ', /MENU )
        id_2 = WIDGET_BUTTON(viewcont, VALUE='Header Info ', UVALUE='HDR')
        id_2 = WIDGET_BUTTON(viewcont, VALUE='Compact Status ', UVALUE='CS')
        id_2 = WIDGET_BUTTON(viewcont, VALUE='IS Report ', UVALUE='ISREP')
        id_2 = WIDGET_BUTTON(viewcont, VALUE='Stability Stats', UVALUE='ISMANN')
        id_2 = WIDGET_BUTTON(viewcont, VALUE='Drift modelling Stats', $
        			UVALUE='ISDRIFT')
        id_2 = WIDGET_BUTTON(viewcont, VALUE='Slopes variation Stats', $
        			UVALUE='ISSLOPV')

;---------------- the Array controls are defined -----------------

        arrcont = WIDGET_BUTTON(controlbase, VALUE=' Arrays ', /MENU)

	flabel = ["Fitted final Signals", "Standard Signals", $
		  "Jump predicted final Signals"]

	fl1 = WIDGET_BUTTON(arrcont, VALUE=flabel(0), /MENU)
        dummy = WIDGET_BUTTON(fl1, $
                        VALUE = "New  ", $
                        UVALUE = '1NEW', EVENT_PRO = 'drft_showdat')
        synch = WIDGET_BUTTON(fl1, $
                        VALUE = "Overplot, same y-axis  ", $
                        UVALUE = '1SYNC', EVENT_PRO = 'drft_showdat')
        nsynch = WIDGET_BUTTON(fl1, $
                        VALUE = "Overplot, new y-axis", $
                        UVALUE = '1NSYNC', EVENT_PRO = 'drft_showdat')
	fl1 = WIDGET_BUTTON(arrcont, VALUE=flabel(1), /MENU)

	IF IS_SCP EQ 0 THEN WIDGET_CONTROL, fl1, sensitive=0  
 
        dummy = WIDGET_BUTTON(fl1, $
                        VALUE = "New  ", $
                        UVALUE = '2NEW', EVENT_PRO = 'drft_showdat')
        synch = WIDGET_BUTTON(fl1, $
                        VALUE = "Overplot, same y-axis  ", $
                        UVALUE = '2SYNC', EVENT_PRO = 'drft_showdat')
        nsynch = WIDGET_BUTTON(fl1, $
                        VALUE = "Overplot, new y-axis", $
                        UVALUE = '2NSYNC', EVENT_PRO = 'drft_showdat')
	fl1 = WIDGET_BUTTON(arrcont, VALUE=flabel(2), /MENU)

	IF STRPOS(tmpdata.mod_func, 'TCHO') EQ -1 THEN $
	   WIDGET_CONTROL, fl1, sensitive=0  
 
        dummy = WIDGET_BUTTON(fl1, $
                        VALUE = "New  ", $
                        UVALUE = '3NEW', EVENT_PRO = 'drft_showdat')
        synch = WIDGET_BUTTON(fl1, $
                        VALUE = "Overplot, same y-axis  ", $
                        UVALUE = '3SYNC', EVENT_PRO = 'drft_showdat')
        nsynch = WIDGET_BUTTON(fl1, $
                        VALUE = "Overplot, new y-axis", $
                        UVALUE = '3NSYNC', EVENT_PRO = 'drft_showdat')

;---------------- the Array controls are defined -----------------

        arrcont = WIDGET_BUTTON(controlbase, VALUE=' Parameters ', /MENU)

	
        dummy = WIDGET_BUTTON(arrcont, $
                        VALUE = "New  ", $
                        UVALUE = 'NEW', EVENT_PRO = 'drft_showpar')
        synch = WIDGET_BUTTON(arrcont, $
                        VALUE = "Overplot, same y-axis  ", $
                        UVALUE = 'SYNC', EVENT_PRO = 'drft_showpar')
        nsynch = WIDGET_BUTTON(arrcont, $
                        VALUE = "Overplot, new y-axis", $
                        UVALUE = 'NSYNC', EVENT_PRO = 'drft_showpar')


;---------------- the Processing controls are defined -----------------

        proccont = WIDGET_BUTTON(controlbase, VALUE=' Process ', $
                                /MENU )
        id_2 = WIDGET_BUTTON(proccont, $
        		VALUE=' Accept modelling in standard way',  $
                               UVALUE='ACCEPT_STD' )
        IF IS_SCP EQ 0 THEN WIDGET_CONTROL, id_2, sensitive=0                       
        id_2 = WIDGET_BUTTON(proccont, $
        		VALUE=' Accept all values from modelling',  $
                               UVALUE='ACCEPT_ALL' )
        id_2 = WIDGET_BUTTON(proccont, $
        		VALUE=' Discard all values from modelling',  $
                               UVALUE='DISCARD_ALL' )
        IF IS_SCP EQ 0 THEN WIDGET_CONTROL, id_2, sensitive=0                       
        id_2 = WIDGET_BUTTON(proccont, $
        		VALUE=' Cancel',  $
                               UVALUE='CANCEL' )

;---------------- the Pixel Choice controls are defined -----------------

        pixcont = WIDGET_BUTTON(controlbase, VALUE=' Pixels ', $
				/MENU)
        pixch = WIDGET_BUTTON(pixcont, VALUE=' Individual choice ', $
				UVALUE='PIXCH' )
        pixch = WIDGET_BUTTON(pixcont, VALUE=' Serial increment  ', $
				UVALUE='PIXCHSER' )
        pixch = WIDGET_BUTTON(pixcont, VALUE=' Serial decrement  ', $
				UVALUE='PIXCHSERD' )
        IF STRMID(tmpdata.det,0,1) EQ 'P' THEN $
        	WIDGET_CONTROL, pixcont, SENSITIVE=0

;---------------- the number of views controls is defined -----------------

        nvbut = cw_bselector(controlbase, $
                        /FRAME, SET_VALUE=NVIEWS-1, $
                        UVALUE = 'NVIEWS', $
                        ['1 Plot', $
                        '2 Plots', $
                        '3 Plots', $
                        '4 Plots'])

;----------------------------------------------------------------------
; Display refresh button

        pixcont = WIDGET_BUTTON(controlbase, VALUE=' Refresh ', $
        		UVALUE="REFRESH")
	
;----------------------------------------------------------------------


	WIDGET_CONTROL, drftdi1_wid, /REALIZE, /HOURGLASS

	FOR i = 0, nviews - 1 DO BEGIN
		WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
		view(i).windownum = temp
		pia_resetview_drft, i, view(i).controlid
           IF STRMID(tmpdata.det,0,1) EQ 'C' THEN BEGIN
                txtval = STRTRIM(STRING(i+1),2)
                WIDGET_CONTROL, pixbut(pixcho(i)), SET_VALUE = txtval
           ENDIF
	ENDFOR

	xMANAGER,No_BLOCK=1, "pia_dispdrift", drftdi1_wid, $ 
		EVENT_HANDLER = "pia_dispdrift_event", GROUP_LEADER=GROUP


	RETURN
END
