;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_DRIFT_DEFIN
;
; PURPOSE:
;	Simple Menu for choosing different drift handling methods 
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_DRIFT_DEFIN, DRIFT_DEFIN_STR
;
; INPUT:
;	(none)
;
; OUTPUT:
;	DRIFT_DEFIN_STR:	a structure containing handling to be used
;
;	
; METHOD:
;	Widgets
;	
; COMMON BLOCKS:
;	none	
;
; MODIFICATION HISTORY:
;	Written by:	C.Gabriel (ESA/ESTEC)		December 1996
;	Interactive+cancel choices included (JACOSTA)   January  1997
;-


PRO pia_drift_defin, drift_defin_str, stop


        base = WIDGET_BASE(TITLE = 'Drift handling', /column, xsize=250)


	driftm = 0
	negroup = cw_bgroup(base, LABEL_TOP = 'Drift handling choices', $
                        /NONEXCLUSIVE, /FRAME, $
                        SET_VALUE = [1,0,driftm], $
                        UVALUE = 'STANDARD', $
                        ["Stability recognition", "Slopes variation ", $
                         "Drift modelling "])
                        
	exgroup = cw_bgroup(base, LABEL_TOP = 'Drift modelling choices', $
                        /NONEXCLUSIVE, /FRAME, $
                        SET_VALUE = [0,1], $
                        UVALUE = 'SETPAR', $
                        ["Set initial parameters   ",$
                         "Use Post-Interactive mode"]) 
                        
	WIDGET_CONTROL, exgroup, sensitive=driftm

        rowbase = WIDGET_BASE(base, /ROW)

	ok_id = WIDGET_BUTTON(rowbase,   VALUE='   OK   ', UVALUE='OK',XSIZE=122)
	canc_id = WIDGET_BUTTON(rowbase, VALUE=' CANCEL ', UVALUE='CANCEL', $
	           XSIZE=122)
	
	WIDGET_CONTROL, base, /REALIZE

	ok = 0
	
	WHILE ok EQ 0 DO BEGIN
	  event = WIDGET_EVENT(BASE)
	  WIDGET_CONTROL, event.id, GET_UVALUE=Uvalue
	  
	  CASE 1 OF 
	    uvalue EQ 'OK': BEGIN
	  	WIDGET_CONTROL, negroup, GET_VALUE=value
	   	  stab = value(0)
	   	  slopv = value(1)
	          driftm = value(2)
	  	WIDGET_CONTROL, exgroup, GET_VALUE=value
	    	  param = value(0)
	    	  interact = value(1)
	   
 	   	drift_defin_str={stab:stab, slopv:slopv, driftm:driftm, $ 
 	          param:param, interact:interact}
	    	ok = 1
	    	stop=0
	     END
	     
	    uvalue EQ 'CANCEL': BEGIN 
	     	stop=1
	     	ok = 1
	     END
	    
	    uvalue EQ 'STANDARD': BEGIN 
	  	WIDGET_CONTROL, negroup, GET_VALUE=value
		driftm = value(2)
		WIDGET_CONTROL, exgroup, sensitive=driftm
	     END

	    ELSE: 
	  ENDCASE
	        
	ENDWHILE
	WIDGET_CONTROL, base, /DESTROY

        RETURN
END

