;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_DRIFT_INIPAR
;
; PURPOSE:
;	Menu for project signals algorithm parameters handling.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_DRIFT_INIPAR, det, GROUP=group 
;
; INPUT:
;	det: The detector to be drift modelled
;
; KEYWORD PARAMETERS:
;	GROUP:	The group leader of the widget hirarchy
;	
; RESTRICTIONS:
;	TMPDATA must be a valid PHTSRD temporary structure
;	
; COMMON BLOCKS:
;	colour_indices
;	not_acc
;	pia_driftmod_cmn
;	pia_drift_par 
;		
; PROCEDURES USED:
;	PIA LIB:
;		decode_admn
;		drift_mod_proc
;		pia_disp_print_file
;		pia_load_driftpar
;		pia_xplot
;       INTERNAL:
;		pia_drift_mod_event
;
; MODIFICATION HISTORY:
;	Written by: JAcosta (IAC/VILSPA-SAI)		October 1996
;	Version 5.1 - Oct.96
;	/Modal use according to IDL >= 5.0 (CG)
;	V7.3
;			
;-
; *********************************************************************
; *  Event routine for PIA_DRIFT_INIPAR
; *********************************************************************
PRO PIA_DRIFT_INIPAR_EVENT, event

  
COMMON PIA_DRIFT_INIPAR_CMN, drift_stop, tmp_det
COMMON PIA_DRIFT_PAR, pia_drift_par 
COMMON DFFUNCT_INFO, funct_info


	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	IF uvalue(0) EQ 'JUNK' THEN RETURN
	
	maxnpar = funct_info.maxnpar

;	wids = {id_minp:minpext_id, id_frac:fractleft_id, id_weig:weightm_id,	$
;			id_discval: discval_id,					$
;			id_func:funct_id, lab:wid_lab, id_lab:wid_id_lab, 	$
;			id_lmin:wid_id_lmin, id_lmax:wid_id_lmax, 		$
;			id_luse:wid_id_luse, id_fix:wid_id_fix, 		$
;			id_ftxt:wid_funtxt, id_chisq:chisqt_id}
			
	WIDGET_CONTROL, event.top, GET_UVALUE=wids_handle
	handle_value, wids_handle, wids


	CASE uvalue(0) OF

	
	'DISCVAL': BEGIN
		WIDGET_CONTROL, wids.id_discval, GET_VALUE = discval_md
		; set corresponding value to be discarded
		; value 1 means use minimum time, 0 use fraction of measurement
	        if discval_md THEN  fractleft = pia_drift_par.mintime $
	            ELSE fractleft = pia_drift_par.fract_left
		WIDGET_CONTROL, wids.id_frac, SET_VALUE=STRTRIM(fractleft,2)
        END

	           

        'FUNCTION': BEGIN
                WIDGET_CONTROL, event.top, /HOURGLASS
                WIDGET_CONTROL, wids.id_func, GET_VALUE=s_funct
                
                ; Reinitializes the fit_par_str if the function is changed
 
                nfunct_par = funct_info.npar(s_funct(0))
                wid_lab = funct_info.parlabel.(s_funct(0)) 
                wid_luse = strtrim(funct_info.prange.(s_funct(0)),2)
                wid_fix = strtrim(funct_info.avar.(s_funct(0)),2)     
                WIDGET_CONTROL, wids.id_ftxt, $ 
                     SET_VALUE=funct_info.lst(2,s_funct(0))
 
                  FOR I=0,nfunct_par-1 DO BEGIN
                        WIDGET_CONTROL, wids.id_fix(i), /SENSITIVE
                        WIDGET_CONTROL, wids.id_lmin(i), /SENSITIVE
                        WIDGET_CONTROL, wids.id_lmax(i), /SENSITIVE
                        WIDGET_CONTROL, wids.id_luse(i), /SENSITIVE
                        WIDGET_CONTROL, wids.id_lab(i), $ 
                            SET_VALUE=STRING(wid_lab(i),format='(a13)')
                        WIDGET_CONTROL, wids.id_fix(i), $
                          SET_VALUE=STRTRIM(wid_fix(i),2)
                        WIDGET_CONTROL, wids.id_luse(i), $
                          SET_VALUE= wid_luse(2,i)
                        WIDGET_CONTROL, wids.id_lmax(i), $
                          SET_VALUE= wid_luse(1,i)
                        WIDGET_CONTROL, wids.id_lmin(i), $
                          SET_VALUE= wid_luse(0,i)
                   ENDFOR
                   
                   if maxnpar-nfunct_par gt 0 then begin
                    for i=nfunct_par, maxnpar-1 do begin
                      WIDGET_CONTROL, wids.id_lab(i), SET_VALUE='          '
                      WIDGET_CONTROL, wids.id_fix(i), SENSITIVE=0
                      WIDGET_CONTROL, wids.id_lmin(i), SENSITIVE=0
                      WIDGET_CONTROL, wids.id_lmax(i), SENSITIVE=0
                      WIDGET_CONTROL, wids.id_luse(i), SENSITIVE=0
                    endfor
                   endif 
                 
        END

	'DEF': BEGIN

		  wid_lab = pia_drift_par.p_label 
        	  ind_funct = where(funct_info.lst(1,*) eq pia_drift_par.ffunct) 
         	  nfunct_par = funct_info.npar(ind_funct(0))

                 WIDGET_CONTROL, wids.id_func,  $
                          SET_VALUE= ind_funct(0)
		           	  
                 WIDGET_CONTROL, wids.id_ftxt,  $
                          SET_VALUE=funct_info.lst(2,ind_funct(0))
		  
	          WIDGET_CONTROL, wids.id_minp, $ 
	               SET_VALUE=STRTRIM(pia_drift_par.minp_ext,2)
	          WIDGET_CONTROL, wids.id_discval, $
	               SET_VALUE=pia_drift_par.use_mintime
	          IF pia_drift_par.use_mintime THEN            $ 
	             fractleft =  pia_drift_par.mintime        $
	            ELSE fractleft = pia_drift_par.fract_left        
	          WIDGET_CONTROL, wids.id_frac, $
	               SET_VALUE=STRTRIM(fractleft,2)
	          WIDGET_CONTROL, wids.id_chisq, $ 
	               SET_VALUE=STRTRIM(pia_drift_par.chisqtol,2)
	          WIDGET_CONTROL, wids.id_weig, $ 
	               SET_VALUE= STRTRIM(pia_drift_par.weigthm,2)
		 
                  FOR I=0,nfunct_par-1 DO BEGIN
                        WIDGET_CONTROL, wids.id_fix(i), /SENSITIVE
                        WIDGET_CONTROL, wids.id_lmin(i), /SENSITIVE
                        WIDGET_CONTROL, wids.id_lmax(i), /SENSITIVE
                        WIDGET_CONTROL, wids.id_luse(i), /SENSITIVE
                        WIDGET_CONTROL, wids.id_lab(i), SET_VALUE=wid_lab(i)
                        WIDGET_CONTROL, wids.id_fix(i), $
                          SET_VALUE=STRTRIM(STRING(pia_drift_par.a_var(i)),2)
                  ENDFOR

                   if maxnpar-nfunct_par gt 0 then begin
                    for i=nfunct_par, maxnpar-1 do begin
                      WIDGET_CONTROL, wids.id_lab(i), SET_VALUE='          '
                      WIDGET_CONTROL, wids.id_fix(i), SENSITIVE=0
                      WIDGET_CONTROL, wids.id_lmin(i), SENSITIVE=0
                      WIDGET_CONTROL, wids.id_lmax(i), SENSITIVE=0
                      WIDGET_CONTROL, wids.id_luse(i), SENSITIVE=0
                    endfor
                   endif
                   
		
	END
	
	'CANCEL': BEGIN

		drift_stop = 1
		WIDGET_CONTROL, event.top, /DESTROY
			
	END
	'ACCEPT': BEGIN
		WIDGET_CONTROL, event.top, /HOURGLASS
	        WIDGET_CONTROL, wids.id_func, GET_VALUE=s_funct

		ind_funct =  s_funct(0)  
		
		nfunct_par =  funct_info.npar(ind_funct(0))
		
		set_driftpar_srd,0,drift_par,/DEFAULT, $
		    FFUNCT= funct_info.lst(1,ind_funct(0)), DET = tmp_det
		     

		WIDGET_CONTROL, wids.id_discval, GET_VALUE=discval_md
		drift_par.use_mintime = discval_md
		WIDGET_CONTROL, wids.id_frac, GET_VALUE=s_fractleft
	        IF discval_md THEN 					$ 
	            drift_par.mintime = FLOAT(s_fractleft(0)) 		$
	         ELSE 							$
		    drift_par.fract_left = FLOAT(s_fractleft(0))
		WIDGET_CONTROL, wids.id_minp, GET_VALUE=s_minpext
		 drift_par.minp_ext = FLOAT(s_minpext(0))
	        WIDGET_CONTROL, wids.id_func, GET_VALUE=s_funct
	         drift_par.ffunct = funct_info.lst(1,s_funct(0))
		WIDGET_CONTROL, wids.id_chisq, GET_VALUE=s_chisqt
		 drift_par.chisqt = FLOAT(s_chisqt(0))
		WIDGET_CONTROL, wids.id_weig, GET_VALUE=s_weightm
		 drift_par.weightm = s_weightm(0)

 		FOR i=0, nfunct_par-1 DO BEGIN
		 WIDGET_CONTROL, wids.id_fix(i), GET_VALUE=value
		  drift_par.a_var(i) = FIX(value(0))
                 WIDGET_CONTROL, wids.id_luse(i), GET_VALUE=value
                  drift_par.p_range(2,i) = FLOAT(value(0))
                 WIDGET_CONTROL, wids.id_lmin(i), GET_VALUE=value
                  drift_par.p_range(0,i) = FLOAT(value(0))
                 WIDGET_CONTROL, wids.id_lmax(i), GET_VALUE=value
                  drift_par.p_range(1,i) = FLOAT(value(0))
 		ENDFOR
		
		pia_drift_par = drift_par
		
		drift_stop = 0
				
		WIDGET_CONTROL, event.top, /DESTROY
	END
	ELSE:
	
	ENDCASE
	
RETURN
END
; *********************************************************************
; *  Menu for PIA_DRIFT_MOD
; *********************************************************************
PRO PIA_DRIFT_INIPAR, det, istop, GROUP=group 

COMMON PIA_DRIFT_INIPAR_CMN, choice, tmp_det
COMMON PIA_DRIFT_PAR, pia_drift_par 
COMMON DFFUNCT_INFO, funct_info

; Return if already active
	IF XRegistered("pia_drift_inipar") THEN BEGIN
		MESSAGE, /INFO, 'Menu already active, returning'
		RETURN
	ENDIF

;check if fit function parameters are defined
if n_elements(funct_info) eq 0 then dffunct_info

tmp_det = det 

ind_det = WHERE(funct_info.det_def EQ tmp_det)
IF n_elements(pia_drift_par) gt 0 THEN  ffunct = pia_drift_par.ffunct $
  ELSE BEGIN
      ;;ffunct= funct_info.det_deffunct(ind_det(0))
      set_driftpar_srd,0,pia_drift_par, /DEFAULT, DET= tmp_det
  ENDELSE
	   	
ind_funct = where(funct_info.lst(1,*) eq ffunct,nf)
	    
        maxnpar = funct_info.maxnpar

	def_val = strarr(5)
	def_avar = strarr(maxnpar)
	def_prange = strarr(3,maxnpar)
	
	; discarding values 
	use_mintime = pia_drift_par.use_mintime
	IF use_mintime THEN discval = pia_drift_par.mintime      $
	   ELSE discval = pia_drift_par.fract_left 

	def_val(0) = [string(pia_drift_par.minp_ext), 	$
		     string(discval), 			$
		     string(pia_drift_par.ffunct),  	$
		     string(pia_drift_par.chisqt),	$
		     pia_drift_par.weightm ]
		     
        nfunct_par = funct_info.npar(ind_funct(0))
        for i=0, nfunct_par-1 do begin 
           def_avar(i) = pia_drift_par.a_var(i)
           def_prange(*,i) = pia_drift_par.p_range(*,i)
        endfor    
	    
	IF not KEYWORD_SET(group) THEN group = !pia_top_wid
	base = WIDGET_BASE(TITLE=" PIA Signal drifts modelling ", /COLUMN,$
				/MODAL, GROUP=group)
	
	parbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(parbase, $
		              VALUE ='Minimum of points for algorithm:   ')
	label = WIDGET_LABEL(parbase, VALUE='           ')
	minpext_id = WIDGET_TEXT(parbase, /EDITABLE, VALUE=STRTRIM(def_val(0),2), $
		UVALUE='JUNK', XSIZE=8)
		
        discard_val = ['Fraction of measurement left out (%):', $
                       'Initial Time not considered      (s):'] 		

	parbase = WIDGET_BASE(base, /ROW)
	discval_id = CW_BSELECTOR(parbase, discard_val, UVALUE='DISCVAL')
	WIDGET_CONTROL, discval_id, SET_VALUE = use_mintime
	label = WIDGET_LABEL(parbase, VALUE='        ')
	fractleft_id = WIDGET_TEXT(parbase, /EDITABLE, $
	        VALUE=STRTRIM(def_val(1),2), UVALUE='JUNK', XSIZE=8)

	parbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(parbase, $
		VALUE='Chi^2 / DoF tolerance level:         ')
	label = WIDGET_LABEL(parbase, VALUE='         ')
	chisqt_id = WIDGET_TEXT(parbase, /EDITABLE, $
	        VALUE=STRTRIM(def_val(3),2), UVALUE='JUNK', XSIZE=8)

	parbase = WIDGET_BASE(base, /ROW) 
	weightm_id = CW_BSELECTOR(parbase, funct_info.weightm(*), $
	   UVALUE='WEIGHTM', $
	   LABEL_LEFT='Weighting method to be used:              ')
	   
	
	parbase = WIDGET_BASE(base, /ROW) 
	funct_id = CW_BSELECTOR(parbase, funct_info.lst(0,*), $
	   UVALUE='FUNCTION', $
	   LABEL_LEFT='Fitting function to be used:              ')
	WIDGET_CONTROL, funct_id, SET_VALUE = ind_funct(0)   
	
	wid_funtxt = WIDGET_LABEL(base, VALUE=funct_info.lst(2,ind_funct(0)))
	junk = WIDGET_LABEL(base, VALUE='    ')
	
        wid_lab = make_array(maxnpar,value=string(" ",format='(a13)'))
        wid_id_lab = lonarr(maxnpar)
        wid_id_sens = lonarr(maxnpar)
        wid_id_val = lonarr(maxnpar)
        wid_id_lmin = lonarr(maxnpar)
        wid_id_lmax = lonarr(maxnpar)
        wid_id_luse = lonarr(maxnpar)
        wid_id_fix = lonarr(maxnpar)
 
        wid_lab(0) = STRING(pia_drift_par.p_label,format='(A13)')
        wid_id_sens(0:nfunct_par-1) = 1
 
        par0base = WIDGET_BASE(base, /column, /FRAME)
        parbase = WIDGET_BASE(par0base, /column)
        parlabel = $
            'Parameter    Var/Fix  Lower lim  Upper lim    Limits'
 
        label = WIDGET_LABEL(parbase, VALUE=parlabel)
  
        FOR i=0,maxnpar-1 DO BEGIN
         parbase = WIDGET_BASE(par0base, /ROW)
         wid_id_lab(i) = WIDGET_LABEL(parbase, VALUE=WID_lab(i))
         label = WIDGET_LABEL(parbase, VALUE='   ')
         wid_id_fix(i) = CW_BSELECTOR(parbase, ["FIX","VAR"], $
                        UVALUE = 'JUNK')
         WIDGET_CONTROL, wid_id_fix(i), SENSITIVE = wid_id_sens(i)
         WIDGET_CONTROL, wid_id_fix(i), SET_VALUE = def_avar(i), $
             SENSITIVE = wid_id_sens(i)
         wid_id_lmin(i) = WIDGET_TEXT(parbase, /EDITABLE, $
                VALUE=STRTRIM(def_prange(0,i),2), $
                UVALUE='JUNK', XSIZE=8)
         WIDGET_CONTROL, wid_id_lmin(i), SENSITIVE = wid_id_sens(i)
         wid_id_lmax(i) = WIDGET_TEXT(parbase, /EDITABLE, $
                VALUE=STRTRIM(def_prange(1,i),2), $
                UVALUE='JUNK', XSIZE=8)
         WIDGET_CONTROL, wid_id_lmax(i), SENSITIVE = wid_id_sens(i)
         luse = string(["Not Used", "Absolute","Relative"],format='(a11)')
         wid_id_luse(i) = cw_bselector(parbase, luse, UVALUE = 'JUNK')
         WIDGET_CONTROL, wid_id_luse(i), SET_VALUE = def_prange(2,i), $
             SENSITIVE = wid_id_sens(i)
        ENDFOR
 
 
				
	cont_base = WIDGET_BASE(base, /ROW)
			
	def_id = WIDGET_BUTTON(cont_base, VALUE='Default Par', UVALUE='DEF')
	
	acce_id = WIDGET_BUTTON(cont_base, VALUE= 'Accept ', $
		UVALUE= 'ACCEPT')
	
	canc_id = WIDGET_BUTTON(cont_base, VALUE= 'Cancel ', $
		UVALUE= 'CANCEL')

	wids = {id_minp:minpext_id, id_frac:fractleft_id, id_weig:weightm_id,	$
			id_discval: discval_id,					$
			id_func:funct_id, lab:wid_lab, id_lab:wid_id_lab, 	$
			id_lmin:wid_id_lmin, id_lmax:wid_id_lmax, 		$
			id_luse:wid_id_luse, id_fix:wid_id_fix, 		$
			id_ftxt:wid_funtxt, id_chisq:chisqt_id}
			
	wids_handle = handle_create()
	handle_value, wids_handle, wids, /SET
	 
        WIDGET_CONTROL, base, /REALIZE, TLB_SET_XOFFSET=150, $
                        TLB_SET_YOFFSET=150, SET_uvalue=wids_handle

        xMANAGER,No_BLOCK=1, "pia_drift_inipar", base, GROUP=group
        
        istop = choice
	
        RETURN
END
	
