;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_DRIFT_MOD
;
; PURPOSE:
;	Menu for modelling PHT signals' drifts. 
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_DRIFT_MOD, tmpdata, pixel, sig_disc, degl_acc, degl_set
;
; INPUT:
;	tmpdata:	A phtsrd like temporary structure
;	pixel:		The pixel number of the data to be used
;	sig_disc:	Flag array corresponding to tmpdata.slop (0:OK,1:BAD)
;	degl_acc:	Flag array corresponding to deglitched points (same)
;	degl_set:	Flag indicating validity of degl_acc
;
; KEYWORD PARAMETERS:
;	GROUP:		The group leader of the widget hirarchy
;	FITRESULTS:	If set, widget prepared for reprocess results
;			(comm. through CB  pia_driftmod_out)
;	
; RESTRICTIONS:
;	TMPDATA must be a valid PHTSRD temporary structure
;	
; COMMON BLOCKS:
;	colour_indices
;	not_acc
;	pia_driftmod_cmn
;	pia_drift_par 
;	pia_driftmod_out
;		
; PROCEDURES USED:
;	PIA LIB:
;		decode_admn
;		drift_mod_proc
;		pia_disp_print_file
;		pia_load_driftpar
;		pia_xplot
;       INTERNAL:
;		pia_drift_mod_event
;
; MODIFICATION HISTORY:
;	Written by: C.Gabriel (ESA/VILSPA-SAI)		August 1996
;	Change call of drift_mod_proc, suppressing
;	 chopped keyword  (J.Acosta)			October 1996
;	Version 5.0 - Aug.96
;	Extended for reprocessing results (Keyword FITRESULTS)
;	 CG -						February 1997
;	Version 6.1
;			
;-
; *********************************************************************
PRO print_fitmodel, tmpfitpar_str, MEASID= measid, GROUP = group

COMMON DFFUNCT_INFO, funct_info

	        curr_find = WHERE(funct_info.lst(1,*) EQ tmpfitpar_str.mod_func)
	        curr_find = curr_find(0) 
		fct_used = funct_info.lst(0,curr_find)
		   
		nparfunct = funct_info.npar(curr_find)

		txtalt = ['  No convergence',$
		       		  '  Parameter(s) out of limits', $
		       		  '  Chi-square too high   ', $
		       		  '  Function specific constraint violated', $
		       		  '  Function specific constraint violated']
		IF STRPOS('Fouks',fct_used) NE -1 THEN $
		          txtalt(3:4) = $
		             ['  Violation of cond.: S_ini - Beta*S(t) > 0 ',$
		       	      '  Temperature condition violated '] 


	        IF strpos(tmpfitpar_str.mod_func,'_RST_') gt -1 THEN BEGIN
	           allrst = 1 
                   ntsteps = tmpfitpar_str.nparams - nparfunct + 1
                   indpar = INDGEN(nparfunct*ntsteps) MOD nparfunct
                   FOR ist = 1, ntsteps-1 DO indpar(ist*nparfunct) = $ 
                       nparfunct -1 + ist
	        ENDIF ELSE BEGIN
	           allrst = 0
                   ntsteps = tmpfitpar_str.neff_steps
                   indpar = INDGEN(nparfunct)
	        ENDELSE   
	             		

		text = ['      Model Transient Signal results ', $
			'      ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~', ' ']

		IF NOT KEYWORD_SET(measid) THEN $ 
                   decode_admn, tmpfitpar_str.tdtnr, measid
		text = [text, 'Measurement:   '+measid]
		
		fct_used = strtrim(funct_info.lst(0,curr_find),2)
		text = [text, ' ', 'Function used is '+ fct_used ]
		     
		IF tmpfitpar_str.use_mintime THEN 			$
		    discval_md_txt = 'Initial time not used: ' +      	$
		    STRING(tmpfitpar_str.mintime,format="(F6.1)")	$ 
		  ELSE discval_md_txt = 'Fraction not used at begin: '+ $
		    STRING(tmpfitpar_str.fract_left,format="(F7.2)")   
		text = [text, ' ', 'General parameters :', 		$
		        'Minimum number of points:   ' + 		$
		        STRTRIM(tmpfitpar_str.minp_ext,2), 		$  
		        discval_md_txt, 				$  
		        'Weighting Method:           ' + 		$
		        tmpfitpar_str.weightm, 			$
		        'Number of effective steps:  ' + 		$ 
		        STRTRIM(tmpfitpar_str.neff_steps,2), ' ']  

		invar = WHERE(tmpfitpar_str.a_var(0,0,*) EQ 1, nvar)
		IF nvar EQ 0 THEN text = [text, 'All parameters were fixed ']
		
		   text = [text,'========================================',''] 
				
		if strpos(funct_info.lst(1,curr_find),'CHO') gt -1 then fchopp=1 $
		    else fchopp =0 

		;
		;write information into a window which can be printed/saved
		;

		tab_tit = 'Step ' + '  Mod Sig.   Err    '
		FOR ipar=0, nparfunct-1 DO tab_tit = tab_tit + STRING(       $ 
			funct_info.parlabel.(curr_find)(ipar),'Err','Var',   $
			FORMAT='(2x,A9,3x,A4,6x,A3)')
		tab_tit = tab_tit + '    Chi^2/dof  Flag Model_success '
		
		text = [text, tab_tit]

		FOR istp = 0, ntsteps-1 DO BEGIN 
		  step_tmp = istp * (1-allrst)
                  tab_ent = STRING(STRTRIM(istp+1,2),                           $
                      tmpfitpar_str.signal(0,istp),                             $
                      tmpfitpar_str.err(0,istp),FORMAT='(I3,2x,2(1x,G9.3))')
		  FOR ipar=0,nparfunct-1 DO BEGIN
		      indpar_tmp = indpar(ipar+istp*nparfunct*allrst)
		      tab_ent = tab_ent + STRING(                               $
		         tmpfitpar_str.param(0,step_tmp,indpar_tmp),            $
			 tmpfitpar_str.sg_param(0,step_tmp,indpar_tmp),         $
			 tmpfitpar_str.a_var(0,step_tmp,indpar_tmp),            $
                         FORMAT='(1x,2(2x,G9.3),3x,I1)')
                  ENDFOR
		  tab_ent = tab_ent + STRING(tmpfitpar_str.chisq(0,step_tmp),   $
                           tmpfitpar_str.flag(0,step_tmp),                      $
                           FORMAT='(2x,G8.2,4x,I3)')
               
	          decode_flag, tmpfitpar_str.flag(0,step_tmp),5, flarr
		  indflg = WHERE(flarr NE 0, nflg)
		  FOR ifl = 0, nflg-1 DO tab_ent = tab_ent + txtalt(indflg(ifl)) $
                                + ' '

                  text = [text, tab_ent]

	        ENDFOR
     
		
		pia_disp_print_file, tmpfitpar_str.tdtnr, $
		        TITLE='Signal Drift Modelling',$
			GROUP=group, TEXT=text, HEIGHT=20, WIDTH=150
		

  
END

; *********************************************************************
PRO plot_fitmodel, time, slop, slun, flag, tmpfitpar_str, TITLE=title, $
     LEGEND = legend, NODATA = nodata 
 
@colour_indices
		;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
		;make a plot with the fitted model
		;
		; plot signal
		pia_xplot, time, slop, slun, psym=4, $
			title=title, $
			xtitle='Time  [s]', ytitle='Signal   [V/s]', $
			legend=legend, color= white

		; plot flagged points
		 ind_nval = where(tmpfitpar_str.slop_flag(0,*) gt 1, nnval)
		 IF nnval GT 0 THEN $
		  pia_xplot, time(ind_nval), slop(ind_nval), psym=7, $
		       legend='Rejected Points', color=red, /overplot
		       
		; plot fitted points
		 ind_val = WHERE(tmpfitpar_str.slop_flag(0,*) LE 1, nval)
		 IF nval GT 0 THEN BEGIN
		  ;pia_xplot, time(ind_val), tmpfitpar_str.slop(0,ind_val), $
		  ;	psym=-3, legend='Model Fitted', color=orange,       $
		  ;	thick=2.5, /overplot
		  pia_xplot, time, tmpfitpar_str.slop(0,*), psym=-3, $
		  	legend='Model Fitted', color=orange,       $
		  	thick=2.5, /overplot
		  
		
		; plot final values	
		  n_sig = n_elements(tmpfitpar_str.time_sg)
		  time_sg = [time(0),tmpfitpar_str.time_sg]
		  signal =  tmpfitpar_str.signal
		  sz_tmp = size(signal)
		  if sz_tmp(0) eq 2 then signal = reform(signal)
		  final_sg = 0. &  final_ti = 0.
		  for is = 0, n_sig-1 do begin
		        final_sg = [final_sg, signal(is), signal(is)]
		    	final_ti = [final_ti, time_sg(is),time_sg(is+1)]
		  endfor
		  pia_xplot, final_ti(1:*), final_sg(1:*), color=green, $
		            legend = 'Final value ',psym=-3,/overplot

                ENDIF

END

PRO PLOT_FITRESI, time, slop, tmpfitpar_str, TITLE= title, LEGEND = legend, $ 
     OPLOT = oplot
 
@colour_indices

		  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
		  ;make a plot with the residuals 
		  ;
		  ;compute residual
		  ind_val = WHERE(tmpfitpar_str.slop_flag LE 1,nval)
		  IF nval EQ 0 THEN RETURN
		  res_fit = tmpfitpar_str.slop(0,ind_val) - slop(0,ind_val)
		  
		  IF NOT KEYWORD_SET(title) THEN title = 'Fit residuals '+dec

 		  pia_xplot, time(ind_val), res_fit, psym=1, $
		        title=title, xtitle='Time  [s]',  $
			ytitle='Residuals   [V/s]',legend=legend, $ 
			overplot = oplot, color= yellow

		   zero_ref = time*0. 	
		   pia_xplot, time, zero_ref, linestyle=2, overplot=99, $
		         color=yellow, symsize=0.5
		
END

; *********************************************************************
; *  Event routine for PIA_DRIFT_MOD
; *********************************************************************
PRO PIA_DRIFT_MOD_EVENT, event

COMMON PIA_DRIFTMOD_CMN, tmpdata1, pix1, cmodetmp, tmpfitpar_str1, $ 
       tmpfitpar_str_def, tmpfitpar_str2, def_val, ntsteps, curr_step, $
       curr_find, new_step, indpar, allrst
COMMON pia_plot_over_cmn, pl_ids, over_state
COMMON pia_driftmod_out, out_fitpar_str, out_fitacc 

COMMON PIA_DRIFT_PAR, pia_drift_par 
COMMON DFFUNCT_INFO, funct_info

@colour_indices

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	IF uvalue(0) EQ 'JUNK' THEN RETURN

        time = tmpdata1.stim
	slop = tmpdata1.slop(pix1,*)
	slun = tmpdata1.slun(pix1,*)
	flag = tmpdata1.flag(pix1,*)
	rpid = tmpdata1.rpid(*,*)
	step = tmpdata1.step        
	det  = tmpdata1.det
	tempe= tmpdata1.temp
	maxnpar = funct_info.maxnpar
        nfunct_par = funct_info.npar(curr_find) 

	
	IF n_elements(pia_drift_par) eq 0 THEN BEGIN
		set_driftpar_srd, tmpfitpar_str1, drift_par
		pia_drift_par = drift_par
	ENDIF	

	WIDGET_CONTROL, event.top, GET_UVALUE=wids

;	wids = {id_minp:minpext_id, id_frac:fractleft_id, id_func:funct_id,	$
;			id_chngstep:wid_id_step , id_chngstep_ok: wid_changok,  $
;			id_discval: discval_id,					$
;			id_curstep:wid_curr_step, id_weig:weightm_id,		$ 
;			lab:wid_lab, id_lab:wid_id_lab, id_val:wid_id_val, 	$
;			id_lmin:wid_id_lmin, id_lmax:wid_id_lmax, 		$
;			id_luse:wid_id_luse, id_fix:wid_id_fix, 		$
;			id_allsteppar:wid_id_allsteppar, 			$
;			id_allstepvar:wid_id_allstepvar, 			$
;			id_ftxt:wid_funtxt, id_chisq:chisqt_id, 	        $
;			id_plotres:plotres_id}

;	; set parameter to all steps
;	IF strmid(uvalue(0),0,11) eq 'ALLSTEP_PAR' THEN BEGIN
;	  ipar = fix(strmid(uvalue(0),11,1))
;	  WIDGET_CONTROL, wids.id_val(ipar), GET_VALUE = value
;	  FOR istp = 0, ntsteps-1 DO BEGIN 
;	     step_tmp = istp * (1-allrst)
;	     indpar_tmp = indpar(ipar+istp*nfunct_par*allrst)
;	     tmpfitpar_str1.param(0,step_tmp,indpar_tmp) = FLOAT(value)
;	  ENDFOR    
;	ENDIF
	  
;	; set variable or fix to all steps
;	IF strmid(uvalue(0),0,11) eq 'ALLSTEP_VAR' THEN BEGIN
;	  ipar = fix(strmid(uvalue(0),11,1))
;	  WIDGET_CONTROL, wids.id_fix(ipar), GET_VALUE = value
;	  FOR istp = 0, ntsteps-1 DO BEGIN 
;	     step_tmp = istp * (1-allrst)
;	     indpar_tmp = indpar(ipar+istp*nfunct_par*allrst)
;	     tmpfitpar_str1.a_var(0,step_tmp,indpar_tmp) = FIX(value) 
;	  ENDFOR    
;	ENDIF
	
	uval_case = STRTRIM(STRMID(uvalue(0),0,11),2)  

	CASE uval_case OF

	'FIXVAR_PAR': BEGIN 
		ipar = fix(STRMID(uvalue(0),11,1))
		WIDGET_CONTROL, wids.id_fix(ipar), GET_VALUE = value
		step_tmp = curr_step * (1-allrst)
		indpar_tmp = indpar(ipar+curr_step*nfunct_par*allrst)
		tmpfitpar_str1.a_var(0,step_tmp,indpar_tmp) = FIX(value)
	END
	
	'ALLSTEP_VAR': BEGIN 
	; set same parameter value to all steps
	        ipar = fix(strmid(uvalue(0),11,1))
	        WIDGET_CONTROL, wids.id_fix(ipar), GET_VALUE = value
	        FOR istp = 0, ntsteps-1 DO BEGIN 
	          step_tmp = istp * (1-allrst)
	          indpar_tmp = indpar(ipar+istp*nfunct_par*allrst)
	          tmpfitpar_str1.a_var(0,step_tmp,indpar_tmp) = FIX(value) 
	        ENDFOR    
	END
	
	'ALLSTEP_PAR': BEGIN 
	; set variable or fix to all steps
	        ipar = fix(strmid(uvalue(0),11,1))
	        WIDGET_CONTROL, wids.id_val(ipar), GET_VALUE = value
	        FOR istp = 0, ntsteps-1 DO BEGIN 
	          step_tmp = istp * (1-allrst)
	          indpar_tmp = indpar(ipar+istp*nfunct_par*allrst)
	          tmpfitpar_str1.param(0,step_tmp,indpar_tmp) = FLOAT(value)
	        ENDFOR    
	END
	
	'CHANGSTEP': BEGIN
		WIDGET_CONTROL, event.top
		WIDGET_CONTROL, wids.id_chngstep, GET_VALUE = step_val
		new_step = fix(step_val(0))-1
		WIDGET_CONTROL, wids.id_chngstep_ok, /SENSITIVE
		WIDGET_CONTROL, wids.id_chngstep_ok, /INPUT_FOCUS
	END	
	
	'CHANGOK': BEGIN
		if new_step ge ntsteps then return
		WIDGET_CONTROL, event.top,/HOURGLASS
		;save the value of the current parameters and their limits
		;just in case they have been changed.  
                step_tmp = curr_step * (1-allrst)
                nfunct_par = funct_info.npar(curr_find)
		FOR i=0, nfunct_par-1 DO BEGIN
		   indpar_tmp = indpar(i+curr_step*nfunct_par*allrst)
		   WIDGET_CONTROL, wids.id_val(i), GET_VALUE=value
		   tmpfitpar_str1.param(0,step_tmp,indpar_tmp) = FLOAT(value(0))
		   WIDGET_CONTROL, wids.id_fix(i), GET_VALUE=value
		   tmpfitpar_str1.a_var(0,step_tmp,indpar_tmp) = FIX(value(0))
		   WIDGET_CONTROL, wids.id_lmin(i), GET_VALUE=value
		   tmpfitpar_str1.prange(0,step_tmp,0,indpar_tmp) = $
		       FLOAT(value(0))
		   WIDGET_CONTROL, wids.id_lmax(i), GET_VALUE=value
		   tmpfitpar_str1.prange(0,step_tmp,1,indpar_tmp) = $
		       FLOAT(value(0))
		   WIDGET_CONTROL, wids.id_luse(i), GET_VALUE=value
		   tmpfitpar_str1.prange(0,step_tmp,2,indpar_tmp) = $
		       FIX(value(0))
		ENDFOR   
		;now new_step becomes the current step
		curr_step = new_step 
		;def_val(5) = tmpfitpar_str1.param(0,curr_step,*)
		label = 'Chopper/Raster step ' + strtrim(curr_step+1,2) + $
	            ' -- Total steps: ' + strtrim(ntsteps,2)
	        WIDGET_CONTROL, wids.id_curstep, SET_VALUE = label
	            
                step_tmp = curr_step * (1-allrst)
		FOR i=0, funct_info.npar(curr_find)-1 DO BEGIN
		   indpar_tmp = indpar(i+curr_step*nfunct_par*allrst)
		   WIDGET_CONTROL, wids.id_val(i),$
		   SET_VALUE=STRTRIM(             $  
		          tmpfitpar_str1.param(0,step_tmp,indpar_tmp),2)
		   WIDGET_CONTROL, wids.id_fix(i), SET_VALUE=                $
		          tmpfitpar_str1.a_var(0,step_tmp,indpar_tmp)
		   WIDGET_CONTROL, wids.id_lmin(i),SET_VALUE= STRTRIM(       $
		          tmpfitpar_str1.prange(0,step_tmp,0,indpar_tmp),2) 
		   WIDGET_CONTROL, wids.id_lmax(i),SET_VALUE= STRTRIM(       $
		          tmpfitpar_str1.prange(0,step_tmp,1,indpar_tmp),2) 
		   WIDGET_CONTROL, wids.id_luse(i),SET_VALUE=                $ 
		          tmpfitpar_str1.prange(0,step_tmp,2,indpar_tmp)     
		ENDFOR   
		WIDGET_CONTROL, wids.id_chngstep_ok, SENSITIVE=0
		WIDGET_CONTROL, wids.id_chngstep, SET_VALUE = ''	  
		
	END

	'DISCVAL': BEGIN
		WIDGET_CONTROL, wids.id_discval, GET_VALUE = discval_md
		; set corresponding value to be discarded
		; value 1 means use minimum time, 0 use fraction of measurement
	        tmpfitpar_str1.use_mintime = discval_md
	        if discval_md THEN  fractleft = tmpfitpar_str1.mintime $
	            ELSE fractleft = tmpfitpar_str1.fract_left
		WIDGET_CONTROL, wids.id_frac, SET_VALUE=STRTRIM(fractleft,2)
	           

	END	
	
	'FUNCTION': BEGIN
		WIDGET_CONTROL, event.top, /HOURGLASS
	        WIDGET_CONTROL, wids.id_func, GET_VALUE=s_funct
	        
		; Reinitializes the fit_par_str if the function is changed
		ffunct = funct_info.lst(1,s_funct(0))
		fitpar_str_init, tmpdata1, tmpfitpar_str1, error, $ 
		     ffunct, PIXEL= pix1+1, CMODE = cmodetmp
		     
		IF error(0) eq 2 THEN BEGIN 
		  WIDGET_CONTROL, wids.id_func, $ 
		     SET_VALUE=curr_find
		  RETURN  
		ENDIF   
		     
		set_driftpar_srd, tmpfitpar_str1, drift_par
		pia_drift_par = drift_par

		curr_find = s_funct(0)
		
        	nfunct_par = funct_info.npar(curr_find) 
		IF strpos(ffunct,'_RST_') gt -1 THEN allrst = 1 ELSE allrst = 0

		wid_lab = funct_info.parlabel.(curr_find) 	    
		WIDGET_CONTROL, wids.id_ftxt, $ 
		   SET_VALUE=funct_info.lst(2,curr_find)

		curr_step = 0
		IF allrst THEN BEGIN 
		   ntsteps = tmpfitpar_str1.nparams - nfunct_par + 1
                   indpar = INDGEN(nfunct_par*ntsteps) MOD nfunct_par
                   FOR ist = 1, ntsteps-1 DO indpar(ist*nfunct_par) = $ 
                                nfunct_par - 1 + ist
		ENDIF ELSE BEGIN 
		   ntsteps = tmpfitpar_str1.neff_steps
		   indpar = INDGEN(nfunct_par)
		ENDELSE   
		
		label = 'Chopper/Raster step ' + strtrim(curr_step+1,2) + $
	            ' -- Total steps: ' + strtrim(ntsteps,2)
	        WIDGET_CONTROL, wids.id_curstep, SET_VALUE = label    
				
                  step_tmp = curr_step * (1-allrst)
		  FOR I=0,nfunct_par-1 DO BEGIN
                        indpar_tmp = indpar(i+curr_step*nfunct_par*allrst)
		        WIDGET_CONTROL, wids.id_val(i), /SENSITIVE
		        WIDGET_CONTROL, wids.id_fix(i), /SENSITIVE
		        WIDGET_CONTROL, wids.id_lmin(i), /SENSITIVE
		        WIDGET_CONTROL, wids.id_lmax(i), /SENSITIVE
		        WIDGET_CONTROL, wids.id_luse(i), /SENSITIVE
		        WIDGET_CONTROL, wids.id_allsteppar(i), /SENSITIVE
		        WIDGET_CONTROL, wids.id_allstepvar(i), /SENSITIVE
			WIDGET_CONTROL, wids.id_lab(i), $
			 SET_VALUE=STRING(wid_lab(i),format='(a13)')
	 		WIDGET_CONTROL, wids.id_val(i), SET_VALUE=   $
	 		  STRTRIM(tmpfitpar_str1.param(0,step_tmp,indpar_tmp),2)
	 		WIDGET_CONTROL, wids.id_fix(i), $
	 		  SET_VALUE=STRTRIM(            $
	 		    tmpfitpar_str1.a_var(0,step_tmp,indpar_tmp),2)
	 		WIDGET_CONTROL, wids.id_lmin(i), SET_VALUE=  $
	 		  STRTRIM(tmpfitpar_str1.prange(0,step_tmp,0, $
	 		       indpar_tmp),2)
	 		WIDGET_CONTROL, wids.id_lmax(i), SET_VALUE=  $
	 		  STRTRIM(tmpfitpar_str1.prange(0,step_tmp,1,  $
	 		       indpar_tmp),2)
	 		WIDGET_CONTROL, wids.id_luse(i), $
	 		  SET_VALUE=tmpfitpar_str1.prange(0,step_tmp,2,$
	 		       indpar_tmp)
		   ENDFOR
		   
		   IF maxnpar-nfunct_par gt 0 THEN BEGIN
		    FOR i=nfunct_par, maxnpar-1 DO BEGIN
		      WIDGET_CONTROL, wids.id_lab(i), $
		       SET_VALUE=STRING(' ',format='(a13)')
		      WIDGET_CONTROL, wids.id_val(i), SET_VALUE=''
		      WIDGET_CONTROL, wids.id_val(i), SENSITIVE=0
		      WIDGET_CONTROL, wids.id_fix(i), SENSITIVE=0
		      WIDGET_CONTROL, wids.id_lmin(i), SET_VALUE=''
		      WIDGET_CONTROL, wids.id_lmin(i), SENSITIVE=0
		      WIDGET_CONTROL, wids.id_lmax(i), SET_VALUE=''
		      WIDGET_CONTROL, wids.id_lmax(i), SENSITIVE=0
		      WIDGET_CONTROL, wids.id_luse(i), SENSITIVE=0
		      WIDGET_CONTROL, wids.id_allsteppar(i), SENSITIVE=0
		      WIDGET_CONTROL, wids.id_allstepvar(i), SENSITIVE=0
 		    ENDFOR
		   ENDIF 
		 
	END	

	'TEST': BEGIN
                ; Read the values from the widgets
		WIDGET_CONTROL, event.top, /HOURGLASS

		WIDGET_CONTROL, wids.id_weig, GET_VALUE=s_weight
	        weight = funct_info.weightm(s_weight(0))
			

		nparam = funct_info.npar(curr_find)
; 		print, nparam, curr_find

                step_tmp = curr_step * (1-allrst)
		FOR i=0,nparam-1 DO BEGIN
                 indpar_tmp = indpar(i+curr_step*nparam*allrst)
		 WIDGET_CONTROL, wids.id_val(i), GET_VALUE=value
		 tmpfitpar_str1.param(0,step_tmp,indpar_tmp) = FLOAT(value(0))
		 WIDGET_CONTROL, wids.id_fix(i), GET_VALUE=value
		 tmpfitpar_str1.a_var(0,step_tmp,indpar_tmp) = FIX(value(0))
		 WIDGET_CONTROL, wids.id_lmin(i), GET_VALUE=value
		 tmpfitpar_str1.prange(0,step_tmp,0,indpar_tmp) = FLOAT(value(0))
		 WIDGET_CONTROL, wids.id_lmax(i), GET_VALUE=value
		 tmpfitpar_str1.prange(0,step_tmp,1,indpar_tmp) = FLOAT(value(0))
		 WIDGET_CONTROL, wids.id_luse(i), GET_VALUE=value
		 tmpfitpar_str1.prange(0,step_tmp,2,indpar_tmp) = FIX(value(0))
		ENDFOR

		invar = WHERE(tmpfitpar_str1.a_var EQ 1, nvar)
		IF nvar EQ 0 THEN $
		   MESSAGE, /INFO, 'Warning: All parameters are fixed'
		   
		tmpfitpar_str2 = tmpfitpar_str1
				   
		
		drift_mod_proc, det, time, slop, slun, flag, rpid, step,    $
			tempe, tmpfitpar_str2, PIXCH=pix1, WEIGHT = weight, $
			CMODE = cmodetmp
		
		decode_admn, tmpdata1.admn, dec
	        legend = ' Pixel '+STRTRIM(pix1+1,2)

		;print information about the fit results
		print_fitmodel, tmpfitpar_str2, GROUP = event.top, $ 
                  MEASID= dec + legend	        
        
		;make a plot with the fitted model
		;
		tit = 'Drift modelling: ' + dec 
		
	        ind_valfit = WHERE(tmpfitpar_str2.slop_flag LE 1,nvalfit)  

		plot_fitmodel, time, slop, slun, flag, tmpfitpar_str2,  $
                    TITLE= tit, LEGEND = legend   

		tit = 'Residuals from drift modelling: ' + dec 
		WIDGET_CONTROL, wids.id_plotres, GET_VALUE = over_state
		oplot = over_state(0) - 1 
	        IF over_state(0) GT 0 AND nvalfit GT 0 THEN $
                   plot_fitresi, time, slop, tmpfitpar_str2,  $
		     title = tit, LEGEND = legend, OPLOT=oplot
		

	END
	
	'REFRESH': BEGIN
	        WIDGET_CONTROL, event.top, /HOURGLASS
	        
		WIDGET_CONTROL, wids.id_minp, GET_VALUE=s_minpext
		 pia_drift_par.minp_ext = FLOAT(s_minpext(0))
		WIDGET_CONTROL, wids.id_discval, GET_VALUE = discval_md
		 pia_drift_par.use_mintime = discval_md 
		WIDGET_CONTROL, wids.id_frac, GET_VALUE=s_fractleft
		 IF discval_md THEN  $ 
		   pia_drift_par.mintime = FLOAT(s_fractleft(0))   $ 
		  ELSE pia_drift_par.fract_left = FLOAT(s_fractleft(0))
		WIDGET_CONTROL, wids.id_chisq, GET_VALUE=s_chisqt
		 pia_drift_par.chisqt = FLOAT(s_chisqt(0))
		 
		fitpar_str_init, tmpdata1, tmpfitpar_str1, error, $   
		    funct_info.lst(1,curr_find), PIXEL= pix1+1,/ONLY_MEASPAR, $
		    CMODE = cmodetmp
		
		 IF total(error) gt 0 THEN BEGIN
	  		MESSAGE, /INFO, 'Initialization is not possible'
	  		RETURN
		 ENDIF

        	  nfunct_par = funct_info.npar(curr_find)
        	  step_tmp = curr_step * (1-allrst)
		  FOR I=0,nfunct_par-1 DO BEGIN
	 		indpar_tmp = indpar(i+curr_step*nfunct_par*allrst)
	 		WIDGET_CONTROL, wids.id_val(i),    $
	 		   SET_VALUE=STRTRIM(STRING(       $
	 		   tmpfitpar_str1.param(0,step_tmp,indpar_tmp)),2)
		  ENDFOR


	END
	
	'NEWPAR': BEGIN
	        WIDGET_CONTROL, event.top, /HOURGLASS
	        
	        ; set new parameters obtained from the fit as initial values
	        tmpfitpar_str1.param = tmpfitpar_str2.param
	        nfunct_par = funct_info.npar(curr_find)
        	step_tmp = curr_step * (1-allrst)
	        FOR I=0, nfunct_par-1  DO BEGIN
	           indpar_tmp = indpar(i+curr_step*nfunct_par*allrst)
	 	   WIDGET_CONTROL, wids.id_val(i), SET_VALUE=STRTRIM(     $
	 		    tmpfitpar_str1.param(0,step_tmp,indpar_tmp),2)

		   ENDFOR

	END
	        
	
	'DEF': BEGIN

		WIDGET_CONTROL, event.top, /HOURGLASS
		
		  tmpfitpar_str1 = tmpfitpar_str_def
		  curr_find = long(def_val(2))
		  curr_step = 0
		  wid_lab = funct_info.parlabel.(curr_find) 	    
        	  nfunct_par = funct_info.npar(curr_find)
        	         	  		  
	          WIDGET_CONTROL, wids.id_minp, $ 
	               SET_VALUE=STRTRIM(tmpfitpar_str1.minp_ext,2)
	          WIDGET_CONTROL, wids.id_discval, $
	               SET_VALUE=tmpfitpar_str1.use_mintime
	          IF tmpfitpar_str1.use_mintime THEN            $ 
	             fractleft =  tmpfitpar_str1.mintime        $
	            ELSE fractleft = tmpfitpar_str1.fract_left        
	          WIDGET_CONTROL, wids.id_frac, $
	               SET_VALUE=STRTRIM(fractleft,2)
	          WIDGET_CONTROL, wids.id_func, SET_VALUE=curr_find
	          WIDGET_CONTROL, wids.id_chisq, $ 
	               SET_VALUE=STRTRIM(tmpfitpar_str1.chisqtol,2)
	          WIDGET_CONTROL, wids.id_weig, $ 
	               SET_VALUE= def_val(4)
	          WIDGET_CONTROL, wids.id_ftxt, $
	               SET_VALUE=funct_info.lst(2,curr_find)
	          
		  step_tmp = curr_step * (1-allrst)
		  FOR I=0,nfunct_par-1 DO BEGIN
		        indpar_tmp = indpar(i+curr_step*nfunct_par*allrst)
		        WIDGET_CONTROL, wids.id_val(i), /SENSITIVE
		        WIDGET_CONTROL, wids.id_fix(i), /SENSITIVE
		        WIDGET_CONTROL, wids.id_lmin(i), /SENSITIVE
		        WIDGET_CONTROL, wids.id_lmax(i), /SENSITIVE
		        WIDGET_CONTROL, wids.id_luse(i), /SENSITIVE
		        WIDGET_CONTROL, wids.id_allsteppar(i), /SENSITIVE
		        WIDGET_CONTROL, wids.id_allstepvar(i), /SENSITIVE
                        WIDGET_CONTROL, wids.id_lab(i), $
			 SET_VALUE=STRING(wid_lab(i),format='(a13)')
 	 		WIDGET_CONTROL, wids.id_val(i),    $
	 		   SET_VALUE=STRTRIM(STRING(       $
	 		   tmpfitpar_str1.param(0,step_tmp,indpar_tmp)),2)
	 		WIDGET_CONTROL, wids.id_fix(i), $
	 		   SET_VALUE=STRTRIM(           $ 
	 		      tmpfitpar_str1.a_var(0,step_tmp,indpar_tmp),2)

	 		WIDGET_CONTROL, wids.id_lmin(i), $
	 		  SET_VALUE=STRTRIM(			      $
	 		    tmpfitpar_str1.prange(0,step_tmp,0,indpar_tmp),2)
	 		WIDGET_CONTROL, wids.id_lmax(i), $
	 		  SET_VALUE=STRTRIM(      $
	 		    tmpfitpar_str1.prange(0,step_tmp,1,indpar_tmp),2)
	 		WIDGET_CONTROL, wids.id_luse(i), SET_VALUE=     $
	 		  tmpfitpar_str1.prange(0,step_tmp,2,indpar_tmp)

		  ENDFOR

		   if maxnpar-nfunct_par gt 0 then begin
		    for i=nfunct_par, maxnpar-1 do begin
		      WIDGET_CONTROL, wids.id_lab(i), SET_VALUE='          '
		      WIDGET_CONTROL, wids.id_val(i), SET_VALUE= ''
		      WIDGET_CONTROL, wids.id_val(i), SENSITIVE=0
		      WIDGET_CONTROL, wids.id_fix(i), SENSITIVE=0
		      WIDGET_CONTROL, wids.id_lmin(i), SENSITIVE=0
		      WIDGET_CONTROL, wids.id_lmax(i), SENSITIVE=0
		      WIDGET_CONTROL, wids.id_luse(i), SENSITIVE=0
		      WIDGET_CONTROL, wids.id_allsteppar(i), SENSITIVE=0
		      WIDGET_CONTROL, wids.id_allstepvar(i), SENSITIVE=0
		    endfor
		   endif 
		
	END
	
	'DEFQUIT': BEGIN

		set_driftpar_srd, tmpfitpar_str_def, drift_par
		pia_drift_par = drift_par
		
		WIDGET_CONTROL, event.top, /DESTROY
			
	END
	'QUIT': BEGIN
		WIDGET_CONTROL, event.top, /HOURGLASS
		WIDGET_CONTROL, wids.id_discval, GET_VALUE=discval_md
		tmpfitpar_str1.use_mintime = discval_md 
		WIDGET_CONTROL, wids.id_frac, GET_VALUE=s_fractleft
		IF discval_md THEN 					$ 
		  tmpfitpar_str1.mintime = FLOAT(s_fractleft(0)) 	$
		 ELSE tmpfitpar_str1.fract_left = FLOAT(s_fractleft(0))
		WIDGET_CONTROL, wids.id_minp, GET_VALUE=s_minpext
		tmpfitpar_str1.minp_ext = FLOAT(s_minpext(0))
	        WIDGET_CONTROL, wids.id_func, GET_VALUE=s_funct
	        tmpfitpar_str1.mod_func = funct_info.lst(1,s_funct(0))
		WIDGET_CONTROL, wids.id_chisq, GET_VALUE=s_chisqt
		 tmpfitpar_str1.chisqtol = FLOAT(s_chisqt(0))
		WIDGET_CONTROL, wids.id_weig, GET_VALUE=s_weightm
		 tmpfitpar_str1.weightm = funct_info.weightm(s_weightm(0))

		nfunct_par = funct_info.npar(s_funct(0))
		step_tmp = curr_step * (1-allrst)
		FOR i=0,nfunct_par-1 DO BEGIN
		 indpar_tmp = indpar(i+curr_step*nfunct_par*allrst)
		 WIDGET_CONTROL, wids.id_fix(i), GET_VALUE=value
		 tmpfitpar_str1.a_var(0,step_tmp,indpar_tmp) = FIX(value(0))
		 WIDGET_CONTROL, wids.id_luse(i), GET_VALUE=value
		 tmpfitpar_str1.prange(0,0,2,indpar_tmp) = FIX(value(0))
		ENDFOR
		
		set_driftpar_srd, tmpfitpar_str1, drift_par
		pia_drift_par = drift_par
				
		WIDGET_CONTROL, event.top, /DESTROY
	END
	
	"FITYES": BEGIN
		IF N_ELEMENTS(tmpfitpar_str2) EQ 0 THEN RETURN
		out_fitpar_str = tmpfitpar_str2
		out_fitacc = pix1+1
		WIDGET_CONTROL, event.top, /DESTROY
 
	END
	
	"FITNOT": BEGIN
		out_fitacc = 0
		WIDGET_CONTROL, event.top, /DESTROY
	END
	
	"HELP": BEGIN
	   	IF !VERSION.OS NE 'vms' THEN $
		spawn, 'w3net $PIA_HTML/um/drift_mod.html &' ELSE $
		spawn, 'w3net /pia_dsk/pia/html/um/drift_mod.html'
		END
	
	ELSE:
	
	ENDCASE
	
RETURN
END
; *********************************************************************
; *  Menu for PIA_DRIFT_MOD
; *********************************************************************
PRO PIA_DRIFT_MOD, tmpdata, pixel, sig_disc, degl_acc, degl_set, GROUP=group,$
		FITRESULTS=fitresults

 
COMMON PIA_DRIFTMOD_CMN, tmpdata1, pix1, cmodetmp, tmpfitpar_str, $ 
       tmpfitpar_str_def, tmpfitpar_str_new, def_val, ntsteps, curr_step, $
       curr_find, new_step, indpar, allrst
COMMON PIA_DRIFT_PAR, pia_drift_par 
COMMON DFFUNCT_INFO, funct_info

; Return if already active
	IF XRegistered("pia_drift_mod") THEN BEGIN
		MESSAGE, /INFO, 'Menu already active, returning'
		RETURN
	ENDIF



;check if fit function parameters are defined
if n_elements(funct_info) eq 0 then dffunct_info

error =0 
;

;read compact status to obtain info about chopper
	give_cs, tmpdata, cst, record, conv_cst, error=error
	IF error EQ 0 THEN cmodetmp = conv_cst.cmod(record)  $
	  ELSE  cmodetmp = ''

; now start initialization of fitting function parameters
     
        tmpdata1 = tmpdata
        pix1 = pixel 
 
; flag the discarded signals using the info coming from common 'not_acc'

	inddisc = WHERE(sig_disc(pix1,*) NE 0, ndisc)
	IF ndisc GT 0 THEN tmpdata1.flag(pix1,inddisc) = 2
	IF degl_set THEN BEGIN
		inddisc = WHERE(degl_acc(pix1,*) NE 0, ndisc)
		IF ndisc GT 0 THEN tmpdata1.flag(pix1,inddisc) = 2
	ENDIF
	   	        
        ;check if pia_drift_par was defined, then use previous values
        ;for parameters which are independent of measurement 

	; use pixel number and not index to avoid problems with 0 values
	; If pixel =0 then keyword_set is not working
        fitpar_str_init, tmpdata1, tmpfitpar_str, error, funct, PIXEL= pix1+1, $
           /ONLY_MEASPAR, CMODE = cmodetmp
        
        ind_funct = where(funct_info.lst(1,*) eq funct,nf)
        if nf eq 0 then return
	curr_find = ind_funct(0)
   
	IF strpos(funct,'_RST_') gt -1 THEN allrst = 1 ELSE allrst = 0
        
        curr_step = 0
        str_istep = strtrim(curr_step)

	ind_weightm = where(STRUPCASE(funct_info.weightm) eq  $
	                     STRUPCASE(tmpfitpar_str.weightm),nweig)
	
        
	; keep the default values of pia_drift_par
        tmpfitpar_str_def = tmpfitpar_str
        
	   	
	; Set the maximum number of parameters for any fitting function
        maxnpar = funct_info.maxnpar
	
	def_val = strarr(maxnpar+5)
	def_avar = strarr(maxnpar)
	def_prange = strarr(3,maxnpar)
	
	; discarding values 
	use_mintime = tmpfitpar_str.use_mintime
	IF use_mintime THEN discval = tmpfitpar_str.mintime      $
	   ELSE discval = tmpfitpar_str.fract_left 
	
	def_val(0) = [string(tmpfitpar_str.minp_ext),	$
		     string(discval), 			$
		     string(ind_funct(0)),  		$
		     string(tmpfitpar_str.chisqtol),    $
		     string(ind_weightm(0)) ]
		     
        nfunct_par = funct_info.npar(ind_funct(0))
        IF allrst THEN BEGIN 
           ntsteps = tmpfitpar_str.nparams - nfunct_par + 1
           indpar = INDGEN(nfunct_par*ntsteps) MOD nfunct_par
           FOR ist = 1, ntsteps-1 DO indpar(ist*nfunct_par) = nfunct_par -1 + ist
        ENDIF ELSE BEGIN 
           ntsteps = tmpfitpar_str.neff_steps
           indpar = INDGEN(nfunct_par)
        ENDELSE   
        step_tmp = curr_step * (1-allrst)
        FOR i=0, nfunct_par-1 DO BEGIN 
           indpar_tmp = indpar(i+curr_step*nfunct_par*allrst)
           def_val(5+i) = tmpfitpar_str.param(0, step_tmp, indpar_tmp)
           def_avar(i) = tmpfitpar_str.a_var(0,step_tmp, indpar_tmp)
           def_prange(*,i) = tmpfitpar_str.prange(0, step_tmp, *, $ 
                             indpar_tmp)
        ENDFOR    
	    

; Set parameters which are not measurement dependent
	
	base = WIDGET_BASE(TITLE=" PIA Signal drifts modelling [" + $ 
	      "Pixel "+strtrim(pix1+1,2)+"]", /COLUMN)
	
	pbase = WIDGET_BASE(base, /COLUMN, /FRAME)
	parbase = WIDGET_BASE(pbase, /ROW)
	label = WIDGET_LABEL(parbase, $
		VALUE ='Minimum of points for algorithm:    ')
	label = WIDGET_LABEL(parbase, VALUE='            ')
	minpext_id = WIDGET_TEXT(parbase, /EDITABLE, VALUE=STRTRIM(def_val(0),2),$
		UVALUE='JUNK', XSIZE=8)


	label = WIDGET_LABEL(parbase, VALUE='           ')
	helpid = WIDGET_BUTTON(parbase, $
	  VALUE= ' HELP ', $
		UVALUE= 'HELP')

        discard_val = ['Fraction of measurement left out (%):', $
                       'Initial Time not considered      (s):'] 		

	parbase = WIDGET_BASE(pbase, /ROW)
	;label = WIDGET_LABEL(parbase, $
	;	VALUE='Fraction of measurement left out (%):')
	discval_id = CW_BSELECTOR(parbase, discard_val, UVALUE='DISCVAL')
	WIDGET_CONTROL, discval_id, SET_VALUE = use_mintime
	label = WIDGET_LABEL(parbase, VALUE='        ')
	fractleft_id = WIDGET_TEXT(parbase, /EDITABLE, $
	        VALUE=STRTRIM(def_val(1),2), UVALUE='JUNK', XSIZE=8)

	parbase = WIDGET_BASE(pbase, /ROW)
	label = WIDGET_LABEL(parbase, $
		VALUE='Chi^2 / DoF tolerance level:         ')
	label = WIDGET_LABEL(parbase, VALUE='           ')
	chisqt_id = WIDGET_TEXT(parbase, /EDITABLE, $
	        VALUE=STRTRIM(def_val(3),2), UVALUE='JUNK', XSIZE=8)
	
	parbase = WIDGET_BASE(pbase, /ROW) 
	weightm_id = CW_BSELECTOR(parbase, funct_info.weightm(*), $
	   UVALUE='WEIGHTM', $
           LABEL_LEFT='Weighting method to be used:                     ')
	WIDGET_CONTROL,weightm_id, SET_VALUE = ind_weightm(0)	
	   
	parbase = WIDGET_BASE(pbase, /ROW) 
	funct_id = CW_BSELECTOR(parbase, funct_info.lst(0,*), $
	   UVALUE='FUNCTION', $
           LABEL_LEFT='Fitting function to be used:                     ')
	WIDGET_CONTROL, funct_id, SET_VALUE = ind_funct(0)	
	IF KEYWORD_SET(FITRESULTS) THEN WIDGET_CONTROL, funct_ID, SENSITIVE=0

	wid_funtxt = WIDGET_LABEL(pbase, VALUE=funct_info.lst(2,ind_funct(0)))
;	junk = WIDGET_LABEL(base, VALUE='    ')
	

;	plotbase = WIDGET_BASE(base, /ROW)
; Set parameters which depend on measurement
	    
	wid_lab = make_array(maxnpar,value=string(" ",format='(a13)'))
	wid_id_lab = lonarr(maxnpar)
	wid_val = strarr(maxnpar)
	wid_id_sens = lonarr(maxnpar)
	wid_id_val = lonarr(maxnpar)
	wid_id_lmin = lonarr(maxnpar)
	wid_id_lmax = lonarr(maxnpar)
	wid_id_luse = lonarr(maxnpar)
	wid_id_fix = lonarr(maxnpar)
	wid_id_allsteppar = lonarr(maxnpar)
	wid_id_allstepvar = lonarr(maxnpar)
	id_allstepvar = 'ALLSTEP_VAR'+strtrim(indgen(maxnpar),2)
	id_allsteppar = 'ALLSTEP_PAR'+strtrim(indgen(maxnpar),2)
	id_varpar =     'FIXVAR_PAR '+strtrim(indgen(maxnpar),2)

	wid_val(0) = STRTRIM(def_val(5:*),2)
	wid_lab(0) = string(funct_info.parlabel.(ind_funct(0)),format='(A13)')
	wid_id_sens(0:nfunct_par-1) = 1
	

	par0base = WIDGET_BASE(base, /column, /FRAME)

	parbase = WIDGET_BASE(par0base, /row)
	label = 'Chopper/Raster step ' + strtrim(curr_step+1,2) + $
	          ' -- Total steps: ' + strtrim(ntsteps,2)
	wid_curr_step = WIDGET_LABEL(parbase, VALUE=label)
	
	parbase = WIDGET_BASE(par0base, /row)
	label = WIDGET_LABEL(parbase, VALUE='New step ')
	wid_id_step = WIDGET_TEXT(parbase, /EDITABLE, XSIZE=4, YSIZE=1, $
	       VALUE=str_istep, UVALUE = 'CHANGSTEP')
	wid_changok = WIDGET_BUTTON(parbase, VALUE='CHANGE ',UVALUE='CHANGOK')
	WIDGET_CONTROL, wid_changok, SENSITIVE=0       
	
	parbase = WIDGET_BASE(par0base, /column)
	parlabel = $
	   '  Parameter         Value    ' + ' All steps ' +$ 
	   'Var/Fix  All steps  Lower lim  Upper lim    Limits   '   	 
	label = WIDGET_LABEL(parbase, VALUE=parlabel)
	

	FOR i=0,maxnpar-1 DO BEGIN
	 parbase = WIDGET_BASE(par0base, /ROW)
	 wid_id_lab(i) = WIDGET_LABEL(parbase, VALUE=WID_lab(i))
	 label = WIDGET_LABEL(parbase, VALUE='   ')
	 wid_id_val(i) = WIDGET_TEXT(parbase, /EDITABLE, $
		VALUE=wid_val(i), $
		UVALUE='JUNK', XSIZE=8)
         wid_id_allsteppar(i) = WIDGET_BUTTON(parbase, VALUE='  Do it ' , $
                   UVALUE=id_allsteppar(i))
         WIDGET_CONTROL,wid_id_allsteppar(i), SENSITIVE = wid_id_sens(i)          
	 WIDGET_CONTROL, wid_id_val(i), SENSITIVE = wid_id_sens(i)	
	 wid_id_fix(i) = CW_BSELECTOR(parbase, ["FIX","VAR"], $
			UVALUE = id_varpar(i))
	 WIDGET_CONTROL, wid_id_fix(i), SENSITIVE = wid_id_sens(i)	
	 WIDGET_CONTROL, wid_id_fix(i), SET_VALUE = def_avar(i), $
	     SENSITIVE = wid_id_sens(i)
         wid_id_allstepvar(i) = WIDGET_BUTTON(parbase, VALUE='  Do it ' , $
                   UVALUE=id_allstepvar(i))
         WIDGET_CONTROL,wid_id_allstepvar(i), SENSITIVE = wid_id_sens(i)          
	 wid_id_lmin(i) = WIDGET_TEXT(parbase, /EDITABLE, $
		VALUE=STRTRIM(def_prange(0,i),2), $
		UVALUE='JUNK', XSIZE=8)
	 WIDGET_CONTROL, wid_id_lmin(i), SENSITIVE = wid_id_sens(i)	
	 wid_id_lmax(i) = WIDGET_TEXT(parbase, /EDITABLE, $
		VALUE=STRTRIM(def_prange(1,i),2), $
		UVALUE='JUNK', XSIZE=8)
	 WIDGET_CONTROL, wid_id_lmax(i), SENSITIVE = wid_id_sens(i)
	 luse = string(["Not Used", "Absolute","Relative"],format='(a11)')	
	 wid_id_luse(i) = cw_bselector(parbase, luse, UVALUE = 'JUNK')  
	 WIDGET_CONTROL, wid_id_luse(i), SET_VALUE = def_prange(2,i), $
	     SENSITIVE = wid_id_sens(i)
	     
	ENDFOR
	
        plotres_id = cw_bgroup(base, $
                        /EXCLUSIVE, /FRAME, $
                        SET_VALUE = 0, $
                        UVALUE = 'JUNK', COLUMN=3,$
                        ['Do not plot residuals   ', 		$
                         'Plot residuals          ',		$
                         'Overplot residuals      '])
                        
	acont_base = WIDGET_BASE(base,/COLUMN,/FRAME)
			
	cont_base = WIDGET_BASE(acont_base, /ROW)
		
	test_id = WIDGET_BUTTON(cont_base, VALUE='OK, test them   ', 		$
	    UVALUE='TEST')
	
	newpa_id = WIDGET_BUTTON(cont_base, VALUE='Last Fit -> Init Par.  ', 	$
	     UVALUE = 'NEWPAR')
	
	refr_id = WIDGET_BUTTON(cont_base, VALUE='Refresh Parameters  ', 	$
	    UVALUE='REFRESH')

	def_id = WIDGET_BUTTON(cont_base, VALUE='Default Values  ', 		$ 
	    UVALUE='DEF')

	
        cont_base = WIDGET_BASE(acont_base, /ROW)
        

	CASE 1 OF 
	   KEYWORD_SET(FITRESULTS): BEGIN 			 
                         quit_id = WIDGET_BUTTON(cont_base, UVALUE= 'FITYES',  $
	                    VALUE= '      Accept FIT Results & Quit         ')
	                 quit_id = WIDGET_BUTTON(cont_base, UVALUE= 'FITNOT',  $
                            VALUE= '    Do NOT Accept FIT Results & Quit    ')
                         widget_control, minpext_id, SENSITIVE=0 
	                 widget_control, chisqt_id, SENSITIVE=0 
			END
           ELSE: BEGIN   ; Testing case
	                 quit_id = WIDGET_BUTTON(cont_base, UVALUE= 'DEFQUIT', $
	                    VALUE= '     Default parameters & Quit          ')
	                 quit_id = WIDGET_BUTTON(cont_base, UVALUE='QUIT',     $
                  	    VALUE= '      Accept parameters & Quit          ')
		 END
        ENDCASE
		  

	wids = {id_minp:minpext_id, id_frac:fractleft_id, id_func:funct_id,	$
			id_chngstep:wid_id_step , id_chngstep_ok: wid_changok,  $
			id_discval: discval_id,					$
			id_curstep:wid_curr_step, id_weig:weightm_id,		$ 
			lab:wid_lab, id_lab:wid_id_lab, id_val:wid_id_val, 	$
			id_lmin:wid_id_lmin, id_lmax:wid_id_lmax, 		$
			id_luse:wid_id_luse, id_fix:wid_id_fix, 		$
			id_allsteppar:wid_id_allsteppar,                        $
			id_allstepvar:wid_id_allstepvar,			$
			id_ftxt:wid_funtxt, id_chisq:chisqt_id, 	        $
			id_plotres:plotres_id}
			
	 
        WIDGET_CONTROL, base, /REALIZE, TLB_SET_XOFFSET=150, $
                        TLB_SET_YOFFSET=0, SET_uvalue=wids

        XMANAGER,No_BLOCK=1, "pia_drift_mod", base, GROUP=group
	
        RETURN
END
	
