;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_LOAD_DRIFTPAR1
;
; PURPOSE:
;	Load drift modelling parameters into structure PIA_DRIFTPAR
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	PIA_LOAD_DRIFTPAR1, drift_par, pixel, FUNCT = funct, NON_INT = non_int 
;
; INPUT:
;	tmpdata:	A phtsrd like temporary structure
;	pixel:		The pixel number of the data to be used
;
; KEYWORD PARAMETERS:
;	FUNCT:		The name of the function to be used
;	NON_INT:	When using it non-interactively less parameters are
;			set variable
;	
; RESTRICTIONS:
;	TMPDATA must be a valid PHTSRD temporary structure
;	
; COMMON BLOCKS:
;	dffunct_info	
;		
; PROCEDURES USED:
;	PIA LIB:
;		fouks_start_par
;		gauss_start_par
;		gaussinv_start_par
;
; MODIFICATION HISTORY:
;	Written by: C.Gabriel (ESA/VILSPA-SAI)		August 1996
;	Version 5.0 - Aug.96
;			
;-
PRO PIA_LOAD_DRIFTPAR1, drift_par, error, FUNCT = funct

COMMON DFFUNCT_INFO, funct_info

; check if common dffunct_info is not defined
if n_elements(funct_info) eq 0 then dffunct_info

if not keyword_set(FUNCT) then funct = funct_info.lst(1,0)

ind_funct = where(funct_info.lst(1,*) eq funct, nind)

IF nind gt 0 THEN BEGIN

  error = 0 	  		 
  fract_left = funct_info.fractleft(ind_funct(0))
  a_var = funct_info.avar.(ind_funct(0)) 
  npar = funct_info.npar(ind_funct(0))
  p_label = funct_info.parlabel.(ind_funct(0))
  prange = funct_info.prange.(ind_funct(0))
  chisqtmax = 5.
  weightm= funct_info.weightm(0)
  minp_ext = 7

  DRIFT_PAR = {p_label:string(p_label,format='(A10)'), p_field:fltarr(npar), $
   s_field:fltarr(npar), a_var:a_var, p_range:prange, flag:0, $
   ffunct:funct, minp_ext:minp_ext, fract_left:fract_left,t_zero:0., $
   chisq:0., chisqt:chisqtmax, weightm:weightm} 
			
ENDIF ELSE BEGIN

  	  print, 'RETURNING: Function not valid'
  	  print, ['VALID FUNCTIONS:',funct_info.lst(1,*)]
  	  error = 1
  	  
ENDELSE  	  
			
			

END
 		  
