;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_load_IDRIFT
;
; PURPOSE:
;	Write a PHT-DRIFT (Signal per chopper plateau) measurement from the 
;	dynamical structure DRIFTDAT (PHTDRIFT type) onto a temporary structure 
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       PIA_LOAD_IDRIFT, driftdat, tmpdrift
;
; INPUT:
;       DRIFTDAT 	: PHTDRIFT like dynamical structure
;
; KEYWORDS:
;	none
;
; OUTPUTS:
;	TMPDRIFT	: A temporary structure of SCP type
;
; RESTRICTIONS:
;       DRIFTDAT must exist
;
; MODIFICATION HISTORY:
;       Written by:	J.Acosta (ESA/MPIA/IAC)          October 1996
;	Oct 96 Version 5.x
;-

PRO PIA_load_IDRIFT, DRIFTDAT, tmpdrift 

        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 2 THEN MESSAGE, $
          'Syntax:  PIA_load_IDRIFT, DRIFTDAT, tmpdrift'

;  Fill temporary variables from the handles
        HANDLE_VALUE, DRIFTDAT.STAB, STAB 
        HANDLE_VALUE, DRIFTDAT.DRIFT, DRIFT
        HANDLE_VALUE, DRIFTDAT.SLOPV, SLOPV

;  Fill the IDRIFT structure
	NAME = DRIFTDAT.ADMN
	
	tmpdrift = {ADMN: NAME, 	$
        PROCT: DRIFTDAT.PROCT , 	$ 
        STAB: STAB, $ 
        SLOPV: SLOPV, $ 
	DRIFT: DRIFT}

        RETURN
END

