;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO READ_IDRIFT, NAME, IPOS, PATH = PATH 
;+
; NAME:
;       READ_IDRIFT
; PURPOSE:
;	READ a PHTIDRIFT (Interactive Signal per Chopper Plateau) file 
;	into the dynamical structure PHTDRIFT  
; CATEGORY:
;	PIA - I/O
; CALLING SEQUENCE:
;       READ_IDRIFT, NAME, IPOS, [PATH = PATH]
;
; INPUT:
;       NAME 	: DRIFT-savefile name
; OPTIONAL INPUT:
;	PATH    : path for the file
;
;
; RESTRICTIONS:
;       NAME must be a valid PHTIDRIFT file 
;
; PROCEDURES USED: 
;       Common Block(s) or @ procedure(s):
;               adm
;               phtdrift
;
; MODIFICATION HISTORY:
;       Written by: J.Acosta (ESA/MPIA/IAC)		October 1996
;	Oct 96 Version 5.x
;
;-
;
@adm
@phtdrift
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  READ_IDRIFT, NAME, [IPOS, PATH = PATH]'

; create filename esp if path is set
	if keyword_set(PATH) then $
	  filename = PATH + NAME $
	else filename = NAME
;  Restore the save file
	RESTORE, FILENAME

;  Create the structures and the handles
        PHTDRIFT_T = {PHTDRIFT_TYPE}
        PHTDRIFT_T.STAB = HANDLE_CREATE()
        PHTDRIFT_T.DRIFT = HANDLE_CREATE()
        PHTDRIFT_T.SLOPV = HANDLE_CREATE()

;  Fill the temporary DRIFT structure
        PHTDRIFT_T.ADMN = PHTIDRIFT.ADMN
        PHTDRIFT_T.PROCT = PHTIDRIFT.PROCT
                           
;  Fill the handles
        HANDLE_VALUE, PHTDRIFT_T.STAB, PHTIDRIFT.STAB, /SET  
        HANDLE_VALUE, PHTDRIFT_T.DRIFT, PHTIDRIFT.DRIFT, /SET  
        HANDLE_VALUE, PHTDRIFT_T.SLOPV, PHTIDRIFT.SLOPV, /SET  

;  Update the PHTSCP structure using the temporary structure
        PHTDRIFT = [PHTDRIFT,PHTDRIFT_T]
        
        IPOS = n_elements(PHTDRIFT)-1

;  Does exist already an administration record for this measurement?
;	       IDNAME = PHTISCP.ADMN
;	       DETID = PHTISCP.DET
;               ADMIND = WHERE(ADM.NAME EQ IDNAME, N)

;  Update the administration file using temporary structure
;               IF (N EQ 1) THEN BEGIN
;                ADM(ADMIND).PHTSCP = N_ELEMENTS(PHTSCP) - 1
;                IF (DETID EQ 'SS') THEN BEGIN
;                  STRPUT, IDNAME, 'L', 1
;                  ADMIND2 = WHERE(ADM.NAME EQ IDNAME, N)
;                  IF (N EQ 1) THEN $
;                        ADM(ADMIND2).PHTSCP = N_ELEMENTS(PHTSCP) - 1 $
;                   ELSE IF (N EQ 0) THEN BEGIN
;                        ADMT = {ADM_TYPE}
;                        ADMT.NAME = IDNAME
;                        SCPPOS = N_ELEMENTS(PHTSCP) - 1
;                        ADMT.PHTSCP = SCPPOS
;                        ADM = [ADM, ADMT]
;                  ENDIF ELSE PRINT, 'READ_ISCP: Several identical ADM-records'
;                ENDIF
;               ENDIF ELSE IF (N EQ 0) THEN BEGIN
;                   ADMT = {ADM_TYPE}
;                   ADMT.NAME = IDNAME
;                   SCPPOS = N_ELEMENTS(PHTSCP) - 1
;                   ADMT.PHTSCP = SCPPOS
;                   ADM = [ADM, ADMT]
;                IF (DETID EQ 'SS') THEN BEGIN
;                  STRPUT, IDNAME, 'L', 1
;                  ADMIND2 = WHERE(ADM.NAME EQ IDNAME, N)
;                  IF (N EQ 1) THEN $
;                        ADM(ADMIND2).PHTSCP = N_ELEMENTS(PHTSCP) - 1 $
;                   ELSE IF (N EQ 0) THEN BEGIN
;                        ADMT = {ADM_TYPE}
;                        ADMT.NAME = IDNAME
;                        SCPPOS = N_ELEMENTS(PHTSCP) - 1
;                        ADMT.PHTSCP = SCPPOS
;                        ADM = [ADM, ADMT]
;                  ENDIF ELSE PRINT, 'READ_ISCP: Several identical ADM-records'
;                ENDIF
;               ENDIF ELSE PRINT, 'READ_ISCP: Several identical ADM-records'
               
               
        RETURN
        END
