;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO WRITE_IDRIFT, IND, PATH = path, FNAME=fname
;+
; NAME:
;       WRITE_IDRIT
; PURPOSE:
;	Write a PHTDRIFT (Signal Drift Data) measurement from the dynamical 
;	structure PHTDRIFT onto an IDL savefile  
; CATEGORY:
;	PIA - I/O
; CALLING SEQUENCE:
;       WRITE_IDRIFT, PHTDRIFT_INDEX, PATH = path, FNAME = fname
;
; INPUT:
;       PHTDRIFT_INDEX 	: Index of the measurement within PHTDRIFT
;
; OUTPUT:
;	IDL save file
;
; RESTRICTIONS:
;       PHTDRIFT(PHTDRIFT_INDEX) must exist
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phtdrift
;
; MODIFICATION HISTORY:
;       Written by: J. Acosta
;	Oct 96 Version 5.x
;
;-
;
;
@phtdrift
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  WRITE_IDRIFT, PHTDRIFT_INDEX, PATH = PATH'

; check if keyword PATh is present

	IF KEYWORD_SET(PATH) then path1=path else path1 = './' 

;  Fill temporary variables from the handles
	HANDLE_VALUE, PHTDRIFT(IND).STAB, STAB
	HANDLE_VALUE, PHTDRIFT(IND).SLOPV, SLOPV
        HANDLE_VALUE, PHTDRIFT(IND).DRIFT, DRIFT

;  Fill the ISRD structure
	if keyword_set(FNAME) then NAME = fname $ 
	    else NAME = PHTDRIFT(IND).ADMN
	    
	ADMN =  PHTDRIFT(IND).ADMN   
	
	PHTIDRIFT = {ADMN: ADMN, 	$
        PROCT: PHTDRIFT(IND).PROCT, 	$ 
        STAB: STAB, 			$   
        SLOPV: SLOPV, 			$   
	DRIFT: DRIFT} 

;  Write it out: use adm naming convention 
	SAVE, PHTIDRIFT, FILE = PATH1 + NAME+'.IDRIFT'
        RETURN
        END
