;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;
; PURPOSE:
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
; INPUT PARAMETERS:
;
; KEYWORD PARAMETERS:
;
; COMMON BLOCKS:
; PROCEDURES USED:
;	PIA LIB:
;       ASTRO LIB:
;       INTERNAL:
; MODIFICATION HISTORY:
;       Written by: J.Acosta (ISO-SOC/VILSPA)          		  July 1998
;	V7.x
;	Expanding AAP output structure with DECP and RAP (CG)	March 2000
;	V8.2
;			
;-
PRO dyncal2aap, tmpdyncal, flux_str, tmpsrd, aapps, NEWHDR = newhdr, $
	INFO = info 

@phtaap
@phtfilter_prop

; check number of arguments 
IF N_PARAMS() LT 3 THEN BEGIN 
   print,'Syntax: dyncal2aap, tmpdyncal, tmpsrd [,hdr]'
   RETURN
ENDIF 

INFO = ''

IF N_ELEMENTS(newhdr) EQ 0 THEN newhdr = tmpdyncal.hdr

det = tmpdyncal.det


; process tmpsrd into tmpscp to get right dimensions
process_tmpsrd, tmpsrd, /NO_SCPBUFF, TMPSCP = tmpscp
cp_disc, tmpscp,flgscp


; get wheel positions etc 
get_wheels, tmpscp.admn, wheels, meast, dr, intt
mdwel = dr* intt

; get some information about filter
CASE strmid(det,0,1)  OF 
	'P': BEGIN 
		filt = wheels(2)
		aper = wheels(1)
		polz = wheels(0)
		cwave = [filtprop.p1cwl, filtprop.p2cwl, filtprop.p3cwl]
		cwvl = cwave(filt-1)
	      END
	'C': BEGIN 
		filt = wheels(1)
		aper = wheels(2)
		polz = wheels(0)
		cwave = [filtprop.c1cwl, filtprop.c2cwl]
		cwvl = cwave(filt-2)
	      END
	'S': BEGIN 
		filt = wheels(1)
		aper = wheels(2)
		polz = wheels(0)
		cwvl = 0.0
	      END
	ELSE: BEGIN 
		MESSAGE,/INFO,'Detector not recognized '
		RETURN
	      END	
ENDCASE	      

npix = pixel_det(det,/IS_AAP)
	      
; use routine flux to get conversion from Jy to MJy/sr
; but be careful because for C100 and C200 the correction of PSF is valid 
; for the whole array
pow = make_array(npix,value=1.e-16)
flux, pow, det, filt, aper, 0, pow_point
flux, pow, det, filt, aper, 1, pow_ext

IF det EQ 'SL' THEN BEGIN 
  flux, pow, 'SS', filt, aper, 0, pow_point1
  flux, pow, 'SS', filt, aper, 1, pow_ext1
  pow_point = [pow_point1, pow_point]
  pow_ext = [pow_ext1, pow_ext]
ENDIF  


conv_point2ext  = pow_ext/pow_point*1.e-6

;compute coordinates
ra = FLTARR(tmpscp.dims)
dec =  FLTARR(tmpscp.dims)
roll =  FLTARR(tmpscp.dims)
get_coordinates, tmpscp.admn, tmpscp.rpid, ra, dec, roll

mnfl = flux_str.flave
mnfu = flux_str.flunc
mdfl = flux_str.flmed
q1fl = flux_str.flq1
q3fl = flux_str.flq3

mnbr = mnfl * conv_point2ext 
mnbu = mnfu * conv_point2ext
mdbr = mdfl * conv_point2ext
q1br = q1fl * conv_point2ext
q3br = q3fl * conv_point2ext

mdr = intarr(tmpscp.dims) + dr
mdwel = intt * (mdr + INTARR(tmpscp.dims)) 


;fill elements
flag = flux_str.flflag*2^8

naap_str = 0
pix_start = 0
pix_end = npix
det_aap = det
admn = tmpdyncal.admn
hdr_str = {hdr0:newhdr}

IF det eq 'SL' THEN BEGIN 
   naap_str = 2
   det_aap = ['SS','SL']
   pix_start = [0,64]
   pix_end   = [63,127]
   hdr_str = {hdr0:newhdr,hdr1:newhdr}
   admns = admn
   STRPUT,admns,'S',1 
   uname = FXPAR(newhdr, 'PIA_MNAM')
   IF uname NE admn THEN INFO = [INFO,  'WARNING: Measurements '+   $
       STRTRIM(admns,2)+' and '+STRTRIM(admn,2)+' will have same user name '] $
   ELSE BEGIN 
      FXADDPAR, newhdr, 'PIA_MNAM',admns
      hdr_str.hdr0 = newhdr
   ENDELSE   
   admn = [admns,admn] 
ENDIF


; FILL aap structure
FOR iaap=0, naap_str-1 DO BEGIN 
	phtaapt = {PHTAAP_TYPE}
	FOR ihan=AAP_FIRST_HANDLE, AAP_LAST_HANDLE DO $
	   phtaapt.(ihan) = HANDLE_CREATE()

	phtaapt.det  = det_aap(iaap)
	phtaapt.admn = admn(iaap)
	phtaapt.dims = tmpscp.dims
	phtaapt.filt = filt
	phtaapt.aper = aper
	phtaapt.polz = polz
	phtaapt.cwvl = cwvl
	
	decp = mnfl(pix_start(iaap):pix_end(iaap)) * 0.
	rap = decp
	
	newheader = hdr_str.(iaap)
	HANDLE_VALUE, phtaapt.hdr, newheader, /SET
	HANDLE_VALUE, phtaapt.time, tmpscp.time, /SET
	HANDLE_VALUE, phtaapt.cstp, tmpscp.step, /SET
	HANDLE_VALUE, phtaapt.cpos, tmpscp.chop, /SET
	HANDLE_VALUE, phtaapt.dwel, mdwel, /SET
        HANDLE_VALUE, phtaapt.mnfl, mnfl(pix_start(iaap):pix_end(iaap)), /SET
	HANDLE_VALUE, phtaapt.mnfu, mnfu(pix_start(iaap):pix_end(iaap)), /SET 
	HANDLE_VALUE, phtaapt.mnbr, mnbr(pix_start(iaap):pix_end(iaap)), /SET
	HANDLE_VALUE, phtaapt.mnbu, mnbu(pix_start(iaap):pix_end(iaap)), /SET
	HANDLE_VALUE, phtaapt.mdfl, mdfl(pix_start(iaap):pix_end(iaap)), /SET
	HANDLE_VALUE, phtaapt.q1fl, q1fl(pix_start(iaap):pix_end(iaap)), /SET
	HANDLE_VALUE, phtaapt.q3fl, q3fl(pix_start(iaap):pix_end(iaap)), /SET
	HANDLE_VALUE, phtaapt.mdbr, mdbr(pix_start(iaap):pix_end(iaap)), /SET
	HANDLE_VALUE, phtaapt.q1br, q1br(pix_start(iaap):pix_end(iaap)), /SET
	HANDLE_VALUE, phtaapt.q3br, q3br(pix_start(iaap):pix_end(iaap)), /SET
	HANDLE_VALUE, phtaapt.rpid, tmpscp.rpid, /SET
	HANDLE_VALUE, phtaapt.dec, dec, /SET
	HANDLE_VALUE, phtaapt.ra, ra, /SET
	HANDLE_VALUE, phtaapt.decp, decp, /SET
	HANDLE_VALUE, phtaapt.rap, rap, /SET
	HANDLE_VALUE, phtaapt.roll, roll, /SET
	HANDLE_VALUE, phtaapt.flag, flag(pix_start(iaap):pix_end(iaap)), /SET
	
	phtaap = [phtaap, phtaapt]
	indaap = N_ELEMENTS(phtaap)-1
	IF iaap EQ 0 THEN aapps = indaap ELSE aapps = [aapps, indaap]
	
; use a trick to derive the rap and decp variables putting the structure back
	pia_load_iaap, phtaap(indaap), tmpaap
	gen_aap, tmpaap
	FXADDPAR, newheader, 'PIA_NAAP', 1, ' New type AAP: AAP2000', $
		BEFORE='XTENSION'
	
	fill_aap, tmpaap, newheader, replace=indaap
	

ENDFOR



RETURN
END
