;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO DYNCAL_CLEAR, index=index 
;+
; NAME:
;       DYNCAL_CLEAR
; PURPOSE:
;       It clears the  PHTDYNCAL structure, if no index is specified then it
;	will clear the whole structure
;
; CATEGORY:
;       PIA - initialization
;
; CALLING SEQUENCE:
;       DYNCAL_CLEAR
;
; INPUT PARAMETERS:
;       None       
; KEYWORDS:
;       Index:  If set, only those will be deleted from buffer
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phtdyncal
;
; MODIFICATION HISTORY:
;       Written by: J.Acosta (ESA/VILSPA-SAI)         		October 1998
;       V7.2
;-

@phtdyncal

        nelbuf = N_ELEMENTS(phtdyncal)
        IF nelbuf EQ 1 THEN RETURN
 
        flag = intarr(nelbuf)
 
        IF NOT KEYWORD_SET(index) THEN index = indgen(nelbuf-1)+1
 
        flag(index) = 1
 
        nele = N_ELEMENTS(index)
 
        if nele ge 1 then $
                for i = 0, nele - 1 do $
                 for ihan = dyncal_first_handle, dyncal_last_handle do $
                        handle_free, phtdyncal(index(i)).(ihan)
 
        ind = WHERE(flag EQ 0)
        phtdyncal = phtdyncal(ind)
 
 
END
 
