;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO FILL_DYNCAL, tmp, newheader, REPLACE=replace 
;+
; NAME:
;       FILL_DYNCAL
;
; PURPOSE:
;	FILLS a temporary structure dyncal into the dynamic structure PHTDYNCAL  
;
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;       FILL_DYNCAL, tmp [,newheader] [,REPLACE=replace]
;
; INPUT:
;       tmp 	: DYNCAL like temporary structure
;
; OPTIONAL INPUT:
;	newheader:  New header to be change into the structure
;
; KEYWORD:
;	REPLACE : IF set (different to 0) put structure into this PHTDYNCAL 
;		  position
;
; RESTRICTIONS:
;       tmp must be a valid phtdyncal like temporary structure
;
; PROCEDURES USED: 
;       Common Block(s) or @ procedure(s):
;               phtdyncal
;
; MODIFICATION HISTORY:
;       Written by:  J. Acosta (ISO-SOC, Vilspa)		July 1998
;	V7.x
;
;-
;
@phtdyncal
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  FILL_dyncal, tmp [,newhdr] [,REPLACE=replace]'


;  Create the structures and the handles
        phtidyncal = {PHTDYNCAL_TYPE}
	
	FOR ihan= dyncal_first_handle, dyncal_last_handle DO        $
	   phtidyncal.(ihan) = HANDLE_CREATE()

;  Fill the temporary ERD structure
        phtidyncal.admn = tmp.admn
        phtidyncal.meas_name = tmp.meas_name
        phtidyncal.det  = tmp.det
        phtidyncal.temperature = tmp.temperature
	phtidyncal.sldi = tmp.sldi
	phtidyncal.tinter = tmp.tinter
        phtidyncal.proc_time = tmp.proc_time
                           
;  Fill the handles
	IF N_PARAMS() LT 2 THEN HDR = tmp.hdr $ 
	  ELSE  HDR= newheader
        HANDLE_VALUE, phtidyncal.hdr,	 hdr	    ,/SET
        HANDLE_VALUE, phtidyncal.time,   tmp.time   ,/SET
	HANDLE_VALUE, phtidyncal.sig_tar,tmp.sig_tar,/SET
        HANDLE_VALUE, phtidyncal.unc_tar,tmp.unc_tar,/SET
        HANDLE_VALUE, phtidyncal.sig_cal,tmp.sig_cal,/SET
        HANDLE_VALUE, phtidyncal.rat	,tmp.rat    ,/SET
        HANDLE_VALUE, phtidyncal.urat	,tmp.urat   ,/SET
        HANDLE_VALUE, phtidyncal.mask	,tmp.mask   ,/SET
        HANDLE_VALUE, phtidyncal.flmed  ,tmp.flmed  ,/SET
        HANDLE_VALUE, phtidyncal.flave  ,tmp.flave  ,/SET
        HANDLE_VALUE, phtidyncal.flunc  ,tmp.flunc  ,/SET
        HANDLE_VALUE, phtidyncal.flux	,tmp.flux   ,/SET
        HANDLE_VALUE, phtidyncal.flag	,tmp.flag   ,/SET
        HANDLE_VALUE, phtidyncal.calid  ,tmp.calid  ,/SET

;  Update the PHTSRD structure using the temporary structure
	IF KEYWORD_SET(REPLACE) THEN BEGIN
		IF N_ELEMENTS(phtdyncal) LE replace THEN $
		  MESSAGE, /INFO, 'Non-existing position, returning' ELSE $
		  phtdyncal(replace) = phtidyncal 
	ENDIF ELSE $
          phtdyncal = [phtdyncal,phtidyncal]

        RETURN
        END
