;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       LOAD_CALIB_INUSE
;
;
; PURPOSE:
;	Load information from the dynamic calibration database
;
; CATEGORY:
;       PIA - Processing
;
; CALLING SEQUENCE:
;       load_calib_inuse, admn_list, calinfo_str
;
; MODIFICATION HISTORY:
;       Written by:     Jose Acosta (ISO SOC - VILSPA)          May 1998
;       Version 7.1
;
;-
PRO load_calib_inuse, admn_lst, cal_info, IFAIL = ifail, DET = det 
ON_ERROR,2

@phtdyncaldb

IF NOT KEYWORD_SET(grado_max) THEN grado_max = !polycheby_maxdeg
IF NOT KEYWORD_SET(det) THEN det = 'SL'
npix = pixel_det(det)

CASE det OF
 'SL': lotable = sl_lotable
 ELSE: BEGIN
         MESSAGE, 'ERROR: There is no database available for detector ' $ 
            +STRTRIM(det,2) 
       END
ENDCASE 
 


; first look for all needed calibrators, removing duplicates 
ind_uniq = REM_DUP(admn_lst)
;check that there is not empty entry
ind_noempty = WHERE(admn_lst(ind_uniq) NE "",noempty)
IF noempty EQ 0 THEN $
         MESSAGE, 'ERROR: Invalid calibrator selection '
ind_uniq = ind_uniq(ind_noempty)  
nuniq = N_ELEMENTS(ind_uniq)

cal_admn = STRARR(nuniq)
cal_time1 = FLTARR(nuniq)
cal_time2 = FLTARR(nuniq)
cal_flux  = FLTARR(nuniq,npix)
cal_grado = INTARR(nuniq,npix)
cal_coefcheby = FLTARR(grado_max,nuniq,npix)


FOR iu=0, nuniq-1 DO BEGIN 
   admn_tmp = admn_lst(ind_uniq(iu))
   ; first check if all needed calibrators are already loaded, if not load them
   ind_exist = WHERE(phtdyncaldb.admn EQ admn_tmp, nexist)
   IF nexist EQ 0 THEN BEGIN
     ind_lotable = WHERE(lotable.admn eq admn_tmp,nlotable)
     IF nlotable EQ 0 THEN MESSAGE, 'ERROR: '+STRTRIM(admn_tmp,2)+ $ 
        ' calibrator is not in the look-up table '
     ;read_chebydb,lotable(ind_lotable).measname+'_cheby_best.coef', $
     ;    tmpdyncaldb, PATH_COEFDB=path_db, DET = det 
     read_chebydb,lotable(ind_lotable).measname+'.coef',tmpdyncaldb, $
         PATH_COEFDB=path_db, DET = det 
     phtdyncaldb = [phtdyncaldb,tmpdyncaldb]    
   ENDIF 
   ind_cal = WHERE(phtdyncaldb.admn EQ admn_tmp)
   cal_admn(iu) = admn_tmp 
   cal_time1(iu) = phtdyncaldb(ind_cal(0)).time1  
   cal_time2(iu) = phtdyncaldb(ind_cal(0)).time2  
   handle_value, phtdyncaldb(ind_cal(0)).coefcheby,tmp
   cal_coefcheby(*,iu,*) = tmp
   handle_value, phtdyncaldb(ind_cal(0)).flux,tmp
   cal_flux(iu,*) = tmp
   handle_value, phtdyncaldb(ind_cal(0)).grado,tmp
   cal_grado(iu,*) = tmp    
ENDFOR 

cal_info = {admn:cal_admn, time1:cal_time1, time2: cal_time2, flux:cal_flux, $
            grado:cal_grado, coefcheby:cal_coefcheby}

RETURN
END
