;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       phtdyncal_init
;
; PURPOSE:
;       Initializes the structure phtdyncalib (dynamic calibration) 
;       defining the contents as a template structure phtdyncalib_type
;       It can be used for clearing the whole structure, in case 
;       this should show as necessary. 
;
; CATEGORY:
;       PIA - initialization
;
; CALLING SEQUENCE:
;       @phtdyncalib_init
;
; COMMON BLOCKS:
;       phtdyncalib
;
; MODIFICATION HISTORY:
;       Written by: J.Acosta (ESA/ESTEC)                  May 1998
;       Version 7.1
;
;-
;
PRO phtdyncal_init, INDEX = index
@phtdyncal
        ON_ERROR, 2
;
	
	PHTDYNCAL_GEN = {PHTDYNCAL_TYPE,	$
	ADMN:' ',				$
	MEAS_NAME:' ',				$
	DET: '??',				$
	TEMPERATURE: [0.,0.],			$
	SLDI: 0L,				$
	TINTER:0.,				$
	PROC_TIME:'',				$
	HDR: HANDLE_CREATE(),			$
	TIME: HANDLE_CREATE(),			$
	SIG_TAR: HANDLE_CREATE(),		$
	UNC_TAR: HANDLE_CREATE(),		$
	SIG_CAL: HANDLE_CREATE(),		$
	RAT: HANDLE_CREATE(),			$
	URAT: HANDLE_CREATE(),			$
	MASK: HANDLE_CREATE(),			$
	FLMED: HANDLE_CREATE(),			$
	FLAVE: HANDLE_CREATE(),			$
	FLUNC: HANDLE_CREATE(),			$
	FLUX: HANDLE_CREATE(),			$
	FLAG:  HANDLE_CREATE(),			$
	CALID: HANDLE_CREATE() }
	
	DYNCAL_FIRST_HANDLE = 7
	DYNCAL_LAST_HANDLE = 20
	
	PHTDYNCAL_DESC = [ 				$
                'ADMN Name ',                     	$
                'User Meas. Name ',                     $
                'Detector ',                		$
                'Temperature ',                		$
		'Number of signals',			$
		'Time interval',			$
                'Last processing time ',                $
		'Target time',				$
		'Target signals',			$
		'Target signal uncertainties',		$
		'Calibrator signals',			$
		'Target/calibrator Ratio ',		$
		'Uncertainty Target/calibrator Ratio ',	$
                'Mask of target signals',		$
                'MEDIAN  calibrated flux ',		$
                'MEAN  calibrated flux',                $
		'SIGMA calibrated flux',		$
		'Assign flux',				$
		'Flag ',				$
		'Calibrator identification '		$
                ]
 


	PHTDYNCAL = {PHTDYNCAL_TYPE}
	
RETURN
END	
