;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       phtdyncaldb_init
;
; PURPOSE:
;       Initializes the structure phtdyncaldb (dynamic calibration database) 
;	defining the contents as a template structure phtdyncaldb_type
;	It can be used for clearing the whole structure, in case 
;	this should show as necessary. 
;
; CATEGORY:
;       PIA - initialization
;
; CALLING SEQUENCE:
;       @phtdyncaldb_init
;
; COMMON BLOCKS:
;	phtdyncaldb
;
; MODIFICATION HISTORY:
;       Written by: J.Acosta (ESA/ESTEC)                  May 1998
;	Version 7.1
;			
;-
;
PRO phtdyncaldb_init, ONLY_NCAL=only_ncal
@phtdyncaldb
        ON_ERROR, 2
;
	; set number of calibrator used per pixel
	ncal_use = 2

	IF KEYWORD_SET(ONLY_NCAL) THEN RETURN
	
	;set maximum degree of Chebyshev expansion
	DEFSYSV,'!polycheby_maxdeg',16
	;; DET SL
	npix = 128
	PHTDYNCALDB_LOT = {SLDYNCALDBLOT_TYPE,  $
	     ADMN:' ', 				$
	     MEASNAME:' ',			$
	     DET: '',  			        $
	     NAME:' ',				$
	     SPTYPE:' ',			$
	     FLUX_L_N:FLTARR(2),		$
	     FLUX: FLTARR(npix),		$  
	     SGREF:FLTARR(6,npix),		$
	     WGREF:BYTARR(6,npix), 		$
	     FLREF:BYTARR(npix),		$
	     PROC_DATE: ' '}
	        	
	
	PHTDYNCALDB_GEN = {PHTDYNCALDB_TYPE,	$
	ADMN:' ',				$
	MEASNAME:' ',				$
	DET: '??',				$
	NAME: ' ',				$
	TIME1:0.,				$
	TIME2:0., 				$
	TEMPERATURE:FLTARR(2), 			$
	FLUX: HANDLE_CREATE(),			$
	GRADO:HANDLE_CREATE(),	     		$
        COEFCHEBY: HANDLE_CREATE(),	     	$
        FLAGCOEF: HANDLE_CREATE()}
	
	DYNCALDB_FIRST_HANDLE = 7
	DYNCALDB_LAST_HANDLE = 10
	
	PHTDYNCALDB_DESC = [ 				 $
                'Internal Name ',                        $
                'Neasurement Filename ',                 $
                'Detector ',                		 $
                'Source Name ',                    	 $
                'Time of first signal    ',              $
                'Time of last signal    ',               $
                'Detector temperature    ',              $
                'Equivalent flux (in Jy)',               $
                'Degree of Chebyshev polynomial',        $
                'Coefficients of Chebyshev polynomials', $
                'Flag of Chebyshev expansion']
 


	PHTDYNCALDB = {PHTDYNCALDB_TYPE}
		

RETURN
END
