;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_def_dyncal
;
; PURPOSE:
;       Simple widget I/F for defining the number of references and/or make
;	a selection of sources to be used in the dynamic calibration
;
; CATEGORY:
;       PIA - graphics
;
; CALLING SEQUENCE:
;       PIA_def_dyncal
;
;
; COMMON BLOCKS:
;       phtdyncaldb
;
; PROCEDURES USED:
;       none
;
; MODIFICATION HISTORY:
;       Written by:     J. Acosta (ISO-SOC, Vilspa)      	August 1998
;       Version 7.x
;	Code bug (not accepted by IDL5.3) corrected (CG)	March 2000
;	V8.2
;-
PRO pia_def_dyncal, det, ncalib, sel_lotable, ISTOP = istop

ON_ERROR, 2

@phtdyncaldb

istop = 0

IF N_ELEMENTS(sl_lotable) EQ 0 THEN get_lotable_all

ncaluse_org = ncal_use
ncaluse_tmp = ncaluse_org

CASE det OF 
	'SL': BEGIN 
		ind_mask_def = WHERE(sl_mask_lotable EQ 1)
	        lotable_tmp = sl_lotable
	      END	
	ELSE: MESSAGE,'Not valid detector for dynamic calibration '
ENDCASE	

ind_mask_org = ind_mask_lotable 
ind_mask_tmp = ind_mask_org

;; define the widget
junkbase = WIDGET_BASE(title='Customize dynamic calibration ',/COLUMN,$
         xsize=400)

junkbase1 = WIDGET_BASE(junkbase, /COLUMN,/frame)
junkbase2 = WIDGET_BASE(junkbase1,/ROW)
junk = WIDGET_LABEL(junkbase2, VAL='Number of calibrators to be used per pixel ')
wid_ncal = WIDGET_TEXT(junkbase2, /EDITABLE, XSIZE=4, YSIZE=1, $ 
		VALUE=STRTRIM(ncal_use,2),UVALUE='NCAL')
junkbase2 = WIDGET_BASE(junkbase1,/ROW)
res1 = WIDGET_BUTTON(junkbase2,VALUE='Previous values',  $
         UVALUE='RESET_NCAL')
res2 = WIDGET_BUTTON(junkbase2,VALUE='Default values', $		
         UVALUE='DEFAULT_NCAL')
junk = WIDGET_LABEL(junkbase,VAL=' ')
junkbase2 = WIDGET_BASE(junkbase,/COLUMN)
junk = WIDGET_BUTTON(junkbase2, UVALUE='PRESEL', $
      VAL='Pre-select individual calibrators from the database ')

junk = WIDGET_LABEL(junkbase,VAL=' ')

wid_setdef = CW_BGROUP(junkbase,' Set selection as default ', /COLUMN, $
      /NONEXCLUSIVE, UVALUE='SETDEF')

junkbase2 = WIDGET_BASE(junkbase,/ROW)
ok = WIDGET_BUTTON(junkbase2, VALUE='  OK  ',UVALUE='OK')
cancel = WIDGET_BUTTON(junkbase2, VALUE=' Cancel ', UVALUE='CANCEL')


;realize the widget
WIDGET_CONTROL, junkbase, /REALIZE


;start loop until exit is selected
exit_wid = 0 
REPEAT  BEGIN
	event = WIDGET_EVENT(junkbase)
	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	CASE uvalue OF 
	'PRESEL': BEGIN 
			pia_presel_dyncal, lotable_tmp, ind_mask_tmp,  $
			     ind_mask_org, ind_mask_def	
			siz = SIZE(ind_mask_tmp)
			IF siz(0) EQ 0 OR N_ELEMENTS(ind_mask_tmp) EQ 0 THEN BEGIN
				ind_mask_tmp = ind_mask_org
				print,'Warning: Selection not valid, '+ $
					' returning to previous one'
			ENDIF		
		  END	
	'OK':     BEGIN
			WIDGET_CONTROL, wid_ncal, GET_VALUE= str_ncal
			ncaluse_tmp = FIX(str_ncal(0)) 
			exit_wid = 1
		  END
	'CANCEL': BEGIN
	            	ncaluse_tmp = ncaluse_org
			ind_mask_tmp = ind_mask_org
			exit_wid = 1
			istop = 1
		  END
	'DEFAULT_NCAL': BEGIN
	                phtdyncaldb_init,/ONLY_NCAL
			ncaluse_tmp = ncal_use
			WIDGET_CONTROL, wid_ncal, $ 
			    SET_VALUE = STRTRIM(ncaluse_tmp,2)
		      END	    
	'RESET_NCAL': BEGIN
			ncaluse_tmp = ncaluse_org
			WIDGET_CONTROL, wid_ncal, $ 
			    SET_VALUE = STRTRIM(ncaluse_tmp,2)
		      END	    
	ELSE:	  
	ENDCASE	  
	
ENDREP UNTIL exit_wid

WIDGET_CONTROL, wid_setdef, GET_VALUE=setdef

WIDGET_CONTROL, junkbase, /DESTROY 


; perform consistency checks: ncal_use > 0 & ncal_use =< N_ELEMENTS(lotable_tmp)
;   
IF ncaluse_tmp GT 0 THEN ncalib = ncaluse_tmp ELSE ncalib = ncaluse_org
IF N_ELEMENTS(ind_mask_tmp) LT ncalib THEN BEGIN 
	ind_mask_tmp = ind_mask_org
	MESSAGE,'Number of preselected calibrators cannot be smaller '+ $
	       'than those selected per pixel.', /INFO
	MESSAGE, 'Returning to previous selection. '       
ENDIF 	 

sel_lotable = lotable_tmp(ind_mask_tmp)

IF setdef THEN BEGIN
	ncal_use = ncalib
	ind_mask_lotable = ind_mask_tmp
ENDIF


RETURN
END
