;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_disp_calid
;
; PURPOSE:
;       Displays calibrator identificator for dynamic calibration
;       
; CATEGORY:
;          PIA - graphics
;
; CALLING SEQUENCE:
;       PIA_disp_calid, tmpdyncal
;
; INPUT PARAMETERS:
;       tmpdyncal: A static phtdyncal structure
;
; KEYWORD PARAMETERS:
;       GROUP=group: Group leader
;
; COMMON BLOCKS:
;       @phtdyncaldb
;
; PROCEDURES USED:
;       PIA:
;               pia_disp_print_file
;		
;
; MODIFICATION HISTORY:
;       Written by: J. Acosta (ISO-SOC, Vilspa) 		        Jul.98
;       V7.x
;
;-
;*****************************************************************************
;main program
;*****************************************************************************
 
pro pia_disp_calid, tmpdyncal, GROUP=group

ON_ERROR,2
 
@phtdyncaldb 


;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, /INFO, $
          'Syntax:  PIA_disp_dyncal, tmpdyncal, [GROUP=group]'
 

; check that lookup table is loaded
 	IF N_ELEMENTS(sl_lotable) EQ 0 THEN phtdyncaldb_init 
 
        CASE tmpdyncal.det OF
	   'SL': lotable = sl_lotable
	   ELSE: MESSAGE,'Detector not valid'
	ENDCASE
 
        decode_admn, tmpdyncal.admn, decname
 
        title = 'Selected calibrators for '+decname

	NCAL_USE = N_ELEMENTS(tmpdyncal.calid(*,0))
	npix = PIXEL_DET(tmpdyncal.det)
	
	text = 'Pixel'
	FOR ical=0,ncal_use-1 DO text = text + '    SRCNAME_CAL'+ $
	      STRTRIM(ical+1,2) +'   '+'MEASID_CAL'+STRTRIM(ical+1,2)
	
	junk = ''
	FOR i =0,STRLEN(text)-1 DO junk = junk + '-'  
	text = [text,junk]   
	
	FOR ipix=0, npix-1 DO BEGIN 
	   addtext =  STRING(ipix+1,FORMAT='(I3,2x)') + '  '  
	    FOR ical=0,ncal_use-1 DO BEGIN
	      calid_admn = tmpdyncal.calid(ical,ipix)
	      ind = where(lotable.admn eq calid_admn,nind)
	      IF nind GT 0 THEN name = lotable(ind).name   $
	         ELSE name = "Meas. error"
	      addtext = addtext + $
	         STRING(name,calid_admn,FORMAT='(4x,A12,2x,A12)')
	    ENDFOR  
	   text = [text,addtext]
	ENDFOR  

        text = [title, ' ', text]
        font='-*-courier-bold-*-*-*-14-*'
	filnam = tmpdyncal.admn+'_calid'
 
        PIA_DISP_PRINT_FILE, filnam, TITLE=title, TEXT=text, $
                HEIGHT=40, FONT=font
 
RETURN
END
 
