;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_DISPDYNCAL
;
; PURPOSE:
;	Menu for PIA Dynamical Calibration Analysis intermediate level.
;
;	This routine should only be called by the PIA Display Data routine
;	and should not be called directly from the command line.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_DISPDYNCAL, dyncalps, srd, aapps,  NV = NV, GROUP=group
;
; INPUT PARAMETERS:
;	dyncalps:	Position within the phtdyncal dynamycal structure
;	srd:		Temporary SRD level structure
;	aapps:		Position within the phtaap dynamycal structure
;
; KEYWORD PARAMETERS:
;	GROUP:	The group leader of the widget hirarchy
;       NV:	Number of Views (1 <= NV <= 4)
;
; COMMON BLOCKS:
;	adm
;	colour_indices
;	drift_not_acc
;	phtdyncal
;	phtaap
;	pia_driftmod_out
;	pia_dispdyncal_cmn (internal)
;	pia_dspchdyn_cmn (internal)
;	pia_dspchz_cmn 
;	pia_widget_info 
;
; PROCEDURES USED:
;	PIA LIB:
;		pia_xplot
;		pia_showstr
;		pia_disp_hdr 
;		pia_disp_cs
;		pia_disp_isr
;		pia_disp_stat
;		pia_dispaap
;       ASTRO LIB:
;       INTERNAL:
;		 drft_showpar
;		 pixbuteventd
;		 viewevent_dyncal
;		 zoomevent_dyncal
;		 zoomsync_dyncal
;		 zoomnsync_dyncal
;		 pia_resetview_dyncal
;		 pia_dispdyncal_event
;
; MODIFICATION HISTORY:
;     Written by: J.Acosta (ESA/VILSPA-SAI)          September 1998
;     Minor correction concerning flags  (JA)        January 1999
;     Replacing numbers by letters in pixel ind.      (Jacosta) March 2000
;       V8.2
;			
;-
; *********************************************************************
; * Show calibrated flux
; *********************************************************************
PRO dyncal_showflux, event
COMMON pia_dispdyncaldat_cmn, tmpdyncal, tmpdyncalps, tmpsrd, tmpaapps, ncal_use
COMMON pia_dspchdyn_cmn, pixcho, psymch, pixcount
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices
     
     WIDGET_CONTROL, event.id, GET_UVALUE= plot_choice
     fluxindexid = WIDGET_INFO(event.id, /PARENT)
     WIDGET_CONTROL, fluxindexid, GET_UVALUE = cal_ind

     ;plot_choice indicates the calibrator index and the choice 
     ; [NEW, SYNC,NSYNC], eg. 1_NEW 
     ;flux_choice is the use of mean (0) or median (1) or flux from model (2)
          
     flux_choice = FIX(gettok(plot_choice,'_'))
         
     CASE flux_choice OF 
         0: BEGIN 
	     flux = tmpdyncal.flave 
	     flunc = tmpdyncal.flunc
	    END 
	 1: BEGIN 
	     flux = tmpdyncal.flmed
	     flunc = tmpdyncal.flunc
	    END
	 ELSE: BEGIN 
	     flux = tmpdyncal.flux
	     flunc = flux*0.
	    END 
     ENDCASE	
      
     CASE plot_choice OF
	'NEW': overpl = 0
	'SYNC': overpl = 1
	'NSYNC': overpl = -1
     ENDCASE
     
     charsize = 1.10
     IF overpl NE 0 THEN BEGIN
		xstyle = 0
		ystyle = 0
		IF zoom_color EQ -1 THEN zoom_color = green ELSE $
			zoom_color = zoom_color + 1
		IF zoom_color EQ 9 then zoom_color = 4
		zoom_psymch = zoom_psymch + 1
		IF zoom_psymch EQ 8 then zoom_psymch = 1

		title = ''
     ENDIF ELSE BEGIN
		xstyle = 0
		ystyle = 0
		zoom_color = -1
		zoom_psymch = psymch
     ENDELSE

     npix = pixel_det(tmpdyncal.det)
     x = INDGEN(npix)+1
     yy = flux(cal_ind,*)
     yyunc = flunc(cal_ind,*)
     
     tit = tmpdyncal.admn+' Calibrated flux'
     IF flux_choice THEN leg = 'Calibrated flux (from medians) ' $
       ELSE leg = 'Calibrated flux (from averages) '
     leg = leg + STRTRIM(cal_ind+1,2) 
     anntmp = '  ' 
     PIA_XPLOT, x, yy, yyunc, psym=zoom_psymch, xtitle='  Pixel Number ',  $
   	ytitle = ytitle, title= tit, legend = leg, $
	overplot = overpl, charsize = charsize,    $ 
	color = zoom_color, xstyle=xstyle,         $       
        ystyle=ystyle, annotation=anntmp                    
     
     
RETURN
END


; *********************************************************************
; *
; *********************************************************************
pro pixbuteventd, event

COMMON pia_dispdyncal_cmn, view, viewsize, nviews, viewoptions, overid,  $
	 dyncaldi1_wid, ical_use 
COMMON pia_dspchdyn_cmn, pixcho, psymch, pixcount
COMMON dspdyn_widg, pixbut

        WIDGET_CONTROL, event.id, GET_UVALUE = new_pixbut

        ind = WHERE(pixcho eq new_pixbut(0))
        ind = ind(0)

       	text = ["A", "B", "C", "D"]
       IF ind LT 0 or ind GE nviews THEN BEGIN

          pixcount = pixcount+1
          IF pixcount GE nviews THEN pixcount = 0

          old_pixcho = pixcho(pixcount)
          pixcho(pixcount) = new_pixbut(0)

          view(pixcount).viewtype = 0
          pia_resetview_dyncal, pixcount, view(pixcount).controlid

          txtval = text(pixcount)
          WIDGET_CONTROL, pixbut(old_pixcho), $
                                SET_VALUE = ' '
          WIDGET_CONTROL, pixbut(pixcho(pixcount)), $
                        SET_VALUE = txtval
        ENDIF
END

; *********************************************************************
; *
; *********************************************************************
pro viewevent_dyncal, event

COMMON pia_dispdyncal_cmn, view, viewsize, nviews, viewoptions, overid,  $
	 dyncaldi1_wid, ical_use 
COMMON pia_dspchdyn_cmn, pixcho, psymch, pixcount

	viewindexid = WIDGET_INFO(event.id, /PARENT)
	WIDGET_CONTROL, viewindexid, GET_UVALUE = viewindex
	WIDGET_CONTROL, event.id, GET_UVALUE = setting
	setting = setting(0)

	IF (view(viewindex(0)).viewtype NE setting) THEN BEGIN
		view(viewindex(0)).viewtype = setting
		pia_resetview_dyncal, viewindex, viewindexid
	ENDIF
END


; *********************************************************************
; *
; *********************************************************************
pro viewevent_dyncal_sub, event

COMMON pia_dispdyncal_cmn, view, viewsize, nviews, viewoptions, overid,  $
	 dyncaldi1_wid, ical_use 
COMMON pia_dspchdyn_cmn, pixcho, psymch, pixcount

	; get index of individual window choice
	viewchoindexid = WIDGET_INFO(event.id, /PARENT)
	WIDGET_CONTROL, viewchoindexid, GET_UVALUE = setting_choi
	; get index of window
        viewindexid = WIDGET_INFO(viewchoindexid,/PARENT)
	WIDGET_CONTROL, viewindexid, GET_UVALUE = viewindex
	; get value of setting 
	WIDGET_CONTROL, event.id, GET_UVALUE = setting
	setting = setting(0)

	IF (view(viewindex(0)).viewtype NE setting_choi OR $
	    view(viewindex(0)).viewtype_sub NE setting) THEN BEGIN
		view(viewindex(0)).viewtype_sub = setting
		view(viewindex(0)).viewtype = setting_choi
		pia_resetview_dyncal, viewindex, viewindexid
	ENDIF
END


; *********************************************************************
; *
; *********************************************************************
pro zoomevent_dyncal, event

	WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
	zoomitdyn, windowindex        
END


; *********************************************************************
; *
; *********************************************************************
pro zoomsync_dyncal, event

	WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
	zoomitdyn, windowindex, overplot = 1        

END

; *********************************************************************
; *
; *********************************************************************
pro zoomnsync_dyncal, event

	WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
	zoomitdyn, windowindex, overplot = -1        

END

; *********************************************************************
; *
; *********************************************************************
pro zoomitdyn, windowindex, overplot=overplot

COMMON pia_dispdyncal_cmn, view, viewsize, nviews, viewoptions, overid,  $
	 dyncaldi1_wid, ical_use 
COMMON pia_dispdyncaldat_cmn, tmpdyncal, tmpdyncalps, tmpsrd, tmpaapps, ncal_use
COMMON pia_dspchdyn_cmn, pixcho, psymch, pixcount
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
COMMON phtacc_ratsig, phtacc_ratsig
@colour_indices

	  
	
	IF (KEYWORD_SET(overplot)) THEN overplot = overplot ELSE overplot = 0

	xtitle = viewoptions(view(windowindex).viewtype).viewxlab
	ytitle = viewoptions(view(windowindex).viewtype).viewylab
	cal_choice = view(windowindex).viewtype_sub

	; get the number of signals discarded starting from  the first in time	
	nsigupto = GET_SIGUPTO(phtacc_ratsig, tmpdyncal.sldi, $ 
		    tmpdyncal.tinter)   

	decode_admn, tmpdyncal.admn, title
	title = title 


        ytype = 0

	charsize = 1.10
	IF overplot NE 0 THEN BEGIN
		xstyle = 0
		ystyle = 0
		IF zoom_color EQ -1 THEN zoom_color = green ELSE $
			zoom_color = zoom_color + 1
		IF zoom_color EQ 9 then zoom_color = 4
		zoom_psymch = zoom_psymch + 1
		IF zoom_psymch EQ 8 then zoom_psymch = 1

		title = ''
	ENDIF ELSE BEGIN
		xstyle = 0
		ystyle = 0
		zoom_color = -1
		zoom_psymch = psymch
        ENDELSE


	CASE view(windowindex).viewtype OF

;Plot signal ratio between target and calibrator
	  0: BEGIN
	  
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Ratio to calib. #'+STRTRIM(cal_choice+1,2) + $ 
		      ': Pixel '+str_pixch
		ytitle = str_pixch 
		
		legend = str_pixch

		; plot valid model fitting, check mask values
		ind_val = WHERE(tmpdyncal.mask(*,cal_choice+1,pixch) EQ 1, nval)
		ind_nval = WHERE(tmpdyncal.mask(*,cal_choice+1,pixch) EQ 0, nnval)
		ind_nsgval = WHERE(tmpdyncal.mask(*,0,pixch) GT 1,nnsgval)
		
		minxx = MIN(tmpdyncal.time,MAX=maxxx)
		yy = tmpdyncal.rat(*,cal_choice,pixch)
		yyunc =  REFORM(tmpdyncal.unc_tar(pixch,*)/  		      $ 
		     tmpdyncal.sig_tar(pixch,*))*yy  

		PIA_XPLOT, tmpdyncal.time, yy, yyunc, psym=zoom_psymch, $
			  xtitle=xtitle, ytitle=ytitle, ytype=ytype,  $
			  color=white,legend = legend, charsize=charsize,     $
			  title=title,subtitle=subtitle, overplot = overplot, $
			  xstyle=xstyle, ystyle=ystyle
	        IF nnval GT 0 THEN $
		 PIA_XPLOT, tmpdyncal.time(ind_nval), yy(ind_nval),           $
		          psym=7, color=magenta, overplot=99,                 $
			  legend=' not valid calibrator signals'
		IF nnsgval GT 0 THEN $ 
		 PIA_XPLOT, tmpdyncal.time(ind_nsgval), yy(ind_nsgval),	      $
		          psym=7, color=red, overplot=99,		      $
			  legend=' discarded signals'  
		; flag discarded points due to selection criterium
		IF nsigupto GT 0 THEN $ 
		 PIA_XPLOT, tmpdyncal.time(0:nsigupto-1), yy(0:nsigupto-1), $
		          psym =7, color=yellow, overplot=99,		      $
			  legend=' not selected signals'  
	  

    	  END

;Plot target signals
	  1: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Signal: Pixel '+str_pixch+'  [V/s]' 
		ytitle = str_pixch 

		
		; plot valid model fitting, use only valid points, note the
		; different meaning of mask, which is a flag
		ind_val = WHERE(tmpdyncal.mask(*,0,pixch) LE 1, nval)
		ind_nval = WHERE(tmpdyncal.mask(*,0,pixch) GT 1, nnval)
		
		minxx = MIN(tmpdyncal.time,MAX=maxxx)
		yy = tmpdyncal.sig_tar(pixch,*)
		yyunc = tmpdyncal.unc_tar(pixch,*)

		PIA_XPLOT, tmpdyncal.time, yy, yyunc, psym=zoom_psymch,       $
		      xtitle=xtitle, ytitle=ytitle, ytype=ytype, title=title, $
		      subtitle=subtitle, overplot = overplot,                 $
		      charsize = charsize, color = zoom_color,                $
			xstyle=xstyle, ystyle=ystyle,                         $
                        legend=strmid(ytitle,0,20),                           $
                        annotation=anntmp                      
	        IF nnval GT 0 THEN $
		 PIA_XPLOT, tmpdyncal.time(ind_nval), yy(ind_nval), psym=7, $
		      color=red,overplot=1, legend=' discarded signals'

		; flag discarded points due to selection criterium
		IF nsigupto GT 0 THEN $ 
		 PIA_XPLOT, tmpdyncal.time(0:nsigupto-1), yy(0:nsigupto-1), $
		          psym =7, color=yellow, overplot=99,		      $
			  legend=' not selected signals'  
    	  END


;Plot  target signal flags
	  2: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Flags: Pixel '+str_pixch
		ytitle = str_pixch 

		pia_xplot, tmpdyncal.time, $
			tmpdyncal.mask(*,0,pixch), $
			psym = zoom_psymch, xtitle=xtitle, subtitle=subtitle,  $
			ytitle=ytitle, title=title, overplot=overplot,         $
			charsize = charsize, color= zoom_color,                $
			symsize=symsize, legend = ytitle              

    	  END

;Plot calibrator signals 
	  3: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Signal Calib. #' + STRTRIM(cal_choice+1,2) + $ 
		  ': Pixel '+str_pixch+'  [V/s]' 
		ytitle = str_pixch 

		; plot valid model fitting, check mask values
		ind_val = WHERE(tmpdyncal.mask(*,cal_choice+1,pixch) EQ 1, nval)
		ind_nval = $
		  WHERE(tmpdyncal.mask(*,cal_choice+1,pixch) EQ 0, nnval)
		
		yy = tmpdyncal.sig_cal(*,cal_choice,pixch)
		
		PIA_XPLOT, tmpdyncal.time, yy, psym=zoom_psymch, xtitle=xtitle, $
		   ytitle=ytitle, subtitle = subtitle, title=title, $
		   overplot=overplot, charsize=charsize, legend=ytitle, $
		   color=zoom_color
	        IF nnval GT 0 THEN $
		 PIA_XPLOT, tmpdyncal.time(ind_nval), yy(ind_nval),            $
	           psym=7, xtitle=xtitle, ytitle=ytitle, title=title,          $
	           subtitle=subtitle,color=red, overplot = 1, $
		   legend=' not valid calibrator signals'

	     END

;Plot average flux 
	  4: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Flux (Average): Pixel '+str_pixch
		ytitle = str_pixch 

	        yyunc = tmpdyncal.flunc(*,pixch)
		pia_xplot, INDGEN(ncal_use)+1, tmpdyncal.flave(*,pixch),       $
			yyunc, psym = zoom_psymch, xtitle=xtitle,     	       $
			ytitle = ytitle, subtitle=subtitle, title=title,       $
			charsize = charsize, symsize=symsize, legend=ytitle,   $
			color = zoom_color, overplot = overplot
			
          END

;Plot median flux
	  5: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Flux (Median): Pixel '+str_pixch
		ytitle = str_pixch 

	        yyunc = tmpdyncal.flunc(*,pixch)
		pia_xplot, INDGEN(ncal_use)+1, tmpdyncal.flmed(*,pixch),       $
			yyunc, psym = zoom_psymch, xtitle=xtitle,     	       $
			ytitle = ytitle, subtitle=subtitle,                    $
			title=title, charsize = charsize, symsize=symsize,     $
			color = zoom_color, legend=ytitle, overplot = overplot


          END

;Plot calibrator flux
	  6: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Calibrator Flux: Pixel '+str_pixch
		ytitle = str_pixch 

		pia_xplot, INDGEN(ncal_use)+1, tmpdyncal.flux(*,pixch),        $
			psym = zoom_psymch, xtitle=xtitle, ytitle = ytitle,    $
			subtitle=subtitle, title=title, charsize = charsize,   $
			symsize=symsize, color = zoom_color, legend=ytitle,    $
			overplot = overplot

          END

	  ELSE: MESSAGE, /INFO, 'Unsupported View'
          ENDCASE

END

; *********************************************************************
; *
; *********************************************************************
pro pia_resetview_dyncal, windowindex, UPDATE_LABEL

COMMON pia_dispdyncal_cmn, view, viewsize, nviews, viewoptions, overid,  $
	 dyncaldi1_wid, ical_use 
COMMON pia_dispdyncaldat_cmn, tmpdyncal, tmpdyncalps, tmpsrd, tmpaapps, ncal_use
COMMON pia_dspchdyn_cmn, pixcho, psymch, pixcount
COMMON phtacc_ratsig, phtacc_ratsig
@colour_indices


	  

	wset, view(windowindex).windownum         ;set to draw in 

	ERASE, color = 100                        ;erase the view


	IF NOT (KEYWORD_SET(UPDATE_LABEL)) THEN $
	  UPDATE_LABEL = 0


        charsize = 0.8
        symsize = 0.5

        title = viewoptions(view(windowindex).viewtype).viewname
	xtitle = viewoptions(view(windowindex).viewtype).viewxlab
	ytitle = viewoptions(view(windowindex).viewtype).viewylab
	cal_choice = view(windowindex).viewtype_sub

	; get the number of signals discarded starting from  the first in time	
	nsigupto = GET_SIGUPTO(phtacc_ratsig, tmpdyncal.sldi, $ 
		    tmpdyncal.tinter)   


	CASE view(windowindex).viewtype OF


;Plot ratio between target and calibrator
	  0: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Ratio to calib. #'+STRTRIM(cal_choice+1,2) + $ 
		      ': Pixel '+str_pixch
		ytitle = str_pixch 

		; plot valid model fitting, check mask values
		ind_val = WHERE(tmpdyncal.mask(*,cal_choice+1,pixch) EQ 1, nval)
		ind_nval = WHERE(tmpdyncal.mask(*,cal_choice+1,pixch) EQ 0, $
		   nnval)
		ind_nsgval = WHERE(tmpdyncal.mask(*,0,pixch) GT 1,nnsgval)
		
		minxx = MIN(tmpdyncal.time,MAX=maxxx)
		yy = tmpdyncal.rat(*,cal_choice,pixch)
		yyunc = REFORM(tmpdyncal.unc_tar(pixch,*)/  		      $ 
		     tmpdyncal.sig_tar(pixch,*))*yy 
		IF nval GT 1 THEN minyy = MIN(yy(ind_val), $ 
		  MAX=maxyy) $
		  ELSE minyy = MIN(yy,MAX=maxyy)   
		PIA_PLOT, [minxx, maxxx],[minyy, maxyy], /nodata, $
			  xtitle=xtitle, ytitle=ytitle, charsize = charsize  

		IF nval GT 0 THEN                                       $
		  PIA_OPLOT, tmpdyncal.time, yy, yerr=yyunc(ind_val),   $
			  psym=4, color=white
		; flag discarded points due to not valid range of calibrator  
	        IF nnval GT 0 THEN $
		  PIA_OPLOT, tmpdyncal.time(ind_nval), yy(ind_nval), $
		          psym=7, color=magenta
		; flag discarded points due to glitches	  
	        IF nnsgval GT 0 THEN $
		  PIA_OPLOT, tmpdyncal.time(ind_nsgval), yy(ind_nsgval), $
		          psym=7, color=red
		; flag discarded points due to selection criterium
		IF nsigupto GT 0 THEN $ 
		  PIA_OPLOT, tmpdyncal.time(0:nsigupto-1), yy(0:nsigupto-1), $
		          psym =7, color=yellow	  

  
		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  
          
          END


;plot target signals
	  1: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Signal: Pixel '+str_pixch+'  [V/s]' 
		ytitle = str_pixch 

		
		; plot valid raw signal, use only valid points, note the
		; different meaning of mask, which is a flag
		ind_val = WHERE(tmpdyncal.mask(*,0,pixch) LE 1, nval)
		ind_nval = WHERE(tmpdyncal.mask(*,0,pixch) GT 1, nnval)
		

		minxx = MIN(tmpdyncal.time,MAX=maxxx)
		yy = tmpdyncal.sig_tar(pixch,*)
		IF nval GT 1 THEN minyy = MIN(yy(ind_val), MAX=maxyy) $
		  ELSE minyy = MIN(yy(*),MAX=maxyy)   
		PIA_PLOT, [minxx, maxxx],[minyy, maxyy], /nodata, $
			  xtitle=xtitle, ytitle=ytitle, charsize = charsize  


		PIA_OPLOT, tmpdyncal.time, tmpdyncal.sig_tar(pixch,*), $
	            yerr = tmpdyncal.unc_tar(pixch,*), psym=4, color=white
	        IF nnval GT 0 THEN $
		 PIA_OPLOT, tmpdyncal.time(ind_nval), $
		          tmpdyncal.sig_tar(pixch,ind_nval), psym=7, color=red
		IF nsigupto GT 0 THEN $ 
		  PIA_OPLOT, tmpdyncal.time(0:nsigupto-1), $
		          tmpdyncal.sig_tar(pixch,0:nsigupto-1), psym =7, $
			  color=yellow	  

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  
         
    	  END

;Plot  target signal flags
	  2: BEGIN

		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Flags: Pixel '+str_pixch
		ytitle = str_pixch 

		
		pia_plot, tmpdyncal.time, $
			tmpdyncal.mask(*,0,pixch), $
			psym = psymch, xtitle=xtitle,  $
			ytitle=ytitle,  $
			title=title,  $
			charsize = charsize, symsize=symsize              

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  
          
    	  END


;Plot calibrator signals 
	  3: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Signal Calib. #' + STRTRIM(cal_choice+1,2) + $ 
		  ': Pixel '+str_pixch+'  [V/s]' 
		ytitle = str_pixch 

		
		; plot valid model fitting, check mask values
		ind_val = WHERE(tmpdyncal.mask(*,cal_choice+1,pixch) EQ 1, nval)
		ind_nval = WHERE(tmpdyncal.mask(*,cal_choice+1,pixch) EQ 0, nnval)
		
		minxx = MIN(tmpdyncal.time,MAX=maxxx)
		yy = tmpdyncal.sig_cal(*,cal_choice,pixch)
		IF nval GT 1 THEN minyy = MIN(yy(ind_val), $ 
		  MAX=maxyy) $
		  ELSE minyy = MIN(yy,MAX=maxyy)   
		PIA_PLOT, [minxx, maxxx],[minyy, maxyy], /nodata, $
			  xtitle=xtitle, ytitle=ytitle, charsize = charsize  

		PIA_OPLOT, tmpdyncal.time, yy, psym=4, color=white
	        IF nnval GT 0 THEN $
		 PIA_OPLOT, tmpdyncal.time(ind_nval), yy(ind_nval), $
			   psym=7, color=red

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  
	     END

;Plot average flux 
	  4: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Flux (Average): Pixel '+str_pixch
		xtitle = 'Calibrator number'
		ytitle = str_pixch 

		pia_plot, INDGEN(ncal_use)+1, tmpdyncal.flave(*,pixch), $
			YERR=tmpdyncal.flunc(*,pixch), psym = psymch, $
			xtitle=xtitle, ytitle = ytitle, $
			title=title, $
			charsize = charsize, symsize=symsize

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  
          
     
          END

;Plot median flux
	  5: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Flux (Median): Pixel '+str_pixch
		ytitle = str_pixch 
		xtitle = viewoptions(5).viewxlab

		pia_plot, INDGEN(ncal_use)+1, tmpdyncal.flmed(*,pixch), $
			YERR=tmpdyncal.flunc(*,pixch), psym = psymch, $
			xtitle=xtitle, ytitle = ytitle, $
			title=title, $
			charsize = charsize, symsize=symsize

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  
			  
		
          END


;Plot calibrator flux
	  6: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Calibrator Flux: Pixel '+str_pixch
		ytitle = str_pixch 

		pia_plot, INDGEN(ncal_use)+1, tmpdyncal.flux(*,pixch), $
			psym = psymch, $
			xtitle=xtitle, ytitle = ytitle, $
			title=title, $
			charsize = charsize, symsize=symsize

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  
			  
		
          END
	  ELSE: WIDGET_CONTROL, UPDATE_LABEL, $
				set_value = 'Unsupported View'
          ENDCASE

END


; ***************************************************************************
;  Combination of several calibrators using different weightings (all pixels)
; ****************************************************************************
PRO cal_combine, event

COMMON pia_dispdyncaldat_cmn, tmpdyncal, tmpdyncalps, tmpsrd, tmpaapps, ncal_use

	WIDGET_CONTROL, event.id, GET_UVALUE= comb_opt

	CASE comb_opt OF
	
	  "COMBINE_SELECT": BEGIN  ;not yet available
	  END

	  ELSE: BEGIN 
	         CASE comb_opt OF 
		    "COMBINE_WEIGHT": weight = 1
		    "COMBINE_SIGMA": weight = 2
		    ELSE: weight = 0
		 ENDCASE   
	  	 combine_dynsrd, tmpdyncal, combflux_avg, combflux_med, $
			combflux_avun, combflux_q1, combflux_q3, $
			OFLAG = oflag, WEIGHT = weight
	  END

	ENDCASE 
	  
	
	flux_str = {flave:combflux_avg, flunc:combflux_avun, flflag:oflag, $
	  flmed:combflux_med, flq1:combflux_q1, flq3:combflux_q3}
	
	; create the aap structure
	dyncal2aap, tmpdyncal, flux_str, tmpsrd, tmpaapps  

        ; display the data in aap window
	IF N_ELEMENTS(tmpaapps) NE 0 THEN $
		pia_dispaap, data = tmpaapps(0) 

END

; ***************************************************************************
;  Combination of several calibrators using different weightings (testing pixel)
; ****************************************************************************
PRO cal_combine_pix, event

;COMMON pia_dispdyncal_cmn, view, viewsize, nviews, viewoptions, overid,  $
;	 dyncaldi1_wid, ical_use 
COMMON pia_dspchdyn_cmn, pixcho, psymch, pixcount
COMMON pia_dispdyncaldat_cmn, tmpdyncal, tmpdyncalps, tmpsrd, tmpaapps, ncal_use
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices


	; type of weighting
	WIDGET_CONTROL, event.id, GET_UVALUE= comb_opt
	
	CASE comb_opt OF
		"COMBINE_WEIGHT": BEGIN 
				    weight = 1
				    legend = 'combine signal ratio for weighting' 
				  END  
		"COMBINE_SIGMA": BEGIN 
				    weight = 2
				    legend = $
				       'combine flux uncertainty for weighting' 
				  END  
		 ELSE: BEGIN 
		 		weight = 0
				legend = 'combined without weighting'
		       END	
	ENDCASE 
	  
	; determine pixel number
	windowindex = WIDGET_INFO(event.id, /PARENT)
	WIDGET_CONTROL, windowindex, GET_UVALUE = vindex
	pixch = pixcho(vindex)  
	
	; select data for selected pixel  
        tmp_mask = REFORM(tmpdyncal.mask(*,1:*,pixch))
        tmp_rat = REFORM(tmpdyncal.rat(*,*,pixch))
        tmp_urat = REFORM(tmpdyncal.urat(*,*,pixch))
        tmp_flave = REFORM(tmpdyncal.flave(*,pixch))
        tmp_flunc = REFORM(tmpdyncal.flunc(*,pixch))
        tmp_flmed = REFORM(tmpdyncal.flmed(*,pixch))
	
        combine_dynsrd_pix, tmp_rat, weight, tmp_flave, tmp_flunc,     $
           tmp_combflave, tmp_combflunc, tmp_flmed, tmp_combflmed,     $
           tmp_combflmed_unc, UNC_RATIO=tmp_urat, NCAL_USE = ncal_use, $ 
           MASK_RAT  = tmp_mask
	   
	str_pixch = STRTRIM(STRING(pixch+1),2)
	str_pixch = 'Flux (Average): Pixel '+str_pixch
	xtitle = 'Calibrator number'
	ytitle = str_pixch 
	decode_admn, tmpdyncal.admn, title
	title = title 
	charsize = 1.10
	
        xplot_state = 0
	IF XREGISTERED("PIA_XPLOT") NE 0 THEN $
	        pia_plot_over, xplot_state, group=event.top
	
        IF xplot_state EQ 2 THEN overplot = -1 ELSE overplot = xplot_state
	
        IF xplot_state NE 0 THEN BEGIN
                IF zoom_color EQ -1 THEN zoom_color = green ELSE $
                        zoom_color = zoom_color + 1
                        IF zoom_color EQ 9 then zoom_color = 1
                zoom_psymch = zoom_psymch + 1
                IF zoom_psymch GT 8 THEN zoom_psymch = 1
                title = ''
        ENDIF ELSE BEGIN
                zoom_color = -1
                zoom_psymch = psymch
        ENDELSE
	
	pia_xplot, AVG(INDGEN(ncal_use)+1), tmp_combflave, tmp_combflunc,   	$
		psym = zoom_psymch, xtitle=xtitle, ytitle = ytitle,        	$
		subtitle=subtitle, title=title, charsize = charsize, 		$
		symsize=symsize, color = zoom_color, legend=legend,    		$
		overplot = overplot


END

; ***************************************************************************
;  Event handling routine for PIA display menu
; ****************************************************************************

PRO pia_dispdyncal_event, event

@adm
@phtcs
@phtdyncal
@phtsrd
@phtaap

COMMON dispcust_cmn, psym, line
COMMON pia_dispdyncal_cmn, view, viewsize, nviews, viewoptions, overid,  $
	 dyncaldi1_wid, ical_use 
COMMON pia_dispdyncaldat_cmn, tmpdyncal, tmpdyncalps, tmpsrd, tmpaapps, ncal_use
COMMON pia_dspchdyn_cmn, pixcho, psymch, pixcount
COMMON pia_widget_info, extfil_wid, intfil_wid, buffil_wid, $
                        erddi1_wid, erddi2_wid, srddi1_wid, srddi2_wid, $
                        scpdi1_wid, scpdi2_wid, spddi1_wid, spddi2_wid, $
                        aapdi1_wid, aapdi2_wid

COMMON dspdyn_widg, pixbut


	  
	
	WIDGET_CONTROL, event.id, get_uvalue = uvalue
        WIDGET_CONTROL, event.top, /HOURGLASS

	det = tmpdyncal.det

	cmap_wind_text = ["A","B","C","D"]

	CASE uvalue OF


; 	  "EXIT":  BEGIN
;		    WIDGET_CONTROL, event.top, /DESTROY 
;		    PIA_DISPSCP, data= tmp_scp.scpps
;		  END


          "HELP":   BEGIN
	   	;IF !VERSION.OS NE 'vms' THEN $
		;spawn, '$w3net $PIA_HTML/um/dynamic_cal.html &' ELSE $
		;spawn, 'w3net /pia_dsk/pia/html/um/dynamic_cal.html'
		END


	  "CUST": BEGIN
			pia_dispcust, GROUP=event.top
			psymch = psym
			 FOR I=0,NVIEWS-1 DO BEGIN
			    pia_resetview_dyncal, i, view(i).controlid
			 ENDFOR
                  END

	  "LOAD": BEGIN
; search for same file and detector type
		    newdata = pickmeas(FTYPE="DYNCAL", DTYPE=det, $ 
		                   POSI=posi)
		    IF newdata NE '' THEN BEGIN



                     datind2 = WHERE(phtdsrd.admn eq newdata, count2)
                    
                     IF count2 GE 1 THEN BEGIN
                        srdlist = phtsrd(dataind2).admn
                        pia_multmeas, scplist
                        dataind2 = datind2(srdlist)
                        pia_load_isrd, phtsrd(dataind2(0)), data_srd
                        tmpsrd = data_srd
		     ENDIF ELSE BEGIN 
		        MESSAGE, /INFO, 'SRD level not found, please load it!!' 
		        RETURN
		     ENDELSE   

                     IF posi(0) NE 0 THEN BEGIN 
			pia_load_idyncal, phtdyncal(datind(posi(0))), $ 
			   tmpdyncal

	                txt = "PIA Dynamic calibration Window -"
	                decode_admn, tmpdata.admn, dattext
	                dattext = txt+dattext
	
	                WIDGET_CONTROL, dattext_id, SET_VALUE = dattext  
			
		        ; refresh all screens
			FOR I=0,NVIEWS-1 DO pia_resetview_dyncal, i,  $ 
			      view(i).controlid                        
                     ENDIF

		    ENDIF
		  END	                  	


	  "SAVE": PCONT_SAVEINT, junk, 'DYNCAL', tmpdata=tmpdyncal

	  "SHOWD": PIA_showstr, tmpdyncal,  GROUP=event.top 
                   
          "HDR": pia_disp_hdr, tmpdyncal.hdr, tmpdyncal.admn, 'PHTDYNCAL'


          "CS": PIA_DISP_CS, tmpsrd.admn

	  "ISREP": PIA_disp_isr,STRMID(tmpsrd.admn,4,8)

	  "ICALID": PIA_DISP_calid, tmpdyncal

	  "SLDISC": BEGIN 
			
		PIA_SGRATDISC, tmpdyncal.tinter, tmpdyncal.sldi
		npix = pixel_det(tmpdyncal.det)
		get_ratsig, tmpsrd.slop, tmpdyncal, NCAL = ncal_use, NPIX=npix
				
		FOR i=0, NVIEWS - 1 do pia_resetview_dyncal, i, view(i).controlid
	  END	
	  
	  ; apply drift recognition to determine the ratio between target and 
	  ; calibrators. Recompute the flux (average and median)
	  "RAT_MANN": BEGIN  
	  END	   
	  
	  ; Use all measurement to determine the ratio between target and  
	  ; calibrators. Recompute the flux (average and median) 
	  "NORAT_MANN": BEGIN  
	  END	   

	  ; Subtract dark current
          "DARKC_ORB": BEGIN 
	    ; check dark current subtraction in header of dynamic calibration
	    ; structure
	    newheader = tmpdyncal.hdr
            darkcur_orb, tmpsrd, NEWHEADER = newheader, ERROR=error
	    change_tmphdr,tmpdyncal, 'DYNCAL',newheader, tmpdyncal
            IF error NE "" THEN BEGIN
                        XDISPLAYFILE, "", $
                          GROUP = event.top, $
                          TITLE = "Not Allowed ", $
                          WIDTH = 50, $
                          HEIGHT = 12, $
                          TEXT = error
            ENDIF ELSE BEGIN 
                 get_ratsig, tmpsrd.slop, tmpdyncal, NCAL = ncal_use, NPIX=npix
	         FOR i=0, NVIEWS - 1 do $ 
		     pia_resetview_dyncal, i, view(i).controlid
	    ENDELSE	     
          END
 
	  ; Customize dark current subtraction 
          "DARKC_ORB_PAR": PIA_DEF_DARKORB
 
	  ; Fit a polynomial to the signal temporal evolution
	  "TARGET_POLYFIT": BEGIN
          END
	  
	  ; Customize the fit of a polynomial to the signal temporal evolution
	  "TARGET_POLYFIT_PAR": BEGIN
          END
	  
	  "CANCEL": BEGIN
		WIDGET_CONTROL, event.top, /DESTROY 
	  END

	  
	  "PIXCH": BEGIN
			old_pixcho = pixcho
			new_pixc = pia_pixchoice(GROUP=event.top, PIXC=pixcho)
			maxpix = max(new_pixc)
                        minpix = min(new_pixc)
			junk = 0
			IF (det EQ 'C1' AND maxpix gt 8) OR $
			   (det EQ 'C2' AND maxpix gt 3) OR $
			   (det EQ 'SS' AND maxpix gt 127) OR $
			   (det EQ 'SL' AND maxpix gt 127) OR $
			   (minpix lt 0)  THEN BEGIN
		    		XDISPLAYFILE, "", $
                    		GROUP = event.top, $
                    		TITLE = "Warning ", $
                    		WIDTH = 30, $
                    		HEIGHT = 6, $
                    		TEXT = [" Your pixel choice is not valid ", $
                                        " and will not be taken "]
		                junk = 1
			ENDIF
			IF junk NE 1 THEN BEGIN  			
			 FOR I=0,NVIEWS-1 DO BEGIN
			  IF new_pixc(i) NE old_pixcho(i) THEN BEGIN
			    pixcho(i) = new_pixc(i)
			    WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
			    view(i).windownum = temp
			    pia_resetview_dyncal, i, view(i).controlid
                            IF STRMID(det,0,1) EQ 'C' THEN BEGIN
                              txtval = cmap_wind_text(i)
                              junk = where(new_pixc eq old_pixcho(i), count)
                              IF count EQ 0 THEN $
                                 WIDGET_CONTROL, pixbut(old_pixcho(i)), $
                                        SET_VALUE = ' '
                              WIDGET_CONTROL, pixbut(pixcho(i)), $
                                        SET_VALUE = txtval
                            ENDIF
                          ENDIF
			 ENDFOR
			ENDIF
          END

	  "PIXCHSER": BEGIN
			old_pixcho = pixcho
			new_pixc = old_pixcho + nviews
			CASE STRMID(det,0,2) OF
				'C1': npix = 9
				'C2': npix = 4
				'SL': npix = 128
				'SS': npix = 128
				'P1': RETURN
				'P2': RETURN
				'P3': RETURN
			ENDCASE  
			new_pixc = new_pixc mod npix
			
			FOR I=0,NVIEWS-1 DO BEGIN
			  IF new_pixc(i) NE old_pixcho(i) THEN BEGIN
			    pixcho(i) = new_pixc(i)
			    WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
			    view(i).windownum = temp
			    pia_resetview_dyncal, i, view(i).controlid
			    IF STRMID(det,0,1) EQ 'C' THEN BEGIN 
			      txtval = cmap_wind_text(i)
			      junk = where(new_pixc eq old_pixcho(i), count)
			      IF count EQ 0 THEN $
			         WIDGET_CONTROL, pixbut(old_pixcho(i)), $
					SET_VALUE = ' '
			      WIDGET_CONTROL, pixbut(pixcho(i)), $
					SET_VALUE = txtval
			    ENDIF 
                          ENDIF
			ENDFOR
          END

	  "PIXCHSERD": BEGIN
			old_pixcho = pixcho
			new_pixc = old_pixcho - nviews
			CASE STRMID(det,0,2) OF
				'C1': npix = 9
				'C2': npix = 4
				'SL': npix = 128
				'SS': npix = 128
				'P1': RETURN
				'P2': RETURN
				'P3': RETURN
			ENDCASE  
			new_pixc = new_pixc mod npix
			
			FOR I=0,NVIEWS-1 DO BEGIN
			  IF new_pixc(i) NE old_pixcho(i) THEN BEGIN
			    pixcho(i) = new_pixc(i)
			    WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
			    view(i).windownum = temp
			    pia_resetview_dyncal, i, view(i).controlid
			    IF STRMID(det,0,1) EQ 'C' THEN BEGIN 
			      txtval = cmap_wind_text(i)
			      junk = where(new_pixc eq old_pixcho(i), count)
			      IF count EQ 0 THEN $
			         WIDGET_CONTROL, pixbut(old_pixcho(i)), $
					SET_VALUE = ' '
			      WIDGET_CONTROL, pixbut(pixcho(i)), $
					SET_VALUE = txtval
			    ENDIF 
                          ENDIF
			ENDFOR
          END

        "NVIEWS": BEGIN

            newviews = event.value + 1
            IF newviews NE nviews THEN BEGIN
                WIDGET_CONTROL, dyncaldi1_wid, /DESTROY
                pia_dispdyncal, tmpdyncalps, tmpaapps, tmpsrd,  $
                   NV = newviews
            ENDIF
         END

	 "REFRESH":  FOR I=0,NVIEWS-1 DO  $
	       pia_resetview_dyncal, i, view(i).controlid


	ENDCASE
	
RETURN
END

; ****************************************************************************
;  PIA Dispdrft - menu definition procedure
; ****************************************************************************

PRO pia_dispdyncal, dyncalps, srd, aapps, NV = NV, GROUP=group

COMMON pia_dispdyncaldat_cmn, tmpdyncal, tmpdyncalps, tmpsrd, tmpaapps, ncal_use
COMMON pia_dispdyncal_cmn, view, viewsize, nviews, viewoptions, overid,  $
	 dyncaldi1_wid, ical_use 
COMMON pia_dspchdyn_cmn, pixcho, psymch, pixcount
COMMON dspdyn_widg, pixbut
COMMON pia_widget_info, extfil_wid, intfil_wid, buffil_wid, $
                        erddi1_wid, erddi2_wid, srddi1_wid, srddi2_wid, $
                        scpdi1_wid, scpdi2_wid, spddi1_wid, spddi2_wid, $
                        aapdi1_wid, aapdi2_wid
;COMMON pia_dispdrift_results, drift_str_res
;COMMON not_acc, degl_acc, degl_set, sig_disc, disc_set 
;COMMON drift_not_acc, d_degl_acc, d_degl_set, d_sig_disc, d_disc_set 
@phtaap
@phtdyncal

;COMMON pia_driftmod_out, out_fitpar_str, out_fitacc 

; If already registered, return

        IF Xregistered("pia_dispdyncal") NE 0 THEN BEGIN
                RETURN
        END

	IF N_PARAMS() LT 1 THEN BEGIN
	  MESSAGE, 'Syntax: PIA_DISPDYNCAL, dyncalps [,aapps] '+$
	      '[,tmpsrd] [,NV=NV]'
	  RETURN
 	ENDIF
	        
	IF N_PARAMS() GE 2 THEN tmpsrd = srd
		   
	IF N_PARAMS() EQ 3 THEN tmpaapps = aapps $ 
	   ELSE tmpaapps = N_ELEMENTS(phtaap) 
	
	pia_load_idyncal, phtdyncal(dyncalps), tmpdyncal
	tmpdyncalps = dyncalps
	
	; set npixel
	npix = pixel_det(tmpdyncal.det)
	
	;number of calibrators
	ncal_use = N_ELEMENTS(tmpdyncal.flave(*,0))
	
	ical_use = 0
	                         	

	;out_fitacc = 0
	
	
	;IF N_ELEMENTS(degl_acc) EQ 0 THEN BEGIN
	;  degl_acc = 0
	;  degl_set = 0
	;ENDIF

	;d_degl_acc = degl_acc
	;d_degl_set = degl_set
	;d_sig_disc = sig_disc
	;d_disc_set = d_disc_set
; initialize views and pixels chosen

        IF KEYWORD_SET(NV) THEN NVIEWS = nv ELSE nviews = 4
        IF nviews GT 4 THEN nviews = 4
        pixcount = -1


	psymch = 4	

	CASE STRMID(tmpdyncal.det, 0,1) of 
          'P': BEGIN 
		pixcho = [0,0,0,0]
	  END
          ELSE: BEGIN  
	         CASE STRMID(tmpdyncal.det,0,2) of
	           'C1': BEGIN
			pixcho = [0,2,4,6]
		   END
	           'C2': BEGIN
			pixcho = [1,2,3,0]
		   END
	           'SS': BEGIN
			pixcho = [10,40,90,120]
		   END
	           'SL': BEGIN
			pixcho = [10,40,90,120]
		   END
		  ELSE: BEGIN
			pixcho = [10,40,90,120]
		   END
	 	  ENDCASE		
	  END
        ENDCASE

	viewsize = 220
	xsize = viewsize * 4 / nviews
	ysize = viewsize

	; define structure for each view
	viewinstance = {	viewtype:0b,    	$
				viewtype_sub:0b, 	$   
				controlid:0L,		$               	
				windowid:0L,		$
				windownum:0}	

        view = REPLICATE(viewinstance, NVIEWS)		; array of view struct.

	viewtype_p = [0,1,3,4] 
	
        IF STRMID(tmpdyncal.det, 0,1) eq 'P' THEN $
                FOR i=0,nviews-1 DO view(i).viewtype = viewtype_p(i)

	;instance = {vopt3, viewname:'', $
        ;          viewid:0, viewxlab:'', $
	;	  viewylab:'', viewmenu:0 }            ;structures describing
	instance = {viewname:'', $
                  viewid:0, viewxlab:'', $
		  viewylab:'', viewmenu:0 }            ;structures describing
	NVIEWOPTS = 7                           	;each type of view 

	viewoptions = REPLICATE(instance, NVIEWOPTS)    

        ; Use only dyncal structure, optionally SRD
        viewoptions(0).viewname = "Ratio target/calib"
        viewoptions(0).viewid = 0
        viewoptions(0).viewylab = "Signal ratio"
        viewoptions(0).viewxlab = "Time       [s]"
	viewoptions(0).viewmenu = 1
        viewoptions(1).viewname = "Target Signals"
        viewoptions(1).viewid = 1
        viewoptions(1).viewylab = "Signal Values       [V/s]"
        viewoptions(1).viewxlab = "Time       [s]"
        viewoptions(2).viewname = "Signal Flags "
        viewoptions(2).viewid = 2
        viewoptions(2).viewylab = "Signal flags "
        viewoptions(2).viewxlab = "Time       [s]"
        viewoptions(3).viewname = "Calibrator Signals"
        viewoptions(3).viewid = 3
        viewoptions(3).viewylab = "Signal Values       [V/s]"
        viewoptions(3).viewxlab = "Time       [s]"
	viewoptions(3).viewmenu = 1
        viewoptions(4).viewname = "Target Flux (from Average)"
        viewoptions(4).viewid = 4
        viewoptions(4).viewylab = "Flux [Jy/beam]"
        viewoptions(4).viewxlab = "Calibrator index   "
        viewoptions(5).viewname = "Target Flux (from Median)"
        viewoptions(5).viewid = 5
        viewoptions(5).viewylab = "Flux [Jy/beam]"
        viewoptions(5).viewxlab = "Calibrator index   "
        viewoptions(6).viewname = "Calibrator Flux "
        viewoptions(6).viewid = 6
        viewoptions(6).viewylab = "Flux [Jy/beam]"
        viewoptions(6).viewxlab = "Calibrator index   "



; top base

	wid = WIDGET_BASE( TITLE="PIA Dynamic Calibration Data Display", $
		/COLUMN, XPAD = 20, YPAD = 20, SPACE = 20)
	dyncaldi1_wid = wid
; control windows

	control = WIDGET_BASE(dyncaldi1_wid, /ROW)

	control_exit = WIDGET_BUTTON(control, VALUE="    Exit    ",$
					 UVALUE='CANCEL')

	control_help = WIDGET_BUTTON(control, VALUE="    Help    ",$
					 UVALUE="HELP")
	control_cust = WIDGET_BUTTON(control, VALUE="  Customize ",$
					 UVALUE="CUST")


	junk = WIDGET_LABEL(control, VALUE = '     ')

	txt = "PIA Dynamic calibration Window -"
	decode_admn, tmpdyncal.admn, dattext
	dattext = txt+dattext
	
	dattext_id = WIDGET_LABEL(control, VALUE = dattext)  

;------------------- the C mapping windows -------------------------

        junk = WIDGET_LABEL(control, VALUE = '       ')

        IF STRMID(tmpdyncal.det, 0,1) eq 'C' THEN BEGIN

        pixver = WIDGET_BASE(control, /COLUMN)
	junk = WIDGET_LABEL(pixver, VALUE='^ +Z')

        pixhor = WIDGET_BASE(pixver,/ROW)

          IF STRMID(tmpdyncal.det, 1,1) eq '1' THEN BEGIN
                pixbut = intarr(9)
                FOR i=0,2 DO pixbut(i*3+2) = $
                        WIDGET_BUTTON(pixhor, VALUE=' ',$
                                XOFFSET=3*i, $,
                                UVALUE=i*3+2,$
                                EVENT_PRO = 'pixbuteventd')
                pixhor = WIDGET_BASE(pixver,/ROW,YOFFSET=10)
                FOR i=0,2 DO pixbut(i*3+1) = $
                        WIDGET_BUTTON(pixhor, VALUE=' ',$
                                XOFFSET=3*i, $
                                UVALUE=i*3+1,$
                                EVENT_PRO = 'pixbuteventd')
                pixhor = WIDGET_BASE(pixver,/ROW,YOFFSET=10)
                FOR i=0,2 DO pixbut(i*3) = $
                        WIDGET_BUTTON(pixhor, VALUE=' ',$
                                XOFFSET=3*i, $
                                UVALUE=i*3,$
                                EVENT_PRO = 'pixbuteventd')
          ENDIF ELSE $
          IF STRMID(tmpdyncal.det, 1,1) eq '2' THEN BEGIN
                pixbut = intarr(4)
                FOR i=0,1 DO pixbut(i+2) = $
                        WIDGET_BUTTON(pixhor, VALUE=' ',$
                                XOFFSET=3*i, $
                                UVALUE=i+2,$
                                EVENT_PRO = 'pixbuteventd')
                pixhor = WIDGET_BASE(pixver,/ROW,YOFFSET=10)
                FOR i=1,0,-1 DO pixbut(i) = $
                        WIDGET_BUTTON(pixhor, VALUE=' ',$
                                XOFFSET=3*i, $
                                UVALUE=i,$
                                EVENT_PRO = 'pixbuteventd')
          ENDIF
	junk = WIDGET_LABEL(pixhor, VALUE='> +Y')
        ENDIF

;----------------- the View windows are defined ------------------

	viewbase = WIDGET_BASE(dyncaldi1_wid, /ROW, SPACE=20)

	viewstorageids = LONARR(NVIEWS)
	overid = lonarr(NVIEWS)	   
	
        cmap_wind_text = ["A","B","C","D"]

        FOR viewindex = 0, NVIEWS - 1 DO BEGIN
          viewbase_sub = WIDGET_BASE(viewbase, /FRAME, /COLUMN)
	  junk = WIDGET_LABEL(viewbase_sub, $
	       VALUE="Window "+cmap_wind_text(viewindex))
          tempbase = WIDGET_BASE(viewbase_sub, /FRAME, /COLUMN, $
				EVENT_PRO = 'viewevent_dyncal')
	  view(viewindex).controlid = WIDGET_BUTTON(tempbase, VALUE="   ",$
				MENU = 2, UVALUE = viewindex, $
				EVENT_PRO = 'viewevent_dyncal')
	  view(viewindex).windowid = WIDGET_DRAW(tempbase, $
				XSIZE = xsize, YSIZE = ysize, $
				RETAIN = 2) 
		FOR i = 0, NVIEWOPTS - 1 DO BEGIN
     			dummy = WIDGET_BUTTON(view(viewindex).controlid, $
                	   VALUE = viewoptions(i).viewname,              $
                	   UVALUE = viewoptions(i).viewid,               $ 
			   MENU=viewoptions(i).viewmenu,                 $
			   EVENT_PRO = 'viewevent_dyncal')
			IF viewoptions(i).viewmenu THEN BEGIN
			   FOR ical=0,ncal_use-1 DO  $
			   dummy1 = WIDGET_BUTTON(dummy, $
			     VALUE='# '+STRTRIM(ical+1,2), UVALUE=ical, $
			     EVENT_PRO='viewevent_dyncal_sub')
			ENDIF     
		ENDFOR

	  zoombase = WIDGET_BASE(tempbase, /FRAME, /ROW)
          zoom = WIDGET_BUTTON(zoombase, $
                        VALUE = " Zoom & Print  ", $
                        UVALUE = viewindex, MENU = 2)

          dummy = WIDGET_BUTTON(zoom, $
                        VALUE = "New  ", $
                        UVALUE = viewindex, EVENT_PRO = 'zoomevent_dyncal')

          synch = WIDGET_BUTTON(zoom, $
                        VALUE = "Overplot, same y-axis  ", $
                        UVALUE = viewindex, EVENT_PRO = 'zoomsync_dyncal')
          nsynch = WIDGET_BUTTON(zoom, $
                        VALUE = "Overplot, new y-axis", $
                        UVALUE = viewindex, EVENT_PRO = 'zoomnsync_dyncal')


	  test = WIDGET_BUTTON(zoombase, MENU = 2,VALUE ='  Testing   ') 
          test_comb = WIDGET_BUTTON(test, $
                        VALUE = "Combine all calibrators ", $
                        UVALUE = viewindex, MENU = 2)
          junk = WIDGET_BUTTON(test_comb, $
                        VALUE = "Weighting by ratio ", $
                        UVALUE = 'COMBINE_WEIGHT', EVENT_PRO = 'cal_combine_pix')
          junk = WIDGET_BUTTON(test_comb, $
                        VALUE = "Weighting by sigma ", $
                        UVALUE = 'COMBINE_SIGMA', EVENT_PRO = 'cal_combine_pix')
          junk = WIDGET_BUTTON(test_comb, $
                        VALUE = "Not weighting ", $
                        UVALUE = 'COMBINE', EVENT_PRO = 'cal_combine_pix')




        ENDFOR

	controlbase = WIDGET_BASE(dyncaldi1_wid, $
                /ROW, $
                SPACE = 40)


;----------------- the Data controls are defined ------------------

        datcont = WIDGET_BUTTON(controlbase, VALUE='    Data    ', /MENU )

        id_2 = WIDGET_BUTTON(datcont, VALUE='Load', UVALUE='LOAD' )
        id_2 = WIDGET_BUTTON(datcont, VALUE='Show Data', UVALUE='SHOWD' )
        id_2 = WIDGET_BUTTON(datcont, VALUE='Save', UVALUE='SAVE' )

        	
;---------------- the Selection controls are defined -----------------
 
        selcont = WIDGET_BUTTON(controlbase, VALUE='  Selection ', /MENU )
        id_2 = WIDGET_BUTTON(selcont, VALUE='Discard Signals', $
                                UVALUE='SLDISC')
	id_2 = WIDGET_BUTTON(selcont, VALUE='Stability recognition ', /MENU)
        id_3 = WIDGET_BUTTON(id_2, VALUE='Apply',UVALUE='RAT_MANN')
	id_3 = WIDGET_BUTTON(id_2, VALUE="Don't apply", UVALUE='NOTRAT_MANN')
	
	WIDGET_CONTROL, id_2, SENSITIVE = 0
	
;---------------- the Correction controls are defined -----------------
        corrcont = WIDGET_BUTTON(controlbase, VALUE=' Correction ', /MENU )
	id_2 = WIDGET_BUTTON(corrcont, $
	  VALUE=' Dark Current Subtr. (orbital dep)', /MENU)
	id_3 = WIDGET_BUTTON(id_2,  $ 
	         VALUE=' Perform it ', $
	         UVALUE ='DARKC_ORB')
	id_3 = WIDGET_BUTTON(id_2,  $ 
	         VALUE=' Customize ', $
	         UVALUE ='DARKC_ORB_PAR')
	id_2 = WIDGET_BUTTON(corrcont, $
	  VALUE='Fit a polynomial to signal temporal evolution', /MENU)
	id_3 = WIDGET_BUTTON(id_2, VALUE='Perform it ', UVALUE='TARGET_POLYFIT')
	id_3 = WIDGET_BUTTON(id_2, VALUE='Customize ', $
	    UVALUE='TARGET_POLYFIT_PAR')	 

	WIDGET_CONTROL, id_2, SENSITIVE = 0

;---------------- the View controls are defined -----------------

        viewcont = WIDGET_BUTTON(controlbase, VALUE='  View  ', /MENU )
        id_2 = WIDGET_BUTTON(viewcont, VALUE='Header Info ', UVALUE='HDR')
        id_2 = WIDGET_BUTTON(viewcont, VALUE='Compact Status ', UVALUE='CS')
        id_2 = WIDGET_BUTTON(viewcont, VALUE='IS Report ', UVALUE='ISREP')
        id_2 = WIDGET_BUTTON(viewcont, VALUE='Calibrator Identity', $
        			UVALUE='ICALID')

;---------------- the Array controls are defined -----------------

        arrcont = WIDGET_BUTTON(controlbase, VALUE=' Arrays ', /MENU)

	flabel = ["Target flux (from average)", "Target Flux (from median)", $
	          "Calibrator flux"]

	FOR ie = 0, N_ELEMENTS(flabel)-1 DO BEGIN 
	  fl1 = WIDGET_BUTTON(arrcont, VALUE=flabel(ie), /MENU)
	  FOR ical=0,ncal_use-1 DO BEGIN 
	    fl2 = WIDGET_BUTTON(fl1,VALUE=' Cal '+STRTRIM(ical+1,2), $
	                UVALUE = ical,/MENU)
            dummy = WIDGET_BUTTON(fl2, $
                        VALUE = "New  ", UVALUE = STRTRIM(ie,2)+'_NEW', $
                        EVENT_PRO = 'dyncal_showflux')
            synch = WIDGET_BUTTON(fl2, VALUE = "Overplot, same y-axis  ", $
                        UVALUE = STRTRIM(ie,2)+'_SYNC', $
                        EVENT_PRO = 'dyncal_showflux')
            nsynch = WIDGET_BUTTON(fl2, VALUE = "Overplot, new y-axis", $
                        UVALUE = STRTRIM(ie,2)+'_NSYNC', $
                        EVENT_PRO = 'dyncal_showflux')
	  ENDFOR		
	ENDFOR		

;---------------- the Parameter controls are defined -----------------

;        arrcont = WIDGET_BUTTON(controlbase, VALUE=' Parameters ', /MENU)

	
;        dummy = WIDGET_BUTTON(arrcont, $
;                        VALUE = "New  ", $
;                        UVALUE = 'NEW', EVENT_PRO = 'drft_showpar')
;        synch = WIDGET_BUTTON(arrcont, $
;                        VALUE = "Overplot, same y-axis  ", $
;                        UVALUE = 'SYNC', EVENT_PRO = 'drft_showpar')
;        nsynch = WIDGET_BUTTON(arrcont, $
;                        VALUE = "Overplot, new y-axis", $
;                        UVALUE = 'NSYNC', EVENT_PRO = 'drft_showpar')


;---------------- the Processing controls are defined -----------------

        proccont = WIDGET_BUTTON(controlbase, VALUE=' Process ', $
                                /MENU )
        id_2 = WIDGET_BUTTON(proccont, $
        		VALUE=' Combine All Calibrators', /MENU)
	id_3 = WIDGET_BUTTON(id_2, Value='Weighting by ratio', $
                 UVALUE='COMBINE_WEIGHT', EVENT_PRO='cal_combine')
 	id_3 = WIDGET_BUTTON(id_2, Value='Weighting by sigma', $
                 UVALUE='COMBINE_SIGMA', EVENT_PRO='cal_combine')
        id_3 = WIDGET_BUTTON(id_2, VALUE=' Not weighting ', UVALUE='COMBINE', $
	         EVENT_PRO='cal_combine')
        ;id_2 = WIDGET_BUTTON(proccont, VALUE=' Select calibrators',  $
        ;         EVENT_PRO='cal_combine',UVALUE='COMBINE_SELECT' )

;---------------- the Pixel Choice controls are defined -----------------

        pixcont = WIDGET_BUTTON(controlbase, VALUE=' Pixels ', $
				/MENU)
        pixch = WIDGET_BUTTON(pixcont, VALUE=' Individual choice ', $
				UVALUE='PIXCH' )
        pixch = WIDGET_BUTTON(pixcont, VALUE=' Serial increment  ', $
				UVALUE='PIXCHSER' )
        pixch = WIDGET_BUTTON(pixcont, VALUE=' Serial decrement  ', $
				UVALUE='PIXCHSERD' )
        IF STRMID(tmpdyncal.det,0,1) EQ 'P' THEN $
        	WIDGET_CONTROL, pixcont, SENSITIVE=0

;---------------- the number of views controls is defined -----------------

        nvbut = cw_bselector(controlbase, $
                        /FRAME, SET_VALUE=NVIEWS-1, $
                        UVALUE = 'NVIEWS', $
                        ['1 Plot', $
                        '2 Plots', $
                        '3 Plots', $
                        '4 Plots'])

;----------------------------------------------------------------------
; Display refresh button

        pixcont = WIDGET_BUTTON(controlbase, VALUE=' Refresh ', $
        		UVALUE="REFRESH")
	
;----------------------------------------------------------------------


	WIDGET_CONTROL, dyncaldi1_wid, /REALIZE, /HOURGLASS

	FOR i = 0, nviews - 1 DO BEGIN
		WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
		view(i).windownum = temp
		pia_resetview_dyncal, i, view(i).controlid
           IF STRMID(tmpdyncal.det,0,1) EQ 'C' THEN BEGIN
                txtval = cmap_wind_text(i)
                WIDGET_CONTROL, pixbut(pixcho(i)), SET_VALUE = txtval
           ENDIF
	ENDFOR

	XMANAGER,No_BLOCK=1, "pia_dispdyncal", dyncaldi1_wid, $ 
		EVENT_HANDLER = "pia_dispdyncal_event", GROUP_LEADER=GROUP

	aapps = tmpaapps

	RETURN
END
