;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_LOAD_IDYNCAL
;
; PURPOSE:
;	Write a PHT-DYNCAL (Signal per chopper plateau) measurement from the 
;	dynamic structure PHTDYNCAL (PHTDRIFT type) onto a temporary structure 
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       PIA_LOAD_IDRIFT, driftdat, tmpdrift
;
; INPUT:
;       DRIFTDAT 	: PHTDRIFT like dynamic structure
;
; KEYWORDS:
;	none
;
; OUTPUTS:
;	TMPDRIFT	: A temporary structure of SCP type
;
; RESTRICTIONS:
;       DRIFTDAT must exist
;
; MODIFICATION HISTORY:
;       Written by:	J.Acosta (ESA/MPIA/IAC)          		July 1998
;	Version 7.x
;-

PRO pia_load_idyncal, dyncaldat, tmpdyncal, DYNCALPS= DYNCALPS

        ON_ERROR, 2
	
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 2 THEN MESSAGE, $
          'Syntax:  pia_load_idyncal, dyncalps, tmpdyncal'
	  
	IF KEYWORD_SET(dyncalps) THEN BEGIN
	  @phtdyncal
	  dyncaldat = phtdyncal(dyncalps)  
        ENDIF
	
;  Fill temporary variables from the handles
        
	HANDLE_VALUE, dyncaldat.hdr, hdr
        HANDLE_VALUE, dyncaldat.time, time
        HANDLE_VALUE, dyncaldat.sig_tar, sig_tar
        HANDLE_VALUE, dyncaldat.unc_tar, unc_tar
        HANDLE_VALUE, dyncaldat.sig_cal, sig_cal
        HANDLE_VALUE, dyncaldat.rat, rat
        HANDLE_VALUE, dyncaldat.urat, urat
        HANDLE_VALUE, dyncaldat.mask, mask
        HANDLE_VALUE, dyncaldat.flmed, flmed
        HANDLE_VALUE, dyncaldat.flave, flave
        HANDLE_VALUE, dyncaldat.flunc, flunc
        HANDLE_VALUE, dyncaldat.flux,  flux
        HANDLE_VALUE, dyncaldat.flag, flag
        HANDLE_VALUE, dyncaldat.calid, calid

;  Fill the temporary structure
	
	tmpdyncal = {admn: dyncaldat.admn, 		$
        meas_name: dyncaldat.meas_name, 		$ 
	det: dyncaldat.det,				$
	temperature: dyncaldat.temperature,		$
	sldi: dyncaldat.sldi,				$
	tinter: dyncaldat.tinter,			$
	proc_time: dyncaldat.proc_time,			$
	hdr: hdr,					$
	time: time,					$
	sig_tar: sig_tar,				$
	unc_tar: unc_tar,				$
	sig_cal: sig_cal,				$
	rat: rat,					$
	urat: urat,					$
	mask: mask,					$
	flmed: flmed,					$
	flave: flave,					$
	flunc: flunc,					$
	flux: flux,					$
	flag: flag, 					$
	calid: calid }

        RETURN
END

