;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_SGRATDISC
;
; PURPOSE:
;	Menu for PIA Signal ratio selection in dynamic calibration.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_SGRATDISC
;
; INPUTS:
;	none
;	
; KEYWORD PARAMETERS:
;	GROUP
;		The group leader of the widget hirarchy
;	NSIG
;		Number of ramps per chopper plateau
;	
; OUTPUTS:
;	none
;	
; SIDE EFFECTS:
;	Modifies the variables in phtacc for selection criteria
;	
; COMMON BLOCKS:
;	pia_sgratdisc_cmn	for internal use
;	phtacc_ratdisc		selection parameters
;	
; PROCEDURES USED:
;	Internal:
;		pia_sgratdisc_event
;
; MODIFICATION HISTORY:
;	Written by:	J.Acosta (IAC) 
;	Coping with MODAL type acc. to IDL>5.0 (CG)	February 1999
;	V7.3.1
;-

; ****************************************************************************
;  Event handling routine for PIA signal selection menu
; ****************************************************************************

PRO pia_sgratdisc_event, event

COMMON pia_sgratdisc_cmn, accratsig_act, wid
COMMON PHTACC_RATSIG, phtacc_ratsig


	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	
	update_text = 0

	CASE uvalue OF

          'ACCEPT': BEGIN
                WIDGET_CONTROL, event.top, /DESTROY	  
	        phtacc_ratsig = accratsig_act
          END

          'CANCEL': WIDGET_CONTROL, event.top, /DESTROY

	  'STANDARD': BEGIN
        	IF event.value EQ 0 THEN BEGIN 
		    accratsig_act.firstsig = event.select
		    accratsig_act.selcrit = 0
		    update_text = 1
		ENDIF	 
		  END

	  'SIGFRAC': BEGIN
			WIDGET_CONTROL, event.id, GET_VALUE=value
                        accratsig_act.mfrac = float(value(0))
 			WIDGET_CONTROL, wid.sigfracok_id, /SENSITIVE
 			WIDGET_CONTROL, wid.sigfracok_id, /INPUT_FOCUS
 	  	END
                    
	     		
	  'FRACOK':  BEGIN
			accratsig_act.selcrit = 1
                        update_text = 1
 			WIDGET_CONTROL, wid.sigfracok_id, SENSITIVE=0
          	END

	  'SIGFROM': BEGIN
			WIDGET_CONTROL, event.id, GET_VALUE=value
                        accratsig_act.sigfrom = fix(value(0))
 			WIDGET_CONTROL, wid.sigfromok_id, /SENSITIVE
 			WIDGET_CONTROL, wid.sigfromok_id, /INPUT_FOCUS
 	  	END
                    
	     		
	  'SIGOK':  BEGIN
			accratsig_act.selcrit = 2
                        update_text = 1
 			WIDGET_CONTROL, wid.sigfromok_id, SENSITIVE=0
          	END

	  'TIMEFROM': BEGIN
			WIDGET_CONTROL, event.id, GET_VALUE=value
                        accratsig_act.timefrom = fix(value(0))
 			WIDGET_CONTROL, wid.timeok_id, /SENSITIVE
 			WIDGET_CONTROL, wid.timeok_id, /INPUT_FOCUS
 	  	END
                    
	     		
	  'TIMEOK':  BEGIN
			accratsig_act.selcrit = 3
                        update_text = 1
 			WIDGET_CONTROL, wid.timeok_id, SENSITIVE=0
          	END

	  'RESET': BEGIN
                        sig1acc = phtacc_ratsig.firstsig
	                mfrac = STRING(phtacc_ratsig.mfrac,format='(F6.2)')
	                sigfrom = STRING(phtacc_ratsig.sigfrom,format='(I4)')
                        timefrom = STRING(phtacc_ratsig.timefrom,format='(F7.2)')
	                
 			WIDGET_CONTROL, wid.sigfromok_id, SENSITIVE=0
			WIDGET_CONTROL, wid.sigfrom_id, SET_VALUE = sigfrom 
 			WIDGET_CONTROL, wid.sigfracok_id, SENSITIVE=0 
			WIDGET_CONTROL, wid.sigfrac_id, SET_VALUE = mfrac 
 			WIDGET_CONTROL, wid.timeok_id, SENSITIVE=0
			WIDGET_CONTROL, wid.time_id, SET_VALUE = timefrom 
			
			accratsig_act = phtacc_ratsig
						 
			update_text = 1      
			
                   END

	  ELSE:		
       	ENDCASE
	
	IF update_text THEN BEGIN
			
	      CASE accratsig_act.selcrit OF 
		 0: sigupto = accratsig_act.firstsig
	         1: sigupto = ROUND(accratsig_act.mfrac *wid.nsignal)
		 2: sigupto = accratsig_act.sigfrom
		 3: sigupto = ROUND(accratsig_act.timefrom/wid.treset)
		 ELSE: sigupto = 0
	      ENDCASE 
			 
	      IF accratsig_act.firstsig THEN $ 
			       sigupto = MAX([accratsig_act.firstsig,sigupto])
			       
	     read_str = 'First ' + STRTRIM(sigupto,2) + $ 
	          ' signals will be discarded'
             WIDGET_CONTROL, wid.text_id, SET_VALUE = read_str

	ENDIF
	
	RETURN
END

; ****************************************************************************
;  PIA SGRATDISC - menu definition procedure
; ****************************************************************************

PRO pia_sgratdisc, t_reset, nsignal, GROUP=group, nsig=nsig

COMMON PHTACC_RATSIG, phtacc_ratsig

; Definitions common to all instances
COMMON pia_sgratdisc_cmn,  accratsig_act, wid

	IF N_ELEMENTS(nsignal) EQ 0 THEN nsignal = 0
	IF N_ELEMENTS(t_reset) EQ 0 THEN t_reset = 1.
  
  	IF N_ELEMENTS(phtacc_ratsig) EQ 0 THEN phtacc_ratsig_init
	
	accratsig_act = phtacc_ratsig
		 
	selcri = phtacc_ratsig.selcrit
        sig1acc = phtacc_ratsig.firstsig
	mfrac = STRING(phtacc_ratsig.mfrac,format='(F6.2)')
	sigfrom = STRING(phtacc_ratsig.sigfrom,format='(I4)')
        timefrom = STRING(phtacc_ratsig.timefrom,format='(F7.2)')


	IF not KEYWORD_SET(GROUP) THEN group=!PIA_TOP_WID
	base = WIDGET_BASE(TITLE = 'PIA Signal ratio selection menu', $ 
		 		/COLUMN, /MODAL, group=group)

        label = WIDGET_LABEL(base, VALUE='Standard Choices')
	stdbase = WIDGET_BASE(base, /COLUMN, /FRAME)
	
	stdbut = cw_bgroup(stdbase, $
			/NONEXCLUSIVE, $
			SET_VALUE = sig1acc, $
			UVALUE = 'STANDARD', $
			["Discard first Signal per measurement"])
				
				
        label = WIDGET_LABEL(base, VALUE='Special Choices')
	
	rodbase = WIDGET_BASE(base, /COLUMN, /FRAME)

	portncbase = WIDGET_BASE(rodbase, /ROW)
	tt = 'Disc. fraction of total signals:     '
	label = WIDGET_LABEL(portncbase, VAL=tt)
	sigfrac_id = WIDGET_TEXT(portncbase, /EDITABLE, VAL=mfrac, $
				UVAL='SIGFRAC',XSIZE=5)
	sigfracok_id = WIDGET_BUTTON(portncbase, VALUE=' OK ', UVALUE='FRACOK')	

	WIDGET_CONTROL, sigfracok_id, SENSITIVE=0

	sigbase = WIDGET_BASE(rodbase, /ROW)
	tt = 'Discard Signals up to:               '
        label = WIDGET_LABEL(sigbase, VALUE=tt)
        sigfrom_id = WIDGET_TEXT(sigbase, /EDITABLE, XSIZE=5, YSIZE=1, $
                        VALUE=sigfrom, UVALUE='SIGFROM')

	sigfromok_id = WIDGET_BUTTON(sigbase, VALUE=' OK ', UVALUE='SIGOK')	

	WIDGET_CONTROL, sigfromok_id, SENSITIVE=0
		
	arobase = WIDGET_BASE(rodbase, /ROW)
	tt = 'Discard initial time up to:          '
        label = WIDGET_LABEL(arobase, VALUE=tt)
        time_id = WIDGET_TEXT(arobase, /EDITABLE, XSIZE=5, YSIZE=1, $
                   VALUE=timefrom, UVALUE='TIMEFROM') 
  
	timeok_id = WIDGET_BUTTON(arobase, VALUE=' OK ', UVALUE='TIMEOK')
		
	WIDGET_CONTROL, timeok_id, SENSITIVE=0
			
	junklabel = WIDGET_LABEL(base,VALUE= '    ')

	CASE selcri OF
	   1: sigupto = ROUND(phtacc_ratsig.mfrac*nsignal) 
           2: sigupto = phtacc_ratsig.sigfrom
	   3: sigupto = ROUND(phtacc_ratsig.timefrom/t_reset)
           ELSE:  sigupto = 0
	ENDCASE 
	   
	IF phtacc_ratsig.firstsig THEN sigupto = MAX([1,sigupto]) 
	
	curr_sel = WIDGET_BASE(base,/ROW)
	
	junk = WIDGET_LABEL(curr_sel, VALUE ='Current Selection: ')   

	read_str = 'First ' + STRTRIM(sigupto,2) + $ 
	          ' signals will be discarded'
	text_id = WIDGET_LABEL(curr_sel,VALUE = read_str)	  

        control = WIDGET_BASE(base,/ROW)

        ;junk = WIDGET_LABEL(control, VALUE = '        ')
        accept = WIDGET_BUTTON(control, VALUE = '       OK       ', $
                        /FRAME, UVALUE = 'ACCEPT')
        ;junk = WIDGET_LABEL(control, VALUE = '           ')
        accept = WIDGET_BUTTON(control, VALUE = '    Default     ', $
                        /FRAME, UVALUE = 'RESET')
        ;junk = WIDGET_LABEL(control, VALUE = '                   ')
        cancel = WIDGET_BUTTON(control, VALUE = '     Cancel     ', $
                        /FRAME, UVALUE = 'CANCEL')

        WIDGET_CONTROL, base, /REALIZE, TLB_SET_XOFFSET=150, $
                        TLB_SET_YOFFSET=150

	wid = {sigfrac_id:sigfrac_id, sigfracok_id:sigfracok_id,        $
	       sigfrom_id:sigfrom_id, sigfromok_id:sigfromok_id,        $
	       time_id: time_id, timeok_id: timeok_id, text_id:text_id, $
	       nsignal:nsignal, treset:t_reset} 

        XMANAGER,No_BLOCK=1, "pia_sgratdisc", base, GROUP=group
	
        RETURN
END

