;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO READ_IDYNCAL, NAME, IPOS, PATH = PATH, ADMN = ADMN 
;+
; NAME:
;       READ_IDYNCAL
; PURPOSE:
;	READ a PHTIDYNCAL (Interactive Signal per Chopper Plateau) file 
;	into the dynamic structure PHTDYNCAL  
; CATEGORY:
;	PIA - I/O
; CALLING SEQUENCE:
;       READ_IDYNCAL, NAME [, IPOS] [, PATH = PATH] [, ADMN = ADMN]
;
; INPUT:
;       NAME 	: PHTDYNCAL-savefile name (*.IDYNCAL)
; OPTIONAL INPUT:
;	PATH    : path for the file
;
; OPTIONAL OUTPUT:
;	IPOS	: index within phtdyncal array
;
; OUTPUT KEYWORD:
;	ADMN    : administration name (phtdyncal.admn)
;
; RESTRICTIONS:
;       NAME must be a valid PHTISCP file 
;
; PROCEDURES USED: 
;       Common Block(s) or @ procedure(s):
;               phtdyncal
;
; MODIFICATION HISTORY:
;       Written by: J. Acosta (ISO-SOC, Vilspa)		July 1998
;	V7.x
;-
;
@phtdyncal
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  READ_IDYNCAL, NAME [, IPOS] [, PATH = PATH] [, ADMN = ADMN]'

;  check name for extension IDYNCAL, name should not contain it!!
        ext_name = '.IDYNCAL'
	trim_pos = strpos(name,ext_name)
	IF trim_pos ne -1 then tmpname = STRMID(name,0,trim_pos) $ 
	   ELSE tmpname = name


; create filename esp if path is set
	if keyword_set(PATH) then $
	  filename = PATH + TMPNAME + ext_name $
	else BEGIN
	  revers_name = STR_REVERSE(tmpname)
	  IF !version.os EQ "VMS" THEN $
	    ind = STRPOS(revers_name,']') ELSE $
	    ind = STRPOS(revers_name,'/') 
	  IF ind eq -1 THEN tmpname = revers_name ELSE $ 	    
	    tmpNAME = STRMID(revers_name,0,ind)
	  tmpname = STR_REVERSE(tmpname)
	  filename = name
	ENDELSE


;  Restore the save file
	RESTORE, FILENAME
	admn = PHTIDYNCAL.ADMN
	hdr = phtidyncal.hdr


;  Append to the phtdyncal buffer
 	fill_dyncal, phtidyncal

;  Get the position within the PHTDYNCAL structure 
	IPOS = N_elements(phtdyncal) - 1 



        RETURN
        END
