;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO WRITE_IDYNCAL, IND, PATH = path, FNAME=fname, TMPDYNCAL = tmpdyncal
;+
; NAME:
;       WRITE_IDRIT
; PURPOSE:
;	Write a PHTDYNCAL (Dynamic Calibration Data) measurement from the dynamic 
;	structure PHTDYNCAL onto an IDL savefile  
; CATEGORY:
;	PIA - I/O
; CALLING SEQUENCE:
;       WRITE_IDYNCAL, PHTDYNCAL_INDEX, PATH = path, FNAME = fname, $
;		 TMPDYNCAL = tmpdyncal
;
; INPUT:
;       PHTDYNCAL_INDEX : Index of the measurement within PHTDYNCAL
;
; OUTPUT:
;	IDL save file
;
; RESTRICTIONS:
;       PHTDYNCAL(PHTDYNCAL_INDEX) must exist, if not TMPDYNCAL should be 
;	a valid phtdyncal static structure
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phtdyncal
;
; MODIFICATION HISTORY:
;       Written by: J. Acosta
;	Jul 98 Version 7.x
;
;-
;
;
@phtdyncal
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  WRITE_IDYNCAL, PHTDYNCAL_INDEX, PATH = PATH'

; check if keyword PATh is present
	IF KEYWORD_SET(PATH) then path1=path else path1 = './' 
	
; check if temporary structure is present
	IF KEYWORD_SET(tmpdyncal) THEN phtidyncal = tmpdyncal $ 
	ELSE  pia_load_idyncal, phtdyncal(ind), phtidyncal	

;check if FNAME is present
	IF NOT KEYWORD_SET(fname) THEN fname = phtidyncal.admn
	 
;  Write it out: use adm naming convention 
	SAVE, PHTIDYNCAL, FILE = PATH1 + FNAME+'.IDYNCAL'
        RETURN
        END
