;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO FILL_dynresp, tmp, newheader, REPLACE=replace 
;+
; NAME:
;       FILL_SRD
;
; PURPOSE:
;	FILLS a temporary structure into the dynamical structure PHTSRD  
;
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;       FILL_DYNRESP, tmp [,newheader] [,REPLACE=replace]
;
; INPUT:
;       tmp 	: DYNRESP like temporary structure
;
; OPTIONAL INPUT:
;	newheader:  New header to be change into the structure
;
; KEYWORD:
;	REPLACE : IF set (different to 0) put structure into this PHTSRD position
;
; RESTRICTIONS:
;       tmp must be a valid phtdynresp like temporary structure
;
; PROCEDURES USED: 
;       Common Block(s) or @ procedure(s):
;               phtdynresp
;
; MODIFICATION HISTORY:
;       Written by: Jose Acosta  (IAC - LA Laguna)		February 2000
;	V8.2
;-
;
@phtdynresp
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  FILL_dynresp, tmp [,newhdr] [,REPLACE=replace]'


;  Create the structures and the handles
        PHTDYNRESPT = {PHTDYNRESP_TYPE}
	FOR ihan =DYNRESP_FIRST_HANDLE,DYNRESP_LAST_HANDLE DO $
	    PHTDYNRESPT.(ihan) = HANDLE_CREATE()

;  Fill the temporary ERD structure
	FOR ihan=0,DYNRESP_FIRST_HANDLE-1 DO $
	    PHTDYNRESPT.(ihan) = tmp.(ihan)
	    
                           
;  Fill the handles
	IF N_PARAMS() LT 2 THEN HDR = tmp.hdr $ 
	  ELSE  HDR= newheader
	ind_hdr = WHERE(TAG_NAMES(tmp) EQ 'HDR')  
	HANDLE_VALUE, phtdynrespt.(ind_hdr(0)), hdr,/SET
	
	ind_nohdr = WHERE(TAG_NAMES(tmp) NE 'HDR',nnohdr)
	ind_hand = WHERE(ind_nohdr GE DYNRESP_FIRST_HANDLE,nhand) 
	FOR ihan=0,nhand-1 DO $
	    HANDLE_VALUE, phtdynrespt.(ind_nohdr(ind_hand(ihan))),   $
	      tmp.(ind_nohdr(ind_hand(ihan))), /SET
	
;  Update the PHTDYNRESP structure using the temporary structure
	IF KEYWORD_SET(REPLACE) THEN BEGIN
		IF N_ELEMENTS(phtdynresp) LE replace THEN $
		  MESSAGE, /INFO, 'Non-existing position, returning' ELSE $
		  phtdynresp(replace) = phtdynrespt 
	ENDIF ELSE $
          phtdynresp = [phtdynresp,phtdynrespt]

        RETURN
        END
