;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
PRO GET_FLDISC, TMPDATA, SIG_DISC, NEWHEADER, $
   ENCODE_FLAG = ENCODE_FLAG

;+
; NAME:
;	GET_SIGDISC
;
; PURPOSE:
;	Get a flag array corresponding to the signals which are discarded
;	according to the actual variables in the common block phtacc. 
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       GET_SIGDISC, Tmpdata, Sig_disc [,Raststeps, Rpchopstep] 
;
; INPUTS:
;       Tmpdata: A PHT-SRD temporary structure
;
; OUTPUTS:
;       Sig_disc:   A flag array (same dimensions as phtsrd.slop) with flag=1
;		    for all discarded signals
;	Raststeps:  An array with consecutive raster positions (as output from
;		    get_rastersteps)
;	Rpchopstep: An array with consecutive raster-chopper combinations (as
;		    output of get_rpchopstep)
;
; KEYWORDS:
;	ENCODE_FLAG: select if tmpdata.flag is changed with the flag encoded
;
; COMMON BLOCKS:
;	phtacc
;	rp_limits
;
; PROCEDURES USED:
;	None
;
; MODIFICATION HISTORY:
;       Written by:	Carlos Gabriel
;	Oct 95 Version 3.5
;	Bug with last point fixed (CG)		December 1995
;	Long variables for loops (CG)		January 1996
;	Extension for discarding signals per raster point,
;	output extension (CG)			September 1997
;	V6.5  
;	Extension for discarding ch.pl. portions (CG)	January 1998
;	V7.0
;	Update (JA+CG)					May 1999
;	V7.4
;-
COMMON PHTACC_FLDYNR, phtacc_fldynr

; Check number of parameters


        ON_ERROR, 2

;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  GET_SIGDISC, tmpdata, sigdisc [,raststeps, rpchopsteps]'

	time = tmpdata.time
	nsignal = tmpdata.sldi
	sigupto = get_flupto(phtacc_fldynr,time,nsignal)
	npix = pixel_det(tmpdata.det)
	
	sig_disc = FIX(tmpdata.flux(0:npix-1,*))*0
	
	IF N_ELEMENTS(newheader) EQ 0 THEN newheader = tmpdata.hdr
	
	IF sigupto GT 0 THEN BEGIN
	 FOR ipix=0,npix-1 DO sig_disc(ipix,0:sigupto) = 1
         fxaddpar, newheader, 'PR_DRDIS',sigupto,  $
            'Dynamic Resp. cal: First Signal ratios discarded'  
	ENDIF	
		
	IF KEYWORD_SET(ENCODE_FLAG) THEN BEGIN
	   encode_piaflag, 'DYNR', 'GENDISC', tmpdata.flag, tmpflag, sig_disc, $
	     DET=tmpdata.det
	   tmpdata.flag = tmpflag  
	ENDIF 	

	RETURN
	END

