;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_DISPDYNRESP
;
; PURPOSE:
;	Menu for PIA DYNRESP Data display.
;	This is a fourth level menu in the PIA hierarchy.
;
;	This routine should only be called by the PIA Display Data routine
;	and should not be called directly from the command line.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_DISPDYNRESP
;	
; KEYWORD PARAMETERS:
;	GROUP:	The group leader of the widget hirarchy
;       DATA:   An element of the PHTDYNRESP dynamic structure
;       NV:     Number of Views (1 <= NV <= 4)
;       REDRAW: To redraw same data
;	
; COMMON BLOCKS:
;	adm
;	colour_indices
;	phtacc
;	phtcs
;	phtdarkcur
;	phtsmc
;	phtdynresp
;	pia_dispdynr_cmn (internal)
;	pia_dspch2_cmn (internal)
;	dspdynr_widg (internal)
;	pia_dspchz_cmn (internal)
;	tmpvalues2 (internal)
;	dispcust_cmn (internal)
;	dynrtext (internal)
;	pia_widget_info (internal)
;
; RESTRICTIONS:
;       DATA must be a valid element of PHTDYNRESP dynamic structure
;		
; PROCEDURES USED:
;	PIA LIB:
;		decode_admn
;		get_convwh
;		get_pht_hk
;		pia_dis2dynresp
;		pia_disp_cs
;		pia_disp_hdr
;		pia_dispcust
;		pia_dispaap
;		pia_load_idynresp
;		pia_oplot
;		pia_pixchoice
;		pia_plot
;		pia_showstr
;		pia_fldynrdisc
;		pia_write_idynresp
;		pia_xplot
;		pickmeas
;		dynresp2aap
;		write_dynresp
;		xdisp_hk
;       ASTRO LIB:
;		fxpar
;		sigma
;       INTERNAL:
;		pixbutevent_dynr
;		viewevent_dynr
;		reselect_area_dynr
;		average_dynr
;		median_dynr
;		zoomevent_dynr
;		zoomsync_dynr
;		zoomnsync_dynr
;		zoomit_dynr
;		pia_resetview_dynr
;		pia_ddynresp_event
;
; MODIFICATION HISTORY:
;       Written by: J. Acosta (IAC - La Laguna)               	February 2000
;	V8.2
;-

; *********************************************************************
; *
; *********************************************************************
pro pixbutevent_dynr, event

COMMON pia_dispdynr_cmn, tmpdata, dynrps, view, viewsize, nviews, viewoptions, $
   overid, sig_disc, dynrdi1_wid 
COMMON pia_dspchdynr_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON dspdynr_widg, pixbut

        WIDGET_CONTROL, event.id, GET_UVALUE = new_pixbut

        ind = WHERE(pixcho eq new_pixbut(0))
        ind = ind(0)

      	text = ["A", "B", "C", "D"]
        IF ind LT 0 or ind GE nviews THEN BEGIN

          pixcount = pixcount+1
          IF pixcount GE nviews THEN pixcount = 0

          old_pixcho = pixcho(pixcount)
          pixcho(pixcount) = new_pixbut(0)

          view(pixcount).viewtype = 0
          pia_resetview_dynr, pixcount, view(pixcount).controlid

          txtval = text(pixcount)
          WIDGET_CONTROL, pixbut(old_pixcho), $
                                SET_VALUE = ' '
          WIDGET_CONTROL, pixbut(pixcho(pixcount)), $
                        SET_VALUE = txtval
        ENDIF
END

; *********************************************************************
; *
; *********************************************************************
pro viewevent_dynr, event

COMMON pia_dispdynr_cmn, tmpdata, dynrps, view, viewsize, nviews, viewoptions, $
   overid, sig_disc, dynrdi1_wid 
COMMON pia_dspchdynr_cmn, pixcho, pixop, pixres, psymch, pixcount

	; get index of individual window choice
	viewchoindexid = WIDGET_INFO(event.id, /PARENT)
	WIDGET_CONTROL, viewchoindexid, GET_UVALUE = setting_choi
	setting_choi = setting_choi(0)
	; get index of window
        viewindexid = WIDGET_INFO(viewchoindexid,/PARENT)
	WIDGET_CONTROL, viewindexid, GET_UVALUE = viewindex

	IF N_ELEMENTS(viewindex) EQ 0 THEN BEGIN
	  viewindex = setting_choi
	  viewindexid = viewchoindexid
 	  WIDGET_CONTROL, event.id, GET_UVALUE = setting
	  setting = setting(0)

          IF (view(viewindex(0)).viewtype NE setting) THEN BEGIN
                view(viewindex(0)).viewtype = setting
                pia_resetview_dynr, viewindex, viewindexid
          ENDIF
	ENDIF ELSE BEGIN
	; get value of setting 
 	  WIDGET_CONTROL, event.id, GET_UVALUE = setting
	  setting = setting(0)

	  IF (view(viewindex(0)).viewtype NE setting_choi OR $
	    view(viewindex(0)).viewtype_sub NE setting) THEN BEGIN
		view(viewindex(0)).viewtype_sub = setting
		view(viewindex(0)).viewtype = setting_choi
		pia_resetview_dynr, viewindex, viewindexid
	  ENDIF
	ENDELSE

END

; *********************************************************************
; *
; *********************************************************************
pro discard_area_dynr, event

COMMON pia_dispdynr_cmn, tmpdata, dynrps, view, viewsize, nviews, viewoptions, $
   overid, sig_disc, dynrdi1_wid 
COMMON pia_dspchdynr_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON zoom_discareas, disc_area, all_disc_areas

        WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        WIDGET_CONTROL, event.top, /HOURGLASS


        pixch = pixcho(windowindex)
	tmpslop = reform(tmpdata.flux(pixch,*))

	        
	pia_xplot, tmpdata.time, $
		   tmpslop, flagged=sig_disc(pixch,*), $
		   tmpdata.uflux(pixch,*), $ 
		   title= 'Discarding area by pixel '+STRTRIM(pixch+1,2),$
		   ytitle='Flux    [Jy]',xtitle='Time     [s]',$
		   psym=psymch, /disc_area

	siz= size(all_disc_areas)
	IF siz(0) EQ 0 THEN RETURN
	
; use only pixel we are interested in -> don't put detector
	decode_piaflag, 'DYNR', 'MANDISC', tmpdata.flag(pixch,*), manflag
	
	FOR I=0,N_ELEMENTS(all_disc_areas)-1 DO BEGIN
	  p1 = all_disc_areas(i).pos1
	  p2 = all_disc_areas(i).pos2
	  IF p1(1) NE 0. or p2(1) NE 0. THEN BEGIN
	     ind = WHERE(tmpslop GE p1(1) AND $
	     		 tmpslop LE p2(1) AND $
			 tmpdata.time GE p1(0) AND $
			 tmpdata.time LE p2(0), ndisc)
	     IF ndisc GT 0 THEN BEGIN
	       manflag(ind) = 1
	       encode_piaflag, 'DYNR', 'MANDISC', tmpdata.flag(pixch,*), tmpflag, $
	        manflag
	       tmpdata.flag(pixch,*) = tmpflag  
	     ENDIF
	  ENDIF
	ENDFOR
	get_validflag, tmpdata.flag, 'DYNR', redflag, $
	  det=tmpdata.det
	sig_disc = redflag
	
	pia_resetview_dynr, windowindex

END

; *********************************************************************
; *
; *********************************************************************
pro reselect_area_dynr, event

COMMON pia_dispdynr_cmn, tmpdata, srdps, view, viewsize, nviews, viewoptions, $
   overid, sig_disc 
COMMON pia_dspchdynr_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON zoom_discareas, disc_area, all_disc_areas

        WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        WIDGET_CONTROL, event.top, /HOURGLASS


        pixch = pixcho(windowindex)
	tmpslop = reform(tmpdata.flux(pixch,*))
	        
	pia_xplot, tmpdata.time, $
		   tmpslop, flagged=sig_disc(pixch,*), $
		   tmpdata.uflux(pixch,*), $ 
		   title= 'Reselecting area by pixel '+STRTRIM(pixch+1,2),$
		   ytitle='Flux    [Jy]',xtitle='Time     [s]',$
		   psym=psymch, /disc_area

	siz= size(all_disc_areas)
	IF siz(0) EQ 0 THEN RETURN
	
; use only pixel we are interested in -> don't put detector
	decode_piaflag, 'DYNR', 'MANDISC', tmpdata.flag(pixch,*), manflag

	FOR I=0,N_ELEMENTS(all_disc_areas)-1 DO BEGIN
	  p1 = all_disc_areas(i).pos1
	  p2 = all_disc_areas(i).pos2
	  IF p1(1) NE 0. or p2(1) NE 0. THEN BEGIN
	     ind = WHERE(tmpslop GE p1(1) AND $
	     		 tmpslop LE p2(1) AND $
			 tmpdata.time GE p1(0) AND $
			 tmpdata.time LE p2(0), ndisc)
	     IF ndisc GT 0 THEN BEGIN
	       manflag(ind) = 0
	       encode_piaflag, 'DYNR', 'MANDISC', tmpdata.flag(pixch,*), tmpflag, $
	        manflag
	       tmpdata.flag(pixch,*) = tmpflag  
	     ENDIF
	  ENDIF
	ENDFOR
	get_validflag, tmpdata.flag, 'DYNR', redflag, $
	  det=tmpdata.det
	sig_disc = redflag
	
	pia_resetview_dynr, windowindex

END


; *********************************************************************
; *
; *********************************************************************
pro average_dynr, event 

COMMON pia_dispdynr_cmn, tmpdata, dynrps, view, viewsize, nviews, viewoptions, $
   overid, sig_disc, dynrdi1_wid 
COMMON pia_dspchdynr_cmn, pixcho, pixop, pixres, psymch, pixcount

        WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
	
        pixch = pixcho(windowindex)
        data = tmpdata.flux(pixch,*)
        unc = tmpdata.uflux(pixch,*)
	wei = tmpdata.weight(pixch,*)
        str = 'Fluxes Averages Pixel '+STRTRIM(STRING(pixch+1),2)
	indacc = WHERE(sig_disc(pixch,*) eq 0, acc)

	IF acc GT 1 THEN weight_mean,data(indacc),unc(indacc),avwe,unwe,$
	    set_weight=wei(indacc)  
		
; Prepare a Byte array to accomodate all strings including carriage returns
	bytstr = [str,'','','']

	str = 'Full measurement average: '+$
	     STRING(avwe)+'    +/-'+STRING(unwe)
	bytstr = [bytstr,str,'']


        XDISPLAYFILE, "", $
              TITLE = "Average including Data Selection ", $
                  WIDTH = 100, $
                  HEIGHT = 10, $
                  TEXT = [bytstr]
END


; *********************************************************************
; *
; *********************************************************************
pro median_dynr, event

COMMON pia_dispdynr_cmn, tmpdata, dynrps, view, viewsize, nviews, viewoptions, $
   overid, sig_disc, dynrdi1_wid 
COMMON pia_dspchdynr_cmn, pixcho, pixop, pixres, psymch, pixcount

        WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
	
        ytitle = viewoptions(view(windowindex).viewtype).viewylab

	wtype = view(windowindex).viewtype

        pixch = pixcho(windowindex)
        data = tmpdata.flux(pixch,*)
        unc = tmpdata.uflux(pixch,*)
	wei = tmpdata.weight(pixch,*)
	str = 'Fluxes Median Pixel '+STRTRIM(STRING(pixch+1),2)
	indacc = WHERE(sig_disc(pixch,*) eq 0 AND wei GT 0., acc)

; Prepare a Byte array to accomodate all strings including carriage returns
	bytstr = [str,'','']

	IF acc GT 1 THEN BEGIN
	   avr = median(data(indacc))
	   sig = sigma(data(indacc))
	   str = 'Full measurement median: '+$
		STRING(avr)+'    +/-'+STRING(sig)								
	ENDIF ELSE str = 'Not enough points to compute the median '	
						
	bytstr = [bytstr,str,'']

; Now get the text and display it
           XDISPLAYFILE, "", $
              TITLE = "Median Value including Data Selection ", $
                  WIDTH = 100, $
                  HEIGHT = 10, $
                  TEXT = [bytstr]

END

; *********************************************************************
; *
; *********************************************************************
pro zoomevent_dynr, event

	WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
	zoomit_dynr, windowindex        
END

; *********************************************************************
; *
; *********************************************************************
pro zoomsync_dynr, event

COMMON pia_dispdynr_cmn, tmpdata, srdps, view, viewsize, nviews, viewoptions, $
   overid, sig_disc  
COMMON pia_dspchdynr_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices

	WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
	zoomit_dynr, windowindex, overplot = 1        

END

; *********************************************************************
; *
; *********************************************************************
pro zoomnsync_dynr, event

COMMON pia_dispdynr_cmn, tmpdata, srdps, view, viewsize, nviews, viewoptions, $
   overid, sig_disc 
COMMON pia_dspchdynr_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices

	WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
	zoomit_dynr, windowindex, overplot = -1        

END

; *********************************************************************
; *
; *********************************************************************
pro zoomit_dynr, windowindex, overplot=overplot, fourier=fourier

COMMON pia_dispdynr_cmn, tmpdata, srdps, view, viewsize, nviews, viewoptions, $
   overid, sig_disc 
COMMON pia_dspdynr_flg_cmn, nflag_active, flag_active_lex, flag_active_label  
COMMON pia_dspchdynr_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices


	IF (KEYWORD_SET(overplot)) THEN overplot = overplot ELSE overplot = 0
        IF (KEYWORD_SET(fourier)) THEN fourier = 1 ELSE fourier = 0

	xtitle = viewoptions(view(windowindex).viewtype).viewxlab
	ytitle = viewoptions(view(windowindex).viewtype).viewylab
	menuchoi = view(windowindex).viewtype_sub
        ytype = 0

	decode_admn, tmpdata.admn, title
	title = title 

	get_convwh, tmpdata.admn, wheels, chmod, champ
	anntmp = title + $
		'  [' + wheels(0) + '  ' + wheels(1) + '  ' + $
		wheels(2) + ']  [' + chmod + '  ' + champ + ']'

	anntmp = anntmp+' (DYNR level)'

	subtitle = ''
	charsize = 1.10
	IF overplot NE 0 THEN BEGIN
		xstyle = 0
		ystyle = 0
		IF zoom_color EQ -1 THEN zoom_color = green ELSE $
			zoom_color = zoom_color + 1
			IF zoom_color EQ 9 then zoom_color = 4
			zoom_psymch = zoom_psymch + 1
			IF zoom_psymch GT 8 THEN zoom_psymch = 1
		ENDIF ELSE BEGIN
		xstyle = 0
		ystyle = 0
		zoom_color = -1
		zoom_psymch = psymch
        ENDELSE

        IF fourier eq 1 THEN BEGIN
		xtitle = 'Frequency       [Hz]'
		ytitle = 'FFT of '+ytitle
		ytype = 1
        ENDIF
	
	CASE view(windowindex).viewtype OF

;Plot pixel signals
	  0: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Flux: Pixel '+str_pixch+'    [Jy]' 
		ytitle = str_pixch 

                IF fourier eq 1 THEN BEGIN
                        xtitle = 'Frequency       [Hz]'
                        ytitle = 'FFT of '+ytitle
                        ytype = 1
                ENDIF
		
		pia_xplot, tmpdata.time, $
			tmpdata.flux(pixch,*), $
			tmpdata.uflux(pixch,*), $
			psym = zoom_psymch, xtitle=xtitle, fourier=fourier, $
			ytitle=ytitle, subtitle=subtitle, $
			title=title, ytype=ytype,  $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,     $       
			xstyle=xstyle, ystyle=ystyle, $
			legend=strmid(ytitle,0,18), $
			annotation=anntmp                    


		indno = WHERE(sig_disc(pixch,*) eq 1, nn)
        	IF nn GT 0 THEN $
		  PIA_XPLOT, tmpdata.time(indno), $
		  tmpdata.flux(pixch,indno), $
		  psym = 7, color=red, overplot=99, $
		  legend=' discarded points'

    	  END
;Plot flag values
	  1: BEGIN
	    	elemnames =  flag_active_label   
		pixch = pixcho(windowindex)
		str_pixch = 'Flag ' + elemnames(menuchoi)+ ': Pixel '+ $
		   STRTRIM(pixch+1,2)
		IF title NE '' THEN title = str_pixch 
		;select flag depending on the choice
		IF flag_active_lex(menuchoi) EQ 'ENCODE' THEN        $
		    tmpflag = tmpdata.flag(pixch,*)                  $
		ELSE decode_piaflag,'DYNR',flag_active_lex(menuchoi), $ 
		    tmpdata.flag(pixch,*),tmpflag
		ytitle = 'Flag' 

                IF fourier eq 1 THEN BEGIN
                        xtitle = 'Frequency       [Hz]'
                        ytitle = 'FFT of '+ytitle
                        ytype = 1
                ENDIF
		
		pia_xplot, tmpdata.time, tmpflag, psym = zoom_psymch,        $
			xtitle=xtitle, fourier=fourier, ytitle=ytitle,       $
			subtitle=subtitle, title=title, ytype=ytype,         $
			overplot = overplot, charsize = charsize,            $
			color = zoom_color, xstyle=xstyle, ystyle=ystyle,    $
			legend=strmid(str_pixch,5,25), annotation=anntmp
          END
;Plot weighting factors
	  2: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Weight: Pixel '+str_pixch
		ytitle = str_pixch 
		pia_xplot, tmpdata.time, tmpdata.weight(pixch,*), $
			xtitle=xtitle, fourier=fourier, ytitle=ytitle, $
			psym = zoom_psymch, subtitle=subtitle, $
			title=title, ytype=ytype,  $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,    $       
			xstyle=xstyle, ystyle=ystyle, $
			legend=strmid(ytitle,0,18), $
			annotation=anntmp              
          END
;Plot temperatures
	  3: BEGIN
		pixch = pixcho(windowindex)
		dimtemp = size(tmpdata.temperature)
		IF dimtemp(0) EQ 2 THEN BEGIN
		   IF pixch GT 63 THEN temptmp = tmpdata.temperature(1,*) ELSE $
		   temptmp = tmpdata.temperature(0,*) 
		ENDIF ELSE temptmp = tmpdata.temperature
		xtmp = INDGEN(N_ELEMENTS(temptmp))+1
		pia_xplot,xtmp, temptmp, psym = zoom_psymch, $
			xtitle=xtitle, fourier=fourier, ytitle=ytitle, $
			subtitle=subtitle, $
			title=title, ytype=ytype,  $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,      $       
			xstyle=xstyle, ystyle=ystyle, $
			legend=strmid(ytitle,0,18), $
			annotation=anntmp      
		        
          END

	  ELSE: WIDGET_CONTROL, UPDATE_LABEL, $
				set_value = 'Unsupported View'
          ENDCASE

END


; *********************************************************************
; *
; *********************************************************************
pro pia_resetview_dynr, windowindex, UPDATE_LABEL

COMMON pia_dispdynr_cmn, tmpdata, dynrps, view, viewsize, nviews, viewoptions, $
   overid, sig_disc, dynrdi1_wid 
COMMON pia_dspdynr_flg_cmn, nflag_active, flag_active_lex, flag_active_label  
COMMON pia_dspchdynr_cmn, pixcho, pixop, pixres, psymch, pixcount
@colour_indices

	wset, view(windowindex).windownum         ;set to draw in 

	ERASE, color = 100                        ;erase the view


	IF NOT (KEYWORD_SET(UPDATE_LABEL)) THEN $
	  UPDATE_LABEL = 0


        charsize = 1.2
        symsize = 0.5

        title = viewoptions(view(windowindex).viewtype).viewname
	xtitle = viewoptions(view(windowindex).viewtype).viewxlab
	ytitle = viewoptions(view(windowindex).viewtype).viewylab
	menuchoi = view(windowindex).viewtype_sub

	CASE view(windowindex).viewtype OF


;Plot pixel signals
	  0: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Flux: Pixel '+str_pixch+'    [Jy]' 
		IF title NE '' THEN title = str_pixch 
		pia_plot, tmpdata.time, $
			tmpdata.flux(pixch,*), $
			yerr=tmpdata.uflux(pixch,*), $
			psym = psymch, xtitle=xtitle, $
			ytitle=ytitle,  $
			charsize = charsize, symsize = symsize

		indno = WHERE(sig_disc(pixch,*) eq 1, nn)
                IF nn GT 0 THEN $
		  PIA_OPLOT, tmpdata.time(indno), $
		  tmpdata.flux(pixch,indno), $
		  psym = 7, color=red

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  
         
    	  END
;Plot flag values
	  1: BEGIN
	    	elemnames =  flag_active_label   
		pixch = pixcho(windowindex)
		str_pixch = 'Flag ' + elemnames(menuchoi)+ ': Pixel '+ $
		   STRTRIM(pixch+1,2)
		IF title NE '' THEN title = str_pixch 
		;select flag depending on the choice
		IF flag_active_lex(menuchoi) EQ 'ENCODE' THEN        $
		    tmpflag = tmpdata.flag(pixch,*)                  $
		ELSE decode_piaflag,'DYNR',flag_active_lex(menuchoi), $ 
		    tmpdata.flag(pixch,*),tmpflag
		    
		pia_plot, tmpdata.time, tmpflag, psym = psymch, $
			xtitle=xtitle, ytitle=ytitle, $
			charsize = charsize, symsize = symsize

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  

          END
;Plot weighting factors
	  2: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Weight: Pixel '+str_pixch
		ytitle = str_pixch 
		pia_plot, tmpdata.time, tmpdata.weight(pixch,*),      $
			psym = psymch, xtitle=xtitle, ytitle=ytitle,  $
			charsize = charsize, symsize = symsize

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = 'Weighting factors'  

          END
;Plot temperatures
	  3: BEGIN
		pixch = pixcho(windowindex)
		dimtemp = size(tmpdata.temperature)
		IF dimtemp(0) EQ 2 THEN BEGIN
		   IF pixch GT 63 THEN temptmp = tmpdata.temperature(1,*) ELSE $
		   temptmp = tmpdata.temperature(0,*) 
		ENDIF ELSE temptmp = tmpdata.temperature
		indtmp = INDGEN(N_ELEMENTS(temptmp))+1
		pia_plot, indtmp, temptmp, psym = psymch, $
			xtitle=xtitle, ytitle=ytitle,  $
			charsize = charsize, symsize = symsize

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = 'Temperature'  

          END

	  ELSE: WIDGET_CONTROL, UPDATE_LABEL, $
				set_value = 'Unsupported View'
          ENDCASE

END


; ***************************************************************************
;  Event handling routine for PIA display menu
; ****************************************************************************

PRO pia_ddynresp_event, event

@adm
@phtcs
@phtdynresp
@phtacc

COMMON pia_dispdynr_cmn, tmpdata, dynrps, view, viewsize, nviews, viewoptions, $
   overid, sig_disc, dynrdi1_wid 
COMMON pia_dspchdynr_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON dispcust_cmn, psym, line
COMMON dynrtext, dattext_id, newheader
COMMON dspdynr_widg, pixbut
COMMON pia_widget_info, extfil_wid, intfil_wid, buffil_wid, $
                        erddi1_wid, erddi2_wid, srddi1_wid, srddi2_wid, $
                        scpdi1_wid, scpdi2_wid, spddi1_wid, spddi2_wid, $
                        aapdi1_wid, aapdi2_wid


	WIDGET_CONTROL, event.id, get_uvalue = uvalue
        WIDGET_CONTROL, event.top, /HOURGLASS

        cmap_wind_text = ["A","B","C","D"]

	CASE uvalue OF


 	  "EXIT":  BEGIN
		    WIDGET_CONTROL, event.top, /DESTROY 
		  END


          "HELP": BEGIN
	   	IF !VERSION.OS NE 'vms' THEN $
		spawn, '$w3net $PIA_HTML/um/srd_window.html &' ELSE $
		spawn, 'w3net /pia_dsk/pia/html/um/srd_window.html'
		END

	  "CUST": BEGIN
			pia_dispcust, GROUP=event.top
			psymch = psym
			 FOR I=0,NVIEWS-1 DO BEGIN
			    pia_resetview_dynr, i, view(i).controlid
			 ENDFOR
          END

	  "LOAD": BEGIN
; search for same file and detector type
		    newdata = pickmeas(FTYPE="DYNR", DTYPE=tmpdata.det, $ 
		          POSI=posi)
		    IF newdata NE '' THEN BEGIN

                     datind = WHERE(phtdynresp.admn eq newdata, count)

                     IF count EQ 0 THEN $
                        MESSAGE, /INFO, 'Measurement not found!'
                     ;;IF count GT 1 THEN datind=datind(posi(0))
                     
                     
                     IF count NE 0 THEN BEGIN 

			dynrespps = datind(posi(0))
		    	pia_load_idynresp, phtdynresp(dynrps), tmpdata		
; Look into the selection criteria
                        ;get_sigdisc, tmpdata, /ENCODE_FLAG
			get_validflag, tmpdata.flag, 'DYNR', redflag, $
			  det=tmpdata.det

                        sig_disc = redflag

; header update
			newheader = tmpdata.hdr

			obj = FXPAR(tmpdata.hdr,'OBJECT')
			attra = FXPAR(tmpdata.hdr,'ATTRA')
			attdec = FXPAR(tmpdata.hdr,'ATTDEC')
			dattext = tmpdata.admn
			more_text = 'OBJ:' + obj + ' ' + give_sradec(attra,attdec)
			dattext = 'DYNRESP '+dattext+ ' - ' + $
				  more_text

			WIDGET_CONTROL, dattext_id, SET_VALUE = dattext  
			
		        for i=0, NVIEWS - 1 do pia_resetview_dynr, i
                     ENDIF
		    ENDIF
		  END	                  	

	  "SAVEBUFF": fill_dynresp, tmpdata, newheader, REPLACE=dynrps

	  "SAVEBUFF_NEW": BEGIN
	               dynrps = N_ELEMENTS(phtdynresp)
                       fill_dynresp, tmpdata, newheader
                   END

	  "SAVEI": BEGIN
	  	    change_tmphdr, tmpdata, 'DYNRESP', newheader, tmpout
	  	    PCONT_SAVEINT, junk, 'DYNR', tmpdata=tmpout
		  END

	  "SAVEF": BEGIN
;		    WRITE_DYNRESP, tmpdata, newheader  
		  END

	  "SHOWD": PIA_SHOWSTR, tmpdata, VALNAMES=phtdynresp_desc, $ 
	                      GROUP=event.top 

	  "DYNRDISC": BEGIN 

		PIA_FLDYNRDISC, tmpdata.time, tmpdata.sldi
		npix = pixel_det(tmpdata.det)
		;get_ratsig, tmpdata.flux, tmpdyncal, NCAL = ncal_use, NPIX=npix
		;PIA_CSIGDISC, nsig=tmpdata.rchp  
				
                get_fldisc, tmpdata, /ENCODE_FLAG
		get_validflag, tmpdata.flag, 'DYNR', redflag, $
			  det=tmpdata.det

                sig_disc = redflag

		FOR i=0, NVIEWS - 1 do pia_resetview_dynr, i
	  END		   

		
          "HDR": BEGIN
                header = newheader
                IF N_ELEMENTS(header) EQ 0 THEN $
                        MESSAGE, /INFO, 'No header defined' ELSE $
                        pia_disp_hdr, header, tmpdata.admn, 'PHTDYNRESP'
          END

          "CS": PIA_disp_cs,tmpdata.admn

	  "ISREP": PIA_disp_isr,STRMID(tmpdata.admn,4,8)

	  "OLREP": PIA_disp_olr,STRMID(tmpdata.admn,4,8)

	  "EOHA": PIA_disp_eoha,STRMID(tmpdata.admn,4,8)

	  "EOHI": PIA_disp_eohi,STRMID(tmpdata.admn,4,8)

	  "SLICES": BEGIN

		npix = N_ELEMENTS(tmpdata.flux(*,0)) - 2
 		IF npix EQ 130 THEN npix = 128

		nslice = N_ELEMENTS(tmpdata.slop(0,*))

		decode_admn, tmpdata.admn, tmpmeas

	  	PIA_XPLOT, indgen(npix) + 1, tmpdata.flux(0:npix-1,0), $
	  		TITLE='Time sequence of Calib. Signals - '+tmpmeas, $
	  		xtitle=' Pixel # ', ytitle='Signal    [V/s]', $
	  		psym=10

		zoom_color = 1

		IF nslice GT 1 THEN BEGIN
	  	 FOR I=1, nslice-1 DO BEGIN
			zoom_color = zoom_color + 1
			IF zoom_color EQ 9 then zoom_color = 1
	  	 	WAIT,0.5
	  	 	PIA_XPLOT, indgen(npix) + 1, tmpdata.flux(0:npix-1,i),$
	  	 	/overplot, color=zoom_color, psym=10
	  	 ENDFOR
	  	ENDIF 
	  END	  	 	

	  "SLICES_3D": BEGIN

		npix = N_ELEMENTS(tmpdata.flux(*,0)) - 2
 		IF npix EQ 130 THEN npix = 128

		decode_admn, tmpdata.admn, tmpmeas

		PIA_XSurface, tmpdata.flux(0:npix-1,*), $
			title='Time sequence of Calibrated Signals - '+tmpmeas,$
			xtitle=' Pixel # ', ytitle='Time    [s]', $
			ztitle='Signal    [V/s]', charsize=1.25, wlego=1

	  END	  	 	

	  "PROC":  BEGIN
		dynresp2aap, tmpdata, aappos, NEWHDR = newheader
		pia_dispaap, data= aappos(0)
	  END

	  "PIXCH": BEGIN
			old_pixcho = pixcho
			new_pixc = pia_pixchoice(GROUP=event.top, PIXC=pixcho)
			maxpix = max(new_pixc)
                        minpix = min(new_pixc)
			junk = 0
			IF (tmpdata.det EQ 'C1' AND maxpix gt 8) OR $
			   (tmpdata.det EQ 'C2' AND maxpix gt 3) OR $
			   (tmpdata.det EQ 'SS' AND maxpix gt 127) OR $
			   (tmpdata.det EQ 'SL' AND maxpix gt 127) OR $
			   (minpix lt 0)  THEN BEGIN
		    		XDISPLAYFILE, "", $
                    		GROUP = event.top, $
                    		TITLE = "Warning ", $
                    		WIDTH = 30, $
                    		HEIGHT = 6, $
                    		TEXT = [" Your pixel choice is not valid ", $
                                        " and will not be taken "]
		                junk = 1
			ENDIF
			IF junk NE 1 THEN BEGIN  			
			 FOR I=0,NVIEWS-1 DO BEGIN
			  IF new_pixc(i) NE old_pixcho(i) THEN BEGIN
			    pixcho(i) = new_pixc(i)
			    WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
			    view(i).windownum = temp
			    pia_resetview_dynr, i, view(i).controlid
                            IF STRMID(tmpdata.det,0,1) EQ 'C' THEN BEGIN
                              txtval = cmap_wind_text(i)
                              junk = where(new_pixc eq old_pixcho(i), count)
                              IF count EQ 0 THEN $
                                 WIDGET_CONTROL, pixbut(old_pixcho(i)), $
                                        SET_VALUE = ' '
                              WIDGET_CONTROL, pixbut(pixcho(i)), $
                                        SET_VALUE = txtval
                            ENDIF
                          ENDIF
			 ENDFOR
			ENDIF
          END

	  "PIXCHSER": BEGIN
			old_pixcho = pixcho
			new_pixc = old_pixcho + nviews
			CASE STRMID(tmpdata.det,0,2) OF
				'C1': npix = 9
				'C2': npix = 4
				'SL': npix = 128
				'SS': npix = 128
				'P1': RETURN
				'P2': RETURN
				'P3': RETURN
			ENDCASE  
			new_pixc = new_pixc mod npix
			
			FOR I=0,NVIEWS-1 DO BEGIN
			  IF new_pixc(i) NE old_pixcho(i) THEN BEGIN
			    pixcho(i) = new_pixc(i)
			    WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
			    view(i).windownum = temp
			    pia_resetview_dynr, i, view(i).controlid
			    IF STRMID(tmpdata.det,0,1) EQ 'C' THEN BEGIN 
			      txtval = cmap_wind_text(i)
			      junk = where(new_pixc eq old_pixcho(i), count)
			      IF count EQ 0 THEN $
			         WIDGET_CONTROL, pixbut(old_pixcho(i)), $
					SET_VALUE = ' '
			      WIDGET_CONTROL, pixbut(pixcho(i)), $
					SET_VALUE = txtval
			    ENDIF 
                          ENDIF
			ENDFOR
          END

	  "PIXCHSERD": BEGIN
			old_pixcho = pixcho
			new_pixc = old_pixcho - nviews
			CASE STRMID(tmpdata.det,0,2) OF
				'C1': npix = 9
				'C2': npix = 4
				'SL': npix = 128
				'SS': npix = 128
				'P1': RETURN
				'P2': RETURN
				'P3': RETURN
			ENDCASE  
			ind=WHERE(new_pixc LT 0,nind)
			IF nind GT 0 THEN new_pixc(ind) = npix+new_pixc(ind)  
			
			FOR I=0,NVIEWS-1 DO BEGIN
			  IF new_pixc(i) NE old_pixcho(i) THEN BEGIN
			    pixcho(i) = new_pixc(i)
			    WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
			    view(i).windownum = temp
			    pia_resetview_dynr, i, view(i).controlid
			    IF STRMID(tmpdata.det,0,1) EQ 'C' THEN BEGIN 
			      txtval = cmap_wind_text(i)
			      junk = where(new_pixc eq old_pixcho(i), count)
			      IF count EQ 0 THEN $
			         WIDGET_CONTROL, pixbut(old_pixcho(i)), $
					SET_VALUE = ' '
			      WIDGET_CONTROL, pixbut(pixcho(i)), $
					SET_VALUE = txtval
			    ENDIF 
                          ENDIF
			ENDFOR
          END

          "NVIEWS": BEGIN

                newviews = event.value + 1
		!PIA_NVIEWS = 1 > newviews < 4
                IF newviews NE nviews THEN BEGIN
                        WIDGET_CONTROL, dynrdi1_wid, /DESTROY
                        pia_dispdynresp, NV = newviews, /redraw
                ENDIF
          END


          "HK" : BEGIN
                get_pht_hk,tmpdata.admn,phtcs_redu
                xdisp_hk
          END


	ENDCASE
	
RETURN
END

; ****************************************************************************
;  PIA Dispdynresp - menu definition procedure
; ****************************************************************************

PRO pia_dispdynresp, GROUP=group, DATA=DATA, NV = NV, REDRAW=redraw 

COMMON pia_dispdynr_cmn, tmpdata, dynrps, view, viewsize, nviews, viewoptions, $
   overid, sig_disc, dynrdi1_wid 
COMMON pia_dspdynr_flg_cmn, nflag_active, flag_active_lex, flag_active_label  
COMMON pia_dspchdynr_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON dynrtext, dattext_id, newheader
COMMON dspdynr_widg, pixbut
COMMON pia_widget_info, extfil_wid, intfil_wid, buffil_wid, $
                        erddi1_wid, erddi2_wid, srddi1_wid, srddi2_wid, $
                        scpdi1_wid, scpdi2_wid, spddi1_wid, spddi2_wid, $
                        aapdi1_wid, aapdi2_wid
COMMON dispcust_cmn, psym, line

@phtdynresp
COMMON piaflag_info, piaflag_str

; If already registered, start second DYNRESP display

        IF Xregistered("pia_dispdynresp") NE 0 THEN BEGIN
;                pia_dis2dynresp, group=group, data=data
		MESSAGE, /INFO, '2nd window not implemented, returning'
                RETURN
        END


        IF NOT KEYWORD_SET(redraw) THEN BEGIN
; load data from dynamic buffers into temporary structure
                dynrespps = data
		PIA_LOAD_Idynresp, phtdynresp(dynrespps), tmpdata 
		newheader = tmpdata.hdr
        ENDIF

; initialize views and pixels chosen
        IF KEYWORD_SET(NV) THEN NVIEWS = nv ELSE NVIEWS = !PIA_NVIEWS
        IF nviews GT 4 THEN nviews = 4
        pixcount = -1


	IF N_ELEMENTS(psym) EQ 0 THEN psymch = 4 ELSE $
		psymch = psym	

	CASE STRMID(tmpdata.det, 0,1) of 
          'P': BEGIN 
		pixcho = [0,0,0,0]
		pixop = 0
		pixres = 0
	  END
          ELSE: BEGIN  
	         CASE STRMID(tmpdata.det,0,2) of
	           'C1': BEGIN
			pixcho = [0,2,4,6]
		   END
	           'C2': BEGIN
			pixcho = [1,2,3,0]
		   END
	           'SS': BEGIN
			pixcho = [10,40,90,120]
		   END
	           'SL': BEGIN
			pixcho = [10,40,90,120]
		   END

		  ELSE: MESSAGE, /INFO, 'Detector not recognized'

	 	  ENDCASE		
	  END
        ENDCASE

	indflag_active = WHERE(piaflag_str.dynr.lex NE 'DUMMY',nflag_active)
	
	nflag_active = nflag_active +1
	
	flag_active_lex = ['ENCODE',piaflag_str.dynr.lex(indflag_active)]
	flag_active_label = ['Encode',piaflag_str.dynr.expla(indflag_active)]

	viewsize = 220
	xsize = viewsize * 4 / nviews
	ysize = viewsize
	;structure for each view
	viewinstance = {        viewtype:0b, 		$	   
				viewtype_sub:0b, 	$       
				controlid:0L,		$       	
				windowid:0L,		$
				windownum:0}	

        view = REPLICATE(viewinstance, NVIEWS)		; array of view struct.

        IF STRMID(tmpdata.det, 0,1) eq 'P' THEN $
                FOR i=0,nviews-1 DO view(i).viewtype = i

	;structures describing each type of view 
	instance = {viewname:'',viewid:0, viewxlab:'', viewylab:'', $
		viewmenu:0, viewmenuchoi:0,viewmenulabel:STRARR(nflag_active) }
	NVIEWOPTS = 4                          	

	viewoptions = REPLICATE(instance, NVIEWOPTS)    

	viewoptions(0).viewname = "Flux Data     [Jy]" 
	viewoptions(0).viewid = 0
	viewoptions(0).viewylab = "Flux    [Jy]"
	viewoptions(0).viewxlab = "Time       [s]"
	viewoptions(1).viewname = "Flux Flag    "
	viewoptions(1).viewid = 1
        viewoptions(1).viewmenu = 1
        viewoptions(1).viewmenuchoi = nflag_active
        viewoptions(1).viewmenulabel = flag_active_label
	viewoptions(1).viewylab = "Flag         "
	viewoptions(1).viewxlab = "Time       [s]"
	viewoptions(2).viewname = "Weighting Factor   " 
	viewoptions(2).viewid = 2
	viewoptions(2).viewylab = "Factor "
	viewoptions(2).viewxlab = "Time       [s]"
	viewoptions(3).viewname = "Temperature     [K]"
	viewoptions(3).viewid = 3
	viewoptions(3).viewylab = "Measured temperature   [K]"
	viewoptions(3).viewxlab = "Time       [s]"

; top base

	dynrdi1_wid = WIDGET_BASE( TITLE="PIA DYNRESP Data Display", /COLUMN, $
				XPAD = 20, YPAD = 20, SPACE = 20)

; control windows

	control = WIDGET_BASE(dynrdi1_wid, /ROW)

	control_exit = WIDGET_BUTTON(control, VALUE="    Exit    ",$
					 UVALUE="EXIT")
	control_help = WIDGET_BUTTON(control, VALUE="    Help    ",$
					 UVALUE="HELP")
	control_cust = WIDGET_BUTTON(control, VALUE="  Customize ",$
					 UVALUE="CUST")


	junk = WIDGET_LABEL(control, VALUE = '     ')

	obj = FXPAR(tmpdata.hdr,'OBJECT')
	attra = FXPAR(tmpdata.hdr,'ATTRA')
	attdec = FXPAR(tmpdata.hdr,'ATTDEC')
	decode_admn, tmpdata.admn, dattext
	more_text = 'OBJ:' + obj + ' ' + give_sradec(attra, attdec)
	dattext = 'SRD '+dattext+ ' - ' + more_text
	dattext_id = WIDGET_LABEL(control, VALUE = dattext)  

;------------------- the C mapping windows -------------------------

        junk = WIDGET_LABEL(control, VALUE = '     ')

        IF STRMID(tmpdata.det, 0,1) eq 'C' THEN BEGIN

         pixver = WIDGET_BASE(control, /COLUMN)
	 junk = WIDGET_LABEL(pixver, VALUE='^ +Z')

         pixhor = WIDGET_BASE(pixver,/ROW)

                                                               
          IF STRMID(tmpdata.det, 1,1) eq '1' THEN BEGIN
                pixbut = lonarr(9)
                FOR i=0,2 DO pixbut(i*3+2) = $
                        WIDGET_BUTTON(pixhor, VALUE=' ',$
                                XOFFSET=2*i, $,
                                UVALUE=i*3+2,$
                                EVENT_PRO = 'pixbutevent_dynr')
                pixhor = WIDGET_BASE(pixver,/ROW,YOFFSET=6)
                FOR i=0,2 DO pixbut(i*3+1) = $
                        WIDGET_BUTTON(pixhor, VALUE=' ',$
                                XOFFSET=2*i, $
                                UVALUE=i*3+1,$
                                EVENT_PRO = 'pixbutevent_dynr')
                pixhor = WIDGET_BASE(pixver,/ROW,YOFFSET=6)
                FOR i=0,2 DO pixbut(i*3) = $
                        WIDGET_BUTTON(pixhor, VALUE=' ',$
                                XOFFSET=2*i, $
                                UVALUE=i*3,$
                                EVENT_PRO = 'pixbutevent_dynr')
          ENDIF ELSE $
          IF STRMID(tmpdata.det, 1,1) eq '2' THEN BEGIN
                pixbut = lonarr(4)
                FOR i=0,1 DO pixbut(i+2) = $
                        WIDGET_BUTTON(pixhor, VALUE=' ',$
                                XOFFSET=3*i, $
                                UVALUE=i+2,$
                                EVENT_PRO = 'pixbutevent_dynr')
                pixhor = WIDGET_BASE(pixver,/ROW,YOFFSET=10)
                FOR i=1,0,-1 DO pixbut(i) = $
                        WIDGET_BUTTON(pixhor, VALUE=' ',$
                                XOFFSET=3*i, $
                                UVALUE=i,$
                                EVENT_PRO = 'pixbutevent_dynr')
          ENDIF
	 junk = WIDGET_LABEL(pixhor, VALUE='> +Y')   
        ENDIF

;----------------- the View windows are defined ------------------

	viewbase = WIDGET_BASE(dynrdi1_wid, /ROW, SPACE=1)

	viewstorageids = LONARR(NVIEWS)
	overid = lonarr(NVIEWS)	   
	
; Provide for Open and Resistor pixels only if necessary
	IF STRMID(tmpdata.det, 0,1) NE 'S' THEN NVIEWOPTS = NVIEWOPTS - 2
	IF STRMID(tmpdata.det, 0,1) EQ 'P' THEN NVIEWOPTS = NVIEWOPTS - 2

	cmap_wind_text=["A","B","C","D"]
	
        FOR viewindex = 0, NVIEWS - 1 DO BEGIN
	  viewbase_sub = WIDGET_BASE(viewbase, /FRAME, /COLUMN)
	  junk = WIDGET_LABEL(viewbase_sub, $
	       VALUE="Window "+cmap_wind_text(viewindex))
	  tempbase = WIDGET_BASE(viewbase_sub, /COLUMN,                  $
				EVENT_PRO = 'viewevent_dynr')
	  view(viewindex).controlid = WIDGET_BUTTON(tempbase, VALUE="   ",   $
				MENU = 2, UVALUE = viewindex, $
				EVENT_PRO = 'viewevent_dynr')
	  view(viewindex).windowid = WIDGET_DRAW(tempbase,                   $
				XSIZE = xsize, YSIZE = ysize,                $
				RETAIN = 2) 
		FOR i = 0, NVIEWOPTS - 1 DO BEGIN
     			dummy = WIDGET_BUTTON(view(viewindex).controlid,   $
                	VALUE = viewoptions(i).viewname,                   $
                	UVALUE = viewoptions(i).viewid,                    $
			MENU=viewoptions(i).viewmenu)
			IF viewoptions(i).viewmenu THEN BEGIN
			   FOR ichoi=0,viewoptions(i).viewmenuchoi-1 DO    $
			   dummy1 = WIDGET_BUTTON(dummy,                   $
			     VALUE=viewoptions(i).viewmenulabel(ichoi),    $
			     UVALUE=ichoi)
			ENDIF     
		ENDFOR

	  zoombase = WIDGET_BASE(tempbase, /FRAME, /ROW)
          zoom = WIDGET_BUTTON(zoombase, $
                        VALUE = "Zoom & Print", $
                        UVALUE = viewindex, MENU = 2)

          dummy = WIDGET_BUTTON(zoom, $
                        VALUE = "New  Window", $
                        UVALUE = viewindex, EVENT_PRO = 'zoomevent_dynr')

          synch = WIDGET_BUTTON(zoom, $
                        VALUE = "Overplot, same y-axis  ", $
                        UVALUE = viewindex, EVENT_PRO = 'zoomsync_dynr')
          nsynch = WIDGET_BUTTON(zoom, $
                        VALUE = "Overplot, new y-axis", $
                        UVALUE = viewindex, EVENT_PRO = 'zoomnsync_dynr')


          process = WIDGET_BUTTON(zoombase, $
                        VALUE = "Test processing", $
                        UVALUE = viewindex, MENU = 2)

          aver = WIDGET_BUTTON(process, $
                        VALUE = "Average", $
                        UVALUE = viewindex, EVENT_PRO = 'average_dynr')

          medi = WIDGET_BUTTON(process, $
                        VALUE = "Median", $
                        UVALUE = viewindex, EVENT_PRO = 'median_dynr')

          discar = WIDGET_BUTTON(process, $
                        VALUE = "Discard area graphically", $
                        UVALUE = viewindex, EVENT_PRO= 'discard_area_dynr')
          resel = WIDGET_BUTTON(process, $
                        VALUE = "Reselect area graphically", $
                        UVALUE = viewindex, EVENT_PRO= 'reselect_area_dynr')
        ENDFOR

	controlbase = WIDGET_BASE(dynrdi1_wid, /ROW, SPACE = 40)


;----------------- the Data controls are defined ------------------

        datcont = WIDGET_BUTTON(controlbase, VALUE='Data', /MENU )
        id_2 = WIDGET_BUTTON(datcont, VALUE='Load', UVALUE='LOAD' )
        id_2 = WIDGET_BUTTON(datcont, VALUE='Save', /MENU )
        id_3 = WIDGET_BUTTON(id_2, VALUE='to DYNRESP buffer', /MENU )
        id_4 = WIDGET_BUTTON(id_3, VALUE='new measurement', $
				 UVALUE='SAVEBUFF_NEW' )
        id_4 = WIDGET_BUTTON(id_3, VALUE='same measurement', $
				 UVALUE='SAVEBUFF' )
        id_3 = WIDGET_BUTTON(id_2, VALUE='to PIA internal file', $
				 UVALUE='SAVEI' )
        id_3 = WIDGET_BUTTON(id_2, VALUE='to FITS external file', $
				UVALUE='SAVEF' )
	WIDGET_CONTROL, id_3, sensitive=0
        id_2 = WIDGET_BUTTON(datcont, VALUE='Show Data', UVALUE='SHOWD' )

;---------------- the Selection controls are defined -----------------

        selcont = WIDGET_BUTTON(controlbase, VALUE='Selection', /MENU )
        id_2 = WIDGET_BUTTON(selcont, VALUE='Discard Data Points', $
				UVALUE='DYNRDISC')

;---------------- the Correction controls are defined -----------------

        corrcont = WIDGET_BUTTON(controlbase, VALUE='Correction', /MENU )
        WIDGET_CONTROL, corrcont, SENSITIVE = 0

;---------------- the View controls are defined -----------------

        viewcont = WIDGET_BUTTON(controlbase, VALUE='View', /MENU )
        id_2 = WIDGET_BUTTON(viewcont, VALUE='Header Info ', UVALUE='HDR')
        id_2 = WIDGET_BUTTON(viewcont, VALUE='Compact Status ', UVALUE='CS')
        cont2 = WIDGET_BUTTON(viewcont, VALUE='Auxiliary Files', /MENU )
        id_2 = WIDGET_BUTTON(cont2, VALUE='IS Report ', UVALUE='ISREP')
        id_2 = WIDGET_BUTTON(cont2, VALUE='OLP Report ', UVALUE='OLREP')
        id_2 = WIDGET_BUTTON(cont2, VALUE='EOHA ', UVALUE='EOHA')
        id_2 = WIDGET_BUTTON(cont2, VALUE='EOHI ', UVALUE='EOHI')

;---------------- the Array controls are defined -----------------

        arraycont = WIDGET_BUTTON(controlbase, VALUE='Array', /MENU )
        id_2 = WIDGET_BUTTON(arraycont, VALUE='Time evolution', /MENU)
        IF STRMID(tmpdata.det,0,1) EQ 'P' THEN $
                        WIDGET_CONTROL, id_2, SENSITIVE=0
        id_3 = WIDGET_BUTTON(id_2, VALUE='Time slices ', UVALUE='SLICES')
        id_3 = WIDGET_BUTTON(id_2, VALUE='3-D view ', UVALUE='SLICES_3D')

        
;---------------- the Processing controls are defined -----------------

        proccont = WIDGET_BUTTON(controlbase, VALUE='Process', /MENU)
        id_2 = WIDGET_BUTTON(proccont, VALUE=' Average/Median   ', $
				UVALUE='PROC' )


;---------------- the Pixel Choice controls are defined -----------------

        pixcont = WIDGET_BUTTON(controlbase, VALUE='Pixels', $
				/MENU)
        pixch = WIDGET_BUTTON(pixcont, VALUE=' Individual choice ', $
				UVALUE='PIXCH' )
        pixch = WIDGET_BUTTON(pixcont, VALUE=' Serial increment  ', $
				UVALUE='PIXCHSER' )
        pixch = WIDGET_BUTTON(pixcont, VALUE=' Serial decrement  ', $
				UVALUE='PIXCHSERD' )
        IF STRMID(tmpdata.det,0,1) EQ 'P' THEN $
        	WIDGET_CONTROL, pixcont, SENSITIVE=0

;---------------- the number of views controls is defined -----------------

        nvbut = cw_bselector(controlbase, $
                        /FRAME, SET_VALUE=NVIEWS-1, $
                        UVALUE = 'NVIEWS', $
                        ['1 Plot', $
                        '2 Plots', $
                        '3 Plots', $
                        '4 Plots'])

                                                
;----------------------------------------------------------------------

       hkbutton=widget_button(controlbase,value=' HK ', uvalue ='HK')

;----------------------------------------------------------------------


; Look into the selection criteria

        ;get_sigdisc, tmpdata, /ENCODE_FLAG
	get_validflag, tmpdata.flag, 'DYNR', redflag, $
	  det=tmpdata.det

	sig_disc = redflag


; Realize widget

	WIDGET_CONTROL, dynrdi1_wid, /REALIZE, /HOURGLASS

	
	FOR i = 0, nviews - 1 DO BEGIN
		WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
		view(i).windownum = temp
		pia_resetview_dynr, i, view(i).controlid
           IF STRMID(tmpdata.det,0,1) EQ 'C' THEN BEGIN
                txtval = cmap_wind_text(i) 
                WIDGET_CONTROL, pixbut(pixcho(i)), SET_VALUE = txtval
           ENDIF
	ENDFOR


	XManager, No_BLOCK=1, "pia_dispdynresp", dynrdi1_wid, $
		EVENT_HANDLER = "pia_ddynresp_event", GROUP_LEADER=GROUP


	RETURN
END
