;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_LOAD_IDYNRESP
;
; PURPOSE:
;	Write a PHT-DYNRESP (Signal per chopper plateau) measurement from the 
;	dynamic structure PHTDYNCAL (PHTDRIFT type) onto a temporary structure 
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       PIA_LOAD_IDRIFT, driftdat, tmpdrift
;
; INPUT:
;       DRIFTDAT 	: PHTDRIFT like dynamic structure
;
; KEYWORDS:
;	none
;
; OUTPUTS:
;	TMPDRIFT	: A temporary structure of SCP type
;
; RESTRICTIONS:
;       DRIFTDAT must exist
;
; MODIFICATION HISTORY:
;       Written by:	J.Acosta (ESA/MPIA/IAC)          	February 2000
;	Version 8.2
;-

PRO pia_load_idynresp, dynresp, tmpdynresp, DYNRESPPS= DYNRESPPS

        ON_ERROR, 2
	
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 2 THEN MESSAGE, $
         'Syntax: pia_load_idynresp, phtdynresp, tmpdyncal, DYNRESPPS= DYNRESPPS'
	  
	IF KEYWORD_SET(dynrespps) THEN BEGIN
	  @phtdynresp
	  dynresp = phtdynresp(dynrespps)  
        ENDIF
	
;  Fill temporary variables from the handles
        
	HANDLE_VALUE, dynresp.hdr, hdr
        HANDLE_VALUE, dynresp.time, time
        HANDLE_VALUE, dynresp.flux, flux
        HANDLE_VALUE, dynresp.uflux, uflux
        HANDLE_VALUE, dynresp.weight, weight
        HANDLE_VALUE, dynresp.flag, flag

;  Fill the temporary structure
	
	tmpdynresp = {admn: dynresp.admn, 	$
        meas_name: dynresp.meas_name, 		$ 
	det: dynresp.det,			$
	temperature: dynresp.temperature,	$
	sldi: dynresp.sldi,			$
	proc_time: dynresp.proc_time,		$
	hdr: hdr,				$
	time: time,				$
	flux: flux,				$
	uflux: uflux,				$
	weight: weight,				$
	flag: flag }

        RETURN
END

