;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PROCESS_SRDDYNR
; PURPOSE:
;	Reduce PHT data from Signal per Ramp to AAP level, using the
;	dynamic response scheme, and
;	taken into account diverse selections or flags
; CATEGORY:
;	PIA - processing
;                
; CALLING SEQUENCE:
;	PROCESS_SRDDYNR, tmpdata, dynrps,  $
;		NO_DYNRBUFF =no_dynrbuff, HDR = hdr, TMPDYNR = phtdynrespt
;
; INPUT PARAMETERS:
;	tmpdata	: structure to be processed
;
; OUTPUT PARAMETERS:
;	dynrps:	position within the common block phtdynresp	  
;
; KEYWORDS:
;	NO_DYNRBUFF	: avoiding putting into CB phtdynresp
;	HDR		: a header to be taken instead of tmpdata.hdr
;	TMPDYNR		: returning the phtdynresp structure as temporary
;
;
; RESTRICTIONS:
;
; METHOD:
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phtdynresp
;
; MODIFICATION HISTORY:
;	Written by: Jose Acosta
;	Bug with header keyword corrected (CG)	March 00
;	V8.2
;-
PRO process_srddynr, tmpdata, dynrps,  $
		NO_DYNRBUFF =no_dynrbuff, HDR = hdr, TMPDYNR = phtdynrespt

;
; Load Needed common blocks :
@phtdynresp

	ON_ERROR, 2                                          
;
; Check the number of parameters
;
	IF N_PARAMS() LT 1 THEN MESSAGE, $
	   'Syntax: PROCESS_SRDDYNR, TMPDATA [,DYNRPOS] [,HDR=HDR] ' + $
	   '[,/NO_DYNRBUFF] [,TMPDYNR=tmpdynr]'
; For each measurement chosen
;
 	IF N_ELEMENTS(phtddynresp) EQ 0 THEN phtdynresp_init
 
	tmpdata1 = tmpdata

; Take the input HDR if present
          IF KEYWORD_SET(hdr) THEN SRDHDR = HDR ELSE $
	  	SRDHDR = tmpdata.HDR

	  det = tmpdata.det
	  npix = pixel_det(det)
	  time = tmpdata.stim
	  slop = tmpdata.slop(0:npix-1,*)
	  slun = tmpdata.slun(0:npix-1,*)
	  flag = tmpdata.flag(0:npix-1,*)
	  IF det EQ 'SL' THEN BEGIN 
	     temp = FLTARR(2)
	     temp(0) = AVG(tmpdata.temp(0,*))
	     temp(1) = AVG(tmpdata.temp(1,*))
          ENDIF ELSE temp = AVG(tmpdata.temp)



;check that dark current has been subtracted
dark_done = fxpar(srdhdr,'PRS_DARK')
IF dark_done EQ 0 THEN print,STRING(7b), $
  'Warning: Dark current should be subtracted before dynamic resp. calibration'
	
;check that detector temperature is within calbirated range
CASE tmpdata.det OF 
 'SL': tempera_range = [2.8,3.1]
 ELSE: tempera_range = [2.6,3.5]
ENDCASE 
ind_tempera = WHERE(temp LT tempera_range(0) OR $
                           temp GT tempera_range(1),ntempout)
IF ntempout GT 0 THEN print,STRING(7b), $
  'Warning: Detector temperature is out of bounds ['   + $ 
  STRTRIM(tempera_range(0),2)  + ', ' +   $
  STRTRIM(tempera_range(1),2) +']'
     
; In principle this processing should be applied only to staring measurements
	  
	  ; calibrate in flux
	  dyncalib_meas, time, slop, flux, weight, det = det	
	  uflux =  slun/slop * flux           
	       	   

;  Accomodate data into the dynresp structure and the scp handles after
;  creating the temporary ones  

;  Change the header according to the selection criteriae 
                
	  PHTDYNRESPT = {			$
	  ADMN: tmpdata.admn,			$
	  MEAS_NAME: tmpdata.admn,		$
	  DET:  tmpdata.det,			$
	  TEMP:  temp,				$
	  SLDI: tmpdata.sldi,			$
	  PROC_TIME: !STIME,			$
	  HDR: srdhdr,				$
	  TIME: time,				$
	  FLUX: flux,				$
	  UFLUX: uflux,				$
	  WEIGHT: weight,			$
	  FLAG: flag  }
	  

	  IF NOT KEYWORD_SET(no_dynrbuff) THEN BEGIN 
              ; Update the PHTDYNRESP structure using the temporary structure
	      fill_dynresp, phtdynrespt
	      DYNRPOS = N_ELEMENTS(PHTDYNRESP) - 1
	      DYNRPS = DYNRPOS 
	  ENDIF


	RETURN
	END
