;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO READ_SPECAL_DYNCAL, FILENAME, TABLE = table, PATH =path
;+
; NAME:
;       READ_SPECAL_CHOP
; PURPOSE:
;       Read the Volts/s to Jy conversion factors and first order correction
;       for SL chopped measurement from a FITS file into the COMMON phtslchopp. 
; CATEGORY:
;       PIA - I/O
;
; CALLING SEQUENCE:
;       READ_SPECAL_CHOP
;
; INPUT PARAMETERS:
;       (none)
;
; OPTIONAL INPUT PARAMETERS:
;       FILENAME: The file to be read
;       PATH: The directory to find the file to be read
;       TABLE: To read a savefile instead of cal-G file
;
; OUTPUT PARAMETERS:
;       NONE
;
; RESTRICTIONS:
;       FILENAME must be a valid PHT PSPECAL fits file
;
; METHOD:
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phtslchopp
;       Astronomical Library:
;               fxhread
;               fxpar
;
; MODIFICATION HISTORY:
;       Written by: J. Acosta (IAC)                             Feb. 1999
;       V8.1
;-
;
; Needed common blocks :
@phtdyncaltab

npix=128  & nsig = 130  & ntime = 13
SL_DYNCAL_TAB = {lflux:FLTARR(nsig,ntime,npix), weight:FLTARR(nsig,ntime,npix),$
     lsig:FLTARR(nsig),ltime:FLTARR(ntime),flux_min:FLTARR(npix), $ 
     flux_max:FLTARR(npix),nsig_neg:29,signal_zero:1.e-5}

; generate signal 
lsig=FLTARR(nsig)
; first the negative part
lsig(0:28) = -10.^(-3. - INDGEN(29) * 2./28.) 
lsig(30:nsig-1) = 10.^(-5. + INDGEN(100) * 7./99.)

; generate time sequence 
ltime = alog10([1.,2.,4.,8.,16.,32.,64.,128.,256.,512.,1024.,2048.,4096.])
sl_dyncal_tab.ltime = ltime
sl_dyncal_tab.lsig = lsig


IF NOT KEYWORD_SET(TABLE) THEN  BEGIN  ; read from CALG file
     ; read first file containing the flux values
     flux = readfits(!CALG+'PSDYNAMIC.FITS',hdr)
     flux_max = FLTARR(npix) & flux_min = FLTARR(npix)
     FOR i=0,npix-1 DO BEGIN
        par = 'FLX' + STRTRIM(i+1,2)
        flux_min(i) = FXPAR(hdr,par+'L')
	flux_max(i) = FXPAR(hdr,par+'U')
     ENDFOR
     ;now read the file containing the weighting factors
     weight = readfits(!CALG+'PSDYNWT.FITS')
ENDIF ELSE BEGIN ; reads from SAVEFILE
     IF N_ELEMENTS(filename) EQ 0 THEN $
          filename ='SL_DYNCAL_CALG.SAV'
     IF N_ELEMENTS(path) EQ 0 THEN path = !CALSAVE +'dyncal_olp/'       
     restore,path+filename
     flux = TRANSPOSE(flux,[1,0,2])
     weight = TRANSPOSE(weight,[1,0,2]) 
ENDELSE 

     sl_dyncal_tab.lflux = flux
     sl_dyncal_tab.weight = weight
     sl_dyncal_tab.flux_min = flux_min
     sl_dyncal_tab.flux_max = flux_max

RETURN
END
