;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	EXTR_NUM
;
; PURPOSE:
;	Extract numerical part from string. 
;	The function facilitates if float or exponential
;	numbers are hidden within names and the exact position
;	is not known.
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	EXTR_NUM(string)
;
; INPUT:
;	string:		(string) any string
;
; KEYWORD PARAMETERS:	
;	none
;
; OUTPUT:
;	function:	(string) containing the first contiguous
;			numerical expression, icluding + and - 
;			signs and characters 'E' and 'D' in both,
;			upper- and lowercase.
;
; COMMON BLOCKS:
;
; RESTRICTIONS:
;
; PROCEDURES USED:	
;	IS_NUM()
;
; EXAMPLE:
;	IDL> print, extr_num('P_3.29')
;	3.29
;
;
;
; MODIFICATION HISTORY:
;	Written by:	Bernhard Schulz
;	21/03/97	first version		BS
;-

function extr_num,string

n = strlen(string)

i=0
while i LT n AND is_num(strmid(string,i,1)) LE 0 do i=i+1
beg = i

while i LT n AND is_num(strmid(string,i,1)) GT 0 do i=i+1
len = i-beg

return, strmid(string, beg, len)

end
