;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO FCS_BUFFER_VIEW_event, event

;+
; NAME:
;       FCS_BUFFER_VIEW
;
; PURPOSE:
;	View the FCS POWER data array which is either a CALG array
;       or just a data array similar to the CALG array format.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;       FCS_BUFFER_VIEW, Buffer, Detector, First_column, 
;	  Fcsa, Trsa, Filters, PREFIX=PREFIX
;
; INPUTS:
;	Buffer  : A 45 x (detectors filters) x 2 x 2 array of float
;       Detector: character string of 'P1', 'P2', 'P3, 'C100' and 'C200'
;       First_Column: FCS Power table, float array of 45 elements
;       Fcsa    : an integer value of either 0 or 1
;       Trsa    : an integer value of either 0 or 1
;       Filters : a string array of filters' name
;
; OUTPUTS:
;	None
;
; OPTIONAL OUTPUTS:
;       Prefix: a character string for the display window title prefix
;
; PROCEDURES USED:
;	None
;
; MODIFICATION HISTORY:
;       Written by:	Wai-Min Tai
;	Oct 95 Version 3.5
;-
; 

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	CASE uvalue of
	'LIST': 
	'QUIT': WIDGET_CONTROL, event.top, /DESTROY 
	ELSE:
	ENDCASE
END

PRO FCS_BUFFER_VIEW, buffer, det, first_column, fcsa, trsa, title, $
              prefix = prefix

	ftitle = det + ' FCS Power Tables'
	if keyword_set(prefix) then ftitle = prefix + ' ' + det + $
          ' FCS Power Tables'
	edbase = WIDGET_BASE(TITLE =ftitle ,/column)

	cptlist = STRING(FORMAT='(e9.3)',first_column) 
	IF STRMID(det,0,1) EQ 'P' THEN $
	  temp = 'Opt Power (W/mm^2)' ELSE $
 	  temp = 'Opt Power (Watts)'
	  

	edvalbase = WIDGET_BASE(edbase, /row)
	
        edvalbas2 = WIDGET_BASE(edvalbase, /column)
	
	xsize = strlen(temp)
	edval = WIDGET_TEXT(edvalbas2, XSIZE=xsize, YSIZE=1, $
	  VALUE = temp)
	edval = WIDGET_TEXT(edvalbas2, XSIZE=xsize, YSIZE=45, $
	  VALUE = cptlist)

	nele = N_ELEMENTS(buffer(0,*,0,0))
	edval_id = lonarr(nele)

	nele = nele - 1
	FOR III=0,nele DO BEGIN  
	 edvalbas3 = WIDGET_BASE(edvalbase, /column)
         xsize = strlen(title(III))
	 edval = WIDGET_TEXT(edvalbas3, XSIZE=xsize, YSIZE=1, $
		VALUE = title(III))
	 edval_id(III) = WIDGET_TEXT(edvalbas3, /EDITABLE, XSIZE=xsize, $
           YSIZE=45, $
	   VALUE = STRING(FORMAT='(f5.2)',buffer(*,III,trsa,fcsa)),$
		UVALUE = 'list')
        ENDFOR

	edconbase = WIDGET_BASE(edbase, /row)
	quit = WIDGET_BUTTON(edconbase, /frame, VALUE=' QUIT ', UVALUE='QUIT') 

	WIDGET_CONTROL, edbase, /REALIZE

	xMANAGER,No_BLOCK=1, "FCS_BUFFER_VIEW", edbase, GROUP=group
	RETURN
END 
