;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	FUNCTION FCS_POW_CONV, RAW_FCS
;+
; NAME:
;	FCS_POW_CONV
;
; PURPOSE:
;	Function to convert fcs powers to physical units (mW)
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	FCS_POW_CONV, Raw_fcs
;
; INPUTS:
;	Raw_fcs  : The raw fcs power value as extracted from telemetry
;
; OUTPUT:
;	Returns the FCS power converted to physical units (mW)
;
; PROCEDURES USED:
;	None
;
; MODIFICATION HISTORY:
;	Written by:	Wai-Ming Tai
;	Oct 95 Version 3.5
;-
;
;
	ON_ERROR, 2
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  FCS_POW_CONV(RAW_FCS)'

	TMMAX = 4095.0
	PMAX  = 50.0
	TEMP  = (RAW_FCS/TMMAX)*PMAX
	RETURN, TEMP
	END
