;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	FF_BCK
;
; PURPOSE:
;	Flat fielding using a map background given by flagged points. 
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	ff_BCK, mnbr, ff_bright, FLAG=flag, FF=ff, error=error
;
; INPUT:
;	mnbr:	the original brightness array
;
; OUTPUT:
;	ff_bright: the flatfielded array
;
; INPUT KEYWORDS:
;	FLAG:	the array (same size as mnbr) with 1 for selected points
;
; OUTPUT KEYWORDS:
;	FF:	the calculated flat field factors
;	ERROR:	0=OK, 1=failed
;	
; COMMON BLOCKS:
;	none
;
; PROCEDURES USED:
;	none
;	
; MODIFICATION HISTORY:
;	Written by:	C.Gabriel (ESA/VILSPA-SAI)	September 1997
;	Version 6.5
;-
PRO FF_BCK, mnbr, ff_bright, FLAG=flag, FF=ff, error=error

	error = 0
	npix = N_ELEMENTS(mnbr(*,0))
	nele = N_ELEMENTS(mnbr(0,*))
	ff_bright = mnbr * 0.

	IF not KEYWORD_SET(flag) then flag = FIX(mnbr * 0) 
	
	ff = fltarr(npix)
	pix_flag = intarr(npix)
	
	FOR I=0, npix-1 DO BEGIN
	  ind = WHERE(flag(i,*) EQ 0, ncount)
	  IF ncount GT 0 THEN BEGIN
	    ff(i) = total(mnbr(i,ind)) / ncount 
	    IF ncount LT 10 THEN $
	     PRINT, 'Pixel ' + STRTRIM(i+1,2) + $
	       ' has too less counts, doubtful results ...'
	  ENDIF ELSE BEGIN
	    PRINT, 'Warning: No valid signals for pixel '+STRTRIM(i+1,2)
	    pix_flag(i) = 1
	  ENDELSE

	ENDFOR	    

	valid_pix = WHERE(pix_flag EQ 0,nvalpix)
	
	medval = total(ff(valid_pix)) / nvalpix
	ff = ff / medval

	FOR I=0,npix-1 DO BEGIN
	  IF NOT pix_flag(i) THEN $
	  ff_bright(i,*)=mnbr(i,*) / ff(i)
	ENDFOR

	RETURN
	END  
	
	
	
