;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	FF_MED_SMOOTH
;
; PURPOSE:
;	Median filtering and smoothing routine for map background. 
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	ff_med_smooth, mnbr, ff_bright, FLAG=flag, FF=ff, $
;		MED_WIDTH=MED_WIDTH, SMOOTH_WIDTH=SMOOTH_WIDTH, NO_FF=NO_FF
;	
; COMMON BLOCKS:
;	none
;
; PROCEDURES USED:
;	none
;	
; MODIFICATION HISTORY:
;	Written by:	C.Gabriel (ESA/VILSPA-SAI)	September 1997
;	Version 6.5
;-
PRO FF_MED_SMOOTH, mnbr, ff_bright, FLAG=flag, FF=ff, $
    MED_WIDTH=MED_WIDTH, SMOOTH_WIDTH=SMOOTH_WIDTH, ERROR=error, NO_FF=NO_FF

	error = 0
	ff_bright = mnbr
	npix = N_ELEMENTS(mnbr(*,0))
	nele = N_ELEMENTS(mnbr(0,*))
	IF not KEYWORD_SET(flag) THEN flag = FIX(mnbr * 0)
	
	IF not KEYWORD_SET(med_width) THEN fw = 24 ELSE fw = MED_WIDTH
	IF not KEYWORD_SET(smooth_width) THEN sw = 9 ELSE sw = SMOOTH_WIDTH
	IF nele LT fw OR nele LT sw THEN BEGIN
	  PRINT, 'Too few signals per pixel for procedure with these params'
	  PRINT, 'Returning'
	  error=1
	  RETURN
	ENDIF
	IF fw LT 8 AND fw NE 1 THEN BEGIN
	  PRINT, 'Width for median filtering too small, returning'
	  ERROR = 1
	  RETURN
	ENDIF

	IF fw EQ 1 AND sw EQ 1 THEN BEGIN
	  PRINT, 'Silly way to lose yours and my time, returning'
	  error=1
	  RETURN
	ENDIF
		
	dmed = mnbr
	dm = dmed
	d = mnbr
	
; check for too low numbers
	FOR ipix=0,npix-1 DO BEGIN
	 ind = WHERE(dmed(ipix,*) LT 0. AND flag(ipix,*) EQ 0,nind)
	 IF nind GT 0 THEN BEGIN
	   PRINT, STRTRIM(nind,2) + ' negative fluxes found in pixel ' + $
	        STRTRIM(ipix+1,2)
	   PRINT, 'adding some offset ...'
	   dmed(ipix,*) = dmed(ipix,*) - 2*min(dmed(ipix,*))
	   dm(ipix,*) = dmed(ipix,*) & d(ipix,*) = dmed(ipix,*)
	 ENDIF
	ENDFOR	 


; filtering per pixel

	pix_flag = intarr(npix)
	tot_med = fltarr(nele)
	FOR ipix=0,npix-1 DO BEGIN

	  IF fw EQ 1 THEN GOTO, ONLY_SMOOTH

	  ind = WHERE(flag(ipix,*) EQ 0, count)
	  nind = WHERE(flag(ipix,*) NE 0, ncount)
	  IF count EQ 0 THEN BEGIN
	    print, 'Warning: No valid signals for pixel '+STRTRIM(ipix+1,2)
	    pix_flag(ipix) = 1
	    GOTO, JUST_OUT
	  ENDIF
	  IF count LT fw THEN BEGIN
	    print, 'No enough valid signals for pixel '+STRTRIM(ipix+1,2)
	    print, 'Median width larger than given area, returning'
	    ERROR = 1
	    RETURN
	  ENDIF
	  dmed(ipix,ind) = MEDIAN(reform(d(ipix,ind)),fw)
; interpolate the not accepted elements
	  IF ncount GT 0 THEN BEGIN
	   res = INTERPOL(dmed(ipix,ind), ind, nind)
	   dmed(ipix,nind) = res
	  ENDIF

; filtering the edges
	  dm(ipix,ind) = MEDIAN(reform(d(ipix,ind)),fw/2)
	  IF ncount GT 0 THEN BEGIN
	   res = INTERPOL(dm(ipix,ind), ind, nind)
	   dm(ipix,nind) = res
	  ENDIF
	  
	  dmed(ipix,0:fw/2-1)=dm(ipix,0:fw/2-1)
	  dmed(ipix,nele-fw/2:nele-1)=dm(ipix,nele-fw/2:nele-1)
	  
	  dm(ipix,ind) = MEDIAN(reform(d(ipix,ind)),fw/4)
	  IF ncount GT 0 THEN BEGIN
	   res = INTERPOL(dm(ipix,ind), ind, nind)
	   dm(ipix,nind) = res
	  ENDIF
	  
	  dmed(ipix,0:fw/4-1)=dm(ipix,0:fw/4-1)
	  dmed(ipix,nele-fw/4:nele-1)=dm(ipix,nele-fw/4:nele-1)

	  dm(ipix,ind) = MEDIAN(reform(d(ipix,ind)),fw/8)
	  IF ncount GT 0 THEN BEGIN
	   res = INTERPOL(dm(ipix,ind), ind, nind)
	   dm(ipix,nind) = res
	  ENDIF
	  dmed(ipix,0:fw/8-1)=dm(ipix,0:fw/8-1)
	  dmed(ipix,nele-fw/8:nele-1)=dm(ipix,nele-fw/8:nele-1)
; sum over all
ONLY_SMOOTH:
; now smooth
	  IF sw GT 2 THEN $
	   dmed(ipix,*) = SMOOTH(reform(dmed(ipix,*)),sw)

	  tot_med = tot_med + reform(dmed(ipix,*))
JUST_OUT:
	  
	ENDFOR

	valid_pix = WHERE(pix_flag EQ 0,nvalpix)

	tot_med = tot_med / nvalpix
	ff = FLTARR(2,npix)
	for i=0,npix-1 DO BEGIN
	  IF NOT pix_flag(i) THEN BEGIN
	    res = dmed(i,*) / tot_med
	    ff(0,i) = AVG(res)
	    ff(1,i) = sigma(res)
	  ENDIF
	ENDFOR


	ff_bright(valid_pix,*) = d(valid_pix,*) / dmed(valid_pix,*) 

; Normalize
	IF NOT KEYWORD_SET(NO_FF) THEN $
	ff_bright(valid_pix,*) = ff_bright(valid_pix,*) * $
			TOTAL(d(valid_pix,*)) / TOTAL(ff_bright(valid_pix,*)) $
	ELSE $
	FOR i=0,nvalpix-1 DO $
	ff_bright(valid_pix(i),*) = ff_bright(valid_pix(i),*) * $
			TOTAL(d(valid_pix(i),*)) / TOTAL(ff_bright(valid_pix(i),*)) 
	
	
	RETURN
	END  
	
	
	
