;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO FILL_AAP, tmp, newheader, REPLACE=replace 
;+
; NAME:
;       FILL_AAP
;
; PURPOSE:
;	FILLS a temporary structure into the dynamical structure PHTAAP  
;
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;       FILL_AAP, tmp, newheader, REPLACE=replace
;
; INPUT:
;       tmp 	: AAP like temporary structure
;
; OPTIONAL INPUT:
;	newheader: Modified header 
;	REPLACE : IF set (different to 0) put structure into this PHTAAP position
;
; RESTRICTIONS:
;       tmp must be a valid phtaap like temporary structure
;
; PROCEDURES USED: 
;       Common Block(s) or @ procedure(s):
;               phtaap
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel  (ESA-SAI)		July 1996
;	central wavelength added (WMT)                  Nov 1996
;	Newheader as optional input (JAcosta)		Apr 1997
;	Check for "old" aap type and corresponding
;	 new computing of CWVL (CG)			Oct 97
;	V6.5
;
;-
;
@phtaap
@phtfilter_prop
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  FILL_AAP, tmp [,newheader] [,REPLACE=replace]'


;  Create the structures and the handles
        PHTAAPT = {PHTAAP_TYPE}
        PHTAAPT.HDR = HANDLE_CREATE()
        PHTAAPT.TIME = HANDLE_CREATE()
        PHTAAPT.CSTP = HANDLE_CREATE()
        PHTAAPT.CPOS = HANDLE_CREATE()
        PHTAAPT.DWEL = HANDLE_CREATE()
        PHTAAPT.MNFL = HANDLE_CREATE()
        PHTAAPT.MNFU = HANDLE_CREATE()
        PHTAAPT.MNBR = HANDLE_CREATE()
        PHTAAPT.MNBU = HANDLE_CREATE()
        PHTAAPT.MDFL = HANDLE_CREATE()
        PHTAAPT.Q1FL = HANDLE_CREATE()
        PHTAAPT.Q3FL = HANDLE_CREATE()
        PHTAAPT.MDBR = HANDLE_CREATE()
        PHTAAPT.Q1BR = HANDLE_CREATE()
        PHTAAPT.Q3BR = HANDLE_CREATE()
        PHTAAPT.RPID = HANDLE_CREATE()
	PHTAAPT.DEC = HANDLE_CREATE()
	PHTAAPT.RA = HANDLE_CREATE()
	PHTAAPT.DECP = HANDLE_CREATE()
	PHTAAPT.RAP = HANDLE_CREATE()
	PHTAAPT.ROLL = HANDLE_CREATE()
	PHTAAPT.FLAG = HANDLE_CREATE()
	

;  Fill the temporary structure
        PHTAAPT.DET  = tmp.DET
        PHTAAPT.ADMN = tmp.ADMN
        PHTAAPT.DIMS = tmp.DIMS
        PHTAAPT.FILT = tmp.FILT
        PHTAAPT.APER = tmp.APER
        PHTAAPT.POLZ = tmp.POLZ
; check for cwvl first (old structures do not have it)
	TAGNAM = TAG_NAMES(tmp)
	indtag = WHERE(tagnam EQ 'CWVL', N)
	IF N GT 0 THEN $
         PHTAAPT.CWVL = tmp.CWVL ELSE BEGIN
           IF STRMID(tmp.det,0,1) EQ 'P' THEN BEGIN
		cwave = [filtprop.p1cwl, filtprop.p2cwl, filtprop.p3cwl]
		cwvl = cwave(tmp.filt-1)
           ENDIF ELSE IF STRMID(tmp.det, 0,1) EQ 'C' THEN BEGIN
		cwave = [filtprop.c1cwl, filtprop.c2cwl]
		cwvl = cwave(tmp.filt-2)
	   ENDIF ELSE cwvl = 0.
	 PHTAAPT.CWVL = cwvl
	ENDELSE


;  Fill the handles
        IF N_PARAMS() LT 2 THEN HDR = tmp.hdr $
          ELSE HDR = newheader
	HANDLE_VALUE, PHTAAPT.HDR,  HDR,      /SET
	HANDLE_VALUE, PHTAAPT.RPID, tmp.RPID, /SET
	HANDLE_VALUE, PHTAAPT.TIME, tmp.TIME, /SET
	HANDLE_VALUE, PHTAAPT.CPOS, tmp.cpos, /SET
	HANDLE_VALUE, PHTAAPT.CSTP, tmp.cstp, /SET
	HANDLE_VALUE, PHTAAPT.DWEL, tmp.dwel, /SET
        HANDLE_VALUE, PHTAAPT.MNFL, tmp.mnfl, /SET 
	HANDLE_VALUE, PHTAAPT.MNFU, tmp.mnfu, /SET 
	HANDLE_VALUE, PHTAAPT.MNBR, tmp.mnbr, /SET 
	HANDLE_VALUE, PHTAAPT.MNBU, tmp.mnbu, /SET
	HANDLE_VALUE, PHTAAPT.MDFL, tmp.mdfl, /SET 
	HANDLE_VALUE, PHTAAPT.Q1FL, tmp.q1fl, /SET 
	HANDLE_VALUE, PHTAAPT.Q3FL, tmp.q3fl, /SET 
	HANDLE_VALUE, PHTAAPT.MDBR, tmp.mdbr, /SET 
	HANDLE_VALUE, PHTAAPT.Q1BR, tmp.q1br, /SET 
	HANDLE_VALUE, PHTAAPT.Q3BR, tmp.q3br, /SET 
	HANDLE_VALUE, PHTAAPT.DEC, tmp.dec, /SET
	HANDLE_VALUE, PHTAAPT.RA, tmp.ra, /SET
	HANDLE_VALUE, PHTAAPT.DECP, tmp.decp, /SET
	HANDLE_VALUE, PHTAAPT.RAP, tmp.rap, /SET
	HANDLE_VALUE, PHTAAPT.ROLL, tmp.roll, /SET
	HANDLE_VALUE, PHTAAPT.FLAG, tmp.flag, /SET


;  Update the PHTAAP structure using the temporary structure
	IF KEYWORD_SET(REPLACE) THEN BEGIN
		IF N_ELEMENTS(phtaap) LE replace THEN $
		  MESSAGE, /INFO, 'Non-existing position, returning' ELSE $
		  phtaap(replace) = phtaapt 
	ENDIF ELSE $
          PHTAAP = [PHTAAP,PHTAAPT]

	RETURN 
        END
