;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO FILL_ERD, tmp, newheader, REPLACE=replace 
;+
; NAME:
;       FILL_ERD
;
; PURPOSE:
;	FILLS a temporary structure into the dynamical structure PHTERD  
;
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;       FILL_ERD, tmp [,newheader] [,REPLACE=replace]
;
; INPUT:
;       tmp 	: ERD like temporary structure
;
; OPTIONAL INPUT:
;	newheader:  New header to be change into the structure
;
; KEYWORD:
;	REPLACE : IF set (different to 0) put structure into this PHTERD position
;
; RESTRICTIONS:
;       tmp must be a valid phterd like temporary structure
;
; PROCEDURES USED: 
;       Common Block(s) or @ procedure(s):
;               phterd
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel  (ESA-SAI)		July 1996
;	newheader optional input added (CG)		May 1997
;	V6.3
;	Keyword FLAG added to the structure (CG)	Nov 1997
;	V6.6
;
;-
;
@phterd
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  FILL_ERD, tmp [,newhdr] [,REPLACE=replace]'


;  Create the structures and the handles
        PHTERDT = {PHTERD_TYPE}
        PHTERDT.HDR = HANDLE_CREATE()
        PHTERDT.RAWP = HANDLE_CREATE()
        PHTERDT.CONP = HANDLE_CREATE()
        PHTERDT.FITV = HANDLE_CREATE()
        PHTERDT.TIME = HANDLE_CREATE()
        PHTERDT.PIXF = HANDLE_CREATE()
        PHTERDT.CHOP = HANDLE_CREATE()
        PHTERDT.STEP = HANDLE_CREATE()
        PHTERDT.FCSN = HANDLE_CREATE()
        PHTERDT.TEMP = HANDLE_CREATE()
        PHTERDT.FCS1 = HANDLE_CREATE()
        PHTERDT.FCS2 = HANDLE_CREATE()
        PHTERDT.TKEY = HANDLE_CREATE()
        PHTERDT.RPID = HANDLE_CREATE()
        PHTERDT.FLAG = HANDLE_CREATE()

;  Fill the temporary ERD structure
        PHTERDT.UNIT = tmp.UNIT
        PHTERDT.DET  = tmp.DET
        PHTERDT.ADMN = tmp.ADMN
        PHTERDT.ORDR = tmp.ORDR
        PHTERDT.DIMS = tmp.DIMS
        PHTERDT.TINT = tmp.TINT
	PHTERDT.NNDR = tmp.NNDR
	PHTERDT.RCHP = tmp.RCHP

;  Fill the handles
	IF N_PARAMS() LT 2 THEN HDR = tmp.hdr $ 
	  ELSE  HDR= newheader
        HANDLE_VALUE, PHTERDT.HDR, HDR, /SET  
        HANDLE_VALUE, PHTERDT.RAWP, tmp.RAWP, /SET  
        HANDLE_VALUE, PHTERDT.CONP, tmp.CONP, /SET     
        HANDLE_VALUE, PHTERDT.FITV, tmp.FITV, /SET     
	HANDLE_VALUE, PHTERDT.PIXF, tmp.PIXF, /SET   
        HANDLE_VALUE, PHTERDT.TIME, tmp.TIME, /SET  
        HANDLE_VALUE, PHTERDT.CHOP, tmp.CHOP, /SET  
        HANDLE_VALUE, PHTERDT.STEP, tmp.STEP, /SET  
        HANDLE_VALUE, PHTERDT.FCSN, tmp.FCSN, /SET  
        HANDLE_VALUE, PHTERDT.TEMP, tmp.TEMP, /SET   
        HANDLE_VALUE, PHTERDT.FCS1, tmp.FCS1, /SET     
	HANDLE_VALUE, PHTERDT.FCS2, tmp.FCS2, /SET   
        HANDLE_VALUE, PHTERDT.TKEY, tmp.TKEY, /SET  
        HANDLE_VALUE, PHTERDT.RPID, tmp.RPID, /SET  
        HANDLE_VALUE, PHTERDT.FLAG, tmp.FLAG, /SET  

;  Update the PHTERD structure using the temporary structure
	IF KEYWORD_SET(REPLACE) THEN BEGIN
		IF N_ELEMENTS(phterd) LE replace THEN $
		  MESSAGE, /INFO, 'Non-existing position, returning' ELSE $
		  phterd(replace) = phterdt 
	ENDIF ELSE $
          PHTERD = [PHTERD,PHTERDT]

        RETURN
        END
