;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO FILL_SCP, tmp, newheader, REPLACE=replace 
;+
; NAME:
;       FILL_SCP
;
; PURPOSE:
;	FILLS a temporary structure into the dynamical structure PHTSCP  
;
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;       FILL_SCP, tmp, newheader, REPLACE=replace
;
; INPUT:
;       tmp 	: SCP like temporary structure
;
; OPTIONAL INPUT:
;	REPLACE : IF set (different to 0) put structure into this PHTSCP position
;
; RESTRICTIONS:
;       tmp must be a valid phtscp like temporary structure
;
; PROCEDURES USED: 
;       Common Block(s) or @ procedure(s):
;               phtscp
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel  (ESA-SAI)		July 1996
;	Modified by: J. Acosta 				September 96
;	V5.0 (Sept.96)
;
;-
;
@phtscp
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  FILL_SCP, tmp, [newheader], [REPLACE=replace]'


;  Create the structures and the handles
        PHTSCPT = {PHTSCP_TYPE}
        PHTSCPT.HDR = HANDLE_CREATE()
        PHTSCPT.TIME = HANDLE_CREATE()
        PHTSCPT.AVER = HANDLE_CREATE()
        PHTSCPT.AVUN = HANDLE_CREATE()
        PHTSCPT.MEDI = HANDLE_CREATE()
        PHTSCPT.Q1ME = HANDLE_CREATE()
        PHTSCPT.Q3ME = HANDLE_CREATE()
        PHTSCPT.FLAG = HANDLE_CREATE()
        PHTSCPT.CHOP = HANDLE_CREATE()
        PHTSCPT.STEP = HANDLE_CREATE()
        PHTSCPT.FCSN = HANDLE_CREATE()
        PHTSCPT.TEMP = HANDLE_CREATE()
        PHTSCPT.FCS1 = HANDLE_CREATE()
        PHTSCPT.FCS2 = HANDLE_CREATE()
        PHTSCPT.TKEY = HANDLE_CREATE()
        PHTSCPT.RPID = HANDLE_CREATE()
        PHTSCPT.ARSI = HANDLE_CREATE()
        PHTSCPT.ANDR = HANDLE_CREATE()
        PHTSCPT.AVSD = HANDLE_CREATE()

;  Fill the temporary ERD structure
        PHTSCPT.UNIT = tmp.UNIT
        PHTSCPT.DET  = tmp.DET
        PHTSCPT.ADMN = tmp.ADMN
        PHTSCPT.ORDR = tmp.ORDR
        PHTSCPT.DIMS = tmp.DIMS
                           
;  Fill the handles
	IF N_PARAMS() LT 2 THEN HDR = tmp.hdr $
	  ELSE HDR = newheader
        HANDLE_VALUE, PHTSCPT.HDR,  HDR, /SET  
        HANDLE_VALUE, PHTSCPT.TIME, tmp.TIME, /SET  
        HANDLE_VALUE, PHTSCPT.AVER, tmp.AVER, /SET  
        HANDLE_VALUE, PHTSCPT.AVUN, tmp.AVUN, /SET     
        HANDLE_VALUE, PHTSCPT.MEDI, tmp.MEDI, /SET   
	HANDLE_VALUE, PHTSCPT.Q1ME, tmp.Q1ME, /SET   
	HANDLE_VALUE, PHTSCPT.Q3ME, tmp.Q3ME, /SET   
        HANDLE_VALUE, PHTSCPT.FLAG, tmp.FLAG, /SET  
        HANDLE_VALUE, PHTSCPT.CHOP, tmp.CHOP, /SET   
        HANDLE_VALUE, PHTSCPT.STEP, tmp.STEP, /SET   
        HANDLE_VALUE, PHTSCPT.FCSN, tmp.FCSN, /SET   
        HANDLE_VALUE, PHTSCPT.TEMP, tmp.TEMP, /SET   
        HANDLE_VALUE, PHTSCPT.FCS1, tmp.FCS1, /SET   
        HANDLE_VALUE, PHTSCPT.FCS2, tmp.FCS2, /SET   
        HANDLE_VALUE, PHTSCPT.TKEY, tmp.TKEY, /SET   
        HANDLE_VALUE, PHTSCPT.RPID, tmp.RPID, /SET   
        HANDLE_VALUE, PHTSCPT.ARSI, tmp.ARSI, /SET   
        HANDLE_VALUE, PHTSCPT.ANDR, tmp.ANDR, /SET   
        HANDLE_VALUE, PHTSCPT.AVSD, tmp.AVSD, /SET   

;  Update the PHTSCP structure using the temporary structure
	IF KEYWORD_SET(REPLACE) THEN BEGIN
		IF N_ELEMENTS(phtscp) LE replace THEN $
		  MESSAGE, /INFO, 'Non-existing position, returning' ELSE $
		  phtscp(replace) = phtscpt 
	ENDIF ELSE $
          PHTSCP = [PHTSCP,PHTSCPT]

        RETURN
        END
