;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO FILL_SPD, tmp, newheader, REPLACE=replace 
;+
; NAME:
;       FILL_SPD
;
; PURPOSE:
;	FILLS a temporary structure into the dynamical structure PHTSPD  
;
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;       FILL_SPD, tmp [,newheader] [,REPLACE=replace]
;
; INPUT:
;       tmp 	: SPD like temporary structure
;
; OPTIONAL INPUT:
;	newheader:  New header to be change into the structure
;
; KEYWORD:
;	REPLACE : IF set (different to 0) put structure into this PHTSPD position
;
; RESTRICTIONS:
;       tmp must be a valid phtspd like temporary structure
;
; PROCEDURES USED: 
;       Common Block(s) or @ procedure(s):
;               phtspd
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel  (ESA-SAI)		July 1996
;
;-
;
@phtspd
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  FILL_SDP, tmp [,newhdr] [,REPLACE=replace]'


;  Create the structures and the handles
        PHTSPDT = {PHTSPD_TYPE}
        PHTSPDT.HDR = HANDLE_CREATE()
        PHTSPDT.KYID = HANDLE_CREATE()
        PHTSPDT.FILT = HANDLE_CREATE()
        PHTSPDT.APER = HANDLE_CREATE()
        PHTSPDT.POLZ = HANDLE_CREATE()
        PHTSPDT.NDRS = HANDLE_CREATE()
        PHTSPDT.DWEL = HANDLE_CREATE()
        PHTSPDT.MEAS = HANDLE_CREATE()
        PHTSPDT.CPOS = HANDLE_CREATE()
        PHTSPDT.TIME = HANDLE_CREATE()
        PHTSPDT.MNPW = HANDLE_CREATE()
        PHTSPDT.MNPU = HANDLE_CREATE()
        PHTSPDT.MDPW = HANDLE_CREATE()
        PHTSPDT.Q1PW = HANDLE_CREATE()
        PHTSPDT.Q3PW = HANDLE_CREATE()
        PHTSPDT.DEC = HANDLE_CREATE()
        PHTSPDT.RA = HANDLE_CREATE()
        PHTSPDT.ROLL = HANDLE_CREATE()
        PHTSPDT.FLAG = HANDLE_CREATE()
        PHTSPDT.CSTP = HANDLE_CREATE()
        PHTSPDT.PLEN = HANDLE_CREATE()
        PHTSPDT.TKEY = HANDLE_CREATE()
        PHTSPDT.RPID = HANDLE_CREATE()

;  Fill the temporary ERD structure
        PHTSPDT.UNIT = tmp.UNIT
        PHTSPDT.DET  = tmp.DET
        PHTSPDT.ADMN = tmp.ADMN
        PHTSPDT.ORDR = tmp.ORDR
        PHTSPDT.DIMS = tmp.DIMS

;  Fill the handles
	IF N_PARAMS() LT 2 THEN HDR = tmp.hdr $ 
	  ELSE  HDR= newheader
        HANDLE_VALUE, PHTSPDT.HDR, HDR, /SET  
        HANDLE_VALUE, PHTSPDT.KYID, tmp.KYID, /SET  
        HANDLE_VALUE, PHTSPDT.FILT, tmp.FILT, /SET     
	HANDLE_VALUE, PHTSPDT.APER, tmp.APER, /SET   
        HANDLE_VALUE, PHTSPDT.TIME, tmp.TIME, /SET  
        HANDLE_VALUE, PHTSPDT.POLZ, tmp.POLZ, /SET  
        HANDLE_VALUE, PHTSPDT.NDRS, tmp.NDRS, /SET   
        HANDLE_VALUE, PHTSPDT.DWEL, tmp.DWEL, /SET     
	HANDLE_VALUE, PHTSPDT.MEAS, tmp.MEAS, /SET   
        HANDLE_VALUE, PHTSPDT.CPOS, tmp.CPOS, /SET  
        HANDLE_VALUE, PHTSPDT.MNPW, tmp.MNPW, /SET  
        HANDLE_VALUE, PHTSPDT.MNPU, tmp.MNPU, /SET  
        HANDLE_VALUE, PHTSPDT.MDPW, tmp.MDPW, /SET  
        HANDLE_VALUE, PHTSPDT.Q1PW, tmp.Q1PW, /SET  
        HANDLE_VALUE, PHTSPDT.Q3PW, tmp.Q3PW, /SET  
        HANDLE_VALUE, PHTSPDT.DEC, tmp.DEC, /SET  
        HANDLE_VALUE, PHTSPDT.RA, tmp.RA, /SET  
        HANDLE_VALUE, PHTSPDT.ROLL, tmp.ROLL, /SET  
        HANDLE_VALUE, PHTSPDT.FLAG, tmp.FLAG, /SET  
        HANDLE_VALUE, PHTSPDT.CSTP, tmp.CSTP, /SET  
        HANDLE_VALUE, PHTSPDT.PLEN, tmp.PLEN, /SET  
        HANDLE_VALUE, PHTSPDT.TKEY, tmp.TKEY, /SET  
        HANDLE_VALUE, PHTSPDT.RPID, tmp.RPID, /SET  


;  Update the PHTSPD structure using the temporary structure
	IF KEYWORD_SET(REPLACE) THEN BEGIN
		IF N_ELEMENTS(phtspd) LE replace THEN $
		  MESSAGE, /INFO, 'Non-existing position, returning' ELSE $
		  phtspd(replace) = phtspdt 
	ENDIF ELSE $
          PHTSPD = [PHTSPD,PHTSPDT]

        RETURN
        END
