;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO FILL_SRD, tmp, newheader, REPLACE=replace 
;+
; NAME:
;       FILL_SRD
;
; PURPOSE:
;	FILLS a temporary structure into the dynamical structure PHTSRD  
;
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;       FILL_SRD, tmp [,newheader] [,REPLACE=replace]
;
; INPUT:
;       tmp 	: SRD like temporary structure
;
; OPTIONAL INPUT:
;	newheader:  New header to be change into the structure
;
; KEYWORD:
;	REPLACE : IF set (different to 0) put structure into this PHTSRD position
;
; RESTRICTIONS:
;       tmp must be a valid phtsrd like temporary structure
;
; PROCEDURES USED: 
;       Common Block(s) or @ procedure(s):
;               phtsrd
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel  (ESA-SAI)		July 1996
;	Modified by: J. Acosta 				September 96
;	V5.0 (Sept.96)
;
;-
;
@adm
@phtsrd
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  FILL_SRD, tmp [,newhdr] [,REPLACE=replace]'


;  Create the structures and the handles
        PHTSRDT = {PHTSRD_TYPE}
        PHTSRDT.HDR = HANDLE_CREATE()
        PHTSRDT.SLOP = HANDLE_CREATE()
        PHTSRDT.SLUN = HANDLE_CREATE()
        PHTSRDT.FLAG = HANDLE_CREATE()
        PHTSRDT.STIM = HANDLE_CREATE()
        PHTSRDT.CHOP = HANDLE_CREATE()
        PHTSRDT.STEP = HANDLE_CREATE()
        PHTSRDT.FCSN = HANDLE_CREATE()
        PHTSRDT.TEMP = HANDLE_CREATE()
        PHTSRDT.FCS1 = HANDLE_CREATE()
        PHTSRDT.FCS2 = HANDLE_CREATE()
        PHTSRDT.TKEY = HANDLE_CREATE()
        PHTSRDT.RPID = HANDLE_CREATE()
        PHTSRDT.RESI = HANDLE_CREATE()
        PHTSRDT.NROS = HANDLE_CREATE()

;  Fill the temporary ERD structure
        PHTSRDT.UNIT = tmp.UNIT
        PHTSRDT.DET  = tmp.DET
        PHTSRDT.ADMN = tmp.ADMN
        PHTSRDT.ORDR = tmp.ORDR
        PHTSRDT.SLDI = tmp.SLDI
        PHTSRDT.RCHP = tmp.RCHP
                           
;  Fill the handles
	IF N_PARAMS() LT 2 THEN HDR = tmp.hdr $ 
	  ELSE  HDR= newheader
        HANDLE_VALUE, PHTSRDT.HDR, HDR, /SET 
        HANDLE_VALUE, PHTSRDT.SLOP, tmp.SLOP, /SET     
	HANDLE_VALUE, PHTSRDT.SLUN, tmp.SLUN, /SET   
        HANDLE_VALUE, PHTSRDT.FLAG, tmp.FLAG, /SET  
        HANDLE_VALUE, PHTSRDT.STIM, tmp.STIM, /SET   
        HANDLE_VALUE, PHTSRDT.CHOP, tmp.CHOP, /SET   
        HANDLE_VALUE, PHTSRDT.STEP, tmp.STEP, /SET   
        HANDLE_VALUE, PHTSRDT.FCSN, tmp.FCSN, /SET   
        HANDLE_VALUE, PHTSRDT.TEMP, tmp.TEMP, /SET   
        HANDLE_VALUE, PHTSRDT.FCS1, tmp.FCS1, /SET   
        HANDLE_VALUE, PHTSRDT.FCS2, tmp.FCS2, /SET   
        HANDLE_VALUE, PHTSRDT.TKEY, tmp.TKEY, /SET   
        HANDLE_VALUE, PHTSRDT.RPID, tmp.RPID, /SET   
        HANDLE_VALUE, PHTSRDT.RESI, tmp.RESI, /SET   
        HANDLE_VALUE, PHTSRDT.NROS, tmp.NROS, /SET   

;  Update the PHTSRD structure using the temporary structure
	IF KEYWORD_SET(REPLACE) THEN BEGIN
		IF N_ELEMENTS(phtsrd) LE replace THEN $
		  MESSAGE, /INFO, 'Non-existing position, returning' ELSE $
		  phtsrd(replace) = phtsrdt 
	ENDIF ELSE $
          PHTSRD = [PHTSRD,PHTSRDT]

        RETURN
        END
