;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO fix_tkey, tkey, tkeyfix
;+
; NAME:
;       FIX_TKEY
;
; PURPOSE:
;	Fix the PHT instrument time key eliminating the effects caused by
;	the virus (probably der_ERD) affecting the key every 2 seconds 
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       FIX_TKEY, Tkey, Tkeyfix
;
; INPUTS:
;       Tkey 	: Original tkey
;
; OUTPUTS:
;	Tkeyfix : Fixed tkey 
;
; PROCEDURES CALLED:
;	ASTRO LIB: nint
;
; MODIFICATION HISTORY:
;       Written by:	Carlos Gabriel
;	Oct 95 Version 3.5
;
;-
;
;
        ON_ERROR, 2

        nele = N_ELEMENTS(tkey)
	tkeyfix = tkey
	diff = lonarr(nele-1)
	FOR i=0L,nele-2 DO diff(i) = tkey(i+1) - tkey(i)
	difnorm = nint(median(diff(0:10)))

	ind = WHERE(diff EQ difnorm-32,n)
	ind = ind + 1
	IF n GT 0 THEN $
		FOR i=0,n-1 DO tkeyfix(ind(i):*) = tkeyfix(ind(i):*) + 32

	difnor2 = difnorm + 224
	ind = WHERE(diff EQ difnor2-32,n)
	ind = ind + 1
	IF n GT 0 THEN $
		FOR i=0,n-1 DO tkeyfix(ind(i):*) = tkeyfix(ind(i):*) + 32

	difnor3 = difnorm + 832
	ind = WHERE(diff EQ difnor3-32,n)
	ind = ind + 1
	IF n GT 0 THEN $
		FOR i=0,n-1 DO tkeyfix(ind(i):*) = tkeyfix(ind(i):*) + 32

	MESSAGE, /INFO, 'Warning: TKEY fix procedure running'

	return
	end 
