;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       DECODE_FLAG
;
; PURPOSE:
;	Decode a flag, coded bitswise
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       decode_flag, flag, nflag, code 
;
; INPUT:
;       flag	Coded flag array (1- or 2-dimensional)
;	nflag	Number of elements coded 
;
; KEYWORDS:
;	(none) 
;	
; OUTPUTS:
;	code	A (2- or 3-dim) array of [nflags,flag-dim] containing 0 or 1
;		for the coded nflags 
;
;
; MODIFICATION HISTORY:
;       Written by:	Jose Acosta (IDC/IAC)		March 1999
;	V7.4
;-
pro decode_flag, flag, nflag, code 

IF n_params() lt 3 THEN BEGIN
  print, 'Syntaxis: decode_flag, flag, nflag, code '
  return
ENDIF  

flagi = flag
siz = SIZE(flag)
CASE siz(0) OF
	0: code = intarr(nflag)
	1: code = intarr(nflag,siz(1))
	2: code = intarr(nflag, siz(1),siz(2))
	ELSE: BEGIN
 		MESSAGE, /INFO, $
		 'Not allowed input - flag dims should be 1 or 2 , returning'
		 RETURN
	END
ENDCASE


for i=nflag-1,0,-1 do begin
  code(i,*,*) = fix(flagi/2^i)
  flagi = flagi mod 2^i
endfor

return
end  
  
