;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       piaflag_info
; PURPOSE:
;       Initializes the common block PIAFLAG_INFO which contains the information
;       for the different flag coding used in PIA at different processing levels.
;
; CATEGORY:
;       PIA - initialization
;
; CALLING SEQUENCE:
;       PIAFLAG_INFO
;
; INPUT PARAMETERS:
;       None       
;
; OUTPUT PARAMETERS: 
;       None
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               piaflag_info
;
; MODIFICATION HISTORY:
;       Written by: J.Acosta
;       Feb 97 Version 7.x
;	Update (JA+CG) May 99
;	IMAP flag included in SPD level (CG) Mar 99
;-
PRO piaflag_info

COMMON piaflag_info, piaflag_str

;ERD flags
Nflag = 9
LEX = MAKE_ARRAY(nflag,value='DUMMY')              
LEX(0) = 'NOTF'
LEX(1) = 'DR'
LEX(2) = 'OUTVOLT'
;LEX(3) = 'ENDCHRS'
LEX(4) = 'GENDISC'
LEX(5) = 'MANDISC'
LEX(6) = 'GLITCH'

EXPLA = MAKE_ARRAY(nflag,value='')              
EXPLA(0) = 'Not On target'
EXPLA(1) = 'Destructive Read'
EXPLA(2) = 'Out of voltage'
;EXPLA(3) = 'Dummy'
EXPLA(4) = 'General discard'
EXPLA(5) = 'Manual discard'
EXPLA(6) = 'Detected glitch'

severe = INTARR(Nflag)
severe(2) = 1
severe(4:6) = 1

flagerd_str = {nflag:nflag, LEX:lex, EXPLA:expla, valflag:2^INDGEN(nflag), $
    severe:severe}


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; SRD flags
Nflag = 10 
LEX = MAKE_ARRAY(nflag,value='DUMMY')              
LEX(0) = 'RAMPNDR_2'
LEX(1) = 'RAMPNDR_1'
LEX(2) = 'NOTF'
LEX(3) = 'GENDISC'
LEX(4) = 'MANDISC'
LEX(5) = 'GLITCH'
LEX(6) = 'NOCHOP'
LEX(7) = 'MANNMASK'

EXPLA = MAKE_ARRAY(nflag,value='')              
EXPLA(0) = '2 readouts/ramp'
EXPLA(1) = '1 readout/ramp'
EXPLA(2) = 'Not On target'
EXPLA(3) = 'General discard'
EXPLA(4) = 'Manual discard'
EXPLA(5) = 'Detected glitch'
EXPLA(6) = 'No valid ch.pos.'
EXPLA(7) = 'Not stabilized '

severe = INTARR(Nflag)
severe(1:6) = 1
       
flagsrd_str = {nflag:nflag, LEX:lex, EXPLA:expla, valflag:2^INDGEN(nflag), $
    severe:severe}

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; DYNRESP flags
Nflag = 10 
LEX = MAKE_ARRAY(nflag,value='DUMMY')              
LEX(0) = 'RAMPNDR_2'
LEX(1) = 'RAMPNDR_1'
LEX(2) = 'NOTF'
LEX(3) = 'GENDISC'
LEX(4) = 'MANDISC'
LEX(5) = 'GLITCH'

EXPLA = MAKE_ARRAY(nflag,value='')              
EXPLA(0) = '2 readouts/ramp'
EXPLA(1) = '1 readout/ramp'
EXPLA(2) = 'Not On target'
EXPLA(3) = 'General discard'
EXPLA(4) = 'Manual discard'
EXPLA(5) = 'Detected glitch'

severe = INTARR(Nflag)
severe(1:5) = 1
       
flagdynr_str = {nflag:nflag, LEX:lex, EXPLA:expla, valflag:2^INDGEN(nflag), $
    severe:severe}

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; SCP flags
Nflag = 10 
LEX = MAKE_ARRAY(nflag,value='DUMMY')              
LEX(0) = 'NSIG_1'
LEX(1) = 'NSIG_0'
LEX(2) = 'NOCHOP'
LEX(3) = 'GENDISC'
LEX(4) = 'MANDISC'
LEX(5) = 'STABIL1'
LEX(6) = 'STABIL2'
LEX(7) = 'DRIFTMOD'

EXPLA = MAKE_ARRAY(nflag,value='')              
EXPLA(0) = 'Only 1 signal'
EXPLA(1) = 'No valid signal'
EXPLA(2) = 'No valid ch.pos.'
EXPLA(3) = 'General discard'
EXPLA(4) = 'Manual discard'
EXPLA(5) = 'Stability flag 1'
EXPLA(6) = 'Stability flag 2'
EXPLA(7) = 'Drift model flag'

severe = INTARR(Nflag)
severe(1:4) = 1    
flagscp_str = {nflag:nflag, LEX:lex, EXPLA:expla, valflag:2^INDGEN(nflag), $
    severe:severe}

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; SPD flags
Nflag = 10 
LEX = MAKE_ARRAY(nflag,value='DUMMY')              
LEX(0) = 'NSIG_1'
LEX(1) = 'NSIG_0'
LEX(2) = 'NOCHOP'
LEX(3) = 'GENDISC'
LEX(4) = 'MANDISC'
LEX(5) = 'IMAPDISC'
LEX(6) = 'QUALIT'
LEX(7) = 'BACKSEL'

EXPLA = MAKE_ARRAY(nflag,value='')
EXPLA(0) = 'Only 1 signal'
EXPLA(1) = 'No valid signal'
EXPLA(2) = 'No valid ch.pos.'
EXPLA(3) = 'General discard'
EXPLA(4) = 'Manual discard'
EXPLA(5) = 'IMAP discard'
EXPLA(6) = 'Quality flag'
EXPLA(7) = 'Bckgr. position'


severe = INTARR(Nflag)
severe(1:5) = 1
       
flagspd_str = {nflag:nflag, LEX:lex, EXPLA:expla, valflag:2^INDGEN(nflag), $
    severe:severe}


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; AAP flags
Nflag = 10 
LEX = MAKE_ARRAY(nflag,value='DUMMY')              
LEX(0) = 'NSIG_1'
LEX(1) = 'NSIG_0'
LEX(2) = 'NOCHOP'
LEX(3) = 'GENDISC'
LEX(4) = 'MANDISC'
LEX(5) = 'IMAPDISC'
LEX(6) = 'QUALIT'
LEX(7) = 'BACKSEL'

EXPLA = MAKE_ARRAY(nflag,value='')              
EXPLA(0) = 'Only 1 signal'
EXPLA(1) = 'No valid signal'
EXPLA(2) = 'No valid ch.pos.'
EXPLA(3) = 'General discard'
EXPLA(4) = 'Manual discard'
EXPLA(5) = 'IMAP discard'
EXPLA(6) = 'Quality flag '
EXPLA(7) = 'Bckgr. position'

severe = INTARR(Nflag)
severe(1:5) = 1
       
flagaap_str = {nflag:nflag, LEX:lex, EXPLA:expla, valflag:2^INDGEN(nflag), $
    severe:severe}

piaflag_str = {erd:flagerd_str, srd:flagsrd_str, scp:flagscp_str, $
               dynr:flagdynr_str, spd:flagspd_str, aap:flagaap_str}
               


RETURN
END
