;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       set_indsevere
; PURPOSE:
;
; CATEGORY:
;       PIA - flag
;
; CALLING SEQUENCE:
;	res = SET_INDSEVERE(datatype, ind_lexical [,/REPLACE] [,/UPDATE] $
;                           [,/DELETE])
;
; INPUT PARAMETERS:
;       datatype:    Data type  [ERD,SRD,SCP,SPD,AAP]     
;	ind_lexical: Array with the lexicals containing severe flags
;
; OUTPUT PARAMETERS: 
;       res: index of flags which are considered severe
;	ind_lexical: If keywords REPLACE or UPDATE are absent it contains  
;	 		the lexical of the default severe flag .
;
; KEYWORDS: 
;	REPLACE: will 
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               piaflag_info
;
; MODIFICATION HISTORY:
;	Written by: Jose Acosta (ISO Soc, VILSPA)		March 1998
;	V7.2				
;	Updated by JA+CG in La Laguna 				May 1999
;	V7.4
;-
;


FUNCTION set_indsevere,dtype, ind_lex, REPLACE = replace, UPDATE = update, $ 
   DELETE = delete, COPYCOM=copycom

COMMON piaflag_info, piaflag_str

; initialize piaflag system if necessary
IF N_ELEMENTS(piaflag_str) EQ 0 THEN piaflag_info
 
  CASE dtype OF 
      'ERD': str = piaflag_str.erd
      'SRD': str = piaflag_str.srd
      'SCP': str = piaflag_str.scp
      'SPD': str = piaflag_str.spd
      'AAP': str = piaflag_str.aap
      ELSE: BEGIN 
             print,'Not valid data type'
             RETURN, 0
            END
  ENDCASE
                   
  nparams = N_PARAMS()
  
  IF nparams LT 1 THEN BEGIN 
          print, 'Syntax:  index = set_indsevere(dtype [,IND_LEX]' + $ 
            ' [,/UPDATE] [,/REPLACE]) ' 
          RETURN, -1
  ENDIF  

IF KEYWORD_SET(DELETE)  AND N_ELEMENTS(ind_lex) GT 0 THEN delete = 1 $ 
    ELSE delete = 0
IF KEYWORD_SET(REPLACE) AND N_ELEMENTS(ind_lex) GT 0 THEN replace = 1 $ 
    ELSE replace=0   
IF KEYWORD_SET(UPDATE) AND N_ELEMENTS(ind_lex) GT 0 THEN update = 1 $ 
    ELSE update=0   
 
  CASE 1 OF 
      REPLACE: BEGIN 
          str.severe = 0 * str.severe
          FOR iele= 0, N_ELEMENTS(ind_lex)-1 DO BEGIN
             ilex = WHERE(str.lex EQ ind_lex(iele),nlex)
             IF nlex GT 0 THEN $ 
  	       str.severe(ilex) = 1
          ENDFOR
         END
      UPDATE: BEGIN
          FOR iele= 0, N_ELEMENTS(ind_lex)-1 DO BEGIN
             ilex = WHERE(str.lex EQ ind_lex(iele),nlex)
             IF nlex GT 0 THEN $
	       str.severe(ilex) = 1
          ENDFOR
         END
      DELETE: BEGIN 
          FOR iele= 0, N_ELEMENTS(ind_lex)-1 DO BEGIN
             ilex = WHERE(str.lex EQ ind_lex(iele),nlex)
             IF nlex GT 0 THEN $
	       str.severe(ilex) = 0
          ENDFOR
 
          END
     ELSE: 
   ENDCASE
     
ind = WHERE(str.severe EQ 1,nind)
IF nind GT 0 THEN ind_lex = str.lex(ind) ELSE ind_lex = ''
   
IF Keyword_set(copycom) THEN BEGIN
  CASE dtype OF 
      'ERD': piaflag_str.erd = str
      'SRD': piaflag_str.srd = str
      'SCP': piaflag_str.scp = str
      'SPD': piaflag_str.spd = str
      'AAP': piaflag_str.aap = str
  ENDCASE
ENDIF

RETURN, ind

END

