;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO Flux_S, Power, Detector, Type, Out 
;+
; NAME:
;	Flux_S
;
; PURPOSE:
;	Extracts the flux and surface brightness for PHT-S
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	FLUX_S, Power, Detector, Type, Out
;
; INPUTS:
;	Power:    Doubleprecision array of input Power in W
;	Detector: Either 'SS' or 'SL'
;	Type:     Conversion type
;	          0: Power -> Flux Density
;	          1: Power -> Surface Brightness
;
; OUTPUTS:
;	Out:      Doubleprecision array of either Flux Density F_nu in Jy
;	          or F_lambda in W/m^2/micron
;
; COMMON BLOCKS:
;	pht_s
;
; PROCEDURES_USED:
;	pht_s_init
;
; MODIFICATION_HISTORY:
;	Written by:	Huw Morris
;	Oct 95 Version 3.5
;	Changed for new derivation: use of W2jy_s and W2Mjy_s (CG)  March 1996
;	Bug for rasters fixed, input pixel taken out  (CG)	    April 1996	
;-
@phtw2jy

	ON_ERROR, 0                      ; Stay within this procedure
          
;  In case of later error, initialise the output array first
	
	Out = Double(power)

	CASE Type OF

	  0: BEGIN


; The conversion factors for S are W2Jy_s and W2MJy_s
	    IF DETECTOR EQ 'SS' THEN $ 	
       	      FOR I=0,63 DO Out(i,*) = Power(i,*) / w2jy_s(i) ELSE $
       	      FOR I=0,63 DO Out(i,*) = Power(i,*) / w2jy_s(i+64)   

	  END

	  1: BEGIN

	    IF DETECTOR EQ 'SS' THEN $ 	
       	      FOR I=0,63 DO Out(i,*) = Power(i,*) / w2Mjy_s(i) ELSE $
       	      FOR I=0,63 DO Out(i,*) = Power(i,*) / w2Mjy_s(i+64)   
	
	  END

	  ELSE: BEGIN

; Error
	   MESSAGE, 'Invalid type conversion specified'
	   RETURN
	
	  END

	ENDCASE

	END
