;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	FPGC_MANAGER
;
; PURPOSE:
;	Menu for FPGC file selection and analysis.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	FPGC_MANAGER
;
; INPUTS:
;	none
;	
; OUTPUTS:
;	none
;
; PROCEDURES CALLED:
;	PIA LIB: anal_fpgc
;	         pia_disp_print_table
;	
; MODIFICATION HISTORY:
;	Written by:	Ingolf Heinrichsen
;	Modified by:	C. Gabriel
;	Oct 95 Version 3.5
;-

; ****************************************************************************
;  Event handling routine for PIA FileView menu
; ****************************************************************************

PRO fpgc_manager_event, event

COMMON pia_cal_fpgc_cmn, fpgc_id, iscp_id, act_fpgcfile, act_iscpfile, $
		act_scanpixl, act_scancoor, x_id, y_id, pixl_id, scan_id  
COMMON pia_extfil_cmn, ftyp, ftyp_filters, dtyp

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.top, GET_UVALUE=stat
	HANDLE_VALUE, stat.id, stat_id
	HANDLE_VALUE, stat.val, stat_val
	WIDGET_CONTROL, event.top, /HOURGLASS

	CASE uvalue OF

; Quit DataReduction

	'QUIT':	BEGIN

		WIDGET_CONTROL, event.top, /DESTROY
	END

;  Select a file with 'pickfile'

	'SELF':	BEGIN
		filt = stat_val.filter

		file = pickfile( PATH=stat_val.defpath, FILTER=filt, $
			/READ, GROUP=event.top, GET_PATH=newpath )

		IF file NE "" THEN BEGIN
			WIDGET_CONTROL, stat_id.filename, SET_VALUE=file
			stat_val.defpath = newpath
			HANDLE_VALUE, stat.val, stat_val, /SET
; pass fpgcfile name to common value for use in other widgets
			act_fpgcfile = file
		ENDIF
	END

; Analyse file 

	'ANALYSE': BEGIN
		WIDGET_CONTROL, event.top, /HOURGLASS

		; read new file and go to next level 
		WIDGET_CONTROL, stat_id.filename, GET_VALUE=file
		stat_val.filename = STRTRIM(file(0),2)
		IF stat_val.filename EQ "" THEN BEGIN
			MESSAGE, /INFO, "No file selected in read."
			RETURN
		ENDIF
		text=strarr(1)
		anal_fpgc, file, text, ERROR=err
;
; Print FPGC file Information into text window
;
        	PIA_DISP_PRINT_FILE, "", $
;                  GROUP = event.top, $
                  TITLE = "Contents of FPGC File", $
                  WIDTH = 80, $
                  HEIGHT = 50, $
                  TEXT = [text]

		HANDLE_VALUE, stat.val, stat_val, /SET
		HANDLE_VALUE, stat.header, header, /SET

	END


; Select file type

	'FTYP':	BEGIN
		stat_val.ftyp = ftyp(event.index)
		stat_val.filter = ftyp_filters(event.index)
		HANDLE_VALUE, stat.val, stat_val, /SET
	END


;  pressed <RETURN> in 'Filename' widget

	'FNAM':	BEGIN
	END

	ELSE:	MESSAGE, /INFO, 'Function not yet implemented.'
	ENDCASE

	RETURN
END

; ****************************************************************************
;  PIA FPGC - menu definition procedure
; ****************************************************************************

PRO fpgc_manager


; Definitions common to all instances

COMMON pia_extfil_cmn, ftyp, ftyp_filters, dtyp

COMMON pia_widget_info, extfil_wid, intfil_wid, buffil_wid, $
			erddi1_wid, erddi2_wid, srddi1_wid, srddi2_wid, $
                        scpdi1_wid, scpdi2_wid, spddi1_wid, spddi2_wid, $
                        aapdi1_wid, aapdi2_wid


; If already registered, pop-up and exit
	IF Xregistered("fpgc_manager") NE 0 THEN BEGIN
		WIDGET_CONTROL, extfil_wid, SHOW=1
		RETURN
	END
		
; Definition of file types:
; file_types    -  Defines what appears in the list widget and can contain
;                  any strings. The largest string determines XSIZE of the
;                  list widget: 12 seems ok.
; ftyp          -  Used in event handling routine to avoid direct coding
;                  of indexes.
; ftyp_filters  -  Used in event handling routine as file filter.
; Take care that the arrays are consistent with each other.

	file_types   =  [	'FPGC File PHT-P', $
				'FPGC File PHT-S', $
				'FPGC File PHT-C']
	ftyp         =	[	'FPGC PHT-P', $
				'FPGC PHT-S', $
				'FPGC PHT-C']

	 ftyp_filters =	[	'*.FPGC_P*', $
	 			'*.FPGC_S*', $
	 			'*.FPGC_C*']   
; Definitions for individual instances

	stat = { $
		id:	HANDLE_CREATE(), $
		val:	HANDLE_CREATE(), $
		header:	HANDLE_CREATE() $
	}

	stat_id = { $
			clos:		0L, $
			vhea:		0L, $
			vtab:		0L, $
		 	filename:	0L, $
			nax1:		0L, $
			ncol:		0L, $
			nrow:		0L, $
                        col:            0L, $
                        cfr:            0L, $
                        cto:            0L, $
                        row:            0L, $
                        rfr:            0L, $
                        rto:            0L $
	}

	stat_val = { $
			defpath:	'', $
			filename:	'', $
			ftyp:		'', $
			filter:		'', $
			fxbunit:	0L, $
			dims:		[ 0L, 0L, 0L ] $
	}


; Set-up widget hierarchy

    extfil_wid = WIDGET_BASE( TITLE="FPGC Data Selection", /COLUMN )

	id_0 = WIDGET_BASE( extfil_wid, /ROW )
	id_1 = WIDGET_BUTTON( id_0, VALUE='    File    ', /MENU )
	id_2 = WIDGET_BUTTON( id_1, VALUE='Select FPGC File...', UVALUE='SELF' )
	id_2 = WIDGET_BUTTON( id_1, VALUE='Analyse FPGC File...', $
			      UVALUE='ANALYSE' )
	id_2 = WIDGET_BUTTON( id_1, VALUE='Quit', UVALUE='QUIT' )


	id_1 = WIDGET_LABEL( id_0, VALUE='                        ' )
	id_1 = WIDGET_BUTTON( id_0, VALUE='    Help    ', UVALUE='HELP' )

	id_0 = WIDGET_BASE( extfil_wid, /ROW )
	id_1 = WIDGET_LABEL( id_0, VALUE='Selected File:' )
	id_1 = WIDGET_LABEL( id_0, VALUE=' ' )
	id_0 = WIDGET_TEXT( extfil_wid, /EDITABLE, XSIZE=40, YSIZE=1, $
			VALUE=' ', UVALUE='FNAM')
	stat_id.filename = id_0

	id_0 = WIDGET_BASE( extfil_wid, /ROW )

	id_1 = WIDGET_BASE( id_0, /COLUMN )
	id_2 = WIDGET_LABEL( id_1, VALUE='Select Filetype:' )
	id_2 = WIDGET_LIST( id_1, YSIZE=6, VALUE=file_types, UVALUE='FTYP' )

	id_1 = WIDGET_LABEL( id_0, VALUE='                        ' )

	id_1 = WIDGET_BASE( id_0, /COLUMN )


        id_0 = WIDGET_BASE( extfil_wid, /ROW)

        id_1 = WIDGET_BASE( id_0, /COLUMN )
        id_2 = WIDGET_BASE( id_1, /ROW )


; Define initial settings

	stat_val.defpath=!fitdir

;  Store values for individual instances with base widget

	HANDLE_VALUE, stat.id, stat_id, /SET, /NO_COPY
	HANDLE_VALUE, stat.val, stat_val, /SET, /NO_COPY
	WIDGET_CONTROL, extfil_wid, SET_UVALUE=stat, /NO_COPY


; Realize widget

	WIDGET_CONTROL, extfil_wid, /REALIZE, TLB_SET_YOFFSET=300, $
				TLB_SET_XOFFSET=10
                                              
       	xMANAGER,No_BLOCK=1, "fpgc_manager", extfil_wid, GROUP=group

	RETURN
END
