;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       GEN_CHOICES_INIT
;
; PURPOSE:
;       Initializes the COMMON block GEN_CHOICE used for automatic /
;	batch processing.
;
; CATEGORY:
;       PIA - initialization
;
; CALLING SEQUENCE:
;       @gen_choices_init
;
; MODIFICATION HISTORY:
;       Written by: C.Gabriel (ESA/VILSPA - SAI)		April 1997
;	V6.2
;	Extensions: reset interval & vignetting corrections + rpid->0b +
;		gen_process ->drft,splitrp  (CG+JA)		May 1997
;	V6.3
;	Resp choices now for single and double options (CG)	July 1997
;	V6.4
;	Pair deglitching (ERD), chopper frequency dependance and
;	 selection for correction menues added (CG)		January 1998
;	V7.0
;	Siglin added (CG)					January 1999
;	V7.3
;	Pattern added (CG)					March 1999
;	Siglin on SCP added (CG)				June 1999
;	V7.4
;       Change default ERD deglitch to 2-Thr.    (CG)           July 1999
;       V8.0
;	PHT-S chopped dynamic calibration added (CG)		September 1999
;	V8.1
;	PHT-S pointing correction added (CG)			December 1999
;	V8.2
;	Default for use of two FCS response derivation set to
;	 average (instead of interpolation) (CG)		May 2002
;	Follow_def option added
;	V10.0
;-	

PRO gen_choices_init

@gen_choices

	gen_select = {erdsel:0,srdsel:0,scpsel:0}
	gen_correct = {linear:1, rpid0:1, resint:0, resint_scp:1, darkc:1, $
	             darkc_srd:0, siglin:0, deglit:1, deglit2:0, pairdeglit:1, $
		     bcksub:1, siglin2:1, spoint:1, $
	             vignet:1, chfr:1, erd_selcor:0, srd_selcor:0, scp_selcor:0}
	gen_process = {drft:1,splitrp:0, pattern:1, slchop:1, dynresp:1, $
			follow_def:1}
	gen_save = {savsrd:0, savscp:0, savspd:0, savaap:0,$
		    savsrdf:0, savscpf:0, savspdf:0, savaapf:0}
	gen_fits = {FITS:0, delete:0}
	IF !VERSION.OS NE 'vms' THEN $
        	gen_filt = 'P?E*.FITS' ELSE $
        	gen_filt = 'P%E*.FITS' 

	gen_stop = 0
	gen_respalt = {single:0,double:1}
	
	RETURN
	END

