;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       GEN_PAP
;
; PURPOSE:
;       Creates a PHTIAAP 2000 structure using the PHTIAAP of last millenium.  
;	Contains empty arrays for the 
;	central RA and DEC position for every point in the AAP, including chopper 
;	deflections and detector pixel offsets.  This makes the data more 
;	transparent and mapping easier.
;
; CATEGORY:
;       PIA - processing
;
; CALLING SEQUENCE:
;       GEN_PAP, phtiaap, phtipap
;
; INPUTS:
;       PHTIAAP		The old AAP structure
;
; KEYWORD PARAMETERS:
;	(none)
;
; OUTPUTS:
;       PHTIPAP		The resulting PHTIPAP = AAP2000
;
; COMMON BLOCKS:
;       (none)
;
; PROCEDURES USED:
;       PIA Procedure(s):	 
;
;       Astronomical Library:	FXPAR
;
; FUNCTIONS USED:	pixel_det (function) 
;
; MODIFICATION HISTORY:
;       Written by:             Min Hur, IPAC/Caltech       	Jan 2000
;	Modification history:
;		Solving problem with P staring data (CG)	May 2000
;	V9.0
;-

PRO gen_pap, phtiaap, phtipap


	IF N_ELEMENTS(phtiaap.mnfl) EQ 1 THEN BEGIN
	  decp = DBLARR(1)
	  rap = decp
	ENDIF ELSE BEGIN
 	 decp = phtiaap.mnfl * 0.
	 rap = decp
        ENDELSE
	phtipap = { $
                ADMN: phtiaap.admn, DET: phtiaap.det, $ $
                DIMS: phtiaap.dims, $
                FILT: phtiaap.filt, APER: phtiaap.aper, POLZ: phtiaap.polz, $
                CWVL: phtiaap.cwvl, $
                HDR: phtiaap.hdr, $
                TIME: phtiaap.time, $
                CSTP: phtiaap.cstp, $
        	CPOS: phtiaap.cpos, $
		DWEL: phtiaap.dwel, $ 
                MNFL: phtiaap.mnfl, $
                MNFU: phtiaap.mnfu, $
                MNBR: phtiaap.mnbr, $
                MNBU: phtiaap.mnbu, $
                MDFL: phtiaap.mdfl, $
        	Q1FL: phtiaap.q1fl, $
        	Q3FL: phtiaap.q3fl, $
                MDBR: phtiaap.mdbr, $
         	Q1BR: phtiaap.q1br, $
        	Q3BR: phtiaap.q3br, $
        	RPID: phtiaap.rpid, $
                DEC:  phtiaap.dec, $
                RA:   phtiaap.ra, $
                DECP: decp, $
                RAP: rap, $
		ROLL: phtiaap.roll, $
                FLAG: phtiaap.flag}

RETURN
END
