;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       GET_ACCVOLT
;
; PURPOSE:
;       Get a flag array corresponding to the read-outs which are discarded
;       due to saturation 
;
; CATEGORY:
;       PIA - processing
;
; CALLING SEQUENCE:
;       GET_ACCVOLT, Tmpdata, volt_disc
;
; INPUTS:
;       Tmpdata: A PHT-ERD temporary structure
;
; OUTPUTS:
;       volt_disc: A flag array (same dimensions as phterd.conp) with flag=1
;                for all discarded signals
;
; KEYWORDS:
;       ENCODE_FLAG: when select tmpdata.flag is changed accordingly to flag 
;  	             encodding
;
; COMMON BLOCKS:
;       phtacc
;       phtselndr
;
; PROCEDURES USED:
;       None
;
; MODIFICATION HISTORY:
;       Written by:     Jose Acosta 				      May 1999
;       V7.4
;
;-
PRO GET_ACCVOLT, TMPDATA, DR, VOLT_DISC,ENCODE_FLAG = ENCODE_FLAG 

; Check the number of parameters
;
	IF N_PARAMS() LT 2 THEN MESSAGE, $
	   'Syntax: GET_ACCVOLT, TMPERD, DR [,VOLT_DISC] [,/ENCODE_FLAG]'

; Flag also the saturated voltages (only for real pixels)

	npix = pixel_det(tmpdata.det)
	decode_pixf, tmpdata.pixf, susp, chpon, chps, dr
	volt_disc = FLTARR(npix,tmpdata.dims)
	FOR I=0,npix-1 DO BEGIN
		erddpix = reform(volt_disc(i,*))
		acc_volt, tmpdata.conp(i,*), erddpix, dr 
		volt_disc(i,*) = erddpix
	ENDFOR

        IF KEYWORD_SET(ENCODE_FLAG) THEN  BEGIN
	   encode_piaflag,'ERD','OUTVOLT',tmpdata.flag(0:npix-1,*), tmpflag, $
	       volt_disc, DET= tmpdata.det
	   tmpdata.flag(0:npix-1,*) = tmpflag    
	ENDIF       
RETURN
END
