;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
pro get_boundaries,idb,idb_f_bounds

;+
; NAME:
;       GET_BOUNDARIES
;
; PURPOSE:
;       Check an idb array for the boundaries of the ANA and STS part
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       GET_BOUNDARIES, Idb, Idb_f_bounds
;
; INPUTS:
;       Idb         :database array
;
; OUTPUTS:
;       Idb_f_bound:  0: begin status  1: end status
;                     2: begin analog  3: end analog
; 
; PROCEDURE:
;       Idb has to be sorted, first coming all the status
;       and then the analog data.
;       get_boundaries searches only for the first ANA entry        
;
; PROCEDURES USED:
;       None
;
; MODIFICATION HISTORY:
;       Written by:	Andreas Karch
;	Oct 95 Version 3.5
;-

;boundaries of the analog and the status parameter group
;idb_f_bound:  0: begin status  1: end status   2: begin analog  3: end analog

idb_f_bounds=intarr(4)

; idb_def should be sorted, so first come all STS and then all ANA values

a=where(idb(2,*) eq 'STS',count1)
a=where(idb(2,*) eq 'ANA',count2)

;print error if there are entries, which are neither STS nor ANA

if  (count1 + count2 ne n_elements(idb(0,*)) ) then print,'error'

;set the values

idb_f_bounds(0)=0
idb_f_bounds(1)=count1-1
idb_f_bounds(2)=count1
idb_f_bounds(3)=count1+count2-1

end
