;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
PRO GET_chopsteps, cpos, step

;+
; NAME:
;	GET_CHOPSTEPS
;
; PURPOSE:
;	Get a step array corresponding to the different chopper positions 
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       GET_CHOPSTEPS, Cpos, Step
;
; INPUTS:
;       Cpos: An array containing different chopper positions
;
; OUTPUTS:
;       Step:  An array (same dimensions as cpos) with position steps
;
; PROCEDURES USED:
;	None
;
; MODIFICATION HISTORY:
;       Written by:	Carlos Gabriel
;	Oct 95 Version 3.5
;-


        ON_ERROR, 2

;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 2 THEN MESSAGE, $
          'Syntax:  GET_chopsteps, cpos, step'

	n0 = N_ELEMENTS(cpos)
	step = INTARR(n0)
	indn0 = indgen(n0)
	count = 1
	
	WHILE n0 NE 0 DO BEGIN
		step(indn0) = count
		indn0 = WHERE(cpos(indn0) NE cpos(indn0(0)), n0)
	        count = count + 1
	ENDWHILE
        RETURN
	END
