;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO GET_CONVWH, MEASNAME, WHEELS, CHMOD, CHAMP
;+
; NAME:
;	GET_CONVWH
;
; PURPOSE:
;	Get the converted wheels positions, chopper mode and amplitude
;	corresponding to tmpdata from the Compact Status structure. 
;
; CATEGORY
;	PIA - processing
;
; CALLING SEQUENCE:
;       GET_CONVWH, Measname, Wheels, Chmod, Champ
;
; INPUTS:
;       Measname: A PHT measurement name (admn)
;
; OUTPUTS:
;       Wheels: A 3 string array containing the converted wheel positions 
;	Chmod:	The chopper mode
;	Champ:	The chopper amplitude
;
; COMMON BLOCKS:
;	phtcs
;
; RESTRICTIONS:
;       Measname must correspond to an ISOPHOT measurement. The corresponding
;	Compact Status informations must be contained whether in a FITS file
;	or in the phtcs dynamical structure
; 
; PROCEDURES USED:
;	PIA LIB: conv_cs
;	         read_cs
;
; MODIFICATION HISTORY:
;       Written by:	Carlos Gabriel - ESA-SAI
;	Oct 95 Version 3.5
;	Version 5.0
;-
@phtcs

; Check number of parameters


        ON_ERROR, 2

;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 2 THEN MESSAGE, $
          'Syntax:  GET_CONVWH, measname, wheels[, chmod, champ]'

	IF STRMID(measname,0,2) EQ 'SS' THEN STRPUT, measname, 'L', 1 
; - change -> shape4
	psta_file='PSTA'+strmid(measname,4,8)+'.FITS'
	read_cs,psta_file,header,csun

	conv_cs, phtcs(csun), cst
	handle_value, cst.handle, cstmp

;calculate index
	index_arr = WHERE(strmid(cstmp.subs,0,2) EQ strmid(measname,0,2),count)

  	IF count GT 0 THEN in = index_arr(fix(strmid(measname,2,2))) $
		ELSE MESSAGE, /INFO, 'Corresponding CS not found'

        wheels = [cstmp.c1ps(in),cstmp.c2ps(in),cstmp.c3ps(in)] 
	chmod = cstmp.cmod(in)
	champ = cstmp.camp(in)
	RETURN
	END
