;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  PRO get_darkcstr, det, darkcstr
;+
; NAME:
;       GET_DARKCSTR
;
; PURPOSE:
;       Returns the dark current structure corresponding to detector
; 
; CATEGORY:
;	PIA - processing
;       
; CALLING SEQUENCE:
;       GET_DARKCSTR, Det, Darkcstr
;
; INPUTS:
;       Det: Detector name. One of: P1, P2, P3, C1, C2, SL
;
; OUTPUTS:
;       Darkcstr: the corresponding dark current structure
;
; PROCEDURES USED:
;	None
;
; MODIFICATION HISTORY:
;	Written by: Carlos Gabriel
;	Oct 95 Version 3.5
;       Check if the calsave file exists, if not then  
;	returns a dummy structure (JAcosta)			October 1997
;-

ON_ERROR, 2

	detind = STRMID(STRUPCASE(det),0,2)

        CASE detind of
                'SL': darkcur_str = {SLDARKSTR_typ}
                'C2': darkcur_str = {C2DARKSTR_typ}
                'C1': darkcur_str = {C1DARKSTR_typ}
                ELSE: darkcur_str = {PDARKSTR_typ}
        ENDCASE

	filename = !CALSAVE+ detind + 'CALDARKC_STR.SAV'
	res = findfile(filename, count = count)
	
	IF count NE 0 THEN RESTORE, filename  $
	  ELSE BEGIN
            print,string(7b),'Filename '+ strtrim(filename,2)+' not found'
            print,'Returning a dummy structure '
          ENDELSE  
	  
	darkcstr = darkcur_str 
	
END

