;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  PRO get_darkcur, det, darkcurr
;+
; NAME:
;       GET_DARKCUR
;
; PURPOSE:
;       Returns the dark current array corresponding to the detector.
; 
; CATEGORY:
;	PIA - processing
;       
; CALLING SEQUENCE:
;       GET_DARKCUR, Det, Darkcurr
;
; INPUTS:
;       Det: Detector name. One of -- P1, P2, P3, C1, C2, SL
;
; OUTPUTS:
;       Darkcurr: the corresponding dark current array
;
; COMMON BLOCKS:
;       phtdarkcur
;
; PROCEDURE:
;       Use FXPAR to extract the keyword info.
;
; PROCEDURES USED:
;	ASTRO LIB: fxpar
;
; MODIFICATION HISTORY:
;	Written by:	Carlos Gabriel
;	Oct 95 Version 3.5
;-
@phtdarkcur
ON_ERROR, 2

	detind = STRMID(STRUPCASE(det),0,2)

	CASE detind OF

	 'P1': darkcurr = FXPAR(DARKCURHDR, 'DARKP1')

	 'P2': darkcurr = FXPAR(DARKCURHDR, 'DARKP2')

	 'P3': darkcurr = FXPAR(DARKCURHDR, 'DARKP3')

	 'C1': darkcurr = FXPAR(DARKCURHDR, 'DARK1C*')

	 'C2': darkcurr = FXPAR(DARKCURHDR, 'DARK2C*')

	 'SL': darkcurr = FXPAR(DARKCURHDR, 'DARKS*')

	 'SS': darkcurr = FXPAR(DARKCURHDR, 'DARKS*')

        ENDCASE

END

