;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  PRO get_fcspre_str, det, fcsprestr
;+
; NAME:
;       GET_FCSPRE_STR
;
; PURPOSE:
;       Returns the FCS Pre-reduced Signal Table corresponding to the detector
; 
; CATEGORY:
;	PIA - I/O
;       
; CALLING SEQUENCE:
;       GET_FCSPRE_STR, Det, Fcsprestr
;
; INPUTS:
;       Det: Detector name. One of -- P1, P2, P3, C1, C2
;
; OUTPUTS:
;       Fcsprestr: the corresponding fcs Pre-Reduced Signal Table
;
; PROCEDURES USED:
;	None
;
; MODIFICATION HISTORY:
;	Written by:	Carlos Gabriel		October 1995
;
;-
ON_ERROR, 2

	detind = STRMID(STRUPCASE(det),0,2)

        CASE detind of
                'C2': fcspre_str = {C2FCSPRE_typ}
                'C1': fcspre_str = {C1FCSPRE_typ}
                ELSE: fcspre_str = {PFCSPRE_typ}
        ENDCASE

	filename = !CALSAVE+ detind + 'CALFCS_PRE_STR.SAV'
	RESTORE, filename
	fcsprestr = fcspre_str 
	
END

