;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  PRO get_fcspstr, det, fcspstr
;+
; NAME:
;       GET_FCSPSTR
;
; PURPOSE:
;       Returns the FCS power structure corresponding to the detector
; 
; CATEGORY:
;	PIA - I/O
;       
; CALLING SEQUENCE:
;       GET_FCSPSTR, Det, Fcspstr
;
; INPUTS:
;       Det: Detector name. One of -- P1, P2, P3, C1, C2
;
; OUTPUTS:
;       Fcspstr: the corresponding fcs power structure
;
; PROCEDURES USED:
;	None
;
; MODIFICATION HISTORY:
;	Written by:	Carlos Gabriel
;	Oct 95 Version 3.5
;	Typ changed	CG	October 1995
;
;-
ON_ERROR, 2

	detind = STRMID(STRUPCASE(det),0,2)

        CASE detind of
                'C2': fcsp_str = {C2_FCSPOW_typ}
                'C1': fcsp_str = {C1_FCSPOW_typ}
                ELSE: fcsp_str = {P_FCSPOW_typ}
        ENDCASE

	filename = !CALSAVE+ detind + 'CALFCSP_STR.SAV'
	RESTORE, filename
	fcspstr = fcsp_str 
	
END

