;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	GET_HEADLINE
;
; PURPOSE:
;	Define a headline out of a PIA map parameter structure  
;
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;	res = GET_HEADLINE(par, n, mm=mm, title=title)
;
; INPUTS:
;	par	: PIA map parameter structure
;	n	: type of map (0:surf.bright., 1:unc., 2:exposure, -1:unknown)
;
; OUTPUT KEYWORDS:
;	MM	: map method string (eg. "Distance Weighting")
;	TITLE	: Default title according to type and datatype of map
;
;
; MODIFICATION HISTORY:
;	Written by:	Carlos Gabriel (ESA/VILSPA-SAI)		January 1999
;	V7.4
;-
FUNCTION get_headline, par, type, mm=mm, title=title

	vars = tag_names(par)
	i = WHERE(vars EQ 'MAPMETHOD' or vars EQ 'DATATYPE' or $
		vars EQ 'ADMN_DECODED', ncount)
	IF ncount NE 3 THEN BEGIN	
		MESSAGE, /INFO, 'Structure not appropriate, returning'
		RETURN, ''
	ENDIF  

	IF type EQ -1 THEN BEGIN
		title="Not defined "
		mm = ""
		RETURN, par.admn_decoded
	ENDIF
	
	CASE par.mapmethod OF
		 0: mm = 'Full_cov'
		 1: mm = 'Dist_wgt'
		 2: mm = 'Trigrid '
		 3: mm = 'Trig_qnt'
		 ELSE: mm='Unknown'
	ENDCASE

	IF type EQ 0 THEN BEGIN
	  IF par.datatype GE 4 THEN title="Flux Density" ELSE $
		                  title="Brightness"
	ENDIF ELSE IF type EQ 1 THEN title="Uncertainty" ELSE $
	  title="Exposure"
	

	HEADLINE=title+": "+par.admn_decoded + ' - ' + mm
	
	RETURN, headline
	END
