;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       GET_INBPOWER
;
; PURPOSE:
;       Returns the In-band power corresponding to a Source on a given filter,
;	as quoted in the calibration file
;
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;	GET_INBPOW, FILENAME, SOURCE_ID, FILTER_ID, INBPOWER
;
; INPUT:
;	filename:	The file to be searched
;	source_id:	Name of the source
;	filter_id:	Official filter identifier       
;
; OUTPUT:
;	inbpower:	The in-band power expected
;
; PROCEDURES USED:
;
; MODIFICATION HISTORY:
;       Written by: Carlos GABRIEL (ESA-SAI)	November 1995
;-
PRO get_inbpower, filename, source_id, filter_id, inbpower

	ON_ERROR, 2
	
;
; Check the number of parameters
;
	IF N_PARAMS() LT 4 THEN MESSAGE, $
	   'Syntax: GET_INBPOW, FILENAME, SOURCE_ID, FILTER_ID, INBPOWER '

	OPENR, unit, filename, /GET_LUN

	inbpower = -1.
	line = ' '
	
	fin = 0
	WHILE (fin EQ 0 AND not eof(unit)) DO BEGIN
	  READF, unit, line
	  posi = STRPOS(line, filter_id)
	  IF posi NE -1 THEN fin = 1
	ENDWHILE

	IF posi EQ -1 THEN BEGIN
	  MESSAGE, /info, 'Filter ID not found, returning'
	  FREE_LUN, unit
	  RETURN
	ENDIF
	
	READF, unit, line
	
	fin = 0
	WHILE (not fin AND not eof(unit)) DO BEGIN
	  READF, unit, line
	  here = STRPOS(line, source_id)
	  IF here NE -1 THEN BEGIN
	  	inbpower = STRMID(line,posi,8)
	  	IF inbpower EQ '********' THEN BEGIN
	  		MESSAGE, /info, 'No entry for this filter, returning'
			inbp = -1.
	  		FREE_LUN, unit
	  		RETURN
	  	ENDIF ELSE inbpower = float(inbpower)
	  	fin = 1
	  ENDIF
	ENDWHILE
	
	IF inbpower EQ -1. THEN BEGIN
	  MESSAGE, /info, 'Source not found in file'
	ENDIF

	FREE_LUN, unit
	RETURN
	END
	
	 
