;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
PRO GET_NCHOPPSWEEP, step, nchopp, ind_sweep_step, chopstep, in_plat_pos
;+
; NAME:
;       GET_NCHOPPSWEEP
; PURPOSE:
;	Given a sequence of chopper positions will produce an array containing
; 	the index where any chopper sweep occurs.  
;
; CATEGORY:
;       PIA - processing
;                
; CALLING SEQUENCE:
;       GET_NCHOPPSWEEP, step, nchopp, ind_sweep, chopstep
;
; INPUT PARAMETERS: 
;	STEP:		
; OUTPUT: 
;    	SWEEP_STEP: 	jump of chopper units
;    	CHOPSTEP:sequential index of step: 1111-2222-1111 ...--> 1111-2222-3333
; RESTRICTIONS:
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;
;       PIA Procedure(s):
;               
;       Astronomical Library:
;
; MODIFICATION HISTORY:
;       Written by: J. Acosta				July 1996
;       V5.x
;	Change one output argument, chopstep is now 
;	sequential change of steps.  JAcosta		Aug. 1997
;       Bug corrected using nr_ref    JAcosta		Nov. 1997
;	Bug for > 32760 chopper plateaus fixed (CG)	Jun. 1998
;	V7.2	
;-
;

sweep_step = step
ind_sweep_step = fix(sweep_step)*0
chopstep = ind_sweep_step + 1
in_plat_pos = indgen(N_ELEMENTS(step)) + 1

if n_elements(step) gt 1 then    $ 
  sweep_step = [step(1:*), step(n_elements(step)-1)] - step ELSE BEGIN
  	sweep_step = 1
  	nchopp = 1
  	ind_sweep_step = 0
  	RETURN
  ENDELSE
  
ind_sweep_step = WHERE(sweep_step ne 0, nchopp) 
; actually the number of chopper plateau is given by number of
;  
nchopp = nchopp + 1
; if only one chopper plateau is found then sweep_step will contain
; the number of elements
IF nchopp eq 1 THEN ind_sweep_step = n_elements(step)-1 $ 
  ELSE ind_sweep_step = [ind_sweep_step,n_elements(step)-1]


 nr_ref = indgen(N_ELEMENTS(step))+1
 
FOR ichopp = 1L, nchopp-1 DO  BEGIN
  chopstep(ind_sweep_step(ichopp-1)+1:ind_sweep_step(ichopp)) = $ 
      chopstep(ind_sweep_step(ichopp-1)+1:ind_sweep_step(ichopp)) + ichopp
  in_plat_pos(ind_sweep_step(ichopp-1)+1:ind_sweep_step(ichopp)) = $
	        nr_ref(0:(ind_sweep_step(ichopp)-ind_sweep_step(ichopp-1)-1))        
ENDFOR	
  

END
