;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	GET_OMEGA
;
; PURPOSE:
;	This function returns omega values und uncertainties from phtomega
;
; CALLING SEQUENCE:
;	res = GET_OMEGA(detector, aperture/pixel, filter)
;
; INPUTS:
;	detector:	one element out of 'P*', 'C1', 'C2'
;	aperture/pixel:	aperture(0-13) for 'P', pixel for C100/C200 
;			(can be array of numbers)
;	filter:		0-13 for P, 0-7 for C100, 0-4 for C200 
;			(can be array of numbers)
;
; OUTPUTS:
;	Returns     res = FLTARR(aper/pixel, filter, 2)  for chosen
;			  aper/pixel(s) and filter(s) with
;
;			res(*,*,0) = values
;			res(*,*,1) = uncertainties
;
; RESTRICTIONS:
;
; COMMON BLOCKS:
;       phtomega
;
; PROCEDURES USED:
;
; MODIFICATION HISTORY:
;	Written by: Carlos GABRIEL (ESA/VILSPA-SAI)		Jan 98 
;	V7.0
;-
FUNCTION get_omega, det, aperpix, filter

@phtomega


	IF N_ELEMENTS(c1om) EQ 0 THEN read_omega
	
	CASE STRMID(det,0,2) of
	 'C1': om=c1om
	 'C2': om=c2om
	 ELSE: om=pom
	END

	RETURN, REFORM(om(aperpix,filter,*))
	
	END
