;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	GET_RAMPSPLIT
;
; PURPOSE:
;	Given an index containing the end of ramps (ERD level) provides a 
;       new index containing the end of subramps after ramp splitting, using 
;	an specified number of	valid readouts.
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	newrampend = get_rampsplit(rampend, NDR_subramp)
;
; INPUT PARAMETERS:
;	rampend		: Index containing the end of complete ramps
;	NDR_subramp	: Number of readouts for each subramp
;
; OUTPUT PARAMETERS:
;	newrampend	: Index containing the end of subramps
;
; KEYWORD INPUT
;	
; 
; RESTRICTIONS:
;
;
; METHOD:
;
;
; COMMON BLOCKS:
;
; MODIFICATION HISTORY:
;	Written by: J.Acosta (IAC)			May 1999
;	V7.4
;-
FUNCTION get_rampsplit, rampend, subd_ramp 

; using rampend determine the limits of subramps
nramp = N_ELEMENTS(rampend)
npts = rampend(0:nramp-1) - [-1,rampend(0:nramp-2)]
maxnpts = MAX(npts)
nsubramp = FIX((maxnpts-1)*1./(subd_ramp-1))

newrampend = rampend
ind_maxnpts = WHERE(npts(0:nramp-1) EQ maxnpts)
FOR isub=1, nsubramp-1 DO BEGIN 
  rampendtmp = rampend(ind_maxnpts) - isub*(subd_ramp-1)
  newrampend = [newrampend, rampendtmp] 
ENDFOR

ind_no_maxnpts = WHERE(npts(0:nramp-1) NE maxnpts,nno_maxnpts)
FOR ispe=0,nno_maxnpts-1 DO BEGIN
 ind_spe = ind_no_maxnpts(ispe)
 nsubramp_spe = FIX((npts(ind_spe)-1)*1./(subd_ramp-1))
; IF last ramp contains only one readout then finish 
 IF nsubramp_spe NE 0 THEN BEGIN
  IF ind_spe EQ 0 THEN startpt = 0 ELSE startpt = rampend(ind_spe-1) 
  rampendtmp = startpt + (INDGEN(nsubramp_spe)+1)*(subd_ramp-1)
  newrampend = [newrampend, rampendtmp] 
 ENDIF
ENDFOR
  

 newrampend = newrampend(BSORT(newrampend))

;check that the last value does not exceed

RETURN, newrampend
END
