;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
PRO GET_rastersteps, rpid, step, flag, time=time, in_rast=in_rast, in_rast_pos

;+
; NAME:
;	GET_RASTERSTEPS
;
; PURPOSE:
;	Get a step array corresponding to the different raster positions 
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       GET_RASTERSTEPS, Rpid, Step[, TIME=time, flag]
;
; INPUTS:
;       Rpid: A Raster Point ID array (BYTEARR(2,*))  
;
; OUTPUTS:
;       Step: An array (same dimensions as RPID(0,*) with position steps
;
; KEYWORD INPUT:
;	Time: A time array (same dimensions as RPID(0,*)) necessary for
;		calculating the flag
;	in_rast: Set if in_rast_pos should be calculated
;
; OPTIONAL OUTPUT: 
;	Flag: An array (same dim as time) flagging with 2 all the elements
;		of every raster point within the first 2 seconds after begin
;	in_rast_pos: An array of positions within the raster point.
;
; PROCEDURES USED:
;	None
;
; MODIFICATION HISTORY:
;       Written by:	Carlos Gabriel
;	Modified by CG (last: September 1996)
;	Version 5.0
;	In_rast_pos as output added (CG)		October 1997
;	V6.5
;	Bug by introducing bitflag system fixed (CG)	August 1999
;	V8.0+
;-


        ON_ERROR, 2

;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 2 THEN MESSAGE, $
'Syntax:  GET_rastersteps, rpid, step, flag, time=time, in_rast=in_rast, in_rast_pos'

	n0 = N_ELEMENTS(rpid(0,*))
	step = INTARR(n0)
	flag = step
	indn0 = lindgen(n0)
	count = 1

	WHILE n0 NE 0 DO BEGIN
		step(indn0) = count
		indn00 = WHERE(rpid(0,indn0) NE rpid(0,indn0(0)), n00) 
		indn01 = WHERE(rpid(1,indn0) NE rpid(1,indn0(0)), n01)

                IF n00 NE 0 AND n01 NE 0 THEN $
			firstn0 = min([indn00(0),indn01(0)]) $
		ELSE IF n00 NE 0 THEN  $
			firstn0 = indn00(0) $
		ELSE IF n01 NE 0 THEN  $
			firstn0 = indn01(0) $
		ELSE BEGIN

; Flag with 2 all the elements which are within 2 sec after RP change
	IF KEYWORD_SET(time) THEN BEGIN
	   stdif = step(1:*) - step(0:N_ELEMENTS(step)-2)
	   inddif = WHERE(stdif GT 0, ndif)
	   inddif = inddif+1
	     
	   FOR istep=0,ndif-1 DO BEGIN
	    indst = WHERE(time(inddif(istep):*)-time(inddif(istep)) LT 2.,n2s)
	    IF n2s GT 0 THEN flag(inddif(istep)+indst) = 1
	   ENDFOR
	ENDIF 
; Calculate the positions within the rasterstep

	IF KEYWORD_SET(in_rast) THEN BEGIN
	 in_rast_pos = step * 0
	 FOR istep=1L, max(step) DO BEGIN
	     indrst = WHERE(step EQ istep, nrst)
	     in_rast_pos(indrst) = indgen(nrst)+1
	 ENDFOR
 	ENDIF
 	RETURN
		ENDELSE		

		indn0 = indn0(firstn0:*)
		n0 = N_ELEMENTS(indn0)


	        count = count + 1
	ENDWHILE


        RETURN
	END
