;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	GET_RPCHOP_SRD
;
; PURPOSE:
;	Get the indexes of a given raster position and chopper plateau.
;	If keyword chopped is set then gives the next chopper plateau
;
; CATEGORY:
;	PIA - algorithms
;
; CALLING SEQUENCE:
;	GET_RPCHOP_SRD, raststeps, step, irast, istep, indrstchopp 
;	   [, indrstchopp2] [,/CHOPPED]   
;
; INPUT:
;	tmpdata:	A phtsrd like temporary structure
;	pixel:		The pixel number of the data to be used
;
; KEYWORD PARAMETERS:
;	CHOPPED: If two contiguous chopper plateau are required
;	
; RESTRICTIONS:
;	TMPDATA must be a valid PHTSRD temporary structure
;	
; COMMON BLOCKS:
;		
; PROCEDURES USED:
;	PIA LIB:
;		get_nchoppsweep
;
;       INTERNAL:
;		
;
; MODIFICATION HISTORY:
;	Written by: J. Acosta (IAC-La Laguna)		September 1996
;	Bug corrected (J.Acosta)  			October 1996
;	Version 5.x - Oct.96
;			
;-
PRO get_rpchop_srd, rastersteps, step, irast, istep, indrstchopp, $ 
      indrstchopp2, CHOPPED=chopped

if keyword_set(chopped) then chopped = 1 else chopped = 0 

; use internal value for istep
iistep = istep 

indrst = where(rastersteps EQ irast)

get_nchoppsweep, step(indrst), nchopp, ind_sweep_step

ind_sweep_step = [-1, ind_sweep_step]  

if nchopp gt 1 then begin 
	np_chopp = ind_sweep_step(iistep)-ind_sweep_step(iistep-1)
        indrstchopp = indrst(indgen(np_chopp)+ind_sweep_step(iistep-1)+1)
        if chopped eq 1 then begin
          np_chopp2 = ind_sweep_step(iistep+chopped)-ind_sweep_step(iistep)
          indrstchopp2 = indrst(indgen(np_chopp2)+ind_sweep_step(iistep)+1)
        endif 
endif else indrstchopp = indrst

RETURN
END	

