;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	GET_RPCHOPSTEP
;
; PURPOSE:
;	Get the indices of raster position / chopper plateau combination.
;
; CATEGORY:
;	PIA - algorithms
;
; CALLING SEQUENCE:
;	GET_RPCHOPstep, rastersteps, step, rpchopstep, in_plat_pos 
;
; INPUT:
;	rastersteps:	array with raster indices
;	step:		array with chopper step position
;
; OUTPUT:
;	rpchopstep:	array (same length as input) with consecutive
;			raster-chopper combination.
;	in_plat_pos:	array (same length as input) with position within
;			raster-chopper plateau
;	
; RESTRICTIONS:
;	
; COMMON BLOCKS:
;		
; PROCEDURES USED:
;	PIA LIB:
;		get_nchoppsweep
;
;       INTERNAL:
;		
;
; MODIFICATION HISTORY:
;	Written by: J. Acosta (IAC-La Laguna) +cg	December 1996
;	in_plat_pos now normal output (CG)		January 1997
;	Avoiding INDGEN in long loops +
;	 loops long initialized (CG)			September 1997
;	V6.5
;	Bug by raster jump fixed (CG)			August 1999
;	V8.0+
;			
;-
PRO get_rpchopstep, rastersteps, step, rpchopstep, in_plat_pos, JUMP=jump


; set at the beginning rpchopstep = rastersteps 
;  valid then for raster staring case - and in_plat_pos to 0

	rpchopstep = rastersteps
	in_plat_pos = rpchopstep * 0

	nele= N_ELEMENTS(rastersteps)
	
;check RPID jumps unsinchronized with chopper jumps
	sweep_rst = [rastersteps(1:nele-1),rastersteps(nele-1)+1] - $
	   rastersteps(0:nele-1)
	jump_rst = WHERE(sweep_rst GE 1,nmax_rst)
	IF nmax_rst GT 0 THEN jump_rst = jump_rst + 1

; look for chopper plateaus
        IF MAX(step) GT 1 THEN is_chopped = 1 ELSE  is_chopped = 0 
	IF is_chopped THEN $
	get_nchoppsweep, step, nchopp, ind_sweep_step, rpchopstep, in_plat_pos
 
; look for raster positions
        jump_rst0 = 0
	FOR irast=0L, nmax_rst-1 DO BEGIN 
	  ;;indrst = where(rastersteps EQ irast)
	  nsubrst = jump_rst(irast) - jump_rst0
	  indrst = LINDGEN(nsubrst) + jump_rst0
 
	  IF is_chopped AND irast LT (nmax_rst-1) THEN BEGIN
           ;check RPID jumps unsinchronized with chopper jumps
	   ind_choprst = WHERE(ind_sweep_step EQ jump_rst(irast),nchprst) 
           IF nchprst EQ 0 THEN $ 
	      rpchopstep(jump_rst(irast)+1:*) = $
	      rpchopstep(jump_rst(irast)+1:*)+ 1            
          ENDIF	
	   ; if not chopping -> set in_plat_pos = positions within a raster
	  IF NOT is_chopped THEN in_plat_pos(indrst) = LINDGEN(nsubrst)+1  
	   
	  jump_rst0 = jump_rst(irast)   
	ENDFOR
	
	sweep = [rpchopstep(1:nele-1),rpchopstep(nele-1)+1] - $
	   rpchopstep(0:nele-1)
	jump = WHERE(sweep GE 1)

RETURN
END	

