;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
PRO GET_SCPDISC, TMPDATA, SCP_DISC, ENCODE_FLAG=encode_flag

;+
; NAME:
;	GET_SCPDISC
;
; PURPOSE:
;	Get a flag array corresponding to the chopper plateaus which are 
;	discarded according to the actual variables in the common block
;	phtacc.
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       GET_SCPDISC, Tmpdata, Scp-disc
;
; INPUTS:
;       Tmpdata: A PHT-SCP temporary structure
;
; OUTPUTS:
;       Scp_disc: A flag array (same dimensions as phtscp.aver) with flag=1
;	          for all discarded signals
;
; COMMON BLOCKS:
; 	phtacc
;
; KEYWORD INPUT:
;	Encode_flag:	Put info on bitflag system
;
; PROCEDURES USED:
;	None
;
; MODIFICATION HISTORY:
;       Written by:	Carlos Gabriel (ESA/ESTEC-SAI)
;	Oct 95 Version 3.5
;	Bad flagged if tmpdata.FLAG > 1 (CG)		January 1996 
;	Bug for individual selection fixed (CG)		September 1997
;	V6.5
;	Bitflag system change (CG)			May 1999
;	V7.4
;-
@phtacc

; Check number of parameters


        ON_ERROR, 2

;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  GET_SCPDISC, tmpdata, scpdisc'

; Copy into variables to avoid problem with 1-element 'arrays' in structures

	aver = tmpdata.aver
	

; Fill scp_disc with discarded chopper plateaux

	nchp = tmpdata.dims
	dim1 = n_elements(aver(*,0))
	scp_disc = intarr(dim1,nchp)

; Check deselected chopper plateaux 
        restxt = ''
	
	IF scpnacc(0) GT 0 AND nchp LE N_ELEMENTS(scpnacc) THEN BEGIN
	   restxt = '# Chopper plateaux <= discarded:  selection canceled'
	   scpnacc = 0
	ENDIF  	

	mincp = mincp(0)
	maxcp = maxcp(0)

	IF mincp GE nchp THEN BEGIN
	   restxt = string([byte(restxt),10b,13b])+$
	 'First Chopper Plateau to be taken > Last found:  selection canceled'
	   mincp = 0
	ENDIF  	

	IF maxcp GT nchp THEN BEGIN
	   restxt = string([byte(restxt),10b,13b])+$
	 'Last Chopper Plateau to be taken > Last found:  selection canceled'
	   maxcp = 0
	ENDIF  	

	indwhr = WHERE(anycp GT nchp, nl)

	IF nl NE 0 THEN BEGIN
	   restxt = string([byte(restxt),10b,13b])+$
	 '>= 1 chopper plateau to be discarded > Last found:  selection canceled'
	   anycp = 0
	ENDIF  	
	

; now compute scp_disc
	
; Taken out corresponding to introduction of bitflag system
;	FOR i=0,dim1-1 DO BEGIN
;	  srddisc = WHERE(flag(i,*) GT 1, ncount)
;	  IF ncount gt 0 THEN scp_disc(i,srddisc) = 1
;	ENDFOR

	IF scpnacc(0) NE 0 THEN $
	   scp_disc(*,scpnacc-1) = 1


	IF mincp gt 0 THEN scp_disc(*,0:mincp-1) = 1
	IF maxcp gt 0 THEN scp_disc(*,maxcp-1:nchp-1) = 1
	IF anycp(0) gt 0 THEN scp_disc(*,anycp-1) = 1

	IF restxt NE '' THEN $
		XDISPLAYFILE, "", $
		TITLE = "Warning ", $
		WIDTH = 60, $
		HEIGHT = 6, $
		TEXT = [restxt]
		
	
	IF KEYWORD_SET(encode_flag) THEN BEGIN
	 encode_piaflag, 'SCP', 'GENDISC', tmpdata.flag, tmpflag, $
	 	scp_disc, det=tmpdata.det, /ALLPIX
	 tmpdata.flag = tmpflag
	ENDIF 

	RETURN
	END



