;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
PRO GET_SIGDISC, TMPDATA, SIG_DISC, RASTSTEPS, RPCHOPSTEP, $
   ENCODE_FLAG = ENCODE_FLAG

;+
; NAME:
;	GET_SIGDISC
;
; PURPOSE:
;	Get a flag array corresponding to the signals which are discarded
;	according to the actual variables in the common block phtacc. 
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       GET_SIGDISC, Tmpdata, Sig_disc [,Raststeps, Rpchopstep] 
;
; INPUTS:
;       Tmpdata: A PHT-SRD temporary structure
;
; OUTPUTS:
;       Sig_disc:   A flag array (same dimensions as phtsrd.slop) with flag=1
;		    for all discarded signals
;	Raststeps:  An array with consecutive raster positions (as output from
;		    get_rastersteps)
;	Rpchopstep: An array with consecutive raster-chopper combinations (as
;		    output of get_rpchopstep)
;
; KEYWORDS:
;	ENCODE_FLAG: select if tmpdata.flag is changed with the flag encoded
;
; COMMON BLOCKS:
;	phtacc
;	rp_limits
;
; PROCEDURES USED:
;	None
;
; MODIFICATION HISTORY:
;       Written by:	Carlos Gabriel
;	Oct 95 Version 3.5
;	Bug with last point fixed (CG)		December 1995
;	Long variables for loops (CG)		January 1996
;	Extension for discarding signals per raster point,
;	output extension (CG)			September 1997
;	V6.5  
;	Extension for discarding ch.pl. portions (CG)	January 1998
;	V7.0
;	Update (JA+CG)					May 1999
;	V7.4
;-
@phtacc
COMMON rp_limits, rp_limits

; Check number of parameters


        ON_ERROR, 2

;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  GET_SIGDISC, tmpdata, sigdisc [,raststeps, rpchopsteps]'

	get_rastersteps, tmpdata.rpid, raststeps, time=tmpdata.stim, rpflag, $
	  /in_rast, in_rast_pos
	get_rpchopstep, raststeps, tmpdata.step, rpchopstep, in_plat_pos

	ntot = tmpdata.sldi

; Check deselected ramps 
        restxt = ''
	minsig = minsig(0)
	maxsig = maxsig(0)

	
	IF max(in_plat_pos) LE N_ELEMENTS(signacc) THEN BEGIN
	   restxt = 'Ramps per chopper plateau < discarded:  selection canceled'
	   signacc = 0
	ENDIF  	

	IF minsig-1 GE ntot THEN BEGIN
	   restxt = string([byte(restxt),10b,13b])+$
		'First Ramp to be taken > last meas ramp:  selection canceled'
	   minsig = 0
	ENDIF  	

	IF maxsig GE ntot THEN BEGIN
	   restxt = string([byte(restxt),10b,13b])+$
		'Last Ramp to be taken > last meas ramp:  selection canceled'
	   maxsig = 0
	ENDIF  	

; Fill sig_disc with discarded signals

	dim1 = n_elements(tmpdata.slop(*,0))
	sig_disc = intarr(dim1,ntot)

	; flags from ERD level will be now different
	;FOR i=0L,dim1-1 DO BEGIN
	;   erddisc = WHERE(tmpdata.flag(i,*) GT 1, ncount)
	;   IF ncount gt 0 THEN sig_disc(i,erddisc) = 1
	;ENDFOR

	IF sig1acc THEN BEGIN
	   inddis1 = WHERE (in_plat_pos eq 1)
	   sig_disc(*,inddis1) = 1
	ENDIF

	FOR i=0L,N_ELEMENTS(signacc)-1 DO BEGIN
	   inddisc = WHERE(in_plat_pos EQ signacc(i), ncount)
	   IF ncount gt 0 THEN sig_disc(*,inddisc) = 1
	ENDFOR

	IF minsig gt 0 THEN sig_disc(*,0:minsig-1) = 1
	IF maxsig gt 0 THEN sig_disc(*,maxsig:ntot-1) = 1

	IF (N_ELEMENTS(anysig) GT 1 or anysig(0) NE 0) THEN BEGIN
		IF max(anysig) LE N_ELEMENTS(sig_disc(0,*)) THEN BEGIN
			sig_disc(*,anysig-1) = 1
			PRINT, 'GET_SIGDISC: Individual signals are discarded'
		ENDIF
	ENDIF

; discard fractions per ch.plateau
	   norm_inp = (FLOAT(in_plat_pos) / MAX(in_plat_pos)) - 0.01 
	IF MAX(raststeps) GT 1 OR max(rpchopstep) EQ 1 THEN BEGIN
	   ind = WHERE(norm_inp LT sigtnacc.star_meas, ncount)
	   IF ncount GT 0 THEN sig_disc(*,ind) = 1
	ENDIF ELSE BEGIN
	   ind = WHERE(norm_inp LT sigtnacc.chop_meas, ncount)
	   IF ncount GT 0 THEN sig_disc(*,ind) = 1
	ENDELSE
	   
	
; discard per raster point if raster measurement
	IF max(tmpdata.rpid) GT 1 THEN $
	 IF N_ELEMENTS(rp_limits) GT 0 THEN $
	   IF max(rp_limits) GT 0 THEN BEGIN
	      ind = WHERE(in_rast_pos GE rp_limits(0) AND $
	                  in_rast_pos LE rp_limits(1), count)
	      IF count GT 0 THEN sig_disc(*,ind) = 1
	   ENDIF 
		
		
	IF KEYWORD_SET(ENCODE_FLAG) THEN BEGIN
	   encode_piaflag, 'SRD', 'GENDISC', tmpdata.flag, tmpflag, sig_disc, $ 
	     DET=tmpdata.det,/ALLPIX
	   tmpdata.flag = tmpflag  
	ENDIF 	
		
	IF restxt NE '' THEN $
		XDISPLAYFILE, "", $
		TITLE = "Warning ", $
		WIDTH = 60, $
		HEIGHT = 6, $
		TEXT = [restxt]

	RETURN
	END



