;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	GET_SYSDATE
; PURPOSE:
;	Return the current date in YYYY-MM-DD format.  This is the format
;	required by the DATE keywords in a FITS header (Y2K compliant)
;
; CALLING SEQUENCE:
;	GET_SYSDATE, sysdate
; INPUTS:
;	None
; OUTPUTS:
;	sysdate = A ten character scalar string specifying the year followed 
;		  by the current month (1-12) and the current day 
;		  (eg "1999-03-27")
;
; EXAMPLE:
;	Add the current date to the DATE keyword in a FITS header,h
;     
;	IDL> GET_SYSDATE, sysdate
;	IDL> addpar2hdr, h, 'DATE', sysdate
;
; REVISION HISTORY:
;	Written      by WMT/DIAS	Feb 1996
;	Y2K Compliance (CG)		Jun 1999
;	V7.4
;-
pro get_sysdate, sysdate
 On_error,2

 if N_params() LT 1 then begin
     print,'Syntax - Get_sysdate, sysdate'
     print,'  sysdate - 10 character output string giving current date'
     return
 endif

; Write out the date
    monthstr = ['JAN', 'FEB', 'MAR', 'APR', 'MAY', 'JUN', 'JUL', 'AUG', $
  	 'SEP', 'OCT', 'NOV', 'DEC']
    monthseq = ['01', '02', '03', '04', '05', '06', '07', '08', $
  	 '09', '10', '11', '12']
    sdate = systime()
    monthind = where(monthstr eq strupcase(strmid(sdate, 4, 3)))
    sysdate = strmid(sdate, 20, 4) + '-' + monthseq(monthind(0)) + '-' + $
         strmid(sdate, 8, 2)

 return
 end
