;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO GET_WHEELS, MEASNAME, WHEELS, MEAST, DR, INTT
;+
; NAME:
;	GET_WHEELS
;
; PURPOSE:
;	Get the wheels positions corresponding to tmpdata from the 
;	Compact Status structure. Get also measurement time, number
;	of destructive read-outs per chopper cycle and integration time
;	on the capacitor.
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       GET_WHEELS, Measname, Wheels, Meast, Dr, Intt
;
; INPUTS:
;       Measname: A PHT measurement name (admn)
;
; OUTPUTS:
;       Wheels: A 3 array containing the wheel positions (absolute order)
;	Meast:	Measurement time
;	Dr:	Number of destructive read-outs
;	Intt:	Integration time 
;
; COMMON BLOCKS:
;	phtcs
;
; PROCEDURES USED:
;	PIA LIB: read_cs
;
; MODIFICATION HISTORY:
;       Written by:	Carlos Gabriel
;	Oct 95 Version 3.5
;-
@phtcs

; Check number of parameters


        ON_ERROR, 2

;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 2 THEN MESSAGE, $
          'Syntax:  GET_WHEELS, measname, wheels, [meast], [dr], [intt]'

; - change -> shape4
	psta_file='PSTA'+strmid(measname,4,8)+'.FITS'
	read_cs,psta_file,header,csun

	handle_value, phtcs(csun).handle, cst

 	subsys=['P1','P2','P3','SL','NN', 'NN','C1','C2']

;calculate index
	subs = subsys(cst.subs)

	index_arr = WHERE(subs EQ strmid(measname,0,2),count)

  	IF count GT 0 THEN in = index_arr(fix(strmid(measname,2,2))) $
		ELSE MESSAGE, /INFO, 'Corresponding CS not found'

        wheels = [cst.c1ps(in),cst.c2ps(in),cst.c3ps(in)] 
	meast = 2 ^ cst.meat(in)
        dr = 2 ^ cst.ndr(in)
	intt = 2. ^ (7 - cst.intt(in)) 
	RETURN
	END
