;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	FUNCTION GGT, n, m
;+
; NAME:
;	GGT
;
; PURPOSE:
;	This function calculates largest common divisor of two numbers.
;
; CATEGORY:
;	General Mathematics
;
; CALLING SEQUENCE:
;	Result = GGT(N,M)
;
; INPUTS:
;	N, M:	Two numbers of which the LCD is required
;
; OUTPUTS:
;	RESULT:	The largest common divisor of N and M.
;
; PROCEDURES USED:
;	None
;
; MODIFICATION HISTORY:
;	Written by:	D. Skaley
;	Oct 95 Version 3.5
;	Avoiding endless loop (CG)		December 1995
;
;-

; Avoid endless loop for n=0 or m=0 
	IF n EQ 0. or m EQ 0. THEN $
		MESSAGE, /info, 'Warning: trying a common divisor of n and 0' 
	IF n EQ 0. THEN n = m
	IF m EQ 0. THEN m = n

	nn = n
	mm = m
	WHILE(nn NE mm) DO IF nn GT mm THEN nn=nn-mm ELSE mm=mm-nn
	RETURN, nn
	END
