;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	GIVE_CS
;
; PURPOSE:	
;	Bring back CS data from phtcs and determine
;	corresponding record to tmpdata 
;
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;	GIVE_CS, tmpdata, cst, record, [conv_cst,] error=error
;
; INPUT PARAMETERS:
;	tmpdata: A valid PHT IA measurement structure (ERD, SRD, ...)  
;
; OUTPUT:
;	cst: 	unconverted compact status structure (as under phtcs.handle)
;	record:	record corresponding to tmpdata within the CS structure
;	conv_cst: converted compact status structure	 
;
; OUTPUT KEYWORDS:
;	error: 1 if output invalid
;
; RESTRICTIONS:   tmpdata must be a valid PHT IA real or dynamical structure
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phtcs
;
; MODIFICATION HISTORY:
;	Written by: C. Gabriel (ESA/VILSPA)		May 1997
;	V6.3
;	Conv_cst added as optional output (CG)		July 1997
;	V6.4
;	Reading CSfile if not in buffer (CG)		June 1999
;	V7.4
;	Avoiding crash if CS file had to be read (CG)	August 1999
;	V8.0	
;-
PRO GIVE_CS, tmpdata, cst, record, cst_conv, error=error

@phtcs
	ON_ERROR, 2

	error = 1
	indcs = WHERE(phtcs.unit EQ STRMID(tmpdata.admn,4,8), count)
	IF count EQ 0 THEN BEGIN
; Read the Compact Status if necessary or get the unit 
		csfile = 'PSTA'+strmid(tmpdata.admn,4,8)+'.FITS'
		read_cs, csfile, cshdr, cslun
		IF cslun EQ -1 THEN BEGIN
	  		MESSAGE, /INFO, 'CS not found, returning'
	  		RETURN
		ENDIF ELSE indcs = cslun
	ENDIF
	conv_cs, phtcs(indcs(0)), convcs
	handle_value, convcs.handle, cst_conv
	one_let = STRMID(tmpdata.det, 0,1)
	IF one_let EQ 'S' THEN nlets = 1 ELSE nlets = 2
	index_arr= WHERE(STRMID(cst_conv.subs,0,nlets) EQ $
			 STRMID(tmpdata.det, 0, nlets), count)
	IF count EQ 0 THEN BEGIN
	  MESSAGE, /INFO, 'Problems in CS, returning'
	  RETURN
	ENDIF

	record = index_arr(fix(STRMID(tmpdata.admn,2,2)))
	handle_value, phtcs(indcs(0)).handle, cst
	error = 0
	
	RETURN
	END

