;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_AALEVEL
;
; PURPOSE:
;	Astrophysical Applications Menu for PIA.
;	This is a display dependant level menu in the PIA hierarchy.
;
;	This routine should only be called by the PIA display menues
;	and should not be called directly from the command line.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_AALEVEL, GROUP=group
;	
; KEYWORD PARAMETERS:
;	GROUP:	The group leader of the widget hirarchy
;		
; PROCEDURES USED:
;	PIA LIB:
;		pia_mapw
;		pia_multi_aap
;		pia_multmeas_choice
;		pia_showstr
;		pia_xplot
;       INTERNAL:
;		pia_aalevel_event
;
; COMMON BLOCKS:
;	pia_aalevel_cmn	for internal use
;	
; MODIFICATION HISTORY:
;	Written by C.Gabriel (ESA/ESTEC-SAI)		April 1995
;	Oct 95 Version 3.5
;	Spectrophotometry case added	(CG)		October 1995
;	Multi-aperture, multi-filter, general listing &
;	  correlation structure added (CG)		January 1996
;	Returning silently if meas.choice cancelled (CG)January 1996
;	Simple polarimetry case added (CG)		February 1996
;	Bug fixed (polar ID and polarization degree 
;		not present in Show str) (CG)		February 1996
;	Call to pia_multmeas for summary (bug fixed)	March 1996
;	Colour correction possibility included (CG)	May 1997
;	V6.3
;	Colour correction extended to medians and 
;	 quartiles (CG)					September 1997
;	V6.5
;	Small graphical change (CG)			October 1997
;	V6.6
;	Summary/Print in table format added (CG)	April 2000
;	V8.2 
;	SuperFits writing I/F added (CG)		May 2000
;	V9.0
;-

; ****************************************************************************
;  Event handling routine for PIA Astrophysical Applications menu
; ****************************************************************************

PRO pia_aalevel_event, event
COMMON pia_aalevel_cmn, aachoice
@phtaap
@colour_indices
COMMON PIA_SELECT_PIXELS_CMN, pixselect
                                                                 
	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue OF

	  'CHOICE': aachoice = event.value

          'ACCEPT': BEGIN

		CASE 1 of

		   aachoice EQ 0 or aachoice EQ 1: BEGIN
			pia_multmeas_choice, 'AAP', meas
			IF meas(0) EQ 0 THEN RETURN

			pixels = 1
			c1_pixind=0
			c2_pixind=0

			ind= WHERE(STRMID(phtaap(meas).admn,0,2) EQ 'C2',nc2)
			IF nc2 GT 0 THEN BEGIN
				pixels = 4
				pia_select_pixels, pixels, det='C200'
				C2_pixind = WHERE(pixselect EQ 1)
			ENDIF
			
			ind= WHERE(STRMID(phtaap(meas).admn,0,2) EQ 'C1',nc1)
			IF nc1 GT 0 THEN BEGIN
				pixels = 9
				pia_select_pixels, pixels, det='C100'
				C1_pixind = WHERE(pixselect EQ 1)
			ENDIF
				
			
			pia_multi_aap, meas, aapstr, C1_pixel=C1_pixind, $
						     C2_pixel=C2_pixind
		
			overplot = 0
			
			PIA_CC_DEFIN, ccstr, /overpl
			
			IF (ccstr.corr) THEN BEGIN
			   overplot = ccstr.oplot
			   cc_txt = ['Color corrections factors',$
			          '=========================',' ', $
			          'Typ: '+ccstr.typ+ '     Value: ' + $
			          STRTRIM(ccstr.value,2), ' ']
			          
			   FOR i=0,N_ELEMENTS(aapstr)-1 DO BEGIN
			     get_cc, aapstr(I).FILT_ID, ccstr.typ, $
			       ccstr.value, cc_val, error=error
			     
			     IF NOT ERROR THEN BEGIN
				cc_txt = [cc_txt,$
				 AAPSTR(I).FILT_ID + ':   ' + $
				 STRTRIM(cc_val,2)]
				 
				aapstr(i).mnfl = aapstr(i).mnfl / cc_val
				aapstr(i).mnfu = aapstr(i).mnfu / cc_val
				aapstr(i).mnbr = aapstr(i).mnbr / cc_val
				aapstr(i).mnbu = aapstr(i).mnbu / cc_val
				aapstr(i).mdfl = aapstr(i).mdfl / cc_val
				aapstr(i).q1fl = aapstr(i).q1fl / cc_val
				aapstr(i).q3fl = aapstr(i).q3fl / cc_val
 				aapstr(i).mdbr = aapstr(i).mdbr / cc_val
				aapstr(i).q1br = aapstr(i).q1br / cc_val
				aapstr(i).q3br = aapstr(i).q3br / cc_val
 			     ENDIF ELSE BEGIN
			        PRINT, aapstr(i).filt_ID + $
			         ' could not be corrected'
				cc_txt = [cc_txt,$
				 AAPSTR(I).FILT_ID + ':   ERROR'] 
			         
			     ENDELSE
			   ENDFOR
			   cctxt = 'Colour corrected '
			   PIA_DISP_PRINT_FILE, '',$
			     TITLE='Colour correction factors used', $
			     TEXT=cc_txt
			ENDIF ELSE cctxt = ''

			IF aachoice EQ 0 THEN BEGIN
			 PIA_XPLOT, aapstr.lambda, aapstr.mnfl, aapstr.mnfu, $
				TITLE=cctxt+'Multi-filter Plot', $
				XTITLE=' Lambda ',$
				YTITLE='Mean Flux    [Jy]', LEGEND=ytitle,$
				psym=4, overplot=overplot
			 text = ["     Multi-Filter info", $
			 	 "     =================", $
			  "FiltID | C. Wavel. |   "+$
			  "Flux  +/-  unc  [Jy] |   Meas.     "]
			 FOR I=0,N_ELEMENTS(aapstr)-1 DO BEGIN
			   decode_admn, aapstr(i).admn, decadm
			   Line = $
			    STRING(format='(a7,3x,f6.2,3x,e11.4,1x,e9.2,4x,a35)',$ 
			     aapstr(i).filt_id,aapstr(i).lambda,aapstr(i).mnfl, $
			     aapstr(i).mnfu, decadm)
			  
			    text = [text, line]      
			 ENDFOR
			ENDIF ELSE BEGIN
			 PIA_XPLOT, aapstr.lambda, aapstr.mnbr, aapstr.mnbu, $
				TITLE=cctxt + 'Multi-filter Plot', $
				XTITLE=' Lambda ',overplot=overplot, $
				YTITLE='Mean Brightness [MJy/sr]', $
				LEGEND=ytitle, psym=4
			 text = ["     Multi-Filter info", $
			 	 "     =================", $
			  "FiltID | C. Wavel. |  "+$
			  "Brightness +/-  unc [MJy/sr] |   Meas.     "]
			 FOR I=0,N_ELEMENTS(aapstr)-1 DO BEGIN
			   decode_admn, aapstr(i).admn, decadm
			   Line = $
			    STRING(format='(a7,3x,f6.2,4x,e11.4,3x,e9.2,5x,a35)',$ 
			     aapstr(i).filt_id,aapstr(i).lambda,aapstr(i).mnbr, $
			     aapstr(i).mnbu, decadm)
			  
			    text = [text, line]      
			 ENDFOR
			ENDELSE
			PIA_DISP_PRINT_FILE, '',$
			     TITLE='Summary on Multi_filter ', $
			     TEXT=text
			END
			
		   aachoice EQ 2 or aachoice EQ 3: BEGIN
			pia_multmeas_choice, 'AAP', meas
			IF meas(0) EQ 0 THEN RETURN
			c1_pixind=0
			c2_pixind=0

			ind= WHERE(STRMID(phtaap(meas).admn,0,2) EQ 'C2',nc2)
			IF nc2 GT 0 THEN BEGIN
				pixels = 4
				pia_select_pixels, pixels, det='C200'
				C2_pixind = WHERE(pixselect EQ 1)
			ENDIF
			
			ind= WHERE(STRMID(phtaap(meas).admn,0,2) EQ 'C1',nc1)
			IF nc1 GT 0 THEN BEGIN
				pixels = 9
				pia_select_pixels, pixels, det='C100'
				C1_pixind = WHERE(pixselect EQ 1)
			ENDIF
				
			
			pia_multi_aap, meas, aapstr, C1_pixel=C1_pixind, $
						     C2_pixel=C2_pixind


			multi_apert_norm, aapstr, apert_str, ERROR=error, $
				MESS=mess
			
			IF ERROR THEN BEGIN 
			  txt = 'Special P04 procedure NOT running'
			  MESSAGE, /INFO, text
			  MESSAGE, /INFO, mess
			  p04_sp = 0
			ENDIF ELSE $
			  p04_sp=1
			  
		        overplot = 0
			PIA_CC_DEFIN, ccstr, /overpl
			
			IF (ccstr.corr) THEN BEGIN
			   overplot = ccstr.oplot
			   FOR i=0,N_ELEMENTS(aapstr)-1 DO BEGIN
			     get_cc, aapstr(I).FILT_ID, ccstr.typ, $
			       ccstr.value, cc_val, error=error
			     IF NOT ERROR THEN BEGIN
				aapstr(i).mnfl = aapstr(i).mnfl / cc_val
				aapstr(i).mnfu = aapstr(i).mnfu / cc_val
				aapstr(i).mnbr = aapstr(i).mnbr / cc_val
				aapstr(i).mnbu = aapstr(i).mnbu / cc_val
				aapstr(i).q1fl = aapstr(i).q1fl / cc_val
				aapstr(i).q3fl = aapstr(i).q3fl / cc_val
 				aapstr(i).mdbr = aapstr(i).mdbr / cc_val
				aapstr(i).q1br = aapstr(i).q1br / cc_val
				aapstr(i).q3br = aapstr(i).q3br / cc_val
			     ENDIF ELSE $
			        PRINT, aapstr(i).filt_ID + $
			         ' could not be corrected'
			   ENDFOR
			   cctxt = 'Colour corrected '
			ENDIF ELSE cctxt = ''

			IF aachoice EQ 2 THEN BEGIN
			 PIA_XPLOT, aapstr.area, aapstr.mnfl, aapstr.mnfu, $
				TITLE=cctxt+'Multi-aperture Plot', psym=4, $
				XTITLE=' Area  [mm^2]', $
				YTITLE='Mean Flux   [Jy]', LEGEND=ytitle, $
				OVERPLOT=overplot 
			 text = ["     Multi-Aperture info", $
			 	 "     ===================", $
			  "FiltID |   Area  |   "+$
			  "Flux  +/-  unc  [Jy] |   Meas.     "]
			 FOR I=0,N_ELEMENTS(aapstr)-1 DO BEGIN
			   decode_admn, aapstr(i).admn, decadm
			   Line = $
			    STRING(format='(a7,3x,f6.2,5x,e9.2,2x,e8.1,4x,a28)',$ 
			     aapstr(i).filt_id,aapstr(i).area,aapstr(i).mnfl, $
			     aapstr(i).mnfu, decadm)
			  
			    text = [text, line]      
			 ENDFOR
			 
			ENDIF ELSE BEGIN
			 PIA_XPLOT, aapstr.area, aapstr.mnbr, aapstr.mnbu, $
				TITLE=cctxt+'Multi-aperture Plot', psym=4, $
				XTITLE=' Area  [mm^2]', $
				YTITLE='Mean Brightness [MJy/sr]', $
				LEGEND=ytitle, overplot=overplot
			 text = ["     Multi-Aperture info", $
			 	 "     ===================", $
			  "FiltID |   Area    |  "+$
			  "Brightness +/-  unc [MJy/sr] |   Meas.     "]
			 FOR I=0,N_ELEMENTS(aapstr)-1 DO BEGIN
			   decode_admn, aapstr(i).admn, decadm
			   Line = $
			    STRING(format='(a7,3x,f6.2,6x,e9.2,4x,e8.1,5x,a28)',$ 
			     aapstr(i).filt_id,aapstr(i).area,aapstr(i).mnbr, $
			     aapstr(i).mnbu, decadm)
			  
			    text = [text, line]      
			 ENDFOR
			ENDELSE
			IF p04_sp THEN BEGIN
			 PIA_XPLOT, aapstr.area, apert_str.rel_sig, $
			 	apert_str.rel_usig, $
				TITLE=cctxt+'Multi-aperture relative Plot', psym=4, $
				XTITLE=' Area  [mm^2]', $
				YTITLE='Relative signal (to 180")', LEGEND=ytitle, $
				OVERPLOT=overplot 
 			 sptext = ["  Special Multi-Aperture info", $
			 	   "  ===========================", $
			  "Area [mm^2] | Srcsig +/- unc [V/s] | "+$
			  "Rel.sig +/- unc | Bckg  +/- unc. | S/N  "]
			  FOR I=0,N_ELEMENTS(aapstr)-1 DO BEGIN
			   Line = $
			    STRING(format='(f6.2, 8x, 2(f6.2,4x), 4x, 4(f6.3,2x), 1x, f7.1)',$ 
			     aapstr(i).area,apert_str(i).src_sig,  $
			     apert_str(i).src_usig,  $
			     apert_str(i).rel_sig,  $
			     apert_str(i).rel_usig,  $
			     apert_str(i).bck_all,  $
			     apert_str(i).ubck_all,  $
			     apert_str(i).s_to_n)
			  
			    sptext = [sptext, line]  
			    
			  ENDFOR
			    text = [text, ' ', ' ', sptext]    
			 ENDIF
			PIA_DISP_PRINT_FILE, '',$
			     TITLE='Summary on Multi_Aperture ', $
			     TEXT=text

			END
		   
		   aachoice EQ 4: pia_specphot

		   aachoice EQ 5: pia_mapw

		   aachoice EQ 6 or aachoice EQ 7: BEGIN
			pia_multmeas_choice, 'AAP', meas
			IF meas(0) EQ 0 THEN RETURN
			c1_pixind=0
			c2_pixind=0

			ind= WHERE(STRMID(phtaap(meas).admn,0,2) EQ 'C2',nc2)
			IF nc2 GT 0 THEN BEGIN
				pixels = 4
				pia_select_pixels, pixels, det='C200'
				C2_pixind = WHERE(pixselect EQ 1)
			ENDIF
			
			ind= WHERE(STRMID(phtaap(meas).admn,0,2) EQ 'C1',nc1)
			IF nc1 GT 0 THEN BEGIN
				pixels = 9
				pia_select_pixels, pixels, det='C100'
				C1_pixind = WHERE(pixselect EQ 1)
			ENDIF
				
			
			pia_multi_aap, meas, aapstr, C1_pixel=C1_pixind, $
						     C2_pixel=C2_pixind

		        overplot = 0
			PIA_CC_DEFIN, ccstr, /overpl
			
			IF (ccstr.corr) THEN BEGIN
			   overplot = ccstr.oplot
			   FOR i=0,N_ELEMENTS(aapstr)-1 DO BEGIN
			     get_cc, aapstr(I).FILT_ID, ccstr.typ, $
			       ccstr.value, cc_val, error=error
			     IF NOT ERROR THEN BEGIN
				aapstr(i).mnfl = aapstr(i).mnfl / cc_val
				aapstr(i).mnfu = aapstr(i).mnfu / cc_val
				aapstr(i).mnbr = aapstr(i).mnbr / cc_val
				aapstr(i).mnbu = aapstr(i).mnbu / cc_val
				aapstr(i).q1fl = aapstr(i).q1fl / cc_val
				aapstr(i).q3fl = aapstr(i).q3fl / cc_val
 				aapstr(i).mdbr = aapstr(i).mdbr / cc_val
				aapstr(i).q1br = aapstr(i).q1br / cc_val
				aapstr(i).q3br = aapstr(i).q3br / cc_val
			     ENDIF ELSE $
			        PRINT, aapstr(i).filt_ID + $
			         ' could not be corrected'
			   ENDFOR
			   cctxt = 'Colour corrected '
			ENDIF ELSE cctxt = ''

			IF aachoice EQ 6 THEN BEGIN
 			 PIA_XPLOT, aapstr.poldeg, aapstr.mnfl, aapstr.mnfu, $
				TITLE=cctxt+'Multi-polarizer Plot', psym=4, $
				XTITLE=' Polarization degree', $
				YTITLE='Mean Flux   [Jy]', LEGEND=ytitle, $
				overplot=overplot
			 text = ["     Multi-Polarizer info", $
			 	 "     ===================", $
			  "FiltID | Polar.angle |  "+$
			  "Flux  +/-  unc  [Jy] |   Meas.     "]
			 FOR I=0,N_ELEMENTS(aapstr)-1 DO BEGIN
			   decode_admn, aapstr(i).admn, decadm
			   Line = $
			    STRING(format='(a7,3x,f6.2,5x,e9.2,2x,e8.1,4x,a35)',$ 
			     aapstr(i).filt_id,aapstr(i).poldeg,aapstr(i).mnfl, $
			     aapstr(i).mnfu, decadm)
			  
			    text = [text, line]      
			 ENDFOR
			ENDIF ELSE BEGIN
			 PIA_XPLOT, aapstr.poldeg, aapstr.mnbr, aapstr.mnbu, $
				TITLE=cctxt+'Multi-polarizer Plot', psym=4, $
				XTITLE=' Polarization degree', $
				YTITLE='Mean Brightness [MJy/sr]', $
				LEGEND=ytitle, overplot=overplot
			 text = ["     Multi-Polarizer info", $
			 	 "     ===================", $
			  "FiltID | Polar.angle |  "+$
			  "Brightness +/- unc  [MJy/sr]|   Meas.     "]
			 FOR I=0,N_ELEMENTS(aapstr)-1 DO BEGIN
			   decode_admn, aapstr(i).admn, decadm
			   Line = $
			    STRING(format='(a7,3x,f6.2,5x,e9.2,2x,e8.1,4x,a35)',$ 
			     aapstr(i).filt_id,aapstr(i).poldeg,aapstr(i).mnbr, $
			     aapstr(i).mnbu, decadm)
			  
			    text = [text, line]      
			 ENDFOR
			ENDELSE 
			PIA_DISP_PRINT_FILE, '',$
			     TITLE='Summary on Multi_Polarizer ', $
			     TEXT=text

			END
		   
		   aachoice EQ 8: BEGIN 
			pia_multmeas_choice, 'AAP', meas
			IF meas(0) EQ 0 THEN RETURN
			valnames = ['Measurement', 'Filter ID', 'Aperture ID',$
			   'Polarizer ID', 'Area', 'Wavelength', 'Pol.degree',$
			   'Mean Flux [Jy]', $
			   'Flux Uncert. [Jy]', 'Mean Brightness [MJy/sr]', $
			   'Brightness Unc. [MJy/sr]', 'Median Flux [Jy]', $
			   'Flux 1st Quantile [Jy]', 'Flux 3rd Quantile [Jy]',$
			   'Median Brightness [MJy/sr]', $
			   'Brightness 1st Quant. [MJy/sr]', $
			   'Brighntess 3rd Quant. [MJy/sr]', $
			   'Right Ascension [degrees]', $
			   'Declination [degrees]', 'Roll angle [degrees]',$
			   'Flag ']
			
			pixels = 1
			c1_pixind=0
			c2_pixind=0

			ind= WHERE(STRMID(phtaap(meas).admn,0,2) EQ 'C2',nc2)
			IF nc2 GT 0 THEN BEGIN
				pixels = 4
				pia_select_pixels, pixels, det='C200'
				C2_pixind = WHERE(pixselect EQ 1)
			ENDIF
			
			ind= WHERE(STRMID(phtaap(meas).admn,0,2) EQ 'C1',nc1)
			IF nc1 GT 0 THEN BEGIN
				pixels = 9
				pia_select_pixels, pixels, det='C100'
				C1_pixind = WHERE(pixselect EQ 1)
			ENDIF
				
			
			WIDGET_CONTROL, event.top, /hourglass
			pia_multi_aap, meas, aapstr, C1_pixel=C1_pixind, $
						     C2_pixel=C2_pixind

			WIDGET_CONTROL, event.top, /hourglass

			PIA_CC_DEFIN, ccstr
			
			IF (ccstr.corr) THEN BEGIN
			   FOR i=0,N_ELEMENTS(aapstr)-1 DO BEGIN
			     get_cc, aapstr(I).FILT_ID, ccstr.typ, $
			       ccstr.value, cc_val, error=error
			     IF NOT ERROR THEN BEGIN
				aapstr(i).mnfl = aapstr(i).mnfl / cc_val
				aapstr(i).mnfu = aapstr(i).mnfu / cc_val
				aapstr(i).mnbr = aapstr(i).mnbr / cc_val
				aapstr(i).mnbu = aapstr(i).mnbu / cc_val
				aapstr(i).q1fl = aapstr(i).q1fl / cc_val
				aapstr(i).q3fl = aapstr(i).q3fl / cc_val
 				aapstr(i).mdbr = aapstr(i).mdbr / cc_val
				aapstr(i).q1br = aapstr(i).q1br / cc_val
				aapstr(i).q3br = aapstr(i).q3br / cc_val
			     ENDIF ELSE $
			        PRINT, aapstr(i).filt_ID + $
			         ' could not be corrected'
			   ENDFOR
			ENDIF 

			pia_showstr, aapstr, GROUP=event.top, VALNAMES=valnames

		     END

		   aachoice EQ 9: BEGIN 

			pia_multmeas_choice, 'AAP', meas
			IF meas(0) EQ 0 THEN RETURN
			WIDGET_CONTROL, event.top, /hourglass

			indns = WHERE(STRMID(phtaap(meas).admn,0,1) NE 'S',nns)

			IF nns NE 0 THEN BEGIN
			 PIA_CC_DEFIN, ccstr			
			 IF not (ccstr.corr) THEN ccstr=0
			ENDIF ELSE ccstr=0
			  
						
			WIDGET_CONTROL, event.top, /hourglass
			photom_init, meas, text, fname, colcor=ccstr
			
			WIDGET_CONTROL, event.top, /hourglass
			PIA_DISP_PRINT_FILE,'', TITLE='Photometry Table',$
				Text=text, font='-*-courier-bold-*-*-*-14-*',$
				Width=90
;			pia_disp_photom, text, fname
	  	   END

		   aachoice EQ 10: BEGIN 

			pia_multmeas_choice, 'AAP', meas
			IF meas(0) EQ 0 THEN RETURN
			WIDGET_CONTROL, event.top, /hourglass

			indns = WHERE(STRMID(phtaap(meas).admn,0,1) NE 'S',nns)

			IF nns NE 0 THEN BEGIN
			 PIA_CC_DEFIN, ccstr			
			 IF not (ccstr.corr) THEN ccstr=0
			ENDIF ELSE ccstr=0
			  
						
			WIDGET_CONTROL, event.top, /hourglass
			photom_reg_table, meas, text, fname, colcor=ccstr
			
			WIDGET_CONTROL, event.top, /hourglass
			PIA_DISP_PRINT_FILE,'', TITLE='Photometry Table',$
				Text=text, font='-*-courier-bold-*-*-*-14-*',$
				Width=90
;			pia_disp_photom, text, fname
	  	   END
		   
		   aachoice EQ 11: BEGIN
			measnames = pickmeas(FTYPE="AAP", /multi,  $
			   posi=posi, GROUP=wd_base)

            		IF measnames(0) EQ '' THEN BEGIN
                		MESSAGE, /INFO, ' No Data selected, returning'
                		RETURN
            		ENDIF

	    		meas = 0L

              		FOR I=0,N_ELEMENTS(measnames) - 1 DO BEGIN
	  			measadd = WHERE(phtaap.admn EQ measnames(I),n)
				meas = [meas,measadd(posi(i))]
	      		ENDFOR
			meas = meas(1:*)
			
			
		   	name = 'Dummy'
			
			list = ["Meas. ID (Det - TDT - Meas. number)", $
			   	"Pixel number", $
			   	"Aperture_Y in arcsec (zero means a circular aperture)", $
				"Aperture_Z in arcsec (diameter if Aperture_Y is zero)", $
				"Wavelength in um", $
				"Uncertainty in wavelength in um", $
				"Mean flux in Jy", $
				"Mean flux uncertainty in Jy", $
				"Median flux in Jy", $
				"Mean brightness in MJy/sr", $
				"Mean brightness uncertainty in MJy/sr", $
				"Median brightness in MJy/sr", $
				"Raster point ID in Y", $
				"Raster point ID in Z", $
				"Declination in degrees", $
				"Right Ascension in degrees", $
				"Roll Angle in degrees", $
				"Flag"]
				
		   	pia_sellist, list, mask, type=" Variables to be used",$
				name=name

			WIDGET_CONTROL, event.top, /hourglass
			write_aap_multi, meas, accvector=mask, filename=name
			
		   END

		   ELSE: MESSAGE, /INFO, 'Not yet implemented'

		ENDCASE

          END

          'CANCEL': BEGIN

                WIDGET_CONTROL, event.top, /DESTROY

          END

       	ENDCASE
	RETURN
END

; ****************************************************************************
;  PIA AALEVEL - Astrophysical Applications menu definition procedure
; ****************************************************************************

PRO pia_aalevel, GROUP=group

COMMON pia_aalevel_cmn, aachoice
COMMON PIA_SELECT_PIXELS_CMN, pixselect

	aabase = WIDGET_BASE(TITLE = 'PIA Astrophysical Applications Menu', $ 
		 		/COLUMN)

	pixselect = [1,1,1,1,1,1,1,1,1]
	aachoice = 0

	stdbut = cw_bgroup(aabase, LABEL_TOP = 'AA Choices', $
			/EXCLUSIVE, /FRAME, $
			SET_VALUE = choice, $
			UVALUE = 'CHOICE', $
			["Multi-Filter Photometry for point sources",$
			 "Multi-Filter Photometry for extended sources", $
			 "Multi-Aperture Photometry for point sources", $
			 "Multi-Aperture Photometry for extended sources", $
			 "Spectro-Photometry ", $
			 "Mapping  ", $
			 "Polarimetry for point sources", $
			 "Polarimetry for extended sources", $
			 "Show/Correlate Mean Values ", $
			 "Summary/Print Values (text format)", $
			 "Summary/Print Values (table format)", $
			 "Write multiple measurements FITS (Super-FITS)" ])

        control = WIDGET_BASE(aabase,/ROW)

        accept = WIDGET_BUTTON(control, VALUE = '  OK  ', $
                        /FRAME, UVALUE = 'ACCEPT')
        junk = WIDGET_LABEL(control, VALUE = '                          ')
        cancel = WIDGET_BUTTON(control, VALUE = '  Cancel  ', $
                        /FRAME, UVALUE = 'CANCEL')

        WIDGET_CONTROL, aabase, /REALIZE, TLB_SET_XOFFSET=150, $
                        TLB_SET_YOFFSET=150

        xMANAGER,No_BLOCK=1, "pia_aalevel", aabase, GROUP=group
	
        RETURN
END

