;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_AAP_BCKSEL
;
; PURPOSE:
;	Menu for performing median filtering and smoothing of data 
;	for obtaining flat field factors from the filtered data. It 
;	includes also the possibility of obtaining directly flat field
;	factors from selected data regions. It returns the filtered, smoothed
;	and/or flat-fielded data.
;	
; CATEGORY:
;	PIA - graphics + processing
;
; CALLING SEQUENCE:
;	PIA_AAP_BCKSEL, mnbr, mnbu, ff_mnbr
;
; INPUT:
;	mnbr:		A 2-dim data array 
;	mnbu:		Uncertainties of mnbr
;
; OUTPUT:
;	ff_mnbr:	The modified array (same dims as mnbr) 
;	
; COMMON BLOCKS:
;	colour_indices
;	pia_dspchz_cmn
;	zoom_discareas
;
; PROCEDURES USED:
;	PIA:
;		ff_bck
;		ff_med_smooth
;		pia_disp_print_file
;		pia_xplot
;	
; MODIFICATION HISTORY:
;	Written by:	Jose Acosta	November 1997
;	Version 6.6
;-

; ****************************************************************************
;  PIA_AAP_BCKSEL
; ****************************************************************************


PRO PIA_AAP_BCKSEL_EVENT, event

@colour_indices
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
COMMON zoom_discareas, d_flags, all_disc_areas


	WIDGET_CONTROL, event.id, GET_UVALUE=action
	WIDGET_CONTROL, event.top, GET_UVALUE=idsa_handle
	handle_value, idsa_handle, idsa 

	psymch = 4
	
	CASE action OF
	  'ALLPIX': BEGIN
	     npix = N_ELEMENTS(idsa.bck_flag(*,0))
	     FOR I=0,npix-1 DO $
	         idsa.bck_flag(I,*) = idsa.bck_flag(idsa.pix,*) 
	         
	     handle_value, idsa_handle, idsa, /SET
	     WIDGET_CONTROL, event.top, SET_UVALUE=idsa_handle
	  END

	  'DSEL': BEGIN
	     WIDGET_CONTROL, idsa.id_pix, GET_VALUE=pix
	     idsa.pix = pix(0)-1
	     data = idsa.data(idsa.pix,*)
	     unc = idsa.unc(idsa.pix,*)
	     flags = idsa.flag(idsa.pix,*)
	     xind = idsa.xdata
	     PIA_XPLOT, xind, data, unc, flagged=flags, $
	           title= 'Discarding data by pixel '+STRTRIM(idsa.pix+1,2),$
		   xtitle='Index',ytitle='Brightness [MJy/sr]',$
		   psym=psymch, /disc_area
	     siz= size(all_disc_areas)
	     IF siz(0) EQ 0 THEN RETURN
	     FOR I=0,N_ELEMENTS(all_disc_areas)-1 DO BEGIN
	       p1 = all_disc_areas(i).pos1
	       p2 = all_disc_areas(i).pos2
	       IF p1(1) NE 0. or p2(1) NE 0. THEN BEGIN
	           ind = WHERE(data GE p1(1) AND $
	     		 data LE p2(1) AND $
			 xind GE p1(0) AND $
			 xind LE p2(0), ndisc)
	           IF ndisc GT 0 THEN $
	               idsa.bck_flag(idsa.pix,ind) = 0
	       ENDIF	  
	      ENDFOR
	     WIDGET_CONTROL, idsa.id_all, /sensitive
	     handle_value, idsa_handle, idsa, /SET
	     WIDGET_CONTROL, event.top, SET_UVALUE=idsa_handle
	  END
	  	     
	  'SEL': BEGIN
	     WIDGET_CONTROL, idsa.id_pix, GET_VALUE=pix
	     idsa.pix = pix(0)-1
	     data = idsa.data(idsa.pix,*)
	     unc = idsa.unc(idsa.pix,*)
	     flags = idsa.flag(idsa.pix,*)
	     xind = idsa.xdata
	     PIA_XPLOT, xind, data, unc, flagged=flags, $
	           title= 'Selecting data by pixel '+STRTRIM(idsa.pix+1,2),$
		   xtitle='Index',ytitle='Brightness [MJy/sr]',$
		   psym=psymch, /disc_area
	     siz= size(all_disc_areas)
	     IF siz(0) EQ 0 THEN RETURN
	     allind = 0
	     FOR I=0,N_ELEMENTS(all_disc_areas)-1 DO BEGIN
	       p1 = all_disc_areas(i).pos1
	       p2 = all_disc_areas(i).pos2
	       IF p1(1) NE 0. or p2(1) NE 0. THEN BEGIN
	           ind = WHERE(data GE p1(1) AND $
	     		 data LE p2(1) AND $
			 xind GE p1(0) AND $
			 xind LE p2(0), ndisc)
	           IF ndisc GT 0 THEN $
	               idsa.bck_flag(idsa.pix,ind) = 1
	       ENDIF
	      ENDFOR
	     WIDGET_CONTROL, idsa.id_all, /sensitive
	     handle_value, idsa_handle, idsa, /SET
	     WIDGET_CONTROL, event.top, SET_UVALUE=idsa_handle
	     ;WIDGET_CONTROL, idsa.id_select, sensitive=0
	  END 

	  'RESET': BEGIN
	     all_disc_areas = -1
	     idsa.flag = idsa.flag * 0
	     handle_value, idsa_handle, idsa, /SET
	     WIDGET_CONTROL, idsa.id_select, /sensitive
	  END
	     
	     
	  'SHOWSEL': BEGIN
	     WIDGET_CONTROL, event.top, /hourglass
	     WIDGET_CONTROL, idsa.id_pix, GET_VALUE=pix
	     pix = pix(0) - 1
	     xind = idsa.xdata
	     title= 'Data: pixel '+STRTRIM(pix+1,2)
	     PIA_XPLOT, xind, idsa.data(pix,*), idsa.unc(pix,*), $
	           title= title,$
		   xtitle='Index',ytitle='Brightness [MJy/sr]',$
		   psym=psymch, legend=title
	     ; plot points with bad flag
	     ind_nval = WHERE(idsa.flag(pix,*) GT 1, nnval)
	     IF nnval GT 0 THEN $
	       PIA_XPLOT, xind(ind_nval), idsa.data(pix,ind_nval),color=red, $
	           psym=7, overplot = 99 
	     ; plot with different symbol and green color the background region
	     ind_bck = WHERE(idsa.bck_flag(pix,*) GT 0,nbck)
	     IF nbck GT 0 THEN $
	       PIA_XPLOT, xind(ind_bck), idsa.data(pix,ind_bck),color=green, $
	         psym=psymch+1,overplot=99	   	    
	  
	  END   	  


	  'CANCEL': BEGIN
	  	idsa.bck_flag = idsa.bck_flag_org 
	        handle_value, idsa_handle, idsa, /SET
	  	WIDGET_CONTROL, event.top, /DESTROY
	  END
	  
	  'ACCEPT': WIDGET_CONTROL, event.top, /DESTROY
	  
	  ELSE:
	ENDCASE
	RETURN
	END
	 

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
PRO PIA_AAP_BCKSEL, time, mnbr, mnbu, bck_reg, flag=flag, SEL_PIX= sel_pix,$
	GROUP_LEADER=group_leader

;	IF Xregistered(PIA_AAP_BCKSEL) THEN RETURN
	
	IF KEYWORD_SET(sel_pix) then BEGIN 
	   pixel = sel_pix 
	   edit_pix = 0
        ENDIF ELSE BEGIN 
           pixel = 0
           edit_pix = 1
        ENDELSE   
	det_pix = N_ELEMENTS(mnbr(*,0)) 
	data = mnbr
	unc = mnbu
	IF N_ELEMENTS(bck_reg) EQ 0 THEN bck_reg = FIX(data*0)
	bck_flag = bck_reg
	IF not KEYWORD_SET(flag) THEN $
	   flag = FIX(data*0)

	IF not KEYWORD_SET(group_leader) THEN group_leader = !pia_top_wid
 	
	base = WIDGET_BASE($
	 TITLE = 'PIA selection of background region for mapping', $
			/COLUMN, GROUP_LEADER=group_leader )

	
	fbase = WIDGET_BASE(base, /COLUMN, /FRAME)
	label = WIDGET_LABEL(fbase, VAL="Graphical Selections")
	rbase = WIDGET_BASE(fbase, /ROW)
	id_select =  WIDGET_BUTTON(rbase,  $
	 VALUE='Add Selected regions ', $
		UVAL="SEL")
	label = WIDGET_LABEL(rbase, VAL="        ")
	id_dselect =  WIDGET_BUTTON(rbase,  $
	 VALUE='Add Discarded regions ', $
		UVAL="DSEL")
	label = WIDGET_LABEL(rbase, VAL="        ")
	id_reset =  WIDGET_BUTTON(rbase,  $
	 VALUE=' Reset ', $
		UVAL="RESET")
	rbase = WIDGET_BASE(fbase, /ROW)
	label = WIDGET_LABEL(rbase, VALUE='Extend to all pixels: ')
	id_all = WIDGET_BUTTON(rbase, VALUE= ' Now ', UVALUE='ALLPIX')
	
	
	rbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(rbase, VALUE='Pixel used for selection:  ')
	id_pix = WIDGET_TEXT(rbase, VALUE=STRTRIM(pixel+1,2), UVALUE='JUNK', $
				XSIZE = 6, EDITABLE=edit_pix)
;       change pixel interactively [TBW]				
	

	fbase = WIDGET_BASE(base, /COLUMN)
	label = WIDGET_LABEL(fbase, VAL="Leaving Background selection")
	rbase = WIDGET_BASE(fbase, /ROW)
	id_shselect = WIDGET_BUTTON(rbase, VALUE=' Show current selection ',$
	            UVALUE ='SHOWSEL')
	id_cancel = WIDGET_BUTTON(rbase, VALUE='    Cancel     ', $
	            UVALUE='CANCEL')
	label = WIDGET_LABEL(rbase, VAL="        ")
	id_accept = WIDGET_BUTTON(rbase, VALUE='Accept changes & Quit', $
	     UVALUE='ACCEPT')

	;WIDGET_CONTROL, id_accept, sensitive=0
	;WIDGET_CONTROL, id_all, sensitive=0
	
	
	idsa = {xdata:time,data:data, unc:unc, flag:flag, bck_flag:bck_flag,  $
		bck_flag_org:bck_flag, pix:pixel, id_pix:id_pix, id_all:id_all, $
		id_accept:id_accept,  $
		id_select:id_select} 
	 
	idsa_handle = handle_create()
	handle_value, idsa_handle, idsa, /SET, /NO_COPY 
	
	WIDGET_CONTROL, base, /realize, SET_UVALUE=idsa_handle
	
	XManager, "pia_aap_bcksel", base

	handle_value, idsa_handle, idsa, /NO_COPY 
	bck_reg = idsa.bck_flag
	
	handle_free, idsa_handle
	
	RETURN
	END	
