;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_AAPVIEW
;
; PURPOSE:
;	User interface to plot 1-dimensional curves of AAP data.
;
; CATEGORY:
;       PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_AAPVIEW, aap, GROUP=group
;
; INPUTS:
;	AAP:		An AAP structure containing data handles.
;
; KEYWORD PARAMETERS:
;	GROUP:		The widget group leader
;
;
; PROCEDURES USED:
;	PIA LIB:
;		PIA_XPLOT
;       INTERNAL:
;		PIA_AAPVIEW_PLOT
;		PRO PIA_AAPVIEW_CLEANUP
;		PRO PIA_AAPVIEW_EVENT
;
; MODIFICATION HISTORY:
;	Written by: D. Skaley, MPIK/Heidelberg		March 1995
;	Oct 95 Version 3.5
;
;-

;*****************************************************************************
; PIA_AAPVIEW_PLOT  -  plot data using PIA_XPLOT
;*****************************************************************************

PRO PIA_AAPVIEW_PLOT, par, OVERPLOT=overplot, GROUP=group

	; restriction to raster points/legs
	HANDLE_VALUE, par.rpid_handle, rpid
	CASE 1 OF
	(par.xraster NE 0 AND par.yraster NE 0): BEGIN
		index = WHERE(	(rpid(0,*) EQ par.xraster) AND $
				(rpid(1,*) EQ par.yraster)    )
		END
	(par.xraster NE 0): BEGIN
		index = WHERE(	(rpid(0,*) EQ par.xraster) )
		END
	(par.yraster NE 0): BEGIN
		index = WHERE(	(rpid(1,*) EQ par.yraster) )
		END
	ELSE:	BEGIN
		index = -1
		END
	ENDCASE

	; get the Y-axis array and name
	HANDLE_VALUE, par.data_handles(par.ynameindex), ydata
	yname = par.data_names(par.ynameindex)
	IF par.ysubindex NE 0 THEN BEGIN
		ydata = ydata(par.ysubindex-1,*)
		yname = yname + "(" + STRCOMPRESS(par.ysubindex) + ")"
	ENDIF

	IF index(0) NE -1 THEN ydata=ydata(index)

	IF par.xnameindex EQ -1 THEN BEGIN	; plot with x-axis = index

		PIA_XPLOT, ydata, GROUP=group, $
			XTITLE=xname, YTITLE=yname, $
			OVERPLOT=overplot, LEGEND=yname

	ENDIF ELSE BEGIN			; plot with named x-axis

		; get the X-axis array and name
		HANDLE_VALUE, par.data_handles(par.xnameindex), xdata
		xname = par.data_names(par.xnameindex)
		IF par.xsubindex NE 0 THEN BEGIN
			xdata = xdata(par.xsubindex-1,*)
			xname = xname + "(" + STRCOMPRESS(par.xsubindex) + ")"
		ENDIF
		IF index(0) NE -1 THEN xdata=xdata(index)

		PIA_XPLOT, xdata, ydata, GROUP=group, $
			XTITLE=xname, YTITLE=yname, $
			OVERPLOT=overplot, LEGEND=yname

	ENDELSE
	RETURN
	END

;*****************************************************************************
; PIA_AAPVIEW_CLEANUP  -  clean-up routine for PIA_AAPVIEW
;*****************************************************************************

PRO PIA_AAPVIEW_CLEANUP, top_id

	WIDGET_CONTROL, top_id, GET_UVALUE=hsave
	HANDLE_FREE, hsave
	RETURN
	END


;*****************************************************************************
; PIA_AAPVIEW_EVENT  -  event handling routine for PIA_AAPVIEW
;*****************************************************************************

PRO PIA_AAPVIEW_EVENT, event

	WIDGET_CONTROL, event.id, GET_UVALUE=action
	WIDGET_CONTROL, event.top, GET_UVALUE=hsave
	HANDLE_VALUE, hsave, save
	HANDLE_VALUE, save.hid, id
	HANDLE_VALUE, save.hpar, par

	CASE action OF

	'QUIT':	WIDGET_CONTROL, event.top, /DESTROY

; data array name selected

	'NAME':	BEGIN
		par.nameindex = event.index
	 	HANDLE_VALUE, par.data_handles(par.nameindex), data, /NO_COPY
		array_size = SIZE(data)
		HANDLE_VALUE, par.data_handles(par.nameindex), data, /SET, $
							/NO_COPY
		; we treat only 1 or 2 dimensional arrays
		IF array_size(0) EQ 1 THEN BEGIN
			indexes = ['*']
		ENDIF ELSE BEGIN
			subsize = array_size(1)
			indexes = ['*',STRING(INDGEN(subsize)+1)]
		ENDELSE
		WIDGET_CONTROL, id.suba, SET_VALUE=indexes
		par.subindex = 0
		HANDLE_VALUE, save.hpar, par, /SET, /NO_COPY
		END

; data sub-array selected

	'SUBA':	BEGIN
		par.subindex = event.index
		HANDLE_VALUE, save.hpar, par, /SET, /NO_COPY
		END

; clear the x-axis selection and set to 'Index'

	'CLRX':	BEGIN
		par.xnameindex = -1
		par.subindex = 0
		WIDGET_CONTROL, id.xname, SET_VALUE='Index'
		HANDLE_VALUE, save.hpar, par, /SET, /NO_COPY
		END

; set x-axis selection to selected name and sub-array index

	'NEWX':	BEGIN
		par.xnameindex = par.nameindex
		par.xsubindex = par.subindex
		IF par.xsubindex EQ 0 THEN ss = "*" $
			ELSE ss = STRCOMPRESS(par.xsubindex)
		sn = par.data_names(par.xnameindex) + "(" + ss + ")"
		WIDGET_CONTROL, id.xname, SET_VALUE=sn
		HANDLE_VALUE, save.hpar, par, /SET, /NO_COPY
		END

; set y-axis selection to selected name and sub-array index

	'NEWY':	BEGIN
		par.ynameindex = par.nameindex
		par.ysubindex = par.subindex
		IF par.ysubindex EQ 0 THEN ss = "*" $
			ELSE ss = STRCOMPRESS(par.ysubindex)
		sn = par.data_names(par.ynameindex) + "(" + ss + ")"
		WIDGET_CONTROL, id.yname, SET_VALUE=sn
		HANDLE_VALUE, save.hpar, par, /SET, /NO_COPY
		END

; restrict arrays to raster points

	'XRAS':	BEGIN
		WIDGET_CONTROL, id.xraster, GET_VALUE=val
		val = STRCOMPRESS(val(0))
		ON_IOERROR, err_xras
		IF val EQ '*' THEN par.xraster=0 ELSE par.xraster=FIX(val)
		IF par.xraster LT 0 OR par.xraster GT par.npts THEN $
			GOTO,err_xras
		HANDLE_VALUE, save.hpar, par, /SET, /NO_COPY
		RETURN
err_xras:
		par.xraster = 0
		WIDGET_CONTROL, id.xraster, SET_VALUE='*'
		HANDLE_VALUE, save.hpar, par, /SET, /NO_COPY
		END

; restrict arrays to raster legs

	'YRAS':	BEGIN
		WIDGET_CONTROL, id.yraster, GET_VALUE=val
		val = STRCOMPRESS(val(0))
		ON_IOERROR, err_yras
		IF val EQ '*' THEN par.yraster=0 ELSE par.yraster=FIX(val)
		IF par.yraster LT 0 OR par.yraster GT par.nlns THEN $
			GOTO,err_yras
		HANDLE_VALUE, save.hpar, par, /SET, /NO_COPY
		RETURN
err_yras:
		par.yraster = 0
		WIDGET_CONTROL, id.yraster, SET_VALUE='*'
		HANDLE_VALUE, save.hpar, par, /SET, /NO_COPY
		END

; plot data to new window

	'PLOT': BEGIN
		overplot = 0
		PIA_AAPVIEW_PLOT, par, OVERPLOT=overplot, GROUP=event.top
		END

; over-plot data with new axis

	'OPL1': BEGIN
		overplot = -1
		PIA_AAPVIEW_PLOT, par, OVERPLOT=overplot, GROUP=event.top
		END

; over-plot data to existing axis

	'OPL2': BEGIN
		WIDGET_CONTROL, id.oplotval, GET_VALUE=val
		overplot = FIX(val(0))
		PIA_AAPVIEW_PLOT, par, OVERPLOT=overplot, GROUP=event.top
		END

	ELSE:
	ENDCASE
	RETURN
	END

;*****************************************************************************
; PIA_AAPVIEW  -  main routine
;*****************************************************************************

PRO PIA_AAPVIEW, aap, GROUP=group

; define array of data array names

	data_names = [ $
		'Time',					$
		'Chopper step number',			$
		'Chopper position',			$
		'Dwell time',				$
		'Raster point ID',			$
		'Flags',				$
		'Right ascension',			$
		'Declination',				$
		'Roll angle',				$
		'Flux mean',				$
		'Flux uncertainty',			$
		'Flux median',				$
		'Flux 1st quartile',			$
		'Flux 3st quartile',			$
		'Brightness mean',			$
		'Brightness uncertainty',		$
		'Brightness median',			$
		'Brightness 1st quartile',		$
		'Brightness 3st quartile'		$
	]

; define array of data handles in exactly the same order as the names

	data_handles = [ $
		aap.time,	$
		aap.cstp,	$
		aap.cpos,	$
		aap.dwel,	$
		aap.rpid,	$
		aap.flag,	$
		aap.ra,		$
		aap.dec,	$
		aap.roll,	$
		aap.mnfl,	$
		aap.mnfu,	$
		aap.mdfl,	$
		aap.q1fl,	$
		aap.q3fl,	$
		aap.mnbr,	$
		aap.mnbu,	$
		aap.mdbr,	$
		aap.q1br,	$
		aap.q3br	$
	]

; define raster point ID handle individually

	rpid_handle = aap.rpid

; define program save parameters

	id = { $
		suba:0L,	$
		xname:0L,	$
		yname:0L,	$
		oplotval:0L,	$
		xraster:0L,	$
		yraster:0L	$
	}

	par = { $
		data_names:data_names,		$
		data_handles:data_handles,	$
		rpid_handle:rpid_handle,	$
		nameindex:0,			$
		subindex:0,			$
		xnameindex:-1,			$
		xsubindex:0,			$
		ynameindex:0,			$
		ysubindex:0,			$
		npts:0,				$
		nlns:0,				$
		xraster:0,			$
		yraster:0			$
	}

; number of raster points / lines

	HANDLE_VALUE, aap.rpid, rpid
	par.npts = MAX(rpid(0,*))
	par.nlns = MAX(rpid(1,*))

; set up widgets

	id_base = WIDGET_BASE( TITLE='AAP Data View', /COLUMN )

	id_upper = WIDGET_BASE( id_base, /ROW )

	id_arrays = WIDGET_BASE( id_upper, /COLUMN )
	id_1 = WIDGET_LABEL( id_arrays, VALUE='Select data to be plotted:' )
	id_1 = WIDGET_BASE( id_arrays, /ROW )
	id_2 = WIDGET_BASE( id_1, /COLUMN )
	id_3 = WIDGET_LABEL( id_2, VALUE='Data Array name:     ' )
	id_3 = WIDGET_LIST( id_2, VALUE=data_names, UVALUE='NAME', $
				XSIZE=16, YSIZE=13 )
	id_2 = WIDGET_BASE( id_1, /COLUMN )
	id_3 = WIDGET_LABEL( id_2, VALUE='Sub-array:' )
	id.suba = WIDGET_LIST( id_2, VALUE='*', UVALUE='SUBA', $
				XSIZE=6, YSIZE=13 )

	id_right = WIDGET_BASE( id_upper, /COLUMN )
	id_2 = WIDGET_LABEL( id_right, VALUE=' ' )
	id_2 = WIDGET_LABEL( id_right, VALUE=' ' )

	id_select = WIDGET_BASE( id_right, /COLUMN )
	id_2 = WIDGET_BASE( id_select, /ROW )
	id_3 = WIDGET_BUTTON( id_2, VALUE='>> X-axis >>', UVALUE='NEWX' )
	id.xname = WIDGET_TEXT( id_2, VALUE=' ', XSIZE=24 )
	id_2 = WIDGET_BASE( id_select, /ROW )
	id_3 = WIDGET_BUTTON( id_2, VALUE='Clear X-axis', UVALUE='CLRX' )
	id_2 = WIDGET_BASE( id_select, /ROW )
	id_3 = WIDGET_BUTTON( id_2, VALUE='>> Y-axis >>', UVALUE='NEWY' )
	id.yname = WIDGET_TEXT( id_2, VALUE=' ', XSIZE=24 )

	id_raster = WIDGET_BASE( id_right, /COLUMN )
	id_0 = WIDGET_BASE( id_raster, /ROW )
	id_1 = WIDGET_LABEL( id_0, VALUE='Restrict arrays to raster points:' )
	id_0 = WIDGET_BASE( id_raster, /ROW )
	id_1 = WIDGET_LABEL( id_0, VALUE='(Enter value and press <RETURN>)' )
	id_0 = WIDGET_BASE( id_raster, /ROW )
	id_1 = WIDGET_LABEL( id_0, $
		VALUE='Points ( 1 ...'+STRCOMPRESS(par.npts)+', * = all): ' )
	id.xraster = WIDGET_TEXT( id_0, VALUE='*', UVA='XRAS', $
		/EDITABLE, XSIZE=12 )
	id_0 = WIDGET_BASE( id_raster, /ROW )
	id_1 = WIDGET_LABEL( id_0, $
		VALUE='Legs    ( 1 ...'+STRCOMPRESS(par.nlns)+', * = all): ' )
	id.yraster = WIDGET_TEXT( id_0, VALUE='*', UVA='YRAS', $
		/EDITABLE, XSIZE=12 )

	id_lower = WIDGET_BASE( id_base, /ROW )
	id_0 = WIDGET_BASE( id_lower, /COLUMN )
	id_2 = WIDGET_BUTTON( id_0, VALUE='Plot (new window)', UVALUE='PLOT' )	
	id_2 = WIDGET_BUTTON( id_0, $
		VALUE='Overplot (same window, new axis)', UVALUE='OPL1' )
	id_2 = WIDGET_BUTTON( id_0, $
		VALUE='Overplot (same window, existing axis)', UVALUE='OPL2' )
	id_2 = WIDGET_BASE( id_0, /ROW )
	id_3 = WIDGET_LABEL( id_2, VALUE="Overplot axis #: " )
	id.oplotval = WIDGET_TEXT( id_2, VALUE='99', XSIZE=16, /EDIT )
	id_2 = WIDGET_BUTTON( id_0, VALUE='    Quit    ', UVALUE='QUIT' )


; store program parameters

	hsave = HANDLE_CREATE()
	hid = HANDLE_CREATE(hsave, VALUE=id )
	hpar = HANDLE_CREATE(hsave, VALUE=par )
	save = { hid:hid, hpar:hpar }
	HANDLE_VALUE, hsave, save, /SET, /NO_COPY

; realize widget

	WIDGET_CONTROL, id_base, /REALIZE, SET_UVALUE=hsave

	xMANAGER,No_BLOCK=1, "PIA_AAPVIEW", id_base, GROUP=group, $
		CLEANUP="PIA_AAPVIEW_CLEANUP"

	RETURN
	END
