;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;     PIA_ANAL_SIG
;
; PURPOSE:
;       Graphical I/F for the analysis of several SRD/SCP measurements
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_ANAL_SIG, GROUP=GROUP
;
; INPUTS:
;	(none)
;
; KEYWORD PARAMETERS:
;
;	GROUP:		
;
; OUTPUTS:
;	(none)
;
; COMMON BLOCKS:
;	phtsrd
;	phtscp
;	pickmeas_results
;
; PROCEDURES CALLED:
;	PIA_LIB:
;		anal_sig
;	Internal:
;		pia_anal_sig_event
;
;
; MODIFICATION HISTORY:
;       Written by:	Carlos GABRIEL (ESA/VILSPA-SAI)		December 1995
;	Widget types changed (CG)				February 1996
;	Bug for SCP orbit files fixed (CG)			February 1996
;	Reading from measurement in buffer included (JAcosta)	February 1997
;	Using new pickmeas and pickmeas_results-CB (CG)	May 1997
;	V6.3
;	Change call to anal_sig, adding admn as argument (JAc)  January 1998
;	V7.0
;
;-
PRO PIA_ANAL_SIG_EVENT, EVENT

@phtsrd
@phtscp
; Definitions common to all instances
COMMON pia_anal_sig_cmn, acttyp, id_dtyp, id_ftyp, id_selmeas, actorb_id
COMMON pickmeas_results, pickmeas_res

	dtyp   =	[	'P1', $
				'P2', $
				'P3', $
				'C1', $
				'C2', $
				'SL' $
                        ]
	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.top, /HOURGLASS

	CASE uvalue OF

; Quit DataReduction

	 'QUIT': BEGIN

			WIDGET_CONTROL, event.top, /DESTROY
	 	 END

; Do a plot, select measurements
	 'ACCEPT': BEGIN 
		    WIDGET_CONTROL, id_ftyp, get_value=ftyp
		    CASE ftyp OF
		   	0: BEGIN
		  			actbuf = phtsrd
		  			acttyp = '*.ISRD' 
		  			buftyp = 'SRD'
		  		END
		  	1: BEGIN
		  			actbuf = phtscp
		  			acttyp = '*.ISCP'
		  			buftyp = 'SCP'
				END
			ELSE: MESSAGE, /info, 'Type not valid ' 
		     ENDCASE
		     		  	
		     WIDGET_CONTROL, id_dtyp, get_value=dtype
		     actdet = dtyp(dtype) 	
		   		
		     IF actdet EQ '' $
			OR acttyp EQ '' THEN BEGIN
			MESSAGE, /INFO, $
			  'I can not work without definitions, returning'
			RETURN
		     ENDIF 
		
	 	     WIDGET_CONTROL, id_selmeas, get_value= selmeas
	 	     
	 	     CASE selmeas OF         ; selection meas.
	 	         0: BEGIN      ; individual internal files
		             firstele = N_ELEMENTS(actbuf)

		             WIDGET_CONTROL, actorb_id, GET_VALUE=orbit
		             files = pia_pickfile(PATH=orbit(0), /multi, $
				filter=actdet(0)+acttyp(0), /READ, $
				group=event.top)
		             IF files(0) EQ '' THEN BEGIN
                	        MESSAGE, /INFO, $ 
                	          ' No Data selected, procedure stopped'
                                RETURN
		             ENDIF

		             WIDGET_CONTROL, event.top, /hourglass

		             nele = N_ELEMENTS(FILES)
		             ind = intarr(nele)

		             FOR I=0,nele-1 DO $
		   	       pia_read_ifile, files(i)
		   	

		             ind = firstele + indgen(nele)

	 	            END
	 	            
	 	         1: BEGIN       ; whole directory internal files       

		             firstele = N_ELEMENTS(actbuf)
		             WIDGET_CONTROL, actorb_id, GET_VALUE=orbit
		   
		             files = FINDFILE(orbit(0)+actdet(0)+acttyp(0))

		             IF files(0) EQ '' THEN BEGIN
			      MESSAGE, /INFO, $
			        'No files found, wrong orbit directory? ...'
			      RETURN
		             ENDIF 

		             FOR I=0,N_ELEMENTS(FILES)-1 DO pia_read_ifile, $ 
		                files(i)
	
		             nele = N_ELEMENTS(files)

		             ind = firstele + indgen(nele)
	 	            END
	 	            
	 	         ELSE: BEGIN    ; read meas. in buffer
	 	              measname = pickmeas(FTYPE=buftyp(0), /multi, $
	 	                 DTYPE=actdet(0))
	 	                 IF measname(0) eq '' THEN BEGIN
			      MESSAGE, /INFO, $
			        'No measurements selected ...'
			      RETURN
		             ENDIF 
	 	              FOR i=0, N_ELEMENTS(measname)-1 DO BEGIN 
	 	                indtmp = where(actbuf.admn eq measname(i),n)
				IF n GT 1 THEN $
				 indtmp = indtmp(pickmeas_res.position(i))
	 	                
	 	                IF i EQ 0 THEN ind =  indtmp(0) $ 
	 	                  ELSE ind = [ind, indtmp(0)]   
	 	              ENDFOR 
	 	             END
	 	             
	 	         ENDCASE  ; end of selection case
	 	         
		         anal_sig, ind, admn, time, signal, noise, flags,  $
		   	      st_time, type=buftyp(0), ERROR=error

		         IF ERROR THEN RETURN 

		         orbstr = {admn:admn, st_time:st_time, time:time,  $
		   	       signal:signal, noise:noise, flags:flags}
		         PIA_SHOWSTR, orbstr, GROUP=event.top, $ 
		            TITLE='Measurement Concatenation'
		         
	 	END         
	 	                
	   ELSE:
	ENDCASE	 
	 	

RETURN
END  


PRO PIA_ANAL_SIG, GROUP=group

; Definitions common to all instances
COMMON pia_anal_sig_cmn, acttyp, id_dtyp, id_ftyp, id_selmeas, actorb_id

; Initialize (or desinitialize)
	actorb = !XDRDIR
	actbuf = ''
	acttyp = ''
	actdet = ''


	file_types   =  [	'SRD level', $
				'SCP level' $
			]

	det_types   =	[	'P1 ', $
				'P2    ', $
				'P3    ', $
				'C100  ', $
				'C200  ', $
				'SS/SL '  $ 
                        ]

; Definitions for individual instances


; Set-up widget hierarchy

   anal_sig_wid = WIDGET_BASE(TITLE="PIA Signals Merging", XSIZE=400, $
        /COLUMN)

	id_0 = WIDGET_BASE(Anal_sig_wid, /ROW,xsize=390 )

	selmeas = ['Select individual files', 'Use whole orbit files', $
	           'Measurements in buffer']
		

; Selection of detector and sprocessing level
	id_0 = WIDGET_BASE( Anal_sig_wid, /ROW,/FRAME )

	id_1 = WIDGET_BASE( id_0, /COLUMN )
	id_dtyp = CW_BGROUP(id_1, LABEL_TOP = 'Detector', $
			/EXCLUSIVE, /FRAME, $
			SET_VALUE = 0, $
			UVALUE = 'DTYP', det_types)

	id_1 = WIDGET_LABEL( id_0, VALUE=' ',xsize=40 )

	id_1 = WIDGET_BASE( id_0, /COLUMN )

	id_selmeas = CW_BGROUP(id_1, LABEL_TOP = 'Select measurements', $
	                /EXCLUSIVE, /FRAME, $
	                SET_VALUE = 2,      $
	                UVALUE= 'SELMEAS', selmeas)		

	;id_2 = WIDGET_LABEL( id_1, VALUE=' ',xsize=50 )

	; id_1 = WIDGET_BASE( id_0, /COLUMN )
	id_ftyp = CW_BGROUP(id_1, LABEL_TOP = 'Proc. level', $
			/EXCLUSIVE, /FRAME, $
			SET_VALUE = 0, $
			UVALUE = 'FTYP', file_types)
			
	id_1 = WIDGET_LABEL( id_0, VALUE=' ',xsize=390 )
	id_0 = WIDGET_BASE( Anal_sig_wid, /ROW)
	id_1 = WIDGET_LABEL( id_0, VALUE='Select Directory: ' )
	actorb_id = WIDGET_TEXT(id_0, VALUE=!XDRDIR, UVALUE='junk', $
			XSIZE=40, /EDITABLE) 	

; Realize widget

	id_0 = WIDGET_BASE(Anal_sig_wid, /ROW )

	id_1 = WIDGET_BUTTON( id_0, $
	  VALUE='    Accept   ',UVALUE='ACCEPT',XSIZE=130 )
	id_1 = WIDGET_BUTTON( id_0, $
	  VALUE='     Quit    ',UVALUE='QUIT',XSIZE=130 )
	id_1 = WIDGET_BUTTON( id_0, $
	  VALUE='     Help    ', UVALUE='HELP',XSIZE=130 )


	WIDGET_CONTROL, anal_sig_wid, /REALIZE, TLB_SET_YOFFSET=500, $
			TLB_SET_XOFFSET=10
  
	xMANAGER,No_BLOCK=1, "pia_anal_sig", anal_sig_wid, GROUP=group

	RETURN
END

	
