;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_BCKSUBT
;
; PURPOSE:
;	Menu for PIA Background subtraction.
;	This is a display dependant level menu in the PIA hierarchy.
;
;	This routine should only be called by the PIA display menues
;	and should not be called directly from the command line.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_BCKSUBT, tmpdata, SPD=SPD, GROUP=group
;
; INPUTS:
;	tmpdata: structure containing data (SCP or SPD level)
;	
; KEYWORD PARAMETERS:
;	SPD:	Data identifier (0:SCP, 1:SPD level)
;	GROUP:	The group leader of the widget hirarchy
;
; COMMON BLOCKS:
;	colour_indices
;	bcksubt_cmn
;	bcksubt_cmn0
;
; PROCEDURES USED:
;	PIA LIB:
;		chop_levels
;		decode_admn
;		pia_print_srcbck
;		pia_showstr
;		pia_xplot
;		pia_xsurface
;		subtr_bckg
;		weight_mean
;		bcksub_calc
;       INTERNAL:
;		pia_bcksubt_event
;	
; MODIFICATION HISTORY:
;	Written by: C.Gabriel (ESA/ESTEC-SAI)		February 1995
;	Modified (last) by: CG				September 1995
;	Oct 95 Version 3.5
;	Accomodating subtracted data into dynamical structures 
;	  introduced  (CG)				December 1995
;	98 & 99 changed -> 'C' and 'I' & chopper position -> chopper
;	 step for better comprehension (CG)		April 1996
;	Call to SAVE uses temporary header (CG) +
;	 bcksub_calc created as external routine	May 1997
;	V6.3
;
;-

; ****************************************************************************
;  Event handling routine for PIA background selection menu
; ****************************************************************************

PRO pia_bcksubt_event, event

COMMON bcksubt_cmn, chplvl, srcsbt, srcstep, bckstep, srcstep_id, bckstep_id, $
        data, subtstr_id, plot_id, lplot_id, lplot_id2, lplot_id3, ispd, $ 
        prtflg, reduce_med
COMMON bcksubt_cmn0, save_id, newhdr
	
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices	

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue OF

          'QUIT': BEGIN
		
                WIDGET_CONTROL, event.top, /DESTROY
          END

	  'STANDARD': BEGIN
	    CASE event.value of
	  	1: BEGIN
		 WIDGET_CONTROL, srcstep_id, /sensitive
		 WIDGET_CONTROL, bckstep_id, /sensitive
		 END
		0: BEGIN
		 WIDGET_CONTROL, srcstep_id, SET_VALUE='C'
		 WIDGET_CONTROL, bckstep_id, SET_VALUE='I'
		 WIDGET_CONTROL, srcstep_id, sensitive=0
		 WIDGET_CONTROL, bckstep_id, sensitive=0
		END
	     ENDCASE
	   END
		 	  			

	  'SRCSTEP': junk = 0

	  'BCKSTEP': junk = 0

	  'OKSTEP' : BEGIN
		
		WIDGET_CONTROL, srcstep_id, GET_VALUE=srcstep
		WIDGET_CONTROL, bckstep_id, GET_VALUE=bckstep

		IF STRTRIM(STRUPCASE(srcstep(0)),2) EQ 'C' THEN srcstep = 98 $
			ELSE srcstep = FIX(srcstep(0))
		IF STRTRIM(STRUPCASE(bckstep(0)),2) EQ 'I' THEN bckstep = 99 $
			ELSE bckstep = FIX(bckstep(0))

		subtr_bckg, data, srcstep, srcsbt, bckstep=bckstep, ISPD=ispd

 		WIDGET_CONTROL, subtstr_id, /SENSITIVE
 		WIDGET_CONTROL, plot_id, /SENSITIVE

 		WIDGET_CONTROL, lplot_id, /SENSITIVE
 		WIDGET_CONTROL, lplot_id2, /SENSITIVE
		IF STRMID(srcsbt.name,0,1) EQ 'C' THEN $
 		   WIDGET_CONTROL, lplot_id3, /SENSITIVE
 		WIDGET_CONTROL, save_id, /SENSITIVE
	  END

	  'SHOPRI': prtflg = event.select

	  'RED_MED': reduce_med = event.select

	  'SHOSTE': pia_showstr, chplvl, GROUP=event.top

	  'SHOSUB': pia_showstr, srcsbt, GROUP=event.top

          'PLTAVE': BEGIN

       		bcksub_calc, srcsbt.aver, srcsbt.avun, srcsbt.flag, aver, avun, $
       		    MEDIAN = reduce_med

                zoom_color = -1
                zoom_psymch = 4

		x = indgen(N_ELEMENTS(aver)) + 1
		decode_admn, srcsbt.name, meas
		anntmp=meas + ' ' + srcsbt.LEVEL + '  SRC step = '+$
			STRTRIM(STRING(srcstep),2) + '  BCK step = ' + $
			STRTRIM(STRING(bckstep),2) 
		ytitle='Average Source - Background (averages)'
        
		PIA_XPLOT, x, aver, avun, psym = 4, $
			xtitle='Pixel # ', ytitle=ytitle, $
			title=' Background subtracted Source', $
			legend=ytitle, annotation=anntmp, group=event.top
		
		IF prtflg EQ 1 THEN $
		 pia_print_srcbck, srcsbt.name, aver, avun, $
			ytitle, GROUP=event.top		

 	  END

          'OPLAVE_S': BEGIN

       		bcksub_calc, srcsbt.aver, srcsbt.avun, srcsbt.flag, aver, avun, $
       		    MEDIAN = reduce_med


                IF zoom_color EQ -1 THEN zoom_color = green ELSE $
                        zoom_color = zoom_color + 1
                IF zoom_color EQ 9 then zoom_color = 4
                zoom_psymch = zoom_psymch + 1
                IF zoom_psymch EQ 8 then zoom_psymch = 1

		x = indgen(N_ELEMENTS(aver)) + 1
		decode_admn, srcsbt.name, meas
		anntmp=meas + ' ' + srcsbt.LEVEL + '  SRC step = '+$
			STRTRIM(STRING(srcstep),2) + '  BCK step = ' + $
			STRTRIM(STRING(bckstep),2) 
		ytitle='Average Source - Background (averages)'
        
		PIA_XPLOT, x, aver, avun, $
			xtitle='Pixel # ', ytitle=ytitle, $
			title=' Background subtracted Source', $
			legend=ytitle, annotation=anntmp, overplot=99,$
			color=zoom_color, psym=zoom_psymch, group=event.top           
		
		IF prtflg EQ 1 THEN $
		 pia_print_srcbck, srcsbt.name, aver, avun, $
			ytitle, GROUP=event.top		

 	  END

          'OPLAVE_N': BEGIN

       		bcksub_calc, srcsbt.aver, srcsbt.avun, srcsbt.flag, aver, avun, $
       		    MEDIAN = reduce_med


		x = indgen(N_ELEMENTS(aver)) + 1
		decode_admn, srcsbt.name, meas
		anntmp=meas + ' ' + srcsbt.LEVEL + '  SRC step = '+$
			STRTRIM(STRING(srcstep),2) + '  BCK step = ' + $
			STRTRIM(STRING(bckstep),2) 
		ytitle='Average Source - Background (averages)'

                IF zoom_color EQ -1 THEN zoom_color = green ELSE $
                        zoom_color = zoom_color + 1
                IF zoom_color EQ 9 then zoom_color = 4
                zoom_psymch = zoom_psymch + 1
                IF zoom_psymch EQ 8 then zoom_psymch = 1
        
		PIA_XPLOT, x, aver, avun, $
			xtitle='Pixel # ', ytitle=ytitle, $
			title=' Background subtracted Source', $
			legend=ytitle, annotation=anntmp, overplot=-1,$
			color=zoom_color, psym=zoom_psymch, group=event.top           
		
		IF prtflg EQ 1 THEN $
		 pia_print_srcbck, srcsbt.name, aver, avun, $
			ytitle, GROUP=event.top		

 	  END
                    
          'PLTMED': BEGIN

       		bcksub_calc, srcsbt.medi, srcsbt.avun, srcsbt.flag, aver, avun, $
       		    MEDIAN = reduce_med

                zoom_color = -1
                zoom_psymch = 4

		x = indgen(N_ELEMENTS(aver)) + 1
		decode_admn, srcsbt.name, meas
		anntmp=meas + ' ' + srcsbt.LEVEL + '  SRC step = '+$
			STRTRIM(STRING(srcstep),2) + '  BCK step = ' + $
			STRTRIM(STRING(bckstep),2) 
		ytitle='Average Source - Background (medians)'
        
		PIA_XPLOT, x, aver, avun, psym=4, $
			xtitle='Pixel # ', ytitle=ytitle, $
			title=' Background subtracted Source', $
			legend=ytitle, annotation=anntmp, group=event.top
		
		IF prtflg EQ 1 THEN $
		 pia_print_srcbck, srcsbt.name, aver, avun, $
			ytitle, GROUP=event.top		

 	  END

          'OPLMED_S': BEGIN

       		bcksub_calc, srcsbt.medi, srcsbt.avun, srcsbt.flag, aver, avun, $
       		    MEDIAN = reduce_med

		x = indgen(N_ELEMENTS(aver)) + 1
		decode_admn, srcsbt.name, meas
		anntmp=meas + ' ' + srcsbt.LEVEL + '  SRC step = '+$
			STRTRIM(STRING(srcstep),2) + '  BCK step = ' + $
			STRTRIM(STRING(bckstep),2) 
		ytitle='Average Source - Background (averages)'
        
                IF zoom_color EQ -1 THEN zoom_color = green ELSE $
                        zoom_color = zoom_color + 1
                IF zoom_color EQ 9 then zoom_color = 4
                zoom_psymch = zoom_psymch + 1
                IF zoom_psymch EQ 8 then zoom_psymch = 1

		PIA_XPLOT, x, aver, avun, $
			xtitle='Pixel # ', ytitle=ytitle, $
			title=' Background subtracted Source', $
			legend=ytitle, annotation=anntmp, overplot=99,$
			color=zoom_color, psym=zoom_psymch, group=event.top           
		
		IF prtflg EQ 1 THEN $
 		 pia_print_srcbck, srcsbt.name, aver, avun, $
			ytitle, GROUP=event.top		

 	  END

          'OPLMED_N': BEGIN

       		bcksub_calc, srcsbt.medi, srcsbt.avun, srcsbt.flag, aver, avun, $
       		    MEDIAN = reduce_med

		x = indgen(N_ELEMENTS(aver)) + 1
		decode_admn, srcsbt.name, meas
		anntmp=meas + ' ' + srcsbt.LEVEL + '  SRC step = '+$
			STRTRIM(STRING(srcstep),2) + '  BCK step = ' + $
			STRTRIM(STRING(bckstep),2) 
		ytitle='Average Source - Background (averages)'
                IF zoom_color EQ -1 THEN zoom_color = green ELSE $
                        zoom_color = zoom_color + 1
                IF zoom_color EQ 9 then zoom_color = 4
                zoom_psymch = zoom_psymch + 1
                IF zoom_psymch EQ 8 then zoom_psymch = 1
        
		PIA_XPLOT, x, aver, avun, $
			xtitle='Pixel # ', ytitle=ytitle, $
			title=' Background subtracted Source', $
			legend=ytitle, annotation=anntmp, overplot=-1, $
			color=zoom_color, psym=zoom_psymch, group=event.top           
		
		IF prtflg EQ 1 THEN $
		 pia_print_srcbck, srcsbt.name, aver, avun, $
			ytitle, GROUP=event.top		

 	  END
                    
	  'LPLTAVE': BEGIN

		decode_admn, srcsbt.name, meas

		tmp = srcsbt.aver

		indnok = WHERE(srcsbt.flag GT 1, nok)
		IF nok GT 0 THEN tmp(indnok) = 0.

		IF N_ELEMENTS(tmp(*,0)) GT 1 THEN $
		 pia_xsurface, tmp, wlego=1, xtitle = 'Pixel #', $
			ytitle= 'Source Chopper Plateau', charsize=2, $
			ztitle= ' SRC-BCK (avrges) ', title=meas, $
			group=event.top  $
                ELSE BEGIN
		 x = INDGEN(N_ELEMENTS(tmp)) + 1
		 pia_xplot, x, tmp, srcsbt.avun, $
			xtitle='Source Chopper Plateau',charsize=1.3,$
			ytitle= ' SRC-BCK (avrges) ', title=meas, psym=4
                ENDELSE

	  END

	  'LPLTMED': BEGIN

		decode_admn, srcsbt.name, meas

		tmp = srcsbt.medi

		indnok = WHERE(srcsbt.flag GT 1, nok)
		IF nok GT 0 THEN tmp(indnok) = 0.

		IF N_ELEMENTS(tmp(*,0)) GT 1 THEN $
 		 pia_xsurface, tmp, wlego=1, xtitle = 'Pixel #', $
			ytitle= 'Source Chopper Plateau',charsize=2, $
			ztitle= ' SRC-BCK (medians)  ', title=meas, $
			group=event.top   $                                
                ELSE BEGIN
		 x = INDGEN(N_ELEMENTS(tmp)) + 1
		 pia_xplot, x, tmp, $
			xtitle='Source Chopper Plateau',charsize=1.3,$
			ytitle= ' SRC-BCK (medians) ', title=meas, psym=4
                 pia_xplot, x, srcsbt.m1qu, overplot=99, psym=2
                 pia_xplot, x, srcsbt.m3qu, overplot=99, psym=2
		ENDELSE
	  END

	  'LPL2AVE': BEGIN

		decode_admn, chplvl.name, meas

		IF N_ELEMENTS(chplvl.aver(*,0)) GT 1 THEN $
		 pia_xsurface, chplvl.aver, wlego=1, xtitle = 'Pixel #', $
			ytitle= 'Chopper Step',charsize=2, $
			ztitle= ' Average of Averages ', title=meas, $
			group=event.top    $                      
                ELSE BEGIN
		 x = INDGEN(N_ELEMENTS(chplvl.aver)) + 1
		 pia_xplot, x, chplvl.aver, chplvl.avun, $
			xtitle= 'Chopper Step', charsize=1.3, $
			ytitle= ' Average of Averages ', title=meas, psym=4
                ENDELSE
	  END

	  'LPL2MED': BEGIN

		decode_admn, chplvl.name, meas

		IF N_ELEMENTS(chplvl.medi(*,0)) GT 1 THEN $
	       	 pia_xsurface, chplvl.medi, wlego=1, xtitle = 'Pixel #', $
			ytitle= 'Chopper Step',charsize=2, $
			ztitle= ' Average of Medians ', title=meas, $
			group=event.top    $                     
                ELSE BEGIN
		 x = INDGEN(N_ELEMENTS(chplvl.medi)) + 1
		 pia_xplot, x, chplvl.medi, $
			xtitle= 'Chopper Step', charsize=1.3, $
			ytitle= ' Average of Medians ', title=meas, psym=4
                 pia_xplot, x, srcsbt.m1qu, overplot=99, psym=2
                 pia_xplot, x, srcsbt.m3qu, overplot=99, psym=2
		ENDELSE
	  END

	  'LPL3AVE': BEGIN

		decode_admn, srcsbt.name, meas
       		bcksub_calc, srcsbt.aver, srcsbt.avun, srcsbt.flag, aver, avun, $
       		    MEDIAN = reduce_med


		CASE STRMID(srcsbt.name,0,2) of

		   'C1':  BEGIN

			caver = FLTARR(3,3)
			FOR III = 0,2 DO BEGIN
			   FOR II = 0,2 DO BEGIN
				caver(III,II) = aver(II+III*3)
			   ENDFOR
			ENDFOR
                    END
		   'C2':  BEGIN

			caver = FLTARR(2,2)

                 	caver(0,0) = aver(1)
                 	caver(0,1) = aver(2)
                 	caver(1,1) = aver(3)
                 	caver(1,0) = aver(0)
		   END
		ENDCASE

		pia_xsurface, caver, wlego=1, xtitle = ' Y-Sky direction', $
			ytitle= ' Z-Sky direction ',charsize=2, $
			ztitle= ' SRC-BCK (averages) ', title=meas, $
			group=event.top                         

	  END

	  'LPL3MED': BEGIN

		decode_admn, srcsbt.name, meas
       		bcksub_calc, srcsbt.medi, srcsbt.avun, srcsbt.flag, aver, avun, $
       		    MEDIAN = reduce_med


		CASE STRMID(srcsbt.name,0,2) of

		   'C1':  BEGIN

			caver = FLTARR(3,3)
			FOR III = 0,2 DO BEGIN
			   FOR II = 0,2 DO BEGIN
				caver(III,II) = aver(II+III*3)
			   ENDFOR
			ENDFOR
                    END
		   'C2':  BEGIN

			caver = FLTARR(2,2)

                 	caver(0,0) = aver(1)
                 	caver(0,1) = aver(2)
                 	caver(1,1) = aver(3)
                 	caver(1,0) = aver(0)
		   END
		ENDCASE

		pia_xsurface, caver, wlego=1, xtitle = ' Y-Sky direction', $
			ytitle= ' Z-Sky direction ',charsize=2, $
			ztitle= ' SRC-BCK (medians) ', title=meas, $
			group=event.top                         

	  END

	  'SAVE': BEGIN
;	        print,' USING median to reduce signals ',reduce_med
	  	WRITE_SUBTR, srcsbt, data, ispd, newhdr, REDUCE_MED = reduce_med
	  END 
	  
       	ENDCASE
RETURN
END

; ****************************************************************************
;  PIA bcksubt - menu definition procedure
; ****************************************************************************

PRO pia_bcksubt, tmpdata, newheader, SPD=SPD, AAP= AAP, GROUP=group

COMMON bcksubt_cmn, chplvl, srcsbt, srcstep, bckstep, srcstep_id, bckstep_id, $
	data, subtstr_id, plot_id, lplot_id, lplot_id2, lplot_id3, ispd, $ 
        prtflg, reduce_med 
COMMON bcksubt_cmn0, save_id, newhdr

	CASE 1 OF 
	   KEYWORD_SET(AAP): ispd = 2
	   KEYWORD_SET(SPD): ispd =1 
	   ELSE: ispd = 0
	ENDCASE
	
	data = tmpdata
	IF N_ELEMENTS(newheader) EQ 0 	THEN newhdr=tmpdata.hdr $
					ELSE newhdr = newheader
	
	chop_levels, tmpdata, chplvl, ispd=ispd

; lego plot of chopper steps averages (y=chopper steps, x=pixel)
; or plot if 1 pixel
	IF N_ELEMENTS(chplvl.aver(*,0)) GT 1 THEN $
          pia_xsurface, chplvl.aver, wlego=1, xtitle = 'Pixel #', $
			ytitle= 'Chopper Step',charsize=2, $
			ztitle= ' Average of Averages ' ELSE BEGIN 
	  x = indgen(N_ELEMENTS(chplvl.aver)) + 1
          pia_xplot, x, chplvl.aver, chplvl.avun, xtitle = 'Chopper Step', $
			charsize=1.3, psym=4, $
			ytitle= ' Average of Averages '
	ENDELSE  
; initial choice
	srcstep = 98
	bckstep = 99
	srcstep_str = 'C'
	bckstep_str = 'I'
	prtflg = 0
	reduce_med = 0
	
	chopbase = WIDGET_BASE(TITLE = 'PIA Background Subtraction Menu', $ 
		 		/COLUMN)

	dummy = WIDGET_LABEL(chopbase, $
	  VALUE=' CHOICE of CHOPPER STEPS for PERFORMING SUBTRACTION ')

	chbase = WIDGET_BASE(chopbase, /COLUMN, /FRAME)
	stdbut = cw_bgroup(chbase, LABEL_TOP = 'STANDARD CHOICE?', $
			/EXCLUSIVE,  $
			SET_VALUE = 0, $
			UVALUE = 'STANDARD', $
			["Source=central position, Background=interpolation",$
			 "Step numbers choice"])	

	achoice = WIDGET_BASE(chopbase, /COLUMN, /FRAME)
	choice = WIDGET_BASE(achoice, /ROW)

        label = WIDGET_LABEL(choice, VALUE=' Chopper Step for:   Source: ' )
        srcstep_id = WIDGET_TEXT(choice, /EDITABLE, XSIZE=3, YSIZE=1, $
                  VALUE=STRTRIM(srcstep_str,2), UVALUE='SRCSTEP')
        label = WIDGET_LABEL(choice, VALUE='    Background: ' )
        bckstep_id = WIDGET_TEXT(choice, /EDITABLE, XSIZE=3, YSIZE=1, $
                  VALUE=STRTRIM(bckstep_str,2), UVALUE='BCKSTEP')
        label = WIDGET_LABEL(choice, VALUE='     ' )

	WIDGET_CONTROL, srcstep_id, sensitive=0
	WIDGET_CONTROL, bckstep_id, sensitive=0

	dummy = WIDGET_LABEL(achoice, VALUE=' Take into account that:     ')
	chotxt = WIDGET_LABEL(achoice, VALUE=$
'Chopper step "C" for central (source) position & "I" for interpolation ')
	chotxt = WIDGET_LABEL(achoice, VALUE=$
'of background steps are valid for all AOTs')	
	chotxt = WIDGET_LABEL(achoice, VALUE=$
' You can change them putting step numbers - (Lego)Plot of avrgs/chopper step')
	chotxt = WIDGET_LABEL(achoice, VALUE=$
'on the left should help you to make up your mind ')	


	dummy = WIDGET_LABEL(chopbase, VALUE='       ')
        stepOK = WIDGET_BUTTON(chopbase, VALUE = ' OK ', $
                        /FRAME, UVALUE = 'OKSTEP')
       	dummy = WIDGET_LABEL(chopbase, VALUE='       ')

	procbase = WIDGET_BASE(chopbase, /COLUMN, /FRAME)

        junk = cw_bgroup(procbase, $
                        /NONEXCLUSIVE,$
                        SET_VALUE = reduce_med, $
                        UVALUE = 'RED_MED', $
                        'Use median instead of weigthed mean to project ' + $
                        'subtracted signals')

	dummy = WIDGET_LABEL(chopbase, VALUE='       ')

	grafbase = WIDGET_BASE(chopbase, /COLUMN, /FRAME)

	dummy = WIDGET_LABEL(grafbase, VALUE=$
		' PLOT RESULTS: ')

	plotbase = WIDGET_BASE(grafbase, /ROW)

	plot_id = WIDGET_BUTTON(plotbase, VALUE='<SRC-BCKG>', /MENU)	
	WIDGET_CONTROL, plot_id, SENSITIVE=0
	
        id_2 = WIDGET_BUTTON(plot_id, VALUE=' of Averages ', /MENU)
        id_3 = WIDGET_BUTTON(id_2, VALUE=' New Plot ', UVALUE='PLTAVE')
        id_3 = WIDGET_BUTTON(id_2, $
		VALUE=' Overplot synchronized', UVALUE='OPLAVE_S')
        id_3 = WIDGET_BUTTON(id_2, $
		VALUE=' Overplot not synchronized', UVALUE='OPLAVE_N')
 
        id_2 = WIDGET_BUTTON(plot_id, VALUE=' of Medians ', /MENU)
        id_3 = WIDGET_BUTTON(id_2, VALUE=' New Plot ', UVALUE='PLTMED')
        id_3 = WIDGET_BUTTON(id_2, $
		VALUE=' Overplot synchronized', UVALUE='OPLMED_S')
        id_3 = WIDGET_BUTTON(id_2, $
		VALUE=' Overplot not synchronized', UVALUE='OPLMED_N')
 

	lplot_id = WIDGET_BUTTON(plotbase, VALUE='SRC-BCK / Plat.', /MENU)	
	WIDGET_CONTROL, lplot_id, SENSITIVE=0
	
        id_2 = WIDGET_BUTTON(lplot_id, VALUE=' Averages ', UVALUE='LPLTAVE')
        id_2 = WIDGET_BUTTON(lplot_id, VALUE=' Medians ', UVALUE='LPLTMED')
 
	lplot_id2 = WIDGET_BUTTON(plotbase, VALUE='<Signal> / Step', /MENU)	
	WIDGET_CONTROL, lplot_id2, SENSITIVE=0
	
        id_2 = WIDGET_BUTTON(lplot_id2, VALUE=' Averages ', UVALUE='LPL2AVE')
        id_2 = WIDGET_BUTTON(lplot_id2, VALUE=' Medians ', UVALUE='LPL2MED')

	lplot_id3 = WIDGET_BUTTON(plotbase, VALUE='<SRC-BCKG>/C', /MENU)	
	WIDGET_CONTROL, lplot_id3, SENSITIVE=0
	
        id_2 = WIDGET_BUTTON(lplot_id3, VALUE=' Averages ', UVALUE='LPL3AVE')
        id_2 = WIDGET_BUTTON(lplot_id3, VALUE=' Medians ', UVALUE='LPL3MED')
 
        junk = cw_bgroup(grafbase, $
                        /NONEXCLUSIVE,$
                        SET_VALUE = prtflg, $
                        UVALUE = 'SHOPRI', $
                        'Show computed results in printfile when plotting')

	dummy = WIDGET_LABEL(chopbase, VALUE='       ')

	ashobase = WIDGET_BASE(chopbase, /COLUMN, /FRAME)

	dummy = WIDGET_LABEL(ashobase, VALUE=$
		'    SHOW DERIVED STRUCTURES:    ')

	shobase = WIDGET_BASE(ashobase, /ROW)

        stepstr_id = WIDGET_BUTTON(shobase, $
			VALUE = '    Chopper steps structures    ', $
                        UVALUE = 'SHOSTE')
        subtstr_id = WIDGET_BUTTON(shobase, $
			VALUE = '     Subtraction structures     ', $
                        UVALUE = 'SHOSUB')
	WIDGET_CONTROL, subtstr_id, SENSITIVE=0


	dummy = WIDGET_LABEL(chopbase, VALUE='       ')

	contbase = WIDGET_BASE(chopbase, /ROW)

        save_id = WIDGET_BUTTON(contbase, VALUE = '  Subtracted meas -> buffer ', $
                        /FRAME, UVALUE = 'SAVE')
	WIDGET_CONTROL, save_id, SENSITIVE=0

	dummy = WIDGET_LABEL(contbase, VALUE='                          ')

        QUIT = WIDGET_BUTTON(contbase, VALUE = '    QUIT     ', $
                        /FRAME, UVALUE = 'QUIT')

        WIDGET_CONTROL, chopbase, /REALIZE, TLB_SET_XOFFSET=420, $
                        TLB_SET_YOFFSET=40

        xMANAGER,No_BLOCK=1, "pia_bcksubt", chopbase, GROUP=group
	
        RETURN
END

