;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_BUFFIL
;
; PURPOSE:
;	Menu for PIA Internal Buffers selection and display.
;	This is a second level menu in the PIA hierarchy.
;
;	This routine should only be called by the PIA main program
;	and should not be called directly from the command line.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_BUFFIL, GROUP=group
;
; KEYWORD PARAMETERS:
;	GROUP:	The group leader of the widget hirarchy
;	
; COMMON BLOCKS:
;	phtaap
;	phterd
;	phtscp
;	phtspd
;	phtsrd
;	pia_buffil_cmn	for internal use
;
; PROCEDURES USED:
;	PIA LIB:
;		decode_admn
;		pia_disp_cs
;		pia_disp_hdr
;		pia_dispdata
;		pia_showdata
;		pickmeas
;       INTERNAL:
;		pia_buffil_event
;	
; MODIFICATION HISTORY:
;	Wrtten by: Carlos GABRIEL (ESA/ESTEC) 		July 1994
;	Modified (last) by: CG, PM			September 1995
;       SMD out, SMC int (SB)                           August 1996
;	Oct 95 Version 3.5
;	Common pia_widget_info extension (CG)		November 1997
;	V6.6
;			
;-

; ****************************************************************************
;  Event handling routine for PIA internal file selection menu
; ****************************************************************************

PRO pia_buffil_event, event
@phterd
@phtsrd
@phtscp
@phtspd
@phtcla
@phtaap

	COMMON pia_buffil_cmn, ftyp, ftyp_filters, dtyp

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.top, GET_UVALUE=stat
	HANDLE_VALUE, stat.id, stat_id
	HANDLE_VALUE, stat.val, stat_val
	WIDGET_CONTROL, event.top, /HOURGLASS

	CASE uvalue OF

; Quit Buffil Selection

	'QUIT':	BEGIN

		WIDGET_CONTROL, event.top, /DESTROY
	END

;  Select a measurement

	'SELF':	BEGIN
		filt = stat_val.filter
		dtype = stat_val.dtyp

		file = pickmeas( FTYPE=filt, DTYPE=dtype, $
				 GROUP=event.top)
                        
		IF file NE "" THEN BEGIN
			WIDGET_CONTROL, stat_id.filename, SET_UVALUE=file
			decode_admn, file, admn
			WIDGET_CONTROL, stat_id.filename, SET_VALUE=admn
			WIDGET_CONTROL, stat_id.vhea, /SENSITIVE
			WIDGET_CONTROL, stat_id.vtab, /SENSITIVE
			WIDGET_CONTROL, stat_id.plot, /SENSITIVE
			WIDGET_CONTROL, stat_id.show, /SENSITIVE
			HANDLE_VALUE, stat.val, stat_val, /SET
		ENDIF

	END


; Plot file 

	'PLOTF': BEGIN
plotf:
		WIDGET_CONTROL, event.top, /HOURGLASS

		WIDGET_CONTROL, stat_id.filename, GET_UVALUE=file
		stat_val.filename = STRTRIM(file(0),2)

		IF stat_val.filename EQ "" THEN BEGIN
			MESSAGE, /INFO, "No file selected in read."
			RETURN
		ENDIF

		
		pia_dispdata, stat_val.filename, stat_val.ftyp, group=group

	END

; Plot file 

	'SHOWF': BEGIN
		WIDGET_CONTROL, event.top, /HOURGLASS

		WIDGET_CONTROL, stat_id.filename, GET_UVALUE=file
		stat_val.filename = STRTRIM(file(0),2)

		IF stat_val.filename EQ "" THEN BEGIN
			MESSAGE, /INFO, "No file selected in read."
			RETURN
		ENDIF

		
		pia_showdata, stat_val.filename, stat_val.ftyp, group=event.top

	END

; View header

	'VHEA':	BEGIN
		WIDGET_CONTROL, stat_id.filename, GET_UVALUE=file
		CASE stat_val.ftyp of
		  'ERD': BEGIN
			buffer= phterd
			typ = 'PHTERD'
			END
		  'SRD': BEGIN
			buffer= phtsrd
			typ = 'PHTSRD'
			END
		  'SCP': BEGIN
			buffer= phtscp
			typ = 'PHTSCP'
			END
		  'CLA': BEGIN
			buffer= phtcla
			typ = 'PHTCLA'
			END
		  'SPD': BEGIN
			buffer= phtspd
			typ = 'PHTSPD'
			END
		  'AAP': BEGIN
			buffer= phtaap
			typ = 'PHTAAP'
			END
		  ELSE: MESSAGE, /INFO, 'No match'
		ENDCASE		

		index = WHERE(buffer.admn EQ file, n)

		IF n NE 0 THEN BEGIN
		  handle_value, buffer(index(0)).hdr, hdr
		  pia_disp_hdr, hdr, file, typ, GROUP=event.top
		ENDIF ELSE MESSAGE, /INFO, ' Measurement not found'
	
	END

; View header

	'VCS':	BEGIN
		WIDGET_CONTROL, stat_id.filename, GET_UVALUE=file
           	PIA_disp_cs, file
	END

; Select file type

	'FTYP':	BEGIN
		stat_val.ftyp = ftyp(event.index)
		stat_val.filter = ftyp_filters(event.index)
		HANDLE_VALUE, stat.val, stat_val, /SET
	END

	'DTYP':	BEGIN
		stat_val.dtyp = dtyp(event.index)
		HANDLE_VALUE, stat.val, stat_val, /SET
	END

	'HELP': BEGIN
	   IF !VERSION.OS NE 'vms' THEN $
               spawn, '$w3net $PIA_HTML/um/meas_sel_window.html &' ELSE $
               spawn, 'w3net /pia_dsk/pia/html/um/meas_sel_window.html',/nowait
      	   END

	ELSE:	MESSAGE, /INFO, 'Function not yet implemented.'  
	ENDCASE

	RETURN
END                                                           

; ****************************************************************************
;  PIA Buffer handling - menu definition procedure
; ****************************************************************************

PRO pia_buffil, GROUP=group


; Definitions common to all instances

	COMMON pia_buffil_cmn, ftyp, ftyp_filters, dtyp


COMMON pia_widget_info, extfil_wid, intfil_wid, buffil_wid, $
                        erddi1_wid, erddi2_wid, srddi1_wid, srddi2_wid, $
                        scpdi1_wid, scpdi2_wid, spddi1_wid, spddi2_wid, $
                        aapdi1_wid, aapdi2_wid

; If already registered, pop-up and exit
        IF Xregistered("pia_buffil") NE 0 THEN BEGIN
                WIDGET_CONTROL, buffil_wid, SHOW=1
                RETURN
        END



; Definition of file types:
; file_types    -  Defines what appears in the list widget and can contain
;                  any strings. The largest string determines XSIZE of the
;                  list widget: 12 seems ok.
; ftyp          -  Used in event handling routine to avoid direct coding
;                  of indexes.
; ftyp_filters  -  Used in event handling routine as file filter.
; Take care that the arrays are consistent with each other.

	file_types   =  [	'ERD Buffer', $
				'SRD Buffer', $
				'SCP Buffer', $
				'SPD Buffer', $
				'AAR Buffer', $
				'Cal A Buffer ' $
			]
	ftyp         =	[	'ERD', $
				'SRD', $
				'SCP', $
				'SPD', $
				'AAR', $
				'CLA' $
			]       
	ftyp_filters =	[	'ERD', $
				'SRD', $
				'SCP', $
				'SPD', $
				'AAR', $
				'CLA' $
			]       
	det_types   =	[	'P1 ', $
				'P2    ', $
				'P3    ', $
				'C100  ', $
				'C200  ', $
				'SS/SL ', $
				'ALL' $
                        ]
	dtyp   =	[	'P1', $
				'P2', $
				'P3', $
				'C1', $
				'C2', $
				'SL', $
				'AL' $
			]


; Definitions for individual instances

	stat = { $
		id:	HANDLE_CREATE(), $
		val:	HANDLE_CREATE(), $
		header:	HANDLE_CREATE() $
	}

	stat_id = { $
			plot:		0L, $
			show:		0L, $
			vhea:		0L, $
			vtab:		0L, $
		 	filename:	0L $
	}

	stat_val = { $
			filename:	'', $
			ftyp:		'', $
			dtyp:		'', $
			filter:		'' $
	}


; Set-up widget hierarchy

	buffil_wid = WIDGET_BASE( TITLE="PIA Measurement Selection", /COLUMN )

	id_0 = WIDGET_BASE( buffil_wid, /ROW )
	id_1 = WIDGET_BUTTON( id_0, VALUE='  Measurement  ', /MENU )
	id_2 = WIDGET_BUTTON( id_1, VALUE='Select Measurement', UVALUE='SELF' )
	id_2 = WIDGET_BUTTON( id_1, VALUE='Plot & Reduce Data', UVALUE='PLOTF' )
	stat_id.plot = id_2
	id_2 = WIDGET_BUTTON( id_1, VALUE='Show Data Values', UVALUE='SHOWF' )
	stat_id.show = id_2
	id_2 = WIDGET_BUTTON( id_1, VALUE='Quit', UVALUE='QUIT' )

	id_1 = WIDGET_BUTTON( id_0, VALUE='    View    ', /MENU )
	id_2 = WIDGET_BUTTON( id_1, VALUE='View Header', UVALUE='VHEA' )
	stat_id.vhea = id_2
	id_2 = WIDGET_BUTTON( id_1, VALUE='View Compact Status', UVALUE='VCS' )
	stat_id.vtab = id_2

	id_1 = WIDGET_LABEL( id_0, VALUE='                        ' )
	id_1 = WIDGET_BUTTON( id_0, VALUE='    Help    ', UVALUE='HELP' )

	id_0 = WIDGET_BASE( buffil_wid, /ROW )
	id_1 = WIDGET_LABEL( id_0, VALUE='Selected Measurement:' )
	id_1 = WIDGET_LABEL( id_0, VALUE=' ' )
	id_0 = WIDGET_TEXT( buffil_wid, /EDITABLE, XSIZE=40, YSIZE=1, $
			VALUE=' ')
	stat_id.filename = id_0

	id_0 = WIDGET_BASE( buffil_wid, /ROW )

	id_1 = WIDGET_BASE( id_0, /COLUMN )
	id_2 = WIDGET_LABEL( id_1, VALUE='Select Data Type:' )
	id_2 = WIDGET_LIST( id_1, YSIZE=7, VALUE=file_types, UVALUE='FTYP' )

	id_1 = WIDGET_LABEL( id_0, VALUE='                        ' )

	id_1 = WIDGET_BASE( id_0, /COLUMN )
	id_2 = WIDGET_LABEL( id_1, VALUE='Select Detector:' )
	id_2 = WIDGET_LIST( id_1, YSIZE=7, VALUE=det_types, UVALUE='DTYP' )



; Define initial settings


	WIDGET_CONTROL, stat_id.vhea, SENSITIVE=0
	WIDGET_CONTROL, stat_id.vtab, SENSITIVE=0
	WIDGET_CONTROL, stat_id.plot, SENSITIVE=0
	WIDGET_CONTROL, stat_id.show, SENSITIVE=0

;  Store values for individual instances with base widget

	HANDLE_VALUE, stat.id, stat_id, /SET, /NO_COPY
	HANDLE_VALUE, stat.val, stat_val, /SET, /NO_COPY
	WIDGET_CONTROL, buffil_wid, SET_UVALUE=stat, /NO_COPY


; Realize widget

	WIDGET_CONTROL, buffil_wid, /REALIZE, TLB_SET_XOFFSET=10, $
			TLB_SET_YOFFSET=600  

	xMANAGER,No_BLOCK=1, "pia_buffil", buffil_wid, GROUP=group

	RETURN
END
