;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_CC_DEFIN
;
; PURPOSE:
;	Simple Menu for choosing colour correction elements 
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_CC_DEFIN, CC_STR [,overpl=overpl]
;
; INPUT:
;	(none)
;
; OUTPUT:
;	CC_STR:	a structure containing parameters for CC
;
; KEYWORD:
;	overpl: if plot to be produced has to be overplotted
;		(only meaningful for the calling program)
;	
; METHOD:
;	Widgets
;	
; COMMON BLOCKS:
;	none	
;
; MODIFICATION HISTORY:
;	Written by:	C.Gabriel (ESA/VILSPA)		May 1997
;	V6.3
;	Extension for modified BB models (CG + IH)	July 1997
;	V6.4
;	Bug for modified BB model nu-2 fixed (CG)	February 1998
;	V7.0
;-


PRO pia_cc_defin, cc_str, overpl=overpl


        base = WIDGET_BASE(TITLE = 'Colour correction', /column, xsize=300)


	oplot = 0
	model = cw_bgroup(base, LABEL_TOP = 'Colour correction choices', $
                        /EXCLUSIVE, /FRAME, $
                        SET_VALUE = 0, $
                        UVALUE = 'MODEL', $
                        ["Black Body model ", "Power Law model ",$
                         "Modified BB (Emissivity ~ nu)", $
                         "Modified BB (Emissivity ~ nu^2)"])
                        
	bbbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(bbbase, VALUE='B-B Temperature ([10.- 10000.]): ')
	bbtxt = WIDGET_TEXT(bbbase, /editable, XSIZE=8, VALUE= '      ',$
		UVALUE='JUNK')

	plbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(plbase, VALUE='Power law index ([-3,-2,...,3]): ')
	pltxt = WIDGET_TEXT(plbase, /editable, XSIZE=8, VALUE= '      ', $
		UVALUE='JUNK')
	WIDGET_CONTROL, plbase, SENSITIVE=0

	IF KEYWORD_SET(overpl) THEN BEGIN
	 overpl = cw_bgroup(base, LABEL_TOP = 'Plot choice', $
                        /EXCLUSIVE, /FRAME, $
                        SET_VALUE = 0, $
                        UVALUE = 'PLOT', $
                        ["Plot new ", "Overplot  "])
        ENDIF
                        
        rowbase = WIDGET_BASE(base, /ROW)

	ok_id = WIDGET_BUTTON(rowbase,   VALUE='       OK       ', $
	    UVALUE='OK',XSIZE=100)
	canc_id = WIDGET_BUTTON(rowbase, VALUE=' No Colour Corr ', $
	    UVALUE='CANCEL', XSIZE=100)
	
	WIDGET_CONTROL, base, /REALIZE

	ok = 0
	
	WHILE ok EQ 0 DO BEGIN
	  event = WIDGET_EVENT(BASE)
	  WIDGET_CONTROL, event.id, GET_UVALUE=Uvalue
	  
	  CASE 1 OF 
	    uvalue EQ 'OK': BEGIN
	  	WIDGET_CONTROL, model, GET_VALUE=value
	   	  corr = 1
		  CASE value(0) OF
	   	  0: BEGIN
	   	     typ = 'bb'
	   	     WIDGET_CONTROL, bbtxt, GET_VALUE=bbtemp
	   	     value = bbtemp(0) 
	             END
	           1:BEGIN
	   	     typ = 'power'
	   	     WIDGET_CONTROL, pltxt, GET_VALUE=plind
	   	     value = plind(0)
	             END
	           2:BEGIN
	   	     typ = 'mbbnu1'
	   	     WIDGET_CONTROL, bbtxt, GET_VALUE=bbtemp
	   	     value = bbtemp(0)
	             END
	           3:BEGIN
	   	     typ = 'mbbnu2'
	   	     WIDGET_CONTROL, bbtxt, GET_VALUE=bbtemp
	   	     value = bbtemp(0)
	             END
		    ENDCASE
	        IF STRTRIM(value,2) EQ '' THEN $
	          PRINT, STRING(7b) + 'Give Value for model'$
	        ELSE BEGIN 
 	   	 cc_str={corr:corr, typ:typ, value:float(value), oplot:oplot}
	    	 ok = 1
	    	 stop=0
	    	ENDELSE
	     END
	     
	    uvalue EQ 'CANCEL': BEGIN 
	     	stop=1
	     	ok = 1
	     	cc_str={corr:0, typ:'', value:0., oplot:0.}
	     END
	    
	    uvalue EQ 'MODEL': BEGIN 
	  	WIDGET_CONTROL, model, GET_VALUE=value
		IF value(0) NE 1 THEN BEGIN
		  WIDGET_CONTROL,bbbase, /sensitive
		  WIDGET_CONTROL,plbase, sensitive=0
		ENDIF ELSE BEGIN
		  WIDGET_CONTROL,plbase, /sensitive
		  WIDGET_CONTROL,bbbase, sensitive=0
		ENDELSE
	     END
	    uvalue EQ 'PLOT': BEGIN 
	  	WIDGET_CONTROL, overpl, GET_VALUE=value
		oplot = value(0)
	    END
	    ELSE: 
	  ENDCASE
	        
	ENDWHILE
	WIDGET_CONTROL, base, /DESTROY

        RETURN
END

