;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_CIMAGE
;
; PURPOSE:
;	PIA C-detectors IMAGE lego plotting.
;	This is a display dependant level menu in the PIA hierarchy.
;
;	This routine should only be called by the PIA display menues
;	and should not be called directly from the command line.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA, tmpdata, step
;
; INPUTS:
;	tmpdata: A structure containing data to be displayed
;	step:	 The chopper step to be plotted
;	rpid_ch: The raster point (BYTARR(2)) to be plotted
;	
; RESTRICTIONS:
;	Up to 4 chopper steps are lego-plotted
;	
; METHOD:
;	Use PIA_Xsurface for lego plotting
;		
; PROCEDURES USED:
;	PIA LIB:
;		cp_disc
;		decode_admn
;		pia_xsurface
;	
; MODIFICATION HISTORY:
;	Written by: C.Gabriel (ESA/ESTEC)		October 1994
;	Modified by: cg					July 1995
;	Extension for raster point choice (CG)		January 1996
;	Extension for raster points combination (CG)	December 1997
;	V6.6
;
;-
;****************************************************************************
;*  PIA CIMAGE - menu definition procedure
;****************************************************************************
PRO pia_cimage, tmpdata, step, rpid_ch 

; Definitions common to all instances

	det = strmid(tmpdata.det,0,2)
	IF det EQ 'C1' THEN med = fltarr(3,3) $
		ELSE med = fltarr(2,2)

; Flag the deselected values
        cp_disc, tmpdata, flagarr

	rpid_copy = tmpdata.rpid
	add0=''	
	add1=''
	
	ch0 = WHERE(tmpdata.rpid(0,*) EQ rpid_ch(0,0) )
	   		
	IF N_ELEMENTS(rpid_ch(0,*)) GT 1 THEN $
	 FOR I=1,N_ELEMENTS(rpid_ch(0,*))-1 DO BEGIN
	   IF rpid_ch(0,i) NE rpid_ch(0,0) THEN BEGIN
	    nch0 = WHERE(tmpdata.rpid(0,*) EQ rpid_ch(0,i) )
	    ch0 = [ch0,nch0]
	    add0=add0+'+'+STRTRIM(rpid_ch(0,i),2)
	   ENDIF
	 ENDFOR  
	 
	ch1 = WHERE(tmpdata.rpid(1,*) EQ rpid_ch(1,0))
	IF N_ELEMENTS(rpid_ch(1,*)) GT 1 THEN $
	 FOR I=1,N_ELEMENTS(rpid_ch(1,*))-1 DO BEGIN
	   IF rpid_ch(1,i) NE rpid_ch(1,0) THEN BEGIN
	    nch1 = WHERE(tmpdata.rpid(1,*) EQ rpid_ch(1,i))
	    add1=add1+'+'+STRTRIM(rpid_ch(1,i),2)
	    ch1 = [ch1,nch1]
	   ENDIF
	 ENDFOR  

	annm = '  RPid [' + $
		STRTRIM(string(FIX(rpid_ch(0,0))),2)+add0+','+$
		STRTRIM(string(FIX(rpid_ch(1,0))),2)+add1+']'


	IF N_ELEMENTS(rpid_ch(0,*)) GT 1 THEN add00='...' ELSE add00=''
	IF N_ELEMENTS(rpid_ch(1,*)) GT 1 THEN add01='...' ELSE add01=''

	rpid_copy(0,ch0)=-1b
	rpid_copy(1,ch1)=-1b

	ind = where(tmpdata.step EQ step AND $
		    rpid_copy(0,*) EQ -1b AND $
		    rpid_copy(1,*) EQ -1b, n)

	IF n EQ 0 THEN BEGIN 
	  MESSAGE, /info, 'Non existing combination of chopper steps and RPID'
	  RETURN
	ENDIF

	CASE det of

	'C1': BEGIN
	   FOR III = 0,2 DO BEGIN
		FOR II = 0,2 DO BEGIN
		   IF n EQ 1 THEN $
			med(iii,ii) = tmpdata.medi(ii+iii*3,ind) ELSE BEGIN
			   indacc = WHERE(flagarr(ii+iii*3,ind) EQ 0, nn)
			   IF nn GT 1 THEN $
		med(iii,ii) = median(tmpdata.medi(ii+iii*3,ind(indacc))) $
			   ELSE IF nn EQ 1 THEN $
		med(iii,ii) = tmpdata.medi(ii+iii*3,ind(indacc)) 
			ENDELSE
		ENDFOR
	   ENDFOR
	END

	'C2': BEGIN
	   IF n EQ 1 THEN BEGIN
	   	med(0,0) = tmpdata.medi(1,ind)
	   	med(0,1) = tmpdata.medi(2,ind)
	   	med(1,1) = tmpdata.medi(3,ind)
	   	med(1,0) = tmpdata.medi(0,ind)
	   ENDIF ELSE BEGIN
		indacc = WHERE(flagarr(1,ind) EQ 0, nn)
		IF nn GT 1 THEN $
	   	  med(0,0) = median(tmpdata.medi(1,ind(indacc))) $
		ELSE IF nn EQ 1 THEN $
	   	  med(0,0) = tmpdata.medi(1,ind(indacc))

		indacc = WHERE(flagarr(2,ind) EQ 0, nn)
		IF nn GT 1 THEN $
	   	  med(0,1) = median(tmpdata.medi(2,ind(indacc))) $
		ELSE IF nn EQ 1 THEN  $
	   	  med(0,1) = tmpdata.medi(2,ind(indacc))

		indacc = WHERE(flagarr(3,ind) EQ 0, nn)
		IF nn GT 1 THEN $
	   	  med(1,1) = median(tmpdata.medi(3,ind)) $
		ELSE IF nn EQ 1 THEN  $
	   	  med(1,1) = tmpdata.medi(3,ind(indacc))

		indacc = WHERE(flagarr(0,ind) EQ 0, nn)
		IF nn GT 1 THEN $
	   	  med(1,0) = median(tmpdata.medi(0,ind)) $
		ELSE IF nn EQ 1 THEN  $
	   	  med(1,0) = tmpdata.medi(0,ind(indacc))
	   ENDELSE
	END		
	
	ELSE:

	ENDCASE

	decode_admn, tmpdata.admn, title
	title = title + ' ' + tmpdata.unit
	IF N_ELEMENTS(tmpdata.step) GT 1 THEN $
	  subtitle = '!C Chopper Step'+strtrim(string(step),2) ELSE $
	  subtitle = ''
	subtitle = subtitle + '  RPid [' + $
		STRTRIM(string(FIX(rpid_ch(0,0))),2)+add00+','+$
		STRTRIM(string(FIX(rpid_ch(1,0))),2) +add01+']'
	xtitle = ' Y Sky direction'
	ytitle = ' Z Sky direction'
	ztitle = ' Median  [V/s]'
	charsize = 1.25	

	PIA_XSurface, med, title=title, xtitle=xtitle, $
		subtitle=subtitle, ytitle=ytitle, ztitle=ztitle, $
		charsize=charsize, wlego=1  

        RETURN
END

