;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_CIMAGE_SPD
;
; PURPOSE:
;	PIA C-detectors IMAGE lego plotting for SPD /AAP level.
;	This is a display dependant level menu in the PIA hierarchy.
;
;	This routine should only be called by the PIA display menues
;	and should not be called directly from the command line.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_CIMAGE_SPD, tmpdata, step, mulch, rpid_ch
;
; INPUTS:
;	tmpdata: An SPD (or AAP) structure containing data to be displayed
;	step:	 The chopper step to be plotted
;	mulch:	 Chopper step number printer flag (0:no, 1:yes)
;	rpid_ch: The raster point (BYTARR(2)) to be plotted
;		
;	
; KEYWORD:
;	AAP:	For AAP structure as input
;
; METHOD:
;	Use PIA_Xsurface for lego plotting
;	
; PROCEDURES USED:
;	PIA LIB:
;		decode_admn
;		get_spddisc
;		pia_xsurface
;
; MODIFICATION HISTORY:
;	Written by: C.Gabriel (ESA/ESTEC)		November 1994
;	Oct 95 Version 3.5
;	Extension for raster point choice (CG)		January 1996
;	Keyword AAP added (CG)				November 1997
;	Extension for raster points combination (CG)	December 1997
;	V6.6
;			
;-
; ****************************************************************************
;  PIA CIMAGE - menu definition procedure
; ****************************************************************************
PRO pia_cimage_spd, tmpdata, step, mulch, rpid_ch, AAP=AAP 

; Definitions common to all instances

	det = strmid(tmpdata.det,0,2)
	IF det EQ 'C1' THEN med = fltarr(3,3) $
		ELSE med = fltarr(2,2)

; Flag the deselected values
        get_spddisc, tmpdata, flagarr

	rpid_copy = tmpdata.rpid
	add0=''	
	add1=''
	
	ch0 = WHERE(tmpdata.rpid(0,*) EQ rpid_ch(0,0) )
	   		
	IF N_ELEMENTS(rpid_ch(0,*)) GT 1 THEN $
	 FOR I=1,N_ELEMENTS(rpid_ch(0,*))-1 DO BEGIN
	   IF rpid_ch(0,i) NE rpid_ch(0,0) THEN BEGIN
	    nch0 = WHERE(tmpdata.rpid(0,*) EQ rpid_ch(0,i) )
	    ch0 = [ch0,nch0]
	    add0=add0+'+'+STRTRIM(rpid_ch(0,i),2)
	   ENDIF
	 ENDFOR  
	 
	ch1 = WHERE(tmpdata.rpid(1,*) EQ rpid_ch(1,0))
	IF N_ELEMENTS(rpid_ch(1,*)) GT 1 THEN $
	 FOR I=1,N_ELEMENTS(rpid_ch(1,*))-1 DO BEGIN
	   IF rpid_ch(1,i) NE rpid_ch(1,0) THEN BEGIN
	    nch1 = WHERE(tmpdata.rpid(1,*) EQ rpid_ch(1,i))
	    add1=add1+'+'+STRTRIM(rpid_ch(1,i),2)
	    ch1 = [ch1,nch1]
	   ENDIF
	 ENDFOR  

	annm = '  RPid [' + $
		STRTRIM(string(FIX(rpid_ch(0,0))),2)+add0+','+$
		STRTRIM(string(FIX(rpid_ch(1,0))),2)+add1+']'


	IF N_ELEMENTS(rpid_ch(0,*)) GT 1 THEN add00='...' ELSE add00=''
	IF N_ELEMENTS(rpid_ch(1,*)) GT 1 THEN add01='...' ELSE add01=''

	rpid_copy(0,ch0)=-1b
	rpid_copy(1,ch1)=-1b
	        
	ind = where(tmpdata.cstp EQ step AND $
		    rpid_copy(0,*) EQ -1b AND $
		    rpid_copy(1,*) EQ -1b, n)

	IF n EQ 0 THEN BEGIN
		MESSAGE, /INFO, 'Non existing combination of chopper steps and RPID'
		RETURN
	ENDIF

	IF KEYWORD_SET(AAP) THEN udata = tmpdata.mnfl ELSE udata = tmpdata.mnpw 
	CASE det of

	'C1': BEGIN
	   FOR III = 0,2 DO BEGIN
		FOR II = 0,2 DO BEGIN
		   IF n EQ 1 THEN $
			med(iii,ii) = udata(ii+iii*3,ind) ELSE BEGIN
			   indacc = WHERE(flagarr(ii+iii*3,ind) EQ 0, nn)
			   IF nn GT 1 THEN $
		med(iii,ii) = median(udata(ii+iii*3,ind(indacc))) $
			   ELSE IF nn EQ 1 THEN $
		med(iii,ii) = udata(ii+iii*3,ind(indacc)) 
			ENDELSE
		ENDFOR
	   ENDFOR
	END

	'C2': BEGIN
	   IF n EQ 1 THEN BEGIN
	   	med(0,0) = udata(1,ind)
	   	med(0,1) = udata(2,ind)
	   	med(1,1) = udata(3,ind)
	   	med(1,0) = udata(0,ind)
	   ENDIF ELSE BEGIN
		indacc = WHERE(flagarr(1,ind) EQ 0, nn)
		IF nn GT 1 THEN $
	   	  med(0,0) = median(udata(1,ind(indacc))) $
		ELSE IF nn EQ 1 THEN $
	   	  med(0,0) = udata(1,ind(indacc))

		indacc = WHERE(flagarr(2,ind) EQ 0, nn)
		IF nn GT 1 THEN $
	   	  med(0,1) = median(udata(2,ind(indacc))) $
		ELSE IF nn EQ 1 THEN  $
	   	  med(0,1) = udata(2,ind(indacc))

		indacc = WHERE(flagarr(3,ind) EQ 0, nn)
		IF nn GT 1 THEN $
	   	  med(1,1) = median(udata(3,ind)) $
		ELSE IF nn EQ 1 THEN  $
	   	  med(1,1) = udata(3,ind(indacc))

		indacc = WHERE(flagarr(0,ind) EQ 0, nn)
		IF nn GT 1 THEN $
	   	  med(1,0) = median(udata(0,ind)) $
		ELSE IF nn EQ 1 THEN  $
	   	  med(1,0) = udata(0,ind(indacc))
	   ENDELSE
	END		
	
	ELSE:

	ENDCASE

	decode_admn, tmpdata.admn, title

	IF mulch EQ 1 THEN $
		subtitle = '!C Chopper Step'+strtrim(string(step),2) ELSE $
		subtitle = ''
	subtitle = subtitle + '  RPid [' + $
		STRTRIM(string(FIX(rpid_ch(0,0))),2)+add00+','+$
		STRTRIM(string(FIX(rpid_ch(1,0))),2)+add01+']'
	xtitle = ' Y Sky direction'
	ytitle = ' Z Sky direction'
	IF KEYWORD_SET(AAP) THEN ztitle=' Mean Flux Density [Jy] ' ELSE $
	ztitle = ' Mean In-band power  [W]'
	charsize = 1.25	

	PIA_XSurface, med, title=title, xtitle=xtitle, $
		subtitle=subtitle, ytitle=ytitle, ztitle=ztitle, $
		charsize=charsize, wlego=1  

        RETURN
END

