;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_CONV_DATE
;
; PURPOSE:
;	To return the string 'date' after conversion 
;
; CALLING SEQUENCE:
;	PIA_CONV_DATE, UTST, DATE
;
; INPUT PARAMETERS:
;	UTST	: Full seconds after 1989.0
;
; OUTPUT PARAMETERS:
;	DATE	: STRING with format 'dd:mm:yyyy - hh:mm:ss'
;
; PROCEDURES USED:
;       ASTRO LIB:
;		date_conv
;
; MODIFICATION HISTORY:
;	Written by: C. Gabriel (ESA/ESTEC)                April 1995
;	Oct 95 Version 3.5
;	Bug fixed using now julian date conversion (CG)	  January 1997 
;			
;-
;
;
;*********************************************************************
;*
;*********************************************************************
PRO PIA_CONV_DATE, UTST, DATE

 On_ERROR,2                                          ;Return to caller
;
; Check the number of parameters
;
	IF N_PARAMS() LT 2 THEN MESSAGE, $
	   'Syntax: PIA_CONV_DATE, UTST, DATE '

	
; convert to julian (not reduced & not sternberg) date

	jd = utst*1.D0 / 60. / 60. / 24
	juldate, [1989,1,1,0,0], jd0
	total_jd = jd+jd0


	daycnv, total_jd + 2400000.D0, year, mn, day, hr

	juldate, [year,1,1,0,0], jd0_act
	part_jd = total_jd - jd0_act + 1	
	
	day = FIX(part_jd)
	min = (hr-FIX(hr)) * 60.
	sec = (min-FIX(min))*60.
	min = FIX(min)
	hr = FIX(hr)
	
	

	DATE = [year,day,hr,min,sec]

	DATE = DATE_CONV(DATE,'STRING')

	RETURN
	END
	

