;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_CORR_VIGN
;
; PURPOSE:
;	Apply vignetting correction procedure to a phtscp structure 
;
; CATEGORY:
;       PIA - processing
;
; CALLING SEQUENCE:
;	pia_corr_vign, tmpdata, tmphdr, GROUP=group
;
; INPUTS:
;	tmpdata:  A PHTscp temporary structure
;	tmphdr:	  The temporary header
;	
; OUTPUTS:
;	tmpdata:  The updated PHTscp temporary structure
;	tmphdr:	  The updated temporary header 
;	
; COMMON BLOCKS:
;	phtvignet
;	
; RESTRICTIONS:
;	tmpdata must be a temporary PHT SCP structure
;	
; PROCEDURES USED:
;	PIA LIB:
;		get_wheels
;		vignet
;		vignet_tables_read
;	
; MODIFICATION HISTORY:
;	Written by: C.Gabriel (ESA/ESTEC)		February 1995
;	Oct 95 Version 3.5
;	Tested and fixed (CG)				May 1997
;	V6.3
;	Returning asap if only FCS 
;	(to avoid HDR line on vignetting) (CG)		October 1997
;	V6.5
;	Avoiding divisions by 0 and fixing q3me (CG)	July 1998
;	V7.2 			
;			
;-
;*********************************************************************
;*
;*********************************************************************
PRO PIA_CORR_VIGN, tmpdata, tmphdr, GROUP=group
@phtvignet
        ON_ERROR, 2

;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  PIA_CORR_VIGN, TMPDATA, TMPHDR, GROUP=group'

	indnfcs = WHERE(tmpdata.fcsn EQ 0, nfcs)
	IF nfcs EQ 0 THEN RETURN
	
; Check if header was given as an argument
IF N_PARAMS() EQ 1 THEN tmphdr = tmpdata.hdr

;  At the moment we just use always default values - In the future this
;  should become an interactive choice
; Read vignet tables into phtvign 

	IF N_ELEMENTS(pc2vign) EQ 0 THEN vignet_tables_read

	GET_WHEELS, tmpdata.admn, wheels

	IF strmid(tmpdata.det,0,1) EQ 'P' THEN BEGIN 
; For P pixel means aperture
		pixel = wheels(1) - 1 		
		filter = wheels(2)
		dim1 = 1
	ENDIF ELSE BEGIN
		dim1 = N_ELEMENTS(tmpdata.aver(*,0)) - 2 
		pixel = indgen(dim1)
		filter = wheels(1)
	ENDELSE

        FOR pix=0,dim1-1 DO BEGIN
		vignet, tmpdata.det, tmpdata.aver(pix,*), $
				tmpdata.avun(pix,*), tmpdata.chop, $
				tmpdata.fcsn, pixel(pix), filter, $
				aver, avun

		vignet, tmpdata.det, tmpdata.medi(pix,*), $
				tmpdata.q1me(pix,*), tmpdata.chop, $
				tmpdata.fcsn, pixel(pix), filter, $
				medi, q1me
		tmpdata.aver(pix,*) = aver			
		tmpdata.avun(pix,*) = avun			
		tmpdata.medi(pix,*) = medi			
;		tmpdata.q1me(pix,*) = q1me			

		quot = q1me * 0. + 1.
		indacc = WHERE(tmpdata.flag(pix,*) LE 1 AND $
		               tmpdata.q1me (pix,*) NE 0., n)
		IF n GT 0 THEN $ 
		  quot(indacc) = q1me(indacc) / tmpdata.q1me(indacc)

		tmpdata.q3me(pix,*) = tmpdata.q3me(pix,*) * quot
		tmpdata.q1me(pix,*) = q1me			
	ENDFOR

; include information in header
	FXADDPAR, tmphdr, 'PRC_VIGN', 1, ' Vignetting corr. applied', $
		BEFORE='XTENSION'
 
        RETURN
	END
		     
