;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_CORRECTIONS
;
; PURPOSE:
;       Widget routine for decision on which correction steps are 
;	enabled/disabled, as well as for customizing them by calls 
;	to the corresponding routines
;
; CATEGORY:
;       PIA - graphics
;
; CALLING SEQUENCE:
;       PIA_CORRECTIONS
;
; KEYWORD INPUTS:
;	ERD:	Corrections for the ERD level listed for choice & customize
;	SRD:	Corrections for the SRD level listed for choice & customize
;	SCP:	Corrections for the SCP level listed for choice & customize
;
; COMMON BLOCKS:
;       gen_choices
;
; PROCEDURES USED:
;       PIA LIB:
;	  deglitch_change
;	  pia_def_darkorb
;	  pia_pairdegl
;	  pia_rodegl
;
; MODIFICATION HISTORY:
;       Written by: Carlos GABRIEL (ESA-SAI/VILSPA)		March 1998
;	V7.0
;	/Modal use according to prescribed by IDL >=5.0 (CG)	January 1999
;	V7.3
;	Signal linearization added (SRD+SCP level)		June 1999
;	V7.4
;	PHT-S pointing correction added (CG)			December 1999
;	V8.2
;-
PRO pia_corrections_event, event
@gen_choices

WIDGET_CONTROL, event.id, get_UVALUE=uvalue
WIDGET_CONTROL, event.top, GET_UVALUE=cor_save
          	handle_value, cor_save(0), cor
	CASE uvalue OF

          'ACCEPT': BEGIN
          
 		gen_correct.linear = cor.linear
		gen_correct.rpid0 = cor.rpid0
		gen_correct.darkc_srd = cor.darkc_srd
		gen_correct.darkc = cor.darkc
		gen_correct.deglit = cor.deglit
		gen_correct.siglin = cor.siglin
		gen_correct.siglin2 = cor.siglin2
		gen_correct.deglit2= cor.deglit2
		gen_correct.pairdeglit= cor.pairdeglit
		gen_correct.resint = cor.resint
		gen_correct.resint_scp = cor.resint_scp
		gen_correct.bcksub = cor.bcksub
		gen_correct.vignet = cor.vignet
		gen_correct.spoint = cor.spoint
		gen_correct.chfr = cor.chfr

                WIDGET_CONTROL, event.top, /DESTROY
                GOTO, out
          END

          'CANCEL': BEGIN

                WIDGET_CONTROL, event.top, /DESTROY
                GOTO, out

          END

	  'ERDSELEC': BEGIN
        	CASE event.value of
		
	        	0: cor.linear = event.select
			
                        1: cor.deglit2 = event.select
                        
                        2: BEGIN
                        	pia_rodegl, -1, 0, GROUP=event.top, /NO_DATA,$
					/modal
                        	WIDGET_CONTROL, event.id, GET_VALUE=all_values
                        	all_values(2) = 0
                        	WIDGET_CONTROL, event.id, SET_VALUE=all_values 
                        END

                        3: cor.pairdeglit = event.select 
                        
                        4: BEGIN
                        	pia_pairdegl, -1, 0, GROUP=event.top, /no_data,$
					/modal
                        	WIDGET_CONTROL, event.id, GET_VALUE=all_values
                        	all_values(4) = 0
                        	WIDGET_CONTROL, event.id, SET_VALUE=all_values 
                        END
		
		ENDCASE
	   END

	  'SRDSELEC': BEGIN
        	CASE event.value of
		
	        	0: cor.rpid0 = event.select
			
                        1: cor.resint = event.select
                        
                        2: cor.darkc_srd = event.select
 			
                        3: BEGIN
                        	pia_def_darkorb, group=event.top, /modal
                        	WIDGET_CONTROL, event.id, GET_VALUE=all_values
                        	all_values(3) = 0
                        	WIDGET_CONTROL, event.id, SET_VALUE=all_values 
                        END

                        4: cor.siglin = event.select 
                        
                        5: cor.deglit = event.select 
                        
                        6: BEGIN
                        	deglitch_change, /no_data, group=event.top, $
				   /modal
                        	WIDGET_CONTROL, event.id, GET_VALUE=all_values
                        	all_values(6) = 0
                        	WIDGET_CONTROL, event.id, SET_VALUE=all_values 
                        END
		
		ENDCASE
	   END

	  'SCPSELEC': BEGIN
        	CASE event.value of
		
	        	0: cor.resint_scp = event.select
			
                        1: cor.darkc = event.select
                        
                        2: BEGIN
                        	pia_def_darkorb, group=event.top, /modal
                        	WIDGET_CONTROL, event.id, GET_VALUE=all_values
                        	all_values(2) = 0
                        	WIDGET_CONTROL, event.id, SET_VALUE=all_values 
                        END

                        3: cor.siglin2 = event.select 
                        
                        4: cor.vignet = event.select 
                        
                        5: cor.bcksub = event.select
		
                        6: cor.chfr = event.select

                        7: cor.spoint = event.select

		ENDCASE
	   END
	ENDCASE
        
        handle_value, cor_save, cor, /SET
	WIDGET_CONTROL, event.top, SET_UVALUE=cor_save
OUT:

	RETURN
	END


PRO pia_corrections, ERD=erd, SRD=srd, SCP=SCP, GROUP=group

; Definitions common to all instances
@gen_choices

	linear=gen_correct.linear
	siglin= gen_correct.siglin
	siglin2= gen_correct.siglin2
	rpid0=gen_correct.rpid0
	resint = gen_correct.resint
	resint_scp = gen_correct.resint_scp
	darkc_srd=gen_correct.darkc_srd 
	darkc=gen_correct.darkc 
	deglit=gen_correct.deglit 
	deglit2=gen_correct.deglit2 
	pairdeglit=gen_correct.pairdeglit 
	bcksub = gen_correct.bcksub 
	vignet = gen_correct.vignet
	spoint = gen_correct.spoint
	chfr = gen_correct.chfr

	cor = {linear:linear, rpid0:rpid0, resint:resint, $
		resint_scp:resint_scp,darkc:darkc, darkc_srd:darkc_srd, $
		deglit:deglit, deglit2:deglit2, pairdeglit:pairdeglit, $
		bcksub:bcksub, vignet:vignet, chfr:chfr, siglin:siglin, $
		siglin2:siglin2, spoint:spoint}

IF not KEYWORD_SET(ERD) and not KEYWORD_SET(SRD) $
  and not KEYWORD_SET(SCP) THEN RETURN
  
	IF not KEYWORD_SET(group) THEN group = !pia_top_wid

	gchbase = WIDGET_BASE(TITLE = 'PIA corrections choice menu', $ 
		 		/COLUMN, /MODAL, GROUP=group )
 
	IF KEYWORD_SET(erd) THEN $
 	erdbut = cw_bgroup(gchbase, LABEL_TOP = 'ERD corrections:', $
			/NONEXCLUSIVE, /FRAME, $
			SET_VALUE = [linear,deglit2,0,pairdeglit,0], $
			UVALUE = 'ERDSELEC', $
			["Ramps Linearization                    ", $
			 "Ramps Deglitching (single ramp method) ", $
			 "    Customize it                       ", $
			 "Ramps Deglitching (2 thresholds method)", $
			 "    Customize it                       "])

	IF KEYWORD_SET(srd) THEN $
 	srdbut = cw_bgroup(gchbase, LABEL_TOP = 'SRD corrections:', $
		/NONEXCLUSIVE, /FRAME, $
		SET_VALUE = [rpid0, resint, darkc_srd,0, siglin, deglit,0], $
		UVALUE = 'SRDSELEC', $
			["Ignore RPID for Tracking Mode in SSO   ", $
			 "Reset Interval Correction              ", $
			 "Dark Current Subtraction               ", $
			 "    Customize it                       ", $
			 "Signal linearization                   ", $
			 "Signals Deglitching                    ", $
			 "    Customize it                       "])

	IF KEYWORD_SET(scp) THEN $
 	scpbut = cw_bgroup(gchbase, LABEL_TOP = 'SCP corrections:', $
			/NONEXCLUSIVE, /FRAME, $
			SET_VALUE = [resint_scp,darkc,0,siglin2,vignet,$
					bcksub,chfr, spoint],$
			UVALUE = 'SCPSELEC', $
			["Reset Interval Correction              ", $
			 "Dark Current Subtraction               ", $
			 "    Customize it                       ", $
			 "Signal linearization                   ", $
			 "Vignetting Correction                  ", $
			 "Background Subtraction in chopped mode ", $
			 "Chopper Frequency Dependence correction", $
			 "PHT-S pointing correction (AAP level)" ])

        control = WIDGET_BASE(gchbase,/ROW)

        accept = WIDGET_BUTTON(control, VALUE = '  OK  ', $
                        /FRAME, UVALUE = 'ACCEPT')
        junk = WIDGET_LABEL(control, VALUE = '                    ')
        cancel = WIDGET_BUTTON(control, VALUE = '  Cancel  ', $
                        /FRAME, UVALUE = 'CANCEL')
        junk = WIDGET_LABEL(control, VALUE = '         ')

	
        WIDGET_CONTROL, gchbase, /REALIZE, TLB_SET_XOFFSET=450

	cor_save = handle_create()
	handle_value, cor_save, cor, /SET
        WIDGET_CONTROL, gchbase, SET_UVALUE=cor_save

        xMANAGER,No_BLOCK=1, "pia_corrections", gchbase, GROUP=group
	
        RETURN
END

	
	
