;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_DECO_DEFIN
;
; PURPOSE:
;	Simple Menu for choosing deconvolution parameters 
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_DECO_DEFIN, DECO_STR 
;
; INPUT:
;	(none)
;
; OUTPUT:
;	DECO_STR: a structure containing parameters for deconvolution
;
;	
; METHOD:
;	Widgets
;	
; COMMON BLOCKS:
;	none	
;
; MODIFICATION HISTORY:
;	Written by:	C.Gabriel (ESA/VILSPA)		September 1998
;	V7.3
;-


PRO pia_deco_defin, d_str


	IF N_ELEMENTS(d_str) EQ 0 THEN $
	  d_str={int_noise:-1., chisq_lim:0.7, $
		max_iter:20, chisq_dif:0.01, bck_subt:'NO', bckgr:0}
		
        base = WIDGET_BASE(TITLE = 'Deconvolution parameters', /column)

;	data = [STRING(d_str.int_noise), STRING(d_str.chisq_lim), $
;		STRING(d_str.max_iter), STRING(d_str.chisq_dif), $
;		STRING(d_str.bck_subt), STRING(d_str.bckgr)] 
	IF STRPOS(STRUPCASE(d_str.bck_subt),'Y') NE -1 THEN $
		d_str.bck_subt = 'YES' ELSE d_str.bck_subt = 'NO'
	data = STRTRIM(STRING(d_str, FORMAT='(A16)'),2)
;	data = STRING(d_str)
	labels = ["Intrinsic noise:", "Chi-square limit:", $
		  "Max. iterations:", "Chisq.diff.limit:", $
		  "Subtr. constant?", "Use bck.constant:" ] 

	table_id = WIDGET_TABLE(base, value=data, /EDITABLE, /ALL_EVENTS,$
			YSIZE=1, XSIZE=N_ELEMENTS(data), COLUMN_LABELS=labels,$
			UVALUE='JUNK', ROW_LABELS=['Values:'], SCR_XSIZE=800,$
			ALIGNMENT=0, COLUMN_WIDTHS=120)
	
	lab = WIDGET_LABEL(base, $
		VAL='Please, hit return after every cell change to make it valid')

        rowbase = WIDGET_BASE(base, /ROW)

	ok_id = WIDGET_BUTTON(rowbase,   VALUE='       OK       ', $
	    UVALUE='OK',XSIZE=100)
	canc_id = WIDGET_BUTTON(rowbase, VALUE='     Cancel     ', $
	    UVALUE='CANCEL', XSIZE=100)
	
	WIDGET_CONTROL, base, /REALIZE

	ok = 0
	
	WHILE ok EQ 0 DO BEGIN
	  event = WIDGET_EVENT(BASE)
	  WIDGET_CONTROL, event.id, GET_UVALUE=Uvalue
	  
	  CASE 1 OF 
	    uvalue EQ 'OK': BEGIN
	  	WIDGET_CONTROL, table_id, GET_VALUE=data
		FOR i=0,5 DO $
		 d_str.(i) = data(i)
		ok=1
	    END
	     
	    uvalue EQ 'CANCEL': BEGIN 
	     	ok = 1
	     END
	    
	    ELSE: 
	  ENDCASE
	        
	ENDWHILE
	WIDGET_CONTROL, base, /DESTROY

        RETURN
END
