;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_DECONV
;
; PURPOSE:
;	Graphical application for map deconvolution 
;
; CATEGORY:
;	PIA - graphics/processing
;
; CALLING SEQUENCE:
;	PIA_DECONV, imap, imappar, imaphdr, dec_imap
;
; INPUTS:
;	IMAP		The two dimensional map of the input image
;
;	IMAPPAR		The map parameter structure  as used in PIA
;
;	IMAPHDR		The header of the measurement
;
;
; OUTPUTS:
;	DEC_IMAP	The deconvolved map
;
; PROCEDURES USED:
;	PIA Procedure(s):
;		pia_mapdraw
;		pia_xsurface
;		phtfilter_init
;	Astronomical Library:
;		max_entropy
;		max_likelihood
;	Internal:
;		pia_deconv_event
;
; COMMON BLOCKS:
;	phtfilter		filter id's
;	phtfilter_prop		filter properties
;
; MODIFICATION HISTORY:
;	Written by:		C. Gabriel, ESA/VILSPA		May 1998
;	V7.2
;	No modal mode now (no need) (CG)
;	No convolution of footprint before interpolation (CG)	September 1998
;	V7.3
;-
PRO PIA_DECONV_EVENT, event

@phtfilter
@phtfilter_prop


	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.top, GET_UVALUE=hsave
	HANDLE_VALUE, hsave, save
	HANDLE_VALUE, save.imaphdr, imaphdr

	CASE uvalue of

	  'CHOICE': BEGIN
	             	save.dec_method = event.value
			HANDLE_VALUE, hsave, save, /SET
		    END
		     
	  'CP': BEGIN
		dpar = save.dpar
		PIA_DECO_DEFIN, dpar
		save.dpar = dpar
		HANDLE_VALUE, hsave, save, /SET
		END

	  'FP': BEGIN
	    	PIA_XSURFACE, save.fp, Title='Original Footprint'
	    	END	   
;	  'CFP': BEGIN
;	    	PIA_XSURFACE, save.cfp, Title='Convolved Footprint'
;	    	END	   
	  'IFP': BEGIN
	    	PIA_XSURFACE, save.fpred, Title='Interpolated Footprint'
	    	END	
	  'OK': BEGIN
	        WIDGET_CONTROL, event.top, /hourglass
;	        WIDGET_CONTROL, save.param_id, GET_VALUE=iter
;	        iter = FIX(iter(0))
	        lmult = 0

; reduce FP if dimensions too large

		red_fpred = save.fpred
		smap = size(save.imap) & smx=smap(1) & smy=smap(2)
		spsf = size(red_fpred) & spx=spsf(1) & spy=spsf(2)
		IF spx GT smx THEN BEGIN
				difx2 = (spx - smx + 1) / 2  			   
			        red_fpred = red_fpred(difx2:spx-difx2-1,*)
				PRINT, $
				'Warning ... image x size larger than FP x size'
				PRINT, $
				' working with corresponding FP portion'
		ENDIF 
		IF spy GT smy THEN BEGIN
				dify2 = (spy - smy + 1) / 2  			   
			        red_fpred = red_fpred(*,dify2:spy-dify2-1)
				PRINT, $
				'Warning ... image y size larger than FP y size'
				PRINT, $
				' working with corresponding FP portion'
		ENDIF 
				

		IF save.dec_method THEN BEGIN
			IF save.dpar.bck_subt NE 'NO' THEN $
			  imap = save.imap-save.dpar.bckgr ELSE imap=save.imap

				
			mem2, imap, red_fpred, dcmap, /init, $
				NITER=save.dpar.max_iter, $
				SIGMA=save.dpar.int_noise, $
				CHIMIN=save.dpar.chisq_lim, $
				STALL=save.dpar.chisq_dif, SCALE=0, $
				HEADER=imaphdr
			IF save.dpar.bck_subt NE 'NO' THEN $
				dcmap = dcmap+save.dpar.bckgr

;		  lucy_guess, iter, save.imap, save.fpred, dcmap
;	         FOR i=1,iter DO MAX_ENTROPY, save.imap, save.fpred, dcmap, $
;	        	lmult, FT_PSF=psf_ft $
	        ENDIF ELSE BEGIN
			 
			IF save.dpar.bck_subt NE 'NO' THEN $
			  imap = save.imap-save.dpar.bckgr ELSE imap=save.imap

			maxlike2, imap, red_fpred, dcmap, /init, $
				NITER=save.dpar.max_iter, $
				SIGMA=save.dpar.int_noise, $
				CHIMIN=save.dpar.chisq_lim, $
				STALL=save.dpar.chisq_dif, SCALE=0, $
				HEADER=imaphdr

			IF save.dpar.bck_subt NE 'NO' THEN $
				dcmap = dcmap+save.dpar.bckgr
					
;			
;		  dlucyiter, save.imap, save.fpred, dcmap, 1, 1000, $
;			SQRT(save.imap), iter, 1.	
;  	         FOR i=1,iter DO MAX_LIKELIHOOD, save.imap, save.fpred, dcmap, $
;	        	FT_PSF=psf_ft  
		ENDELSE

		hdcmap = HANDLE_CREATE()
	        HANDLE_VALUE, hdcmap, dcmap, /SET
	        save.dcmap = hdcmap
;	        save.niter = iter
		HANDLE_VALUE, save.imaphdr, imaphdr, /SET
		HANDLE_VALUE, hsave, save, /SET

;		WIDGET_CONTROL, save.dcmap_id, /sensitive
		WIDGET_CONTROL, save.idcmap_id, /sensitive
		WIDGET_CONTROL, save.quit_id, /sensitive
	        END
	  'ORMAP': PIA_XSURFACE, save.imap, TITLE='Original map'

	  'ORIMAP': PIA_mapdraw, save.imap, save.imappar.trans, save.imappar,$
	  	     imaphdr, 0, TITLE='Original map', $
	  	     HEADLINE="Brightness Map: "+save.imappar.admn_decoded

	  'DCMAP': BEGIN
	  	handle_value, save.dcmap, dcmap
	  	IF save.dec_method THEN met = 'Max.Entr.' ELSE met = 'Max.Lhood'
		Title='Deconvolved map - '+ met + ' - ' 	  	
		PIA_XSURFACE, dcmap, Title=title
	  	END

	  'IDCMAP': BEGIN
	  	handle_value, save.dcmap, dcmap
	  	IF save.dec_method THEN met = 'Max.Entr.' ELSE met = 'Max.Lhood'
	  	res = $
	  	 STRPOS(save.imappar.admn_decoded,dec_admn(save.imappar.admn))
	  	IF res NE -1 THEN $
	  	 admndec = STRMID(save.imappar.admn_decoded,0,res-2) ELSE $
	  	 admndec = '' 
		headline = "Deconvolved Map (" + met + "): "+admndec
	  	PIA_mapdraw, dcmap, save.imappar.trans, save.imappar,$
	  	 imaphdr, 0, TITLE='Deconvolved map', $
	  	 HEADLINE=headline, /NO_DECONV
	  	END

	  'QUIT': WIDGET_CONTROL, event.top, /destroy
	  
	  'CANCEL': BEGIN
	        save.dcmap = 0L
	        handle_value, hsave, save, /SET
	        WIDGET_CONTROL, event.top, /destroy
	   END
	           
	  ELSE:
 	  
 	ENDCASE
 	  
 	RETURN
 	END	
		
;;;;;;;;;;;;;;;               The menu routine      ;;;;;;;;;;;;;;;;;;;;;;	
	     

PRO PIA_DECONV, imap, imappar, imaphdr, dec_imap

@phtfilter
@phtfilter_prop

	IF N_ELEMENTS(c1filters) EQ 0 THEN PHTFILTER_INIT

	filts = [p1filters, p2filters, p3filters, c1filters, c2filters]

; calculate noise intrinsic to image and min for background
	int_noise = GET_MAP_NOISE(IMAP)
;	difx = median(abs(imap - shift(imap,1,0))) 
;	dify = median(abs(imap - shift(imap,0,1)))
;	int_noise = (difx+dify) * 0.5
	bckgr = min(imap)

	filter = STRTRIM(imappar.filter,2)
	IF STRPOS(filter, '_UM') NE -1 THEN BEGIN
	   res1 = STRPOS(filter, '_')
	   res2 = STRPOS(filter, '_', res1+1)
	   IF res1 NE -1 AND res2 NE -1 THEN BEGIN
	     filter = STRMID(filter,0,2) + STRMID(filter,res1,res2-res1)
;	     help, filter
	   ENDIF
	ENDIF	
		 
	CASE imappar.detector of
	
	'C1': BEGIN
		fxread, !CALG + 'PC1FOOTP.FITS', fp, fp_hdr
		ind = WHERE(c1filters EQ filter, count)
		IF count EQ 0 THEN BEGIN
		   MESSAGE, /INFO, 'Filter not found, returning'
		   RETURN
		ENDIF
		fp = REFORM(fp(ind,*,*))
		fp = fp / TOTAL(fp)
		fpsize = [7.5,7.5]
		steps = 35
	END
	
	'C2': BEGIN
		fxread, !CALG + 'PC2FOOTP.FITS', fp, fp_hdr
		ind = WHERE(c2filters EQ filter, count)
		IF count EQ 0 THEN BEGIN
		   MESSAGE, /INFO, 'Filter not found, returning'
		   RETURN
		ENDIF
		fp = REFORM(fp(ind,*,*))
		fp = fp / TOTAL(fp)
		fpsize = [15.,15.]
		steps = 35
	END
	
	'P2': BEGIN
; first see if map contains aperture info, otherwise return
		tagnam = tag_names(imappar)
		ind = WHERE(tag_names(imappar) EQ 'APER', count)
		IF count EQ 0 THEN BEGIN
		  MESSAGE, /INFO, 'Map structure is old type, no aperture info'
		  MESSAGE, /INFO, 'No possible to deconvolve, returning'
		  RETURN
		ENDIF ELSE aper = imappar.aper - 1
				
		fxread, !CALG + 'PP2FOOTP.FITS', fp, fp_hdr
		ind = WHERE(p2filters EQ filter, count)
		IF count EQ 0 THEN BEGIN
		   MESSAGE, /INFO, 'Filter not found, returning'
		   RETURN
		ENDIF

		fp = REFORM(fp(ind,aper,*,*))
		fp = fp / TOTAL(fp)
		IF aper LT 6 OR aper GT 10 THEN $
		 fpsize = [3.,3.] ELSE fpsize = [2.,2.]
		steps = 87
	END

	'P3': BEGIN
; first see if map contains aperture info, otherwise return
		tagnam = tag_names(imappar)
		ind = WHERE(tag_names(imappar) EQ 'APER', count)
		IF count EQ 0 THEN BEGIN
		  MESSAGE, /INFO, 'Map structure is old type, no aperture info'
		  MESSAGE, /INFO, 'No possible to deconvolve, returning'
		  RETURN
		ENDIF ELSE aper = imappar.aper - 1
				
		fxread, !CALG + 'PP3FOOTP.FITS', fp, fp_hdr
		ind = WHERE(p3filters EQ filter, count)
		IF count EQ 0 THEN BEGIN
		   MESSAGE, /INFO, 'Filter not found, returning'
		   RETURN
		ENDIF

		fp = REFORM(fp(ind,aper,*,*))
		fp = fp / TOTAL(fp)
		IF aper LT 6 THEN $
		fpsize = [10.,10.] ELSE fpsize = [2.,2.]
		steps = 41
	END
	
	ELSE: BEGIN
	 MESSAGE, /INFO, 'Not yet implemented, returning
	 RETURN
	END
	
	ENDCASE
	
	pixs = imappar.pixsize
	fcts = pixs / fpsize
	
; convolve first to image pixel size - IS NOT NECESSARY since 
; it is a footprint matrix and not a psf
;	unos = [round(fcts(0)),round(fcts(1))] > [1,1]
;	kernel = fltarr(unos(0)+2,unos(1)+2)
;	kernel(1:unos(0),1:unos(1)) = 1
	
;	conv_fp = convol(fp,kernel, total(kernel))
	
; get always an odd number of pixels for the reduced matrix
	nx = fix((steps)/fcts(0)/2)* 2 + 1
	ny = fix((steps)/fcts(1)/2)* 2 + 1

	tot = (steps-1) * fpsize
	totx = (nx-1) * pixs(0)
	toty = (ny-1) * pixs(1)	
	
	int_posx = (indgen(nx) * pixs(0) + (tot(0)-totx)/2) / fpsize(0)
	int_posy = (indgen(ny) * pixs(1) + (tot(1)-toty)/2) / fpsize(1)

	fpred = $
	 interpolate(fp, int_posx, int_posy, /grid)
	fpred = fpred / total(fpred)	
		
	
	base = WIDGET_BASE(TITLE="PIA map deconvolution menu", /COLUMN)
	
	r_base = WIDGET_BASE(base, /ROW, /FRAME, /BASE_ALIGN_CENTER, /ALIGN_CENTER)
        stdbut = cw_bgroup(r_base, LABEL_TOP = 'Method Choice', $
                        /EXCLUSIVE, /FRAME, ROW=2, $
                        SET_VALUE = 0, $
                        UVALUE = 'CHOICE', $
                        ["Max. Likelihood ",$
                         "Max. Entropy "])

	c_base = WIDGET_BASE(r_base, /COLUMN)
	label = WIDGET_LABEL(c_base, VALUE='')
	label = WIDGET_LABEL(c_base, VALUE='')
	label = WIDGET_LABEL(c_base, VALUE='')
	label = WIDGET_LABEL(c_base, VALUE='')
	label = WIDGET_LABEL(c_base, VALUE='')
	param_id = WIDGET_BUTTON(c_base, VALUE=' Change param. ', UVALUE='CP')

	label = WIDGET_LABEL(base, VALUE='  ')

	sbase = WIDGET_BASE(base, /Column, /FRAME, /BASE_ALIGN_CENTER, /ALIGN_CENTER)
	label = WIDGET_LABEL(sbase, VALUE='Draw maps')
	parbase = WIDGET_BASE(sbase, /ROW)
	imap_id = WIDGET_BUTTON(parbase, $
		VALUE='  Original Map   ', UVALUE='ORIMAP')
	idcmap_id = WIDGET_BUTTON(parbase,  $
		VALUE=' Deconvolved Map ', UVALUE='IDCMAP')
	WIDGET_CONTROL, idcmap_id, sensitive=0

	label = WIDGET_LABEL(base, VALUE='  ')
		
	sbase = WIDGET_BASE(base, /Column, /FRAME, /BASE_ALIGN_CENTER, /ALIGN_CENTER)
	label = WIDGET_LABEL(sbase, VALUE='    Display surfaces of footprints    ')
	parbase = WIDGET_BASE(sbase, /ROW)
	footpr_id = WIDGET_BUTTON(parbase, VALUE=' Original FP ', UVALUE='FP')
;	cfootpr_id = WIDGET_BUTTON(parbase,VALUE=' Conv. FP ', UVALUE='CFP')
	ifootp_id = WIDGET_BUTTON(parbase, VALUE='Interpolated FP', UVALUE='IFP')
	;map_id = WIDGET_BUTTON(parbase,    VALUE=' Orig. Map', UVALUE='ORMAP')
	;dcmap_id = WIDGET_BUTTON(parbase,  VALUE='Deconv. Map', UVALUE='DCMAP')
	;WIDGET_CONTROL, dcmap_id, sensitive=0
	
	label = WIDGET_LABEL(base, VALUE='  ')
	
	cont_base = WIDGET_BASE(base, /ROW, /BASE_ALIGN_CENTER, /ALIGN_CENTER)
	
	test_id = WIDGET_BUTTON(cont_base, VALUE= ' Deconvolve  ', UVALUE='OK')
	
	quit_id = WIDGET_BUTTON(cont_base, VALUE= '    Quit     ', $
		UVALUE= 'QUIT')
;	WIDGET_CONTROL, quit_id, sensitive=0
;	canc_id = WIDGET_BUTTON(cont_base, VALUE= '    Cancel   ', $
;		UVALUE= 'CANCEL')

	dpar = {int_noise:int_noise, chisq_lim:1.0, $
		max_iter:20, chisq_dif:0.01, bck_subt:'NO', bckgr:bckgr}
	imhdr = HANDLE_CREATE()
	HANDLE_VALUE, imhdr, imaphdr, /SET
	save = {imap:imap, imappar:imappar, imaphdr:imhdr, dcmap:0L, $
		fp:fp, fpred:fpred, quit_id:quit_id, $
		param_id:param_id, idcmap_id:idcmap_id, $
		niter:0, dec_method:0, dpar:dpar}
	
	hsave = HANDLE_CREATE()
	HANDLE_VALUE, hsave, save, /SET

        WIDGET_CONTROL, base, /REALIZE, TLB_SET_XOFFSET=150, $
                        TLB_SET_YOFFSET=150, SET_UVALUE=hsave

        xMANAGER,No_BLOCK=1, "pia_deconv", base, GROUP=group
        
        handle_value, hsave, save
	IF save.dcmap NE 0L THEN $
         handle_value, save.dcmap, dec_imap ELSE dec_imap = -1
	
        RETURN
END
	
