;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_def_darkorb
;
; PURPOSE:
;	Simple widget I/F for defining how the orbital dark current subtraction
;	is performed 
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_def_darkorb
;
;	
; COMMON BLOCKS:
;	phtdarkorb
;
; PROCEDURES USED:
;	none
;	
; MODIFICATION HISTORY:
;	Written by:	C.Gabriel (ESA/VILSPA-SAI)	December 1997
;	Version 6.6
;	Bug corrected (JAc)				February 1998
;	Option for subtraction of dark current dependant on exposure
;	 time (only for PHT-S) added (JAc)		January 1999 
;	Keyword modal added for inclusion in modal
;	widgets (CG)					January 1999
;	V7.3
;-

; ****************************************************************************
;  PIA_def_darkorb
; ****************************************************************************

PRO pia_def_darkorb, group=group, modal=modal
@phtdarkorb


        junkbase = WIDGET_BASE(TITLE=$
          'How to apply orbit dependant dark current subtraction', $
            /COLUMN, XSIZE=500, group=group, modal=modal)
        

	jun2base = WIDGET_BASE(junkbase, /ROW)
	junk = WIDGET_LABEL(jun2base, $
	 VAL='PIA can subtract dark currents interpolated for every data point', $
		UVAL='JUNK')

	jun2base = WIDGET_BASE(junkbase, /COLUMN, /FRAME, /EXCLUSIVE)
	butall = WIDGET_BUTTON(jun2base, $
		VAL='Interpolate one value per data point', UVAL='ALL')
	butrp = WIDGET_BUTTON(jun2base, $
		VAL="Interpolate one value per raster point", UVAL='RP')
	butmeas = WIDGET_BUTTON(jun2base, $
		VAL="Interpolate just one value for whole measurement", UVAL='MEAS')
	butaot = WIDGET_BUTTON(jun2base, $
		VAL="Use central AOT value (pipeline mode)", UVAL='AOT')
		
	jun2base = WIDGET_BASE(junkbase, /COLUMN, /FRAME, /NONEXCLUSIVE)
	buttdep	= WIDGET_BUTTON(jun2base, UVAL='TDEP', $
	      VAL='Subtract dark current dependent on exposure time (only for SL')
	      

;check if dark current cal-G files have been read 
	IF N_ELEMENTS(C1DARKORB) EQ 0 THEN read_darkorb

	orig_rp = darkprorp
	orig_m = darkprom
	orig_aot = darkproaot
	orig_tdep = darktdep
	CASE 1 OF 
	   darkprorp: WIDGET_CONTROL, butrp, /SET_BUTTON
	   darkprom:  WIDGET_CONTROL, butmeas, /SET_BUTTON
	   darkproaot: WIDGET_CONTROL, butaot, /SET_BUTTON
	   ELSE: WIDGET_CONTROL, butall, /SET_BUTTON
	ENDCASE   
	WIDGET_CONTROL, buttdep, SET_BUTTON=orig_tdep

	jun2base = WIDGET_BASE(junkbase, /ROW)
	ok = WIDGET_BUTTON(jun2base, VALUE=' OK ', UVALUE='OK')
 	cancel = WIDGET_BUTTON(jun2base, VALUE=' Cancel ', UVALUE='CANCEL')
	anythout = 0
       WIDGET_CONTROL, junkbase, /REALIZE

WAITING:
	event = WIDGET_EVENT(junkbase)
	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue OF
	'ALL': BEGIN
	   darkprorp=0 & darkprom=0 & darkproaot=0
	END
	'RP': BEGIN
	   darkprorp=1 & darkprom=0 & darkproaot=0
	END
	'MEAS': BEGIN
	   darkprorp=0 & darkprom=1 & darkproaot=0
	END
	'AOT': BEGIN
	   darkprorp=0 & darkprom=0 & darkproaot=1
	END
	'TDEP': darktdep = event.select
	'OK': BEGIN
	   WIDGET_CONTROL, junkbase, /DESTROY
           RETURN
        END
	'CANCEL': BEGIN
	   darkprorp = orig_rp 
	   darkprom  = orig_m
	   darkproat = orig_aot
	   darktdep = orig_tdep
	   WIDGET_CONTROL, junkbase, /DESTROY
           RETURN
        END
	ELSE:
	ENDCASE
	
	GOTO, WAITING

END

