;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_DEFRATIO
;
; PURPOSE:
;	Define ratio of detector response at central wavelength to
;	the response integrated over the filter width.
;	for PHT-P and PHT-C filters and store the values in a common block.
;
; CATEGORY:
;          PIA - initialization
;
; CALLING SEQUENCE:
;	PIA_DEFRATIO
;
; COMMON BLOCKS:
;	piacmn_pow2fb	To hold the ratio values
;
; MODIFICATION HISTORY:
;	Written by: D. Skaley, MPIK/Heidelberg 		Feb-95 ds
;			Took values from SPG procedure 'AAP_RATIO' (S.Guest)
;	Oct 95 Version 3.5
;			
;-
;*********************************************************************
;*
;*********************************************************************
PRO PIA_DEFRATIO

; common blocks:

@piacmn_pow2fb

; define the ratio arrays (members of common block PIACMN_POW2FB)
; we waste arrays index 0 and start with index 1
; to be compatible with filter numbering

	p_ratio = fltarr(15)
	c_ratio = fltarr(15)

	p_ratio(1:14) = [	0.996331, $
				0.949813, $
				0.650458, $
				0.300356, $
				0.977160, $
				0.564719, $
				0.974204, $
				0.448120, $
				0.229456, $
				0.163978, $
				0.104554, $
				0.112635, $
				0.039396, $
				0.025151 ]

	c_ratio(1:14) = [	0.002686, $
				0.023633, $
				0.025848, $
				0.054442, $
				0.041932, $
				0.033823, $
				0.036781, $
				0.024585, $
				0.014506, $
				0.024346, $
				0.019624, $
				0.012828, $
				0.021799, $
				0.000000 ]

; transform 1/micron -> 1/m

	p_ratio = p_ratio * 1.E6
	c_ratio = c_ratio * 1.E6

	RETURN
	END
