;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_DEFWAVEL
;
; PURPOSE:
;	Define central wavelenghts of filters for PHT-P and PHT-C
;	and store them in a common block.
;
; CATEGORY:
;          PIA - initialization
;
; CALLING SEQUENCE:
;	PIA_DEFWAVEL
;
; COMMON BLOCKS:
;	piacmn_pow2fb	To hold the weavelength values
;
; MODIFICATION HISTORY:
;	Written by: D. Skaley, MPIK/Heidelberg			Feb-95
;			Took values from SPG procedure 'AAP_CENTRAL' (S.Guest)
;	Modified (last) by: cg					Sep-95	
;	Oct 95 Version 3.5
;			
;-
;*********************************************************************
;*
;*********************************************************************
PRO PIA_DEFWAVEL

; common blocks:

@piacmn_pow2fb

; define the wavelength arrays (members of common block PIACMN_POW2FB)
; we waste arrays index 0 and start with index 1
; to be compatible with filter numbering

	p_wavel = fltarr(15)
	c_wavel = fltarr(15)

; wavelenghts in microns

	p_wavel(1:14) = [ 3.29, 3.60, 4.85, 7.30, 7.70, 10.0, 11.3, $
			 12.8, 16.0, 11.5, 20.0, 25.0, 60.0, 100.0 ]
	c_wavel(1:14) = [ 125.0, 90.0, 50.0, 60.0, 70.0, 100.0, 105.0, $
			  90.0, 160.0, 200.0, 180.0, 135.0, 120.0, 0.0 ]

; convert from microns to meters

	p_wavel = p_wavel * 1.E-6
	c_wavel = c_wavel * 1.E-6

	RETURN
	END
