;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_DIS2SRD
;
; PURPOSE:
;	Menu for PIA SRD Data display.
;	This is a fourth level menu in the PIA hierarchy.
;
;	This routine should only be called by the PIA Display Data routine
;	and should not be called directly from the command line.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;       PIA_DISPSRD, GROUP=group, DATA=data, NV=nv, REDRAW=redraw
;
; KEYWORD PARAMETERS:
;	GROUP:	The group leader of the widget hirarchy
;       DATA:   An element of the PHTSRD dynamic structure
;       NV:     Number of Views (1 <= NV <= 4)
;       REDRAW:	To redraw same data
;	
; RESTRICTIONS:
;       DATA must be a valid element of PHTSRD dynamic structure
;	
; COMMON BLOCKS:
;	adm
;	colour_indices
;	phtacc
;	phtcs
;	pia_drift_inipar_cmn
;	pia_dsp2srd_cmn (internal)
;	pia_dsp2ch2_cmn (internal)
;	dsp2srd_wid (internal)
;	pia_dspchz_cmn (internal)
;	not2_acc (internal)
;	tmp2values2 (internal)
;	srd2text (internal)
;	dispcust_cmn (internal)
;	pia_widget_info (internal)
;		
; PROCEDURES USED:
;	PIA LIB:
;		decode_admn
;		deglitch_change
;		do_deglitch
;		get_convwh
;		get_pht_hk
;		get_sigdisc
;		pia_disp_cs
;		pia_disp_hdr
;		pia_dispcust
;		pia_dispscp
;		pia_drift_inipar
;		pia_load_isrd
;		pia_mann
;		pia_multchoice
;		pia_multmeas
;		pia_oplot
;		pia_pixchoice
;		pia_plot
;		pia_showstr
;		pia_sigdisc
;		pia_sm
;		pia_write_isrd
;		pia_xplot
;		pickmeas
;		process_tmpsrd
;		write_srd
;		xdisp_hk
;       ASTRO LIB:
;		avg
;		fxpar
;		sigma
;       INTERNAL:
; 		pixbut2event2
; 		view2event2
; 		stabil2_par
; 		deglitch2_par
; 		average2chop2
; 		average2nonch2
; 		average2event2
; 		median2chop2
; 		median2nonch2
; 		median2event2
; 		zoom2event2
; 		zoom2fourier2
; 		zoom2sync2
; 		zoom2nsync2
; 		zoom2it2
; 		pia_reset2view2
; 		pia_dsrd2_event
;
; MODIFICATION HISTORY:
;       Written by: C.Gabriel (ESA/ESTEC)               July 1994
;	Modified (last)  CGabriel			February 97
;	Call to Deglitching routines modified to include
;	discarding flags  (JA)				March 97
;	V6.1
;	Graphical signal discarding added +
;	 reset interval correction added +
;	 saving internal file upgraded +
;	 direct discrimination for measurement selection +
;	 auxiliary files display added (EOH*, OLR) (CG) May 1997	
;	Added button to reset RPID	(JAcosta)	June 1997
;	V6.3
;	Uncertainties from reset int corr added (CG)	September 1997
;	Allowing for graph. multi de(re)-selection (CG)	September 1997 
;	V6.5
;	Added possibility to save corrections in phtsrd 
;	buffer + calling sequence to pia_dispscp (JAc)   October 1997
;	Orbital position dependant dark current 
;	 subtraction added (CG)				December 1997
;	V6.6
;	Allowing external v. for reset int.corr (CG)	February 1998
;	V7.0
;	Pixel numbering bug for aver/median fixed (CG)	July 1998
;	V7.2
;	Bug in the unc. calc. after reset int. corr. fixed (CG)
;							September 1998
;	Dynamic calibration for PHT-S added 
;	 (CG based on JA's work)			November 1998
;	V7.3
;	Linearization included (only int.version) (CG) 	December 1998
;	V7.3
;	Widget problem (INT instead of LON) fixed (CG)	February 1999
;	Pattern processing added (CG)			May 1999
;	Adapted for the use of bitflags (JA + CG)	May 1999 
;	Use of process_tmpsrd with pattern option (CG)	June 1999
;	V7.4
;	Exit including possibility of saving meas. +
;	replacing numbers by letters in pixel ind. (CG)	January 2000
;	V8.2
;	   
;-
; *********************************************************************
; *
; *********************************************************************
pro pixbut2event2, event

COMMON pia_dsp2srd_cmn, tmpdata, srdps, view, viewsize, nviews, viewoptions, $
  overid
COMMON pia_dsp2ch2_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON dsp2srd_widg, pixbut

        WIDGET_CONTROL, event.id, GET_UVALUE = new_pixbut

        ind = WHERE(pixcho eq new_pixbut(0))
        ind = ind(0)

	text = ["A", "B", "C", "D"]
        IF ind LT 0 or ind GE nviews THEN BEGIN

          pixcount = pixcount+1
          IF pixcount GE nviews THEN pixcount = 0

          old_pixcho = pixcho(pixcount)
          pixcho(pixcount) = new_pixbut(0)

          view(pixcount).viewtype = 0
          pia_reset2view2, pixcount, view(pixcount).controlid

	  txtval = text(pixcount)                

          WIDGET_CONTROL, pixbut(old_pixcho), $
                                SET_VALUE = ' '
          WIDGET_CONTROL, pixbut(pixcho(pixcount)), $
                        SET_VALUE = txtval
        ENDIF
END

; *********************************************************************
; *
; *********************************************************************
pro view2event2, event

COMMON pia_dsp2srd_cmn, tmpdata, srdps, view, viewsize, nviews, viewoptions, $
   overid 
COMMON pia_dsp2ch2_cmn, pixcho, pixop, pixres, psymch, pixcount

	; get index of individual window choice
	viewchoindexid = WIDGET_INFO(event.id, /PARENT)
	WIDGET_CONTROL, viewchoindexid, GET_UVALUE = setting_choi
	setting_choi = setting_choi(0)
	; get index of window
        viewindexid = WIDGET_INFO(viewchoindexid,/PARENT)
	WIDGET_CONTROL, viewindexid, GET_UVALUE = viewindex

	IF N_ELEMENTS(viewindex) EQ 0 THEN BEGIN
	  viewindex = setting_choi
	  viewindexid = viewchoindexid
 	  WIDGET_CONTROL, event.id, GET_UVALUE = setting
	  setting = setting(0)

          IF (view(viewindex(0)).viewtype NE setting) THEN BEGIN
                view(viewindex(0)).viewtype = setting
                pia_reset2view2, viewindex, viewindexid
          ENDIF
	ENDIF ELSE BEGIN
	; get value of setting 
 	  WIDGET_CONTROL, event.id, GET_UVALUE = setting
	  setting = setting(0)

	  IF (view(viewindex(0)).viewtype NE setting_choi OR $
	    view(viewindex(0)).viewtype_sub NE setting) THEN BEGIN
		view(viewindex(0)).viewtype_sub = setting
		view(viewindex(0)).viewtype = setting_choi
		pia_reset2view2, viewindex, viewindexid
	  ENDIF
	ENDELSE

END


; *********************************************************************
; *
; *********************************************************************
pro discard2_area2, event

COMMON pia_dsp2srd_cmn, tmpdata, srdps, view, viewsize, nviews, viewoptions, $
   overid
COMMON pia_dsp2ch2_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON not2_acc, degl_acc, degl_set, sig_disc, disc_set
COMMON zoom_discareas, disc_area, all_disc_areas

        WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        WIDGET_CONTROL, event.top, /HOURGLASS


        pixch = pixcho(windowindex)
	tmpslop = reform(tmpdata.slop(pixch,*))
	        
	pia_xplot, tmpdata.stim, $
		   tmpslop, flagged=sig_disc(pixch,*), $
		   tmpdata.slun(pixch,*), $ 
		   title= 'Discarding area by pixel '+STRTRIM(pixch+1,2),$
		   ytitle='Signal    [V/s]',xtitle='Time     [s]',$
		   psym=psymch, /disc_area


	siz= size(all_disc_areas)
	IF siz(0) EQ 0 THEN RETURN
	
; use only pixel we are interested in -> don't put detector
	decode_piaflag, 'SRD', 'MANDISC', tmpdata.flag(pixch,*), manflag
	
	FOR I=0,N_ELEMENTS(all_disc_areas)-1 DO BEGIN
	  p1 = all_disc_areas(i).pos1
	  p2 = all_disc_areas(i).pos2
	  IF p1(1) NE 0. or p2(1) NE 0. THEN BEGIN
	     ind = WHERE(tmpslop GE p1(1) AND $
	     		 tmpslop LE p2(1) AND $
			 tmpdata.stim GE p1(0) AND $
			 tmpdata.stim LE p2(0), ndisc)
	     IF ndisc GT 0 THEN BEGIN
	       manflag(ind) = 1
	       encode_piaflag, 'SRD', 'MANDISC', tmpdata.flag(pixch,*), tmpflag, $
	        manflag
	       tmpdata.flag(pixch,*) = tmpflag  
	     ENDIF
	  ENDIF
	ENDFOR
	get_validflag, tmpdata.flag, 'SRD', redflag, $
	  det=tmpdata.det, /allpix
	sig_disc = redflag
	
	pia_reset2view2, windowindex


END

; *********************************************************************
; *
; *********************************************************************
pro reselect2_area2, event

COMMON pia_dsp2srd_cmn, tmpdata, srdps, view, viewsize, nviews, viewoptions, $
   overid
COMMON pia_dsp2ch2_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON not2_acc, degl_acc, degl_set, sig_disc, disc_set
COMMON zoom_discarea, disc_area

        WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        WIDGET_CONTROL, event.top, /HOURGLASS


        pixch = pixcho(windowindex)
	tmpslop = reform(tmpdata.slop(pixch,*))
	        
	pia_xplot, tmpdata.stim, $
		   tmpslop, flagged=sig_disc(pixch,*), $
		   tmpdata.slun(pixch,*), $ 
		   title= 'Reselecting area by pixel '+STRTRIM(pixch+1,2),$
		   ytitle='Signal    [V/s]',xtitle='Time     [s]',$
		   psym=psymch, /disc_area


	siz= size(all_disc_areas)
	IF siz(0) EQ 0 THEN RETURN
	
; use only pixel we are interested in -> don't put detector
	decode_piaflag, 'SRD', 'MANDISC', tmpdata.flag(pixch,*), manflag

	FOR I=0,N_ELEMENTS(all_disc_areas)-1 DO BEGIN
	  p1 = all_disc_areas(i).pos1
	  p2 = all_disc_areas(i).pos2
	  IF p1(1) NE 0. or p2(1) NE 0. THEN BEGIN
	     ind = WHERE(tmpslop GE p1(1) AND $
	     		 tmpslop LE p2(1) AND $
			 tmpdata.stim GE p1(0) AND $
			 tmpdata.stim LE p2(0), ndisc)
	     IF ndisc GT 0 THEN BEGIN
	       manflag(ind) = 0
	       encode_piaflag, 'SRD', 'MANDISC', tmpdata.flag(pixch,*), tmpflag, $
	        manflag
	       tmpdata.flag(pixch,*) = tmpflag  
	     ENDIF
	  ENDIF
	ENDFOR
	get_validflag, tmpdata.flag, 'SRD', redflag, $
	  det=tmpdata.det, /allpix
	sig_disc = redflag

	pia_reset2view2, windowindex

END

; *********************************************************************
; *
; *********************************************************************
pro drift2_par, event

COMMON pia_dsp2srd_cmn, tmpdata, srdps, view, viewsize, nviews, viewoptions, $
   overid
COMMON pia_dsp2ch2_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON not2_acc, degl_acc, degl_set, sig_disc, disc_set

        WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        WIDGET_CONTROL, event.top, /HOURGLASS


        pixch = pixcho(windowindex)

	pia_drift_mod, tmpdata, pixch, sig_disc, degl_acc, degl_set
	
END

; *********************************************************************
; *
; *********************************************************************
pro stabil2_par, event

COMMON pia_dsp2srd_cmn, tmpdata, srdps, view, viewsize, nviews, viewoptions, $
   overid
COMMON pia_dsp2ch2_cmn, pixcho, pixop, pixres, psymch, pixcount

        WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        WIDGET_CONTROL, event.top, /HOURGLASS


        pixch = pixcho(windowindex)

	pia_mann, tmpdata, pixch
	
END


; *********************************************************************
; *
; *********************************************************************
pro deglitch2_par, event

COMMON pia_dsp2srd_cmn, tmpdata, srdps, view, viewsize, nviews, viewoptions, $ 
   overid 
COMMON pia_dsp2ch2_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON not2_acc, degl_acc, degl_set, sig_disc, disc_set 

	WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        WIDGET_CONTROL, event.top, /HOURGLASS

	pixch = pixcho(windowindex)
	slop = tmpdata.slop(pixch,*)
	slun = tmpdata.slun(pixch,*)
        sgdisc = sig_disc(pixch,*)
 
	deglitch_change, tmpdata.stim, slop, tmpdata.step, tmpdata.rpid, $ 
	    slun, sgdisc

END

; *********************************************************************
; *
; *********************************************************************
pro average2chop2, event

COMMON pia_dsp2srd_cmn, tmpdata, srdps, view, viewsize, nviews, viewoptions, $
   overid
COMMON pia_dsp2ch2_cmn, pixcho, pixop, pixres, psymch, pixcount

        WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        WIDGET_CONTROL, event.top, /HOURGLASS

	average2event2, windowindex, chopped=1

	END

; *********************************************************************
; *
; *********************************************************************
pro average2nonch2, event

COMMON pia_dsp2srd_cmn, tmpdata, srdps, view, viewsize, nviews, viewoptions, $
   overid
COMMON pia_dsp2ch2_cmn, pixcho, pixop, pixres, psymch, pixcount

        WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        WIDGET_CONTROL, event.top, /HOURGLASS

	average2event2, windowindex

	END

; *********************************************************************
; *
; *********************************************************************
pro average2event2, windowindex, chopped=chopped

COMMON pia_dsp2srd_cmn, tmpdata, srdps, view, viewsize, nviews, viewoptions, $
   overid
COMMON pia_dsp2ch2_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON not2_acc, degl_acc, degl_set, sig_disc, disc_set 
COMMON tmp2values2, tmprpid, tmprpid_name

	wtype = view(windowindex).viewtype 

        ytitle = viewoptions(wtype).viewylab

	notacc = 0
	notac1 = 0

        CASE wtype OF

          0: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.slop(pixch,*)
                unc = tmpdata.slun(pixch,*)
		str = 'Slopes Averages Pixel '+STRTRIM(STRING(pixch+1),2)
		IF degl_set THEN $
		  indnacc = WHERE(degl_acc(pixch,*) eq 1, notacc)
		IF disc_set THEN $
		  indnac1 = WHERE(sig_disc(pixch,*) eq 1, notac1)
 
		
          END
          1: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.flag(pixch,*)
                unc = 0
		str = 'Flag Averages Pixel '+STRTRIM(STRING(pixch+1),2)
          END
          2: BEGIN
                data = tmpdata.chop
                unc = 0
		str = 'Chopper Position Averages'
          END
          3: BEGIN
		pixch = pixcho(windowindex)
		dimtemp = size(tmpdata.temp)
		IF dimtemp(0) EQ 2 THEN BEGIN
		   IF pixch GT 63 THEN temptmp = tmpdata.temp(1,*) ELSE $
		   temptmp = tmpdata.temp(0,*) 
		ENDIF ELSE temptmp = tmpdata.temp
                data = temptmp
                unc = 0
		str = 'Temperature Averages'
          END
          4: BEGIN
                data = tmpdata.fcs1
                unc = 0
		str = 'FCS1 el.Power Averages'
          END
          5: BEGIN
                data = tmpdata.fcs2
                unc = 0
		str = 'FCS2 el.Power Averages'
          END
          6: BEGIN
                data = tmpdata.tkey
                unc = 0
		str = 'Time Key Averages'
          END
          7: BEGIN
                data = tmprpid
                unc = 0
		str = tmprpid_name + ' Averages'
          END
          8: BEGIN
                data = tmpdata.slop(pixop,*)
                unc = tmpdata.slun(pixop,*)
		str = 'Slopes Averages Open Pixel'
		IF degl_set THEN $
		  indnacc = WHERE(degl_acc(pixop,*) eq 1, notacc)
		IF disc_set THEN $
		  indnac1 = WHERE(sig_disc(pixop,*) eq 1, notac1)
          END
          9: BEGIN
                data = tmpdata.slop(pixres,*)
                unc = tmpdata.slun(pixres,*)
		str = 'Slopes Averages Resistor Pixel'
		IF degl_set THEN $
		  indnacc = WHERE(degl_acc(pixres,*) eq 1, notacc)
		IF disc_set THEN $
		  indnac1 = WHERE(sig_disc(pixres,*) eq 1, notac1)
          END
          10: BEGIN
                data = tmpdata.slop(pixop+2,*)
                unc = tmpdata.slun(pixop+2,*)
		str = 'Slopes Averages Open Pixel SL'
		IF degl_set THEN $
		  indnacc = WHERE(degl_acc(pixop+2,*) eq 1, notacc)
		IF disc_set THEN $
		  indnac1 = WHERE(sig_disc(pixop+2,*) eq 1, notac1)
          END
          11: BEGIN
                data = tmpdata.slop(pixres+2,*)
                unc = tmpdata.slun(pixres+2,*)
		str = 'Slopes Averages Resistor Pixel SL'
		IF degl_set THEN $
		  indnacc = WHERE(degl_acc(pixres+2,*) eq 1, notacc)
		IF disc_set THEN $
		  indnac1 = WHERE(sig_disc(pixres+2,*) eq 1, notac1)
          END
          ELSE: MESSAGE, /INFO, 'Not allowed CASE'

        ENDCASE

; Prepare a Byte array to accomodate all strings including carriage returns
	bytstr = [BYTE(str),10b,13b,10b,13b]

	
	accarr = INTARR(N_ELEMENTS(data))

	IF degl_set THEN BEGIN 
	     IF	(wtype EQ 0 or wtype EQ 8 or wtype EQ 9) AND $ 
		(notacc GT 0)   THEN  accarr(indnacc) = 1
        ENDIF

	IF disc_set THEN BEGIN 
	     IF	(wtype EQ 0 or wtype EQ 8 or wtype EQ 9) AND $ 
		(notac1 GT 0)   THEN  accarr(indnac1) = 1
        ENDIF

	IF KEYWORD_SET(chopped) THEN BEGIN 

	   indfcs = WHERE(tmpdata.fcsn gt 0, n)

; FCS case - fcsn=1 (FCS1) fcs2=2 (FCS2) fcsn=0 (CFOV, if also FCS1 or FCS2)
	   IF n GT 0 THEN BEGIN

		FOR I=0,2 DO BEGIN
		   indfcs = WHERE(tmpdata.fcsn eq I AND accarr EQ 0, nfcs)     
		   IF nfcs ne 0 THEN BEGIN
			avr = avg(data(indfcs))
			sig = sigma(data(indfcs))
			IF I eq 0 THEN $
			  str = 'CFOV position: '+$
				STRING(avr)+'    +/-'+STRING(sig) $ 								
			ELSE $
			  str = 'FCS'+STRTRIM(STRING(I),2)+' position: '+$
				STRING(avr)+'    +/-'+STRING(sig)								

			bytstr = [bytstr,BYTE(str),10b,13b]
		   ENDIF		
		ENDFOR 
	   ENDIF ELSE BEGIN

; Chopped Case (not calibration involved)
		nrst = 1
		i = 0
		WHILE nrst NE 0 DO BEGIN 
                   i = i + 1
		   indstp = WHERE(tmpdata.step eq i AND accarr EQ 0, nrst)     
		   IF nrst ne 0 THEN BEGIN
			avr = avg(data(indstp))
			sig = sigma(data(indstp))
			str = 'Step '+STRTRIM(STRING(I),2)+' position: '+$
				STRING(avr)+'    +/-'+STRING(sig)								
			bytstr = [bytstr,BYTE(str),10b,13b]
		   ENDIF		
		ENDWHILE
	   ENDELSE 
	ENDIF ELSE BEGIN			

; Not chopped Case
           indacc = WHERE(accarr EQ 0)
	   avr = avg(data(indacc))
	   sig = sigma(data(indacc))
	   str = 'Full measurement average: '+$
		STRING(avr)+'    +/-'+STRING(sig)								
	   bytstr = [bytstr,BYTE(str),10b,13b]
        ENDELSE

; Now get the text and display it

        text = STRING(bytstr)

	IF disc_set AND degl_set THEN BEGIN
           XDISPLAYFILE, "", $
              TITLE = "Average after Deglitching and Selection", $
                  WIDTH = 100, $
                  HEIGHT = 10, $
                  TEXT = [text]
        ENDIF ELSE IF disc_set AND NOT degl_set THEN BEGIN
           XDISPLAYFILE, "", $
              TITLE = "Average after Selection ", $
                  WIDTH = 100, $
                  HEIGHT = 10, $
                  TEXT = [text]
        ENDIF ELSE IF degl_set AND NOT disc_set THEN BEGIN
           XDISPLAYFILE, "", $
              TITLE = "Average after Deglitching ", $
                  WIDTH = 100, $
                  HEIGHT = 10, $
                  TEXT = [text]
	ENDIF ELSE BEGIN  
           XDISPLAYFILE, "", $
              TITLE = "Average - No selection, No deglitching ", $
                  WIDTH = 100, $
                  HEIGHT = 10, $
                  TEXT = [text]
	ENDELSE
END

; *********************************************************************
; *
; *********************************************************************
pro median2chop2, event

COMMON pia_dsp2srd_cmn, tmpdata, srdps, view, viewsize, nviews, viewoptions, $
   overid
COMMON pia_dsp2ch2_cmn, pixcho, pixop, pixres, psymch, pixcount

        WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        WIDGET_CONTROL, event.top, /HOURGLASS

	median2event2, windowindex, chopped=1

	END

; *********************************************************************
; *
; *********************************************************************
pro median2nonch2, event

COMMON pia_dsp2srd_cmn, tmpdata, srdps, view, viewsize, nviews, viewoptions, $
   overid
COMMON pia_dsp2ch2_cmn, pixcho, pixop, pixres, psymch, pixcount

        WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        WIDGET_CONTROL, event.top, /HOURGLASS

	median2event2, windowindex

	END

; *********************************************************************
; *
; *********************************************************************
pro median2event2, windowindex, chopped=chopped

COMMON pia_dsp2srd_cmn, tmpdata, srdps, view, viewsize, nviews, viewoptions, $
   overid
COMMON pia_dsp2ch2_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON not2_acc, degl_acc, degl_set, sig_disc, disc_set
COMMON tmp2values2, tmprpid, tmprpid_name

        ytitle = viewoptions(view(windowindex).viewtype).viewylab

	wtype = view(windowindex).viewtype

	notacc = 0
	notac1 = 0

        CASE wtype OF

          0: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.slop(pixch,*)
                unc = tmpdata.slun(pixch,*)
		str = 'Slopes Median Pixel '+STRTRIM(STRING(pixch+1),2)
		IF degl_set THEN $
		  indnacc = WHERE(degl_acc(pixch,*) eq 1, notacc)
		IF disc_set THEN $
		  indnac1 = WHERE(sig_disc(pixch,*) eq 1, notac1)
          END
          1: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.flag(pixch,*)
                unc = 0
		str = 'Flag Median Pixel '+STRTRIM(STRING(pixch+1),2)
          END
          2: BEGIN
                data = tmpdata.chop
                unc = 0
		str = 'Chopper Position Median'
          END
          3: BEGIN
		pixch = pixcho(windowindex)
		dimtemp = size(tmpdata.temp)
		IF dimtemp(0) EQ 2 THEN BEGIN
		   IF pixch GT 63 THEN temptmp = tmpdata.temp(1,*) ELSE $
		   temptmp = tmpdata.temp(0,*) 
		ENDIF ELSE temptmp = tmpdata.temp
                data = temptmp
                unc = 0
		str = 'Temperature Median'
          END
          4: BEGIN
                data = tmpdata.fcs1
                unc = 0
		str = 'FCS1 el.Power Median'
          END
          5: BEGIN
                data = tmpdata.fcs2
                unc = 0
		str = 'FCS2 el.Power Median'
          END
          6: BEGIN
                data = tmpdata.tkey
                unc = 0
		str = 'Time Key Median'
          END
          7: BEGIN
                data = tmprpid
                unc = 0
		str = tmprpid_name + ' Median'
          END
          8: BEGIN
                data = tmpdata.slop(pixop,*)
                unc = tmpdata.slun(pixop,*)
		str = 'Slopes Median Open Pixel'
		IF degl_set THEN $
		  indnacc = WHERE(degl_acc(pixop,*) eq 1, notacc)
		IF disc_set THEN $
		  indnac1 = WHERE(sig_disc(pixop,*) eq 1, notac1)
          END
          9: BEGIN
                data = tmpdata.slop(pixres,*)
                unc = tmpdata.slop(pixres,*)
		str = 'Slopes Median Resistor Pixel'
		IF degl_set THEN $
		  indnacc = WHERE(degl_acc(pixres,*) eq 1, notacc)
		IF disc_set THEN $
		  indnac1 = WHERE(sig_disc(pixres,*) eq 1, notac1)
          END
          10: BEGIN
                data = tmpdata.slop(pixop+2,*)
                unc = tmpdata.slun(pixop+2,*)
		str = 'Slopes Median Open Pixel SL'
		IF degl_set THEN $
		  indnacc = WHERE(degl_acc(pixop+2,*) eq 1, notacc)
		IF disc_set THEN $
		  indnac1 = WHERE(sig_disc(pixop+2,*) eq 1, notac1)
          END
          11: BEGIN
                data = tmpdata.slop(pixres+2,*)
                unc = tmpdata.slop(pixres+2,*)
		str = 'Slopes Median Resistor Pixel SL'
		IF degl_set THEN $
		  indnacc = WHERE(degl_acc(pixres+2,*) eq 1, notacc)
		IF disc_set THEN $
		  indnac1 = WHERE(sig_disc(pixres+2,*) eq 1, notac1)
          END
          ELSE: MESSAGE, /INFO, 'Not allowed CASE'

        ENDCASE

; Prepare a Byte array to accomodate all strings including carriage returns
	bytstr = [str,'','']

	accarr = INTARR(N_ELEMENTS(data))

	IF degl_set THEN BEGIN 
	     IF	(wtype EQ 0 or wtype EQ 8 or wtype EQ 9) AND $ 
		(notacc GT 0)   THEN   accarr(indnacc) = 1
        ENDIF

	IF disc_set THEN BEGIN 
	     IF	(wtype EQ 0 or wtype EQ 8 or wtype EQ 9) AND $ 
		(notac1 GT 0)   THEN   accarr(indnac1) = 1
        ENDIF

	IF KEYWORD_SET(chopped) THEN BEGIN 

	   indfcs = WHERE(tmpdata.fcsn gt 0, n)

; FCS case - fcsn=1 (FCS1) fcsn=2 (FCS2) fcsn=0 (CFOV, if also FCS1 or FCS2)
	   IF n GT 0 THEN BEGIN

		FOR I=0,2 DO BEGIN
		   indfcs = WHERE(tmpdata.fcsn eq I AND accarr EQ 0, nfcs)     
		   IF nfcs ne 0 THEN BEGIN
			avr = median(data(indfcs))
			sig = sigma(data(indfcs))
			IF I eq 0 THEN $
			  str = 'CFOV position: '+$
				STRING(avr)+'    +/-'+STRING(sig) $ 								
			ELSE $
			  str = 'FCS'+STRTRIM(STRING(I),2)+' position: '+$
				STRING(avr)+'    +/-'+STRING(sig)								

			bytstr = [bytstr,str,'']
		   ENDIF		
		ENDFOR 
	   ENDIF ELSE BEGIN

; Chopped Case (not calibration involved)
		nrst = 1
		i = 0
		WHILE nrst NE 0 DO BEGIN 
                   i = i + 1
		   indstp = WHERE(tmpdata.step eq i AND accarr EQ 0, nrst)     
		   IF nrst ne 0 THEN BEGIN
			avr = median(data(indstp))
			sig = sigma(data(indstp))
			str = 'Step '+STRTRIM(STRING(I),2)+' position: '+$
				STRING(avr)+'    +/-'+STRING(sig)								
			bytstr = [bytstr,str,'']
		   ENDIF		
		ENDWHILE
	   ENDELSE 
	ENDIF ELSE BEGIN			

; Not chopped Case

           indacc = WHERE(accarr EQ 0)
	   avr = median(data(indacc))
	   sig = sigma(data(indacc))
	   str = 'Full measurement median: '+$
		STRING(avr)+'    +/-'+STRING(sig)								
	   bytstr = [bytstr,str,'']
        ENDELSE

; Now get the text and display it

        text = bytstr

	IF disc_set AND degl_set THEN BEGIN
           XDISPLAYFILE, "", $
              TITLE = "Median Calculation after Deglitching and Selection", $
                  WIDTH = 100, $
                  HEIGHT = 10, $
                  TEXT = [text]
        ENDIF ELSE IF disc_set AND not degl_set THEN BEGIN
           XDISPLAYFILE, "", $
              TITLE = "Median Calculation after Selection ", $
                  WIDTH = 100, $
                  HEIGHT = 10, $
                  TEXT = [text]
        ENDIF ELSE IF degl_set AND NOT disc_set THEN BEGIN
           XDISPLAYFILE, "", $
              TITLE = "Median Calculation after Deglitching ", $
                  WIDTH = 100, $
                  HEIGHT = 10, $
                  TEXT = [text]
	ENDIF ELSE BEGIN  
           XDISPLAYFILE, "", $
              TITLE = "Median Calculation - No selection, No deglitching ", $
                  WIDTH = 100, $
                  HEIGHT = 10, $
                  TEXT = [text]
	ENDELSE
END

; *********************************************************************
; *
; *********************************************************************
pro zoom2event2, event

COMMON pia_dsp2srd_cmn, tmpdata, srdps, view, viewsize, nviews, viewoptions, $
   overid 
COMMON pia_dsp2ch2_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices

	WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
	zoom2it2, windowindex        
END

; *********************************************************************
; *
; *********************************************************************
pro zoom2fourier2, event

COMMON pia_dsp2srd_cmn, tmpdata, srdps, view, viewsize, nviews, viewoptions, $
   overid
COMMON pia_dsp2ch2_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices

        WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        zoom2it2, windowindex, fourier = 1
END

; *********************************************************************
; *
; *********************************************************************
pro zoom2sync2, event

COMMON pia_dsp2srd_cmn, tmpdata, srdps, view, viewsize, nviews, viewoptions, $
  overid 
COMMON pia_dsp2ch2_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices

	WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
	zoom2it2, windowindex, overplot = 1        

END

; *********************************************************************
; *
; *********************************************************************
pro zoom2nsync2, event

COMMON pia_dsp2srd_cmn, tmpdata, srdps, view, viewsize, nviews, viewoptions, $
   overid 
COMMON pia_dsp2ch2_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices

	WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
	zoom2it2, windowindex, overplot = -1        

END

; *********************************************************************
; *
; *********************************************************************
pro zoom2it2, windowindex, overplot=overplot, fourier=fourier

COMMON pia_dsp2srd_cmn, tmpdata, srdps, view, viewsize, nviews, viewoptions, $
   overid 
COMMON pia_dsp2srd_flg_cmn, nflag_active, flag_active_lex, flag_active_label  
COMMON pia_dsp2ch2_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
COMMON not2_acc, degl_acc, degl_set, sig_disc, disc_set
COMMON tmp2values2, tmprpid, tmprpid_name
@colour_indices

	IF (KEYWORD_SET(overplot)) THEN overplot = overplot ELSE overplot = 0
        IF (KEYWORD_SET(fourier)) THEN fourier = 1 ELSE fourier = 0

	xtitle = viewoptions(view(windowindex).viewtype).viewxlab
	ytitle = viewoptions(view(windowindex).viewtype).viewylab
        ytype = 0

	decode_admn, tmpdata.admn, title
	menuchoi = view(windowindex).viewtype_sub
	title = title + '  ' + tmpdata.unit

        get_convwh, tmpdata.admn, wheels, chmod, champ
        anntmp = title + $
		'  [' + wheels(0) + '  ' + wheels(1) + '  ' + $
		wheels(2) + ']  [' + chmod + '  ' + champ + ']'

	anntmp = anntmp+' (SRD level)'

        subtitle = ''

	charsize = 1.10
	IF overplot NE 0 THEN BEGIN
		xstyle = 0
		ystyle = 0
		IF zoom_color EQ -1 THEN zoom_color = green ELSE $
			zoom_color = zoom_color + 1
		IF zoom_color EQ 9 then zoom_color = 4
		zoom_psymch = zoom_psymch + 1
		IF zoom_psymch GT 8 THEN zoom_psymch = 1
		title = ''
	ENDIF ELSE BEGIN
		xstyle = 0
		ystyle = 0
		zoom_color = -1
		zoom_psymch = psymch
        ENDELSE

                IF fourier eq 1 THEN BEGIN
                        xtitle = 'Frequency       [Hz]'
                        ytitle = 'FFT of '+ytitle
                        ytype = 1
                ENDIF
	
	CASE view(windowindex).viewtype OF

;Plot pixel signals
	  0: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Signal: Pixel '+str_pixch+'    [Volt/s]' 
		ytitle = str_pixch 

                IF fourier eq 1 THEN BEGIN
                        ytitle = 'FFT of '+ytitle
                        xtitle = 'Frequency       [Hz]'
                        ytype = 1
                ENDIF
		

		pia_xplot, tmpdata.stim, $
			tmpdata.slop(pixch,*), $
			tmpdata.slun(pixch,*), $
			psym = zoom_psymch, xtitle=xtitle, fourier=fourier, $
			ytitle = ytitle, $
			title = title, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,         $   
			xstyle=xstyle, ystyle=ystyle,  $
			legend=strmid(ytitle,0,18), $
			annotation=anntmp                    

		IF degl_set AND fourier EQ 0 THEN BEGIN
			indno = WHERE(degl_acc(pixch,*) eq 1, nn)
                        IF nn GT 0 THEN $
			  PIA_XPLOT, tmpdata.stim(indno), $
			  tmpdata.slop(pixch,indno), $
			  psym = 1, color=red, overplot=99, $
			  legend=' deglitched points'      
                ENDIF

		IF disc_set AND fourier EQ 0 THEN BEGIN
			indno = WHERE(sig_disc(pixch,*) eq 1, nn)
                        IF nn GT 0 THEN $
			  PIA_XPLOT, tmpdata.stim(indno), $
			  tmpdata.slop(pixch,indno), $
			  psym = 7, color=red, overplot=99, $
			  legend=' discarded points'      
                ENDIF

    	  END
;Plot flag values
	  1: BEGIN
	    	elemnames =  flag_active_label   
		pixch = pixcho(windowindex)
		str_pixch = 'Flag ' + elemnames(menuchoi)+ ': Pixel '+ $
		   STRTRIM(pixch+1,2)
		IF title NE '' THEN title = str_pixch 
		;select flag depending on the choice
		IF flag_active_lex(menuchoi) EQ 'ENCODE' THEN        $
		    tmpflag = tmpdata.flag(pixch,*)                  $
		ELSE decode_piaflag,'SRD',flag_active_lex(menuchoi), $ 
		    tmpdata.flag(pixch,*),tmpflag
		ytitle = 'Flag' 

                IF fourier eq 1 THEN BEGIN
                        xtitle = 'Frequency       [Hz]'
                        ytitle = 'FFT of '+ytitle
                        ytype = 1
                ENDIF
		
		pia_xplot, tmpdata.stim, tmpflag, psym = zoom_psymch,        $
			xtitle=xtitle, fourier=fourier, ytitle=ytitle,       $
			subtitle=subtitle, title=title, ytype=ytype,         $
			overplot = overplot, charsize = charsize,            $
			color = zoom_color, xstyle=xstyle, ystyle=ystyle,    $
			legend=strmid(str_pixch,5,25), annotation=anntmp              
          END
;Plot chopper positions
	  2: BEGIN
		pia_xplot, tmpdata.stim, tmpdata.chop, psym = zoom_psymch, $
			xtitle=xtitle, fourier=fourier, ytitle = ytitle, title = title, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,         $       
			xstyle=xstyle, ystyle=ystyle, $
                        legend=strmid(ytitle,0,20), $
                        annotation=anntmp  
          END
;Plot temperatures
	  3: BEGIN
		pixch = pixcho(windowindex)
		dimtemp = size(tmpdata.temp)
		IF dimtemp(0) EQ 2 THEN BEGIN
		   IF pixch GT 63 THEN temptmp = tmpdata.temp(1,*) ELSE $
		   temptmp = tmpdata.temp(0,*) 
		ENDIF ELSE temptmp = tmpdata.temp
		pia_xplot, tmpdata.stim, temptmp, psym = zoom_psymch, $
			xtitle=xtitle, fourier=fourier, ytitle = ytitle, title = title, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,         $       
			xstyle=xstyle, ystyle=ystyle, $
                        legend=strmid(ytitle,0,20), $
                        annotation=anntmp  
          END
;Plot FCS1 electrical powers
	  4: BEGIN
		pia_xplot, tmpdata.stim, tmpdata.fcs1, psym = zoom_psymch, $
			xtitle=xtitle, fourier=fourier, ytitle = ytitle, title = title, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,         $       
			xstyle=xstyle, ystyle=ystyle, $
                        legend=strmid(ytitle,0,20), $
                        annotation=anntmp  
          END
;Plot FCS2 electrical powers
	  5: BEGIN
		pia_xplot, tmpdata.stim, tmpdata.fcs2, psym = zoom_psymch, $
			xtitle=xtitle, fourier=fourier, ytitle = ytitle, title = title, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,         $       
			xstyle=xstyle, ystyle=ystyle, $
                        legend=strmid(ytitle,0,20), $
                        annotation=anntmp  
          END
;Plot time keys
	  6: BEGIN
		pia_xplot, tmpdata.stim, tmpdata.tkey, psym = zoom_psymch, $
			xtitle=xtitle, fourier=fourier, ytitle = ytitle, title = title, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,         $       
			xstyle=xstyle, ystyle=ystyle, $
                        legend=strmid(ytitle,0,20), $
                        annotation=anntmp  
          END
;Plot raster point ID
	  7: BEGIN
		elemnames = ['Raster Point ID 1', 'Raster Point ID 2']
		tmprpid = tmpdata.rpid(menuchoi,*)
		tmprpid_name = elemnames(menuchoi)
		pia_xplot, tmpdata.stim, tmprpid, psym = zoom_psymch, $
			xtitle=xtitle, fourier=fourier, ytitle=tmprpid_name, $
			subtitle=subtitle, title=title, ytype=ytype, $
			overplot = overplot, charsize = charsize,   $
			color = zoom_color, xstyle=xstyle, ystyle=ystyle,  $
			legend=strmid(ytitle,0,18), annotation=anntmp
			              
	  END
;Open Pixel
          8: BEGIN

		pia_xplot, tmpdata.stim, $
			tmpdata.slop(pixop,*), $
			tmpdata.slun(pixop,*), $
			psym = zoom_psymch, xtitle=xtitle, fourier=fourier, $
			ytitle = ytitle, $
			title = title, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,         $       
			xstyle=xstyle, ystyle=ystyle, $
                        legend=strmid(ytitle,0,20), $
                        annotation=anntmp                    

		IF degl_set AND fourier EQ 0 THEN BEGIN
			indno = WHERE(degl_acc(pixop,*) eq 1, nn)
                        IF nn GT 0 THEN $
			  PIA_XPLOT, tmpdata.stim(indno), $
			  tmpdata.slop(pixop,indno), $
			  psym = 1, color=red, overplot=99, $
                        legend=' deglitched points'        
                ENDIF

		IF disc_set AND fourier EQ 0 THEN BEGIN
			indno = WHERE(sig_disc(pixop,*) eq 1, nn)
                        IF nn GT 0 THEN $
			  PIA_XPLOT, tmpdata.stim(indno), $
			  tmpdata.slop(pixop,indno), $
			  psym = 7, color=red, overplot=99, $
                        legend=' discarded points'        
                ENDIF
          END

;Resistor Pixel
          9: BEGIN

		pia_xplot, tmpdata.stim, $
			tmpdata.slop(pixres,*), $
			tmpdata.slun(pixres,*), $
			psym = zoom_psymch, xtitle=xtitle, fourier=fourier, $
			ytitle = ytitle, $
			title = title, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,         $       
			xstyle=xstyle, ystyle=ystyle, $
                        legend=strmid(ytitle,0,20), $
                        annotation=anntmp                    

		IF degl_set AND fourier EQ 0 THEN BEGIN
			indno = WHERE(degl_acc(pixres,*) eq 1, nn)
                        IF nn GT 0 THEN $
			  PIA_XPLOT, tmpdata.stim(indno), $
			  tmpdata.slop(pixres,indno), $
			  psym = 1, color=red, overplot=99, $
                        legend=' deglitched points'        
                ENDIF

		IF disc_set AND fourier EQ 0 THEN BEGIN
			indno = WHERE(sig_disc(pixres,*) eq 1, nn)
                        IF nn GT 0 THEN $
			  PIA_XPLOT, tmpdata.stim(indno), $
			  tmpdata.slop(pixres,indno), $
			  psym = 7, color=red, overplot=99, $
                        legend=' discarded points'        
                ENDIF
          END

;Open Pixel
          10: BEGIN

		pia_xplot, tmpdata.stim, $
			tmpdata.slop(pixop+2,*), $
			tmpdata.slun(pixop+2,*), $
			psym = zoom_psymch, xtitle=xtitle, fourier=fourier, $
			ytitle = ytitle, $
			title = title, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,         $       
			xstyle=xstyle, ystyle=ystyle, $
                        legend=strmid(ytitle,0,20), $
                        annotation=anntmp                    

		IF degl_set AND fourier EQ 0 THEN BEGIN
			indno = WHERE(degl_acc(pixop+2,*) eq 1, nn)
                        IF nn GT 0 THEN $
			  PIA_XPLOT, tmpdata.stim(indno), $
			  tmpdata.slop(pixop+2,indno), $
			  psym = 1, color=red, overplot=99, $
                        legend=' deglitched points'        
                ENDIF

		IF disc_set AND fourier EQ 0 THEN BEGIN
			indno = WHERE(sig_disc(pixop+2,*) eq 1, nn)
                        IF nn GT 0 THEN $
			  PIA_XPLOT, tmpdata.stim(indno), $
			  tmpdata.slop(pixop+2,indno), $
			  psym = 7, color=red, overplot=99, $
                        legend=' discarded points'        
                ENDIF
          END

;Resistor Pixel
          11: BEGIN

		pia_xplot, tmpdata.stim, $
			tmpdata.slop(pixres+2,*), $
			tmpdata.slun(pixres+2,*), $
			psym = zoom_psymch, xtitle=xtitle, fourier=fourier, $
			ytitle = ytitle, $
			title = title, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,         $       
			xstyle=xstyle, ystyle=ystyle, $
                        legend=strmid(ytitle,0,20), $
                        annotation=anntmp                    

		IF degl_set AND fourier EQ 0 THEN BEGIN
			indno = WHERE(degl_acc(pixres+2,*) eq 1, nn)
                        IF nn GT 0 THEN $
			  PIA_XPLOT, tmpdata.stim(indno), $
			  tmpdata.slop(pixres+2,indno), $
			  psym = 1, color=red, overplot=99, $
                        legend=' deglitched points'        
                ENDIF

		IF disc_set AND fourier EQ 0 THEN BEGIN
			indno = WHERE(sig_disc(pixres+2,*) eq 1, nn)
                        IF nn GT 0 THEN $
			  PIA_XPLOT, tmpdata.stim(indno), $
			  tmpdata.slop(pixres+2,indno), $
			  psym = 7, color=red, overplot=99, $
                        legend=' discarded points'        
                ENDIF
          END


	  ELSE: WIDGET_CONTROL, UPDATE_LABEL, $
				set_value = 'Unsupported View'
          ENDCASE

END


; *********************************************************************
; *
; *********************************************************************
pro pia_reset2view2, windowindex, UPDATE_LABEL

COMMON pia_dsp2srd_cmn, tmpdata, srdps, view, viewsize, nviews, viewoptions, $
   overid 
COMMON pia_dsp2srd_flg_cmn, nflag_active, flag_active_lex, flag_active_label  
COMMON pia_dsp2ch2_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON not2_acc, degl_acc, degl_set, sig_disc, disc_set
COMMON tmp2values2, tmprpid, tmprpid_name
@colour_indices

	wset, view(windowindex).windownum         ;set to draw in 

	ERASE, color = 100                        ;erase the view


	IF NOT (KEYWORD_SET(UPDATE_LABEL)) THEN $
	  UPDATE_LABEL = 0


        charsize = 1.2
        symsize = 0.5

        title = viewoptions(view(windowindex).viewtype).viewname
	xtitle = viewoptions(view(windowindex).viewtype).viewxlab
	ytitle = viewoptions(view(windowindex).viewtype).viewylab
	menuchoi = view(windowindex).viewtype_sub

	CASE view(windowindex).viewtype OF


;Plot pixel signals
	  0: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Signal: Pixel '+str_pixch+'    [Volt/s]' 
		IF title NE '' THEN title = str_pixch 
		pia_plot, tmpdata.stim, $
			tmpdata.slop(pixch,*), $
			yerr=tmpdata.slun(pixch,*), $
			psym = psymch, xtitle=xtitle, $
			ytitle = ytitle, $
			charsize = charsize, symsize = symsize

		IF degl_set THEN BEGIN
			indno = WHERE(degl_acc(pixch,*) eq 1, nn)
                        IF nn GT 0 THEN $
			  PIA_OPLOT, tmpdata.stim(indno), $
			  tmpdata.slop(pixch,indno), $
			  psym = 7, color=red
                ENDIF

		IF disc_set THEN BEGIN
			indno = WHERE(sig_disc(pixch,*) eq 1, nn)
                        IF nn GT 0 THEN $
			  PIA_OPLOT, tmpdata.stim(indno), $
			  tmpdata.slop(pixch,indno), $
			  psym = 7, color=red
                ENDIF

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  
         
    	  END
;Plot flag values
	  1: BEGIN
	    	elemnames =  flag_active_label   
		pixch = pixcho(windowindex)
		str_pixch = 'Flag ' + elemnames(menuchoi)+ ': Pixel '+ $
		   STRTRIM(pixch+1,2)
		IF title NE '' THEN title = str_pixch 
		;select flag depending on the choice
		IF flag_active_lex(menuchoi) EQ 'ENCODE' THEN        $
		    tmpflag = tmpdata.flag(pixch,*)                  $
		ELSE decode_piaflag,'SRD',flag_active_lex(menuchoi), $ 
		    tmpdata.flag(pixch,*),tmpflag
		    
		pia_plot, tmpdata.stim, tmpflag, psym = psymch, $
			xtitle=xtitle, ytitle=ytitle, $
			charsize = charsize, symsize = symsize

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  


          END
;Plot chopper positions
	  2: BEGIN
		pia_plot, tmpdata.stim, tmpdata.chop, psym = psymch, $
			xtitle=xtitle, ytitle = ytitle, $
			charsize = charsize, symsize = symsize

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = 'Chopper position'  

          END
;Plot temperatures
	  3: BEGIN
		pixch = pixcho(windowindex)
		dimtemp = size(tmpdata.temp)
		IF dimtemp(0) EQ 2 THEN BEGIN
		   IF pixch GT 63 THEN temptmp = tmpdata.temp(1,*) ELSE $
		   temptmp = tmpdata.temp(0,*) 
		ENDIF ELSE temptmp = tmpdata.temp
		pia_plot, tmpdata.stim, temptmp, psym = psymch, $
			xtitle=xtitle, ytitle = ytitle, $
			charsize = charsize, symsize = symsize

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = 'Temperature'  

          END
;Plot FCS1 electrical powers
	  4: BEGIN
		pia_plot, tmpdata.stim, tmpdata.fcs1, psym = psymch, $
			xtitle = xtitle, ytitle = ytitle, $
			charsize = charsize, symsize = symsize

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = 'FCS1 Power'  

          END
;Plot FCS2 electrical powers
	  5: BEGIN
		pia_plot, tmpdata.stim, tmpdata.fcs2, psym = psymch, $
			xtitle = xtitle, ytitle = ytitle, $
			charsize = charsize, symsize = symsize

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = 'FCS2 Power' 

          END
;Plot time keys
	  6: BEGIN
		pia_plot, tmpdata.stim, tmpdata.tkey, psym = psymch, $
			xtitle = xtitle, ytitle = ytitle, $
			charsize = charsize, symsize = symsize

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = 'Instrument Time Key'

          END
;Plot raster point ID
	  7: BEGIN
		elemnames = ['Raster Point ID 1', 'Raster Point ID 2']
		
		tmprpid = tmpdata.rpid(menuchoi,*)
		tmprpid_name = elemnames(menuchoi)

		pia_plot, tmpdata.stim, tmprpid, psym = psymch, $
			xtitle = xtitle, ytitle = tmprpid_name,  $
			charsize = charsize, symsize = symsize

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value =  tmprpid_name 

	  END
;Open Pixel
          8: BEGIN
                pia_plot, tmpdata.stim, tmpdata.slop(pixop,*), psym = psymch, $
                	yerr=tmpdata.slun(pixres,*), $
                        xtitle = xtitle, ytitle = ytitle, $
                        charsize = charsize, symsize = symsize

		IF degl_set THEN BEGIN
			indno = WHERE(degl_acc(pixop,*) eq 1, nn)
                        IF nn GT 0 THEN $
			  PIA_OPLOT, tmpdata.stim(indno), $
			  tmpdata.slop(pixop,indno), $
			  psym = 7, color=red
                ENDIF

		IF disc_set THEN BEGIN
			indno = WHERE(sig_disc(pixop,*) eq 1, nn)
                        IF nn GT 0 THEN $
			  PIA_OPLOT, tmpdata.stim(indno), $
			  tmpdata.slop(pixop,indno), $
			  psym = 7, color=red
                ENDIF

                IF(keyword_set(UPDATE_LABEL)) then $
                        WIDGET_CONTROL, update_label, $
                        set_value = 'Signal: Open Pixel    [Volt/sec]'
          END

;Resistor Pixel
          9: BEGIN
                pia_plot, tmpdata.stim, tmpdata.slop(pixres,*), psym = psymch, $
                	yerr=tmpdata.slun(pixres,*), $
                        xtitle = xtitle, ytitle = ytitle, $
                        charsize = charsize, symsize = symsize

		IF degl_set THEN BEGIN
			indno = WHERE(degl_acc(pixres,*) eq 1, nn)
                        IF nn GT 0 THEN $
			  PIA_OPLOT, tmpdata.stim(indno), $
			  tmpdata.slop(pixres,indno), $
			  psym = 7, color=red
                ENDIF

		IF disc_set THEN BEGIN
			indno = WHERE(sig_disc(pixres,*) eq 1, nn)
                        IF nn GT 0 THEN $
			  PIA_OPLOT, tmpdata.stim(indno), $
			  tmpdata.slop(pixres,indno), $
			  psym = 7, color=red
                ENDIF

                IF(keyword_set(UPDATE_LABEL)) then $
                        WIDGET_CONTROL, update_label, $
                        set_value = 'Signal: Resistor Pixel [Volt]'
          END

;Open Pixel
          10: BEGIN
                pia_plot, tmpdata.stim, tmpdata.slop(pixop+2,*), psym = psymch, $
                	yerr=tmpdata.slun(pixres,*), $
                        xtitle = xtitle, ytitle = ytitle, $
                        charsize = charsize, symsize = symsize

		IF degl_set THEN BEGIN
			indno = WHERE(degl_acc(pixop+2,*) eq 1, nn)
                        IF nn GT 0 THEN $
			  PIA_OPLOT, tmpdata.stim(indno), $
			  tmpdata.slop(pixop+2,indno), $
			  psym = 7, color=red
                ENDIF

		IF disc_set THEN BEGIN
			indno = WHERE(sig_disc(pixop+2,*) eq 1, nn)
                        IF nn GT 0 THEN $
			  PIA_OPLOT, tmpdata.stim(indno), $
			  tmpdata.slop(pixop+2,indno), $
			  psym = 7, color=red
                ENDIF

                IF(keyword_set(UPDATE_LABEL)) then $
                        WIDGET_CONTROL, update_label, $
                        set_value = 'Signal: Open Pixel    [Volt/sec]'
          END

;Resistor Pixel
          11: BEGIN
                pia_plot, tmpdata.stim, tmpdata.slop(pixres+2,*), psym = psymch, $
                	yerr=tmpdata.slun(pixres+2,*), $
                        xtitle = xtitle, ytitle = ytitle, $
                        charsize = charsize, symsize = symsize

		IF degl_set THEN BEGIN
			indno = WHERE(degl_acc(pixres+2,*) eq 1, nn)
                        IF nn GT 0 THEN $
			  PIA_OPLOT, tmpdata.stim(indno), $
			  tmpdata.slop(pixres+2,indno), $
			  psym = 7, color=red
                ENDIF

		IF disc_set THEN BEGIN
			indno = WHERE(sig_disc(pixres+2,*) eq 1, nn)
                        IF nn GT 0 THEN $
			  PIA_OPLOT, tmpdata.stim(indno), $
			  tmpdata.slop(pixres+2,indno), $
			  psym = 7, color=red
                ENDIF

                IF(keyword_set(UPDATE_LABEL)) then $
                        WIDGET_CONTROL, update_label, $
                        set_value = 'Signal: Resistor Pixel [Volt]'
          END


	  ELSE: WIDGET_CONTROL, UPDATE_LABEL, $
				set_value = 'Unsupported View'
          ENDCASE

END


; ***************************************************************************
;  Event handling routine for PIA display menu
; ****************************************************************************

PRO pia_dsrd2_event, event

@adm
@phtcs
@phtsrd
@phtsmc
@phtacc

COMMON pia_dsp2srd_cmn, tmpdata, srdps, view, viewsize, nviews, viewoptions, $
   overid 
COMMON pia_dsp2ch2_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON srd2text, dattext_id, newheader
COMMON dispcust_cmn, psym, line
COMMON dsp2srd_widg, pixbut
COMMON not2_acc, degl_acc, degl_set, sig_disc, disc_set 
COMMON pia_widget_info, extfil_wid, intfil_wid, buffil_wid, $
                        erddi1_wid, erddi2_wid, srddi1_wid, srddi2_wid, $
                        scpdi1_wid, scpdi2_wid, spddi1_wid, spddi2_wid, $
                        aapdi1_wid, aapdi2_wid
COMMON PIA_DRIFT_PAR, pia_drift_par 

	WIDGET_CONTROL, event.id, get_uvalue = uvalue
        WIDGET_CONTROL, event.top, /HOURGLASS

        cmap_wind_text = ["A","B","C","D"]

	CASE uvalue OF


 	  "EXIT":  BEGIN
		    WIDGET_CONTROL, event.top, /DESTROY 
		  END

 	  "SAVEXIT":  BEGIN
	  	    fill_srd, tmpdata, newheader, REPLACE=srdps
		    WIDGET_CONTROL, event.top, /DESTROY 
		  END


          "HELP":   BEGIN
	   	IF !VERSION.OS NE 'vms' THEN $
		spawn, '$w3net $PIA_HTML/um/srd_window.html &' ELSE $
		spawn, 'w3net /pia_dsk/pia/html/um/srd_window.html'
		END

	  "CUST": BEGIN
			pia_dispcust, GROUP=event.top
			psymch = psym
			 FOR I=0,NVIEWS-1 DO BEGIN
			    pia_reset2view2, i, view(i).controlid
			 ENDFOR
          END

	  "LOAD": BEGIN
; search for same file and detector type
		    newdata = pickmeas(FTYPE="SRD", DTYPE=tmpdata.det, POSI=posi)
		    IF newdata NE '' THEN BEGIN

                     datind = WHERE(phtsrd.admn eq newdata, count)

                     IF count EQ 0 THEN $
                        MESSAGE, /INFO, 'Measurement not found!'
                     ;;IF count GT 1 THEN datind=datind(posi(0))

                     IF count NE 0 THEN BEGIN 

			degl_set = 0
			disc_set = 0
			srdps = datind(posi(0))
		    	pia_load_isrd, phtsrd(srdps), tmpdata		
; Look into the selection criteria
        		get_sigdisc, tmpdata, /ENCODE_FLAG
			get_validflag, tmpdata.flag, 'SRD', redflag, $
			  det=tmpdata.det, /allpix

                        sig_disc = redflag
        		disc_set = 1

; header update
			newheader = tmpdata.hdr

			obj = FXPAR(tmpdata.hdr,'OBJECT')
			attra = FXPAR(tmpdata.hdr,'ATTRA')
			attdec = FXPAR(tmpdata.hdr,'ATTDEC')
			decode_admn, tmpdata.admn, dattext
			more_text = 'OBJ:' + obj + ' ' + give_sradec(attra, attdec)
			dattext = 'SRD '+dattext+ ' - '+$
				tmpdata.unit+ ' - ' + more_text

			WIDGET_CONTROL, dattext_id, SET_VALUE = dattext  
			
		        for i=0, NVIEWS - 1 do pia_reset2view2, i
                     ENDIF
		    ENDIF
		  END	                  	

	  "SAVEBUFF": fill_srd, tmpdata, newheader, REPLACE=srdps

	  "SAVEBUFF_NEW": BEGIN
	               srdps = N_ELEMENTS(phtsrd)
                       fill_srd, tmpdata, newheader
                   END

	  "SAVEI": BEGIN
	  	    change_tmphdr, tmpdata, 'SRD', newheader, tmpout
	  	    PCONT_SAVEINT, junk, 'SRD', tmpdata=tmpout
		  END

	  "SAVEF": BEGIN
		    WRITE_SRD, tmpdata, newheader  
		  END

          "SHOWD": PIA_SHOWSTR, tmpdata, VALNAMES=phtsrd_desc, GROUP=event.top

	  "SLDISC": BEGIN 

		PIA_SIGDISC, nsig=tmpdata.rchp  

                get_sigdisc, tmpdata, /ENCODE_FLAG
		get_validflag, tmpdata.flag, 'SRD', redflag, $
			  det=tmpdata.det, /allpix

                sig_disc = redflag
		disc_set = 1

		FOR i=0, NVIEWS - 1 do pia_reset2view2, i
	  END		   

	  "DEGL_PAR": BEGIN
	  	deglitch_change, /no_data, group=event.top, $
				   /modal
	  END

	  "DEGL": BEGIN

; reset the glitch flags to 0 - use also the OTF low points for deglitching 

		indsevere_deglitch = set_indsevere('SRD',['NOTF','GLITCH'],$
		     /DELETE)
		get_validflag, tmpdata.flag, 'SRD', redflag, $
		   INDSEVERE = indsevere_deglitch,det=tmpdata.det,/allpix
		do_deglitch, tmpdata, redflag, newheader, degl_acc, $
			/ENCODE_FLAG, GROUP=group 
                degl_set = 1

		FOR i=0, NVIEWS - 1 do pia_reset2view2, i
	  END

	  "RLIN": BEGIN

		rlin_proc, tmpdata, newhdr=newheader, /SRD
		
		FOR i=0, NVIEWS - 1 do pia_reset2view2, i
	  END

	  "RINT": BEGIN
; check: if correction already applied return
                done = fxpar(newheader,'PRS_RIN0')
                IF done NE 0 THEN BEGIN
                        XDISPLAYFILE, "", $
                          GROUP = event.top, $
                          TITLE = "Not Allowed ", $
                          WIDTH = 50, $
                          HEIGHT = 12, $
                          TEXT = [" Reset interval correction for this", $
                                  " measurement was already applied "]
                        RETURN
                ENDIF
; check: if dark current subtracted give warning
                done = fxpar(newheader,'PRS_DARK')
                IF done NE 0 THEN BEGIN
                        XDISPLAYFILE, "", $
                          GROUP = event.top, $
                          TITLE = "Wrong done, friend ", $
                          WIDTH = 50, $
                          HEIGHT = 12, $
                          TEXT = [" Dark Current subtracion for this", $
                                  " measurement was applied.", $
                                  " Actually reset interval correction ",$
                                  " should be performed before! " ]
                ENDIF
                
		do_corr_resetint, tmpdata, newheader


                FOR I=0,NVIEWS-1 DO BEGIN
                            WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
                            view(i).windownum = temp
                            pia_reset2view2, i, view(i).controlid
                ENDFOR
           END 
               
               
	  "RPIDSET": BEGIN
	  ; reset RPID to avoid raster in SSO observations
	  	tmpdata.rpid = tmpdata.rpid * 0 + 1b
		FXADDPAR, newheader, 'PR_RPID0', 'RPID change', $
		       "All RPID's set to [1b,1b] ", BEFORE='XTENSION'
	  		
           END 

	  "DARKC_ORB": BEGIN 
	    darkcur_orb, tmpdata, NEWHEADER = newheader, ERROR=error
	    IF error NE "" THEN BEGIN
                        XDISPLAYFILE, "", $
                          GROUP = event.top, $
                          TITLE = "Not Allowed ", $
                          WIDTH = 50, $
                          HEIGHT = 12, $
                          TEXT = error
	    ENDIF ELSE FOR i=0, NVIEWS - 1 do pia_reset2view2, i
          END

	  "DARKC_ORB_PAR": PIA_DEF_DARKORB

          "DARKC": BEGIN
; check: if dark current subtraction already applied return
                done = fxpar(newheader,'PRS_DARK')
                IF done NE 0 THEN BEGIN
                        XDISPLAYFILE, "", $
                          GROUP = event.top, $
                          TITLE = "Not Allowed ", $
                          WIDTH = 50, $
                          HEIGHT = 12, $
                          TEXT = [" Dark Current for this", $
                                  " measurement was already applied "]
                        RETURN
                ENDIF

		detpix = pixel_det(tmpdata.det)

                darkcur, tmpdata.slop(0:detpix-1,*), tmpdata.det, outslop

; Replace slop contents, log it into the newheader
                IF (N_ELEMENTS(tmpdata.slop(0:detpix-1,*)) EQ    $
                        N_ELEMENTS(outslop)) THEN BEGIN
                          tmpdata.slop(0:detpix-1,*) = outslop

		    	FXADDPAR, newheader, 'PRS_DARK', 1,$ 
		    	     'Dark Current subtracted', BEFORE = 'XTENSION'


			 ; Update the windows with the subtracted values 
                          FOR I=0,NVIEWS-1 DO BEGIN
                            WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
                            view(i).windownum = temp
                            pia_reset2view2, i, view(i).controlid
                          ENDFOR
                ENDIF
          END

          "HDR": BEGIN
                header = newheader
                IF N_ELEMENTS(header) EQ 0 THEN $
                        MESSAGE, /INFO, 'No header defined' ELSE $
                        pia_disp_hdr, header, tmpdata.admn, 'PHTSRD'
          END

          "CS":PIA_disp_cs,tmpdata.admn

	  "ISREP": PIA_disp_isr,STRMID(tmpdata.admn,4,8)

	  "OLREP": PIA_disp_olr,STRMID(tmpdata.admn,4,8)

	  "EOHA": PIA_disp_eoha,STRMID(tmpdata.admn,4,8)

	  "EOHI": PIA_disp_eohi,STRMID(tmpdata.admn,4,8)

	  "SLICES": BEGIN

		npix = N_ELEMENTS(tmpdata.slop(*,0)) - 2
 		IF npix EQ 130 THEN npix = 128

		nslice = N_ELEMENTS(tmpdata.slop(0,*))

		decode_admn, tmpdata.admn, tmpmeas

	  	PIA_XPLOT, indgen(npix) + 1, tmpdata.slop(0:npix-1,0), $
	  		TITLE='Time development of Signal - '+tmpmeas, $
	  		xtitle=' Pixel # ', ytitle='Signal    [V/s]', $
	  		psym=10

		zoom_color = 1

		IF nslice GT 1 THEN BEGIN
	  	 FOR I=1, nslice-1 DO BEGIN
			zoom_color = zoom_color + 1
			IF zoom_color EQ 9 then zoom_color = 1
	  	 	WAIT,0.5
	  	 	PIA_XPLOT, indgen(npix) + 1, tmpdata.slop(0:npix-1,i),$
	  	 	/overplot, color=zoom_color, psym=10
	  	 ENDFOR
	  	ENDIF 
	  END	  	 	

	  "SLICES_3D": BEGIN

		npix = N_ELEMENTS(tmpdata.slop(*,0)) - 2
 		IF npix EQ 130 THEN npix = 128

		decode_admn, tmpdata.admn, tmpmeas

		PIA_XSurface, tmpdata.slop(0:npix-1,*), $
			title='Time evol. of Signals - '+tmpmeas, $
			xtitle=' Pixel # ', ytitle='Time    [s]', $
			ztitle='Signal    [V/s]', charsize=1.25, wlego=1

	  END	  	 	

	  "PROC":  BEGIN
                process_tmpsrd, tmpdata, newheader, scppos
                pia_dispscp, data= scppos

	  END

	  "PROC_DRFT":  BEGIN
		pia_drift_defin, defin_str, STOP
		
		IF stop EQ 1 THEN RETURN
		
		IF (defin_str.driftm) AND (defin_str.param) THEN BEGIN
		  pia_drift_inipar, tmpdata.det, stop_driftmpar, group=event.top 
		  if stop_driftmpar NE 0 THEN RETURN
		ENDIF    

	        WIDGET_CONTROL, event.top, /HOURGLASS
		
		driftmod = defin_str.driftm
		process_tmpsrd, tmpdata, newheader, scppos, driftps, $
		  driftcorr=defin_str.stab, slop_var = defin_str.slopv, $
		  driftmod= driftmod
		  
		  IF scppos eq -1 THEN RETURN

		IF (driftmod) THEN BEGIN
		  IF (defin_str.interact) THEN $
		   pia_dispdrift, driftps, tmpdata, scppos $
		  ELSE BEGIN
		    drift_std_scp, driftps, scppos
  		    pia_dispscp, data= scppos
		  ENDELSE
		ENDIF ELSE pia_dispscp, data= scppos
	  END

	  "PROC_DYNR":  BEGIN
		process_srddynr, tmpdata, dynrpos, HDR=newheader
		pia_dispdynresp, data= dynrpos
	  END

	  "PROC_DYNCAL":  BEGIN
                WIDGET_CONTROL, event.top, /HOURGLASS
		select_dyncalib, tmpdata, cal_str
		calib_dynsrd, tmpdata, cal_str.admn, dyncalps, $ 
		    NEWHEADER = newheader
		pia_dispdyncal, dyncalps, tmpdata
	  END

	  "PROC_DYNCAL_CUSTO":  BEGIN
		pia_def_dyncal, tmpdata.det, ncalib, sel_lotable, ISTOP = istop
		IF NOT istop THEN BEGIN 
                  WIDGET_CONTROL, event.top, /HOURGLASS
		  select_dyncalib, tmpdata, cal_str,NCALUSE=ncalib, $ 
		    LOTABLE_DB=sel_lotable
		  calib_dynsrd, tmpdata, cal_str.admn, dyncalps, $ 
		    NEWHEADER = newheader
		  pia_dispdyncal, dyncalps, tmpdata
		ENDIF  
	  END

	  "PATTERN": BEGIN
		process_tmpsrd, tmpdata, newheader, scppos, tmpscp=tmpscp, $
		 /pattern
		PIA_DISPSCP, data=scppos
	  END	        

	  "PIXCH": BEGIN
			old_pixcho = pixcho
			new_pixc = pia_pixchoice(GROUP=event.top, PIXC=pixcho)
			maxpix = max(new_pixc)
                        minpix = min(new_pixc)
			junk = 0
			IF (tmpdata.det EQ 'C1' AND maxpix gt 8) OR $
			   (tmpdata.det EQ 'C2' AND maxpix gt 3) OR $
			   (tmpdata.det EQ 'SS' AND maxpix gt 127) OR $
			   (tmpdata.det EQ 'SL' AND maxpix gt 127) OR $
			   (minpix lt 0)  THEN BEGIN
		    		XDISPLAYFILE, "", $
                    		GROUP = event.top, $
                    		TITLE = "Warning ", $
                    		WIDTH = 30, $
                    		HEIGHT = 6, $
                    		TEXT = [" Your pixel choice is not valid ", $
                                        " and will not be taken "]
		                junk = 1
			ENDIF
			IF junk NE 1 THEN BEGIN  			
			 FOR I=0,NVIEWS-1 DO BEGIN
			  IF new_pixc(i) NE old_pixcho(i) THEN BEGIN
			    pixcho(i) = new_pixc(i)
			    WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
			    view(i).windownum = temp
			    pia_reset2view2, i, view(i).controlid
                            IF STRMID(tmpdata.det,0,1) EQ 'C' THEN BEGIN
                              txtval = cmap_wind_text(i)
                              junk = where(new_pixc eq old_pixcho(i), count)
                              IF count EQ 0 THEN $
                                 WIDGET_CONTROL, pixbut(old_pixcho(i)), $
                                        SET_VALUE = ' '
                              WIDGET_CONTROL, pixbut(pixcho(i)), $
                                        SET_VALUE = txtval
                            ENDIF
                          ENDIF
			 ENDFOR
			ENDIF
          END

	  "PIXCHSER": BEGIN
			old_pixcho = pixcho
			new_pixc = old_pixcho + nviews
			CASE STRMID(tmpdata.det,0,2) OF
				'C1': npix = 9
				'C2': npix = 4
				'SL': npix = 128
				'SS': npix = 128
				'P1': RETURN
				'P2': RETURN
				'P3': RETURN
			ENDCASE  
			new_pixc = new_pixc mod npix
			
			FOR I=0,NVIEWS-1 DO BEGIN
			  IF new_pixc(i) NE old_pixcho(i) THEN BEGIN
			    pixcho(i) = new_pixc(i)
			    WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
			    view(i).windownum = temp
			    pia_reset2view2, i, view(i).controlid
			    IF STRMID(tmpdata.det,0,1) EQ 'C' THEN BEGIN 
			      txtval = cmap_wind_text(i)
			      junk = where(new_pixc eq old_pixcho(i), count)
			      IF count EQ 0 THEN $
			         WIDGET_CONTROL, pixbut(old_pixcho(i)), $
					SET_VALUE = ' '
			      WIDGET_CONTROL, pixbut(pixcho(i)), $
					SET_VALUE = txtval
			    ENDIF 
                          ENDIF
			ENDFOR
          END

	  "PIXCHSERD": BEGIN
			old_pixcho = pixcho
			new_pixc = old_pixcho - nviews
			CASE STRMID(tmpdata.det,0,2) OF
				'C1': npix = 9
				'C2': npix = 4
				'SL': npix = 128
				'SS': npix = 128
				'P1': RETURN
				'P2': RETURN
				'P3': RETURN
			ENDCASE  
			ind=WHERE(new_pixc LT 0,nind)
			IF nind GT 0 THEN new_pixc(ind) = npix+new_pixc(ind)  
			
			FOR I=0,NVIEWS-1 DO BEGIN
			  IF new_pixc(i) NE old_pixcho(i) THEN BEGIN
			    pixcho(i) = new_pixc(i)
			    WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
			    view(i).windownum = temp
			    pia_reset2view2, i, view(i).controlid
			    IF STRMID(tmpdata.det,0,1) EQ 'C' THEN BEGIN 
			      txtval = cmap_wind_text(i)
			      junk = where(new_pixc eq old_pixcho(i), count)
			      IF count EQ 0 THEN $
			         WIDGET_CONTROL, pixbut(old_pixcho(i)), $
					SET_VALUE = ' '
			      WIDGET_CONTROL, pixbut(pixcho(i)), $
					SET_VALUE = txtval
			    ENDIF 
                          ENDIF
			ENDFOR
          END

          "NVIEWS": BEGIN

                newviews = event.value + 1
		!PIA_NVIEWS = 1 > newviews < 4
                IF newviews NE nviews THEN BEGIN
                        WIDGET_CONTROL, srddi2_wid, /DESTROY
                        pia_dis2srd, NV = newviews, /redraw
                ENDIF
          END


          "HK" : BEGIN
                get_pht_hk,tmpdata.admn,phtcs_redu
                xdisp_hk
          END

          "SRM0" : BEGIN
                 serhdr = newheader
                 pia_SM, tmpdata, serhdr, 0, smcpos
                 IF N_ELEMENTS(smcpos) NE 0 THEN $
                    pia_sm_dispsmc, data=phtsmc(smcpos)
          END

          "SRM1" : BEGIN
                 serhdr = newheader
                 pia_SM, tmpdata, serhdr, 1, smcpos
                 IF N_ELEMENTS(smcpos) NE 0 THEN $
                    pia_sm_dispsmc, data=phtsmc(smcpos)
          END

          "SRM2" : BEGIN
                 serhdr = newheader
                 pia_SM, tmpdata, serhdr, 2, smcpos
                 IF N_ELEMENTS(smcpos) NE 0 THEN $
                    pia_sm_dispsmc, data=phtsmc(smcpos)
          END
 
          
         ENDCASE

RETURN
END

; ****************************************************************************
;  PIA DispSRD - menu definition procedure
; ****************************************************************************

PRO pia_dis2srd, GROUP=group, DATA=DATA, NV = NV, REDRAW=redraw


COMMON pia_dsp2srd_cmn, tmpdata, srdps, view, viewsize, nviews, viewoptions, $ 
   overid 
COMMON pia_dsp2srd_flg_cmn, nflag_active, flag_active_lex, flag_active_label  
COMMON pia_dsp2ch2_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON srd2text, dattext_id, newheader
COMMON dsp2srd_widg, pixbut
COMMON not2_acc, degl_acc, degl_set, sig_disc, disc_set
COMMON pia_widget_info, extfil_wid, intfil_wid, buffil_wid, $
                        erddi1_wid, erddi2_wid, srddi1_wid, srddi2_wid, $
                        scpdi1_wid, scpdi2_wid, spddi1_wid, spddi2_wid, $
                        aapdi1_wid, aapdi2_wid
COMMON dispcust_cmn, psym, line

@phtsrd
COMMON piaflag_info, piaflag_str

; If already registered, start second ERD display

        IF Xregistered("pia_dis2srd") NE 0 THEN BEGIN
                WIDGET_CONTROL, srddi2_wid, /DESTROY
        END


        IF NOT KEYWORD_SET(redraw) THEN BEGIN
; load data from dynamic buffers into temporary structure
                srdps = data
		PIA_LOAD_ISRD, phtsrd(srdps), tmpdata 
                newheader = tmpdata.hdr
; set deglitching and selection to not in the beginning
		degl_set = 0
		disc_set = 0
        ENDIF

; initialize views and pixels chosen
        IF KEYWORD_SET(NV) THEN NVIEWS = nv ELSE nviews = !PIA_NVIEWS
        IF nviews GT 4 THEN nviews = 4
        pixcount = -1


	IF N_ELEMENTS(psym) EQ 0 THEN psymch = 4 ELSE $
		psymch = psym	

	CASE STRMID(tmpdata.det, 0,1) of 
          'P': BEGIN 
		pixcho = [0,0,0,0]
		pixop = 0
		pixres = 0
	  END
          ELSE: BEGIN  
	         CASE STRMID(tmpdata.det,0,2) of
	           'C1': BEGIN
			pixcho = [0,2,4,6]
			pixop = 9
			pixres = 10
		   END
	           'C2': BEGIN
			pixcho = [1,2,3,0]
			pixop = 4
			pixres = 5
		   END
	           'SS': BEGIN
			pixcho = [10,40,90,120]
			pixop = 128
			pixres = 129
		   END
	           'SL': BEGIN
			pixcho = [10,40,90,120]
			pixop = 128
			pixres = 129
		   END
		  ELSE: MESSAGE, /INFO, 'Detector not recognized'
	 	  ENDCASE		
	  END
        ENDCASE

	indflag_active = WHERE(piaflag_str.srd.lex NE 'DUMMY',nflag_active)
	
	nflag_active = nflag_active +1
	
	flag_active_lex = ['ENCODE',piaflag_str.srd.lex(indflag_active)]
	flag_active_label = ['Encode',piaflag_str.srd.expla(indflag_active)]

	viewsize = 220
	xsize = viewsize * 4 / nviews
	ysize = viewsize

	;structure for each view
	viewinstance = {        viewtype:0b, 		$	   
				viewtype_sub:0b, 	$       
				controlid:0L,		$       	
				windowid:0L,		$
				windownum:0}	

        view = REPLICATE(viewinstance, NVIEWS)		; array of view struct.

        IF STRMID(tmpdata.det, 0,1) eq 'P' THEN $
                FOR i=0,nviews-1 DO view(i).viewtype = i

	;structures describing each type of view 
	instance = {viewname:'',viewid:0, viewxlab:'', viewylab:'', $
		viewmenu:0, viewmenuchoi:0,viewmenulabel:STRARR(nflag_active) }
	NVIEWOPTS = 12                           	

	viewoptions = REPLICATE(instance, NVIEWOPTS)    

        viewoptions(0).viewname = "Signal Data     [Volt/sec]"
        viewoptions(0).viewid = 0
        viewoptions(0).viewylab = "Signal    [V/s]"
        viewoptions(0).viewxlab = "Time       [s]"
	viewoptions(1).viewname = "Signal Flag    "
	viewoptions(1).viewid = 1
        viewoptions(1).viewmenu = 1
        viewoptions(1).viewmenuchoi = nflag_active
        viewoptions(1).viewmenulabel = flag_active_label
	viewoptions(1).viewylab = "Flag         "
	viewoptions(1).viewxlab = "Time       [s]"
        viewoptions(2).viewname = "Chopper Position  [arcsec]"
        viewoptions(2).viewid = 2
        viewoptions(2).viewylab = "Chopper position  [arcsec]"
        viewoptions(2).viewxlab = "Time       [s]"
        viewoptions(3).viewname = "Temperature     [K]"
        viewoptions(3).viewid = 3
        viewoptions(3).viewylab = "Measured temperature   [K]"
        viewoptions(3).viewxlab = "Time       [s]"
        viewoptions(4).viewname = "FCS1 electrical Power [mW]"
        viewoptions(4).viewid = 4
        viewoptions(4).viewylab = "Measured Power        [mW]"
        viewoptions(4).viewxlab = "Time       [s]"
        viewoptions(5).viewname = "FCS2 electrical Power [mW]"
        viewoptions(5).viewid = 5
        viewoptions(5).viewylab = "Measured Power        [mW]"
        viewoptions(5).viewxlab = "Time       [s]"
        viewoptions(6).viewname = "Time Key"
        viewoptions(6).viewid = 6
        viewoptions(6).viewylab = "Instrument Time Key "
        viewoptions(6).viewxlab = "Time       [s]"
	viewoptions(7).viewname = "Raster Point ID"
	viewoptions(7).viewid = 7
        viewoptions(7).viewmenu = 1
        viewoptions(7).viewmenuchoi = 2
        viewoptions(7).viewmenulabel = ['1','2']
	viewoptions(7).viewylab = "Raster Point ID "
	viewoptions(7).viewxlab = "Time       [s]"
        viewoptions(8).viewname = "Signal Open Pixel    [V/s]"
        viewoptions(8).viewid = 8
        viewoptions(8).viewylab = "Signal     [V/s] "
        viewoptions(8).viewxlab = "Time       [s]"
        viewoptions(9).viewname = "Signal Resistor      [V/s]"
        viewoptions(9).viewid = 9
        viewoptions(9).viewylab = "Signal     [V/s] "
        viewoptions(9).viewxlab = "Time       [s]"
        viewoptions(10).viewname = "Signal Open Pxl SL  [V/s]"
        viewoptions(10).viewid = 10
        viewoptions(10).viewylab = "Signal     [V/s] "
        viewoptions(10).viewxlab = "Time       [s]"
        viewoptions(11).viewname = "Signal Resistor SL  [V/s]"
        viewoptions(11).viewid = 11
        viewoptions(11).viewylab = "Signal     [V/s] "
        viewoptions(11).viewxlab = "Time       [s]"

; top base

	srddi2_wid = WIDGET_BASE( TITLE="PIA SRD 2nd Data Display", /COLUMN, $
				XPAD = 20, YPAD = 20, SPACE = 20)

; control windows

	control = WIDGET_BASE(srddi2_wid, /ROW)

	control_exit = WIDGET_BUTTON(control, VALUE="    Exit    ",$
					 /ALIGN_CENTER, /MENU)
	save_quit = WIDGET_BUTTON(control_exit, $
		VALUE="Save modified measurement into buffer and Quit",$
					 UVALUE="SAVEXIT")
	simple_quit = WIDGET_BUTTON(control_exit, $
		VALUE="Quit without saving modified measurement into buffer",$
					 UVALUE="EXIT")
	control_help = WIDGET_BUTTON(control, VALUE="    Help    ",$
					 /ALIGN_CENTER, UVALUE="HELP")
	control_cust = WIDGET_BUTTON(control, VALUE="  Customize ",$
					 /ALIGN_CENTER, UVALUE="CUST")


	junk = WIDGET_LABEL(control, VALUE = '     ')

	obj = FXPAR(tmpdata.hdr,'OBJECT')
	attra = FXPAR(tmpdata.hdr,'ATTRA')
	attdec = FXPAR(tmpdata.hdr,'ATTDEC')
	decode_admn, tmpdata.admn, dattext
	more_text = 'OBJ:' + obj +  ' ' + give_sradec(attra, attdec)
	dattext = 'SRD '+dattext+ ' - '+tmpdata.unit+ ' - ' + more_text
	dattext_id = WIDGET_LABEL(control, VALUE = dattext)  

;------------------- the C mapping windows -------------------------

        junk = WIDGET_LABEL(control, VALUE = '     ')

        IF STRMID(tmpdata.det, 0,1) eq 'C' THEN BEGIN

        pixver = WIDGET_BASE(control, /COLUMN)
        junk = WIDGET_LABEL(pixver, VALUE='^ +Z')

        pixhor = WIDGET_BASE(pixver,/ROW)

          IF STRMID(tmpdata.det, 1,1) eq '1' THEN BEGIN
                pixbut = lonarr(9)
                FOR i=0,2 DO pixbut(i*3+2) = $
                        WIDGET_BUTTON(pixhor, VALUE=' ',$
                                XOFFSET=3*i, $,
                                UVALUE=i*3+2,$
                                EVENT_PRO = 'pixbut2event2')
                pixhor = WIDGET_BASE(pixver,/ROW,YOFFSET=10)
                FOR i=0,2 DO pixbut(i*3+1) = $
                        WIDGET_BUTTON(pixhor, VALUE=' ',$
                                XOFFSET=3*i, $
                                UVALUE=i*3+1,$
                                EVENT_PRO = 'pixbut2event2')
                pixhor = WIDGET_BASE(pixver,/ROW,YOFFSET=10)
                FOR i=0,2 DO pixbut(i*3) = $
                        WIDGET_BUTTON(pixhor, VALUE=' ',$
                                XOFFSET=3*i, $
                                UVALUE=i*3,$
                                EVENT_PRO = 'pixbut2event2')
          ENDIF ELSE $
          IF STRMID(tmpdata.det, 1,1) eq '2' THEN BEGIN
                pixbut = lonarr(4)
                FOR i=0,1 DO pixbut(i+2) = $
                        WIDGET_BUTTON(pixhor, VALUE=' ',$
                                XOFFSET=3*i, $
                                UVALUE=i+2,$
                                EVENT_PRO = 'pixbut2event2')
                pixhor = WIDGET_BASE(pixver,/ROW,YOFFSET=10)
                FOR i=1,0,-1 DO pixbut(i) = $
                        WIDGET_BUTTON(pixhor, VALUE=' ',$
                                XOFFSET=3*i, $
                                UVALUE=i,$
                                EVENT_PRO = 'pixbut2event2')
          ENDIF
         junk = WIDGET_LABEL(pixhor, VALUE='> +Y')                               
        ENDIF

;----------------- the View windows are defined ------------------

	viewbase = WIDGET_BASE(srddi2_wid, /ROW, SPACE=1)

	viewstorageids = LONARR(NVIEWS)
	overid = lonarr(NVIEWS)	   
	
; Provide for Open and Resistor pixels only if necessary
	IF STRMID(tmpdata.det, 0,1) NE 'S' THEN NVIEWOPTS = NVIEWOPTS - 2
	IF STRMID(tmpdata.det, 0,1) EQ 'P' THEN NVIEWOPTS = NVIEWOPTS - 2

	cmap_wind_text=["A","B","C","D"]
	
        FOR viewindex = 0, NVIEWS - 1 DO BEGIN
	  viewbase_sub = WIDGET_BASE(viewbase, /FRAME, /COLUMN)
	  junk = WIDGET_LABEL(viewbase_sub, $
	       VALUE="Window "+cmap_wind_text(viewindex))
	  tempbase = WIDGET_BASE(viewbase_sub, /COLUMN,                  $
				EVENT_PRO = 'view2event2')
	  view(viewindex).controlid = WIDGET_BUTTON(tempbase, VALUE="   ",   $
				MENU = 2, UVALUE = viewindex, $
				EVENT_PRO = 'view2event2')
	  view(viewindex).windowid = WIDGET_DRAW(tempbase,                   $
				XSIZE = xsize, YSIZE = ysize,                $
				RETAIN = 2) 
		FOR i = 0, NVIEWOPTS - 1 DO BEGIN
     			dummy = WIDGET_BUTTON(view(viewindex).controlid,   $
                	VALUE = viewoptions(i).viewname,                   $
                	UVALUE = viewoptions(i).viewid,                    $
			MENU=viewoptions(i).viewmenu)
			IF viewoptions(i).viewmenu THEN BEGIN
			   FOR ichoi=0,viewoptions(i).viewmenuchoi-1 DO    $
			   dummy1 = WIDGET_BUTTON(dummy,                   $
			     VALUE=viewoptions(i).viewmenulabel(ichoi),    $
			     UVALUE=ichoi)
			ENDIF     
		ENDFOR

	  zoombase = WIDGET_BASE(tempbase, /FRAME, /ROW)
          zoom = WIDGET_BUTTON(zoombase, $
                        VALUE = "Zoom & Print",$
                        UVALUE = viewindex, MENU = 2)

     	  dummy = WIDGET_BUTTON(zoom, $
                  	VALUE = "New Plot ", $
                	UVALUE = viewindex, EVENT_PRO = 'zoom2event2')

          synch = WIDGET_BUTTON(zoom, $
                        VALUE = "Overplot, same y-axis  ", $
                        UVALUE = viewindex, EVENT_PRO = 'zoom2sync2')
          nsynch = WIDGET_BUTTON(zoom, $
                        VALUE = "Overplot, new y-axis", $
                        UVALUE = viewindex, EVENT_PRO = 'zoom2nsync2')

          process = WIDGET_BUTTON(zoombase, $
                        VALUE = "Test processing", $
                        UVALUE = viewindex, MENU = 2)

          fourier = WIDGET_BUTTON(process, $
                        VALUE = "Fourier", $
                        UVALUE = viewindex, EVENT_PRO = 'zoom2fourier2')

          aver = WIDGET_BUTTON(process, $
                        VALUE = "Average", $
                        UVALUE = viewindex, MENU = 2)

          average = WIDGET_BUTTON(aver, $
                        VALUE = "Chopper ", $
                        UVALUE = viewindex, EVENT_PRO = 'average2chop2')

          average = WIDGET_BUTTON(aver, $
                        VALUE = "Non-Chopper", $
                        UVALUE = viewindex, EVENT_PRO = 'average2nonch2')

          medi = WIDGET_BUTTON(process, $
                        VALUE = "Median", $
                        UVALUE = viewindex, MENU = 2)

          median = WIDGET_BUTTON(medi, $
                        VALUE = "Chopper", $
                        UVALUE = viewindex, EVENT_PRO = 'median2chop2')

          median = WIDGET_BUTTON(medi, $
                        VALUE = "Non-Chopper", $
                        UVALUE = viewindex, EVENT_PRO = 'median2nonch2')

	  deglit = WIDGET_BUTTON(process, $
			VALUE = "Deglitching", $
			UVALUE = viewindex, EVENT_PRO= 'deglitch2_par')

          stabil = WIDGET_BUTTON(process, $
                        VALUE = "Drift Stability", $
                        UVALUE = viewindex, EVENT_PRO= 'stabil2_par')

          drift = WIDGET_BUTTON(process, $
                        VALUE = "Drift Modelling", $
                        UVALUE = viewindex, EVENT_PRO= 'drift2_par')

          discar = WIDGET_BUTTON(process, $
                        VALUE = "Discard area graphically", $
                        UVALUE = viewindex, EVENT_PRO= 'discard2_area2')
          resel = WIDGET_BUTTON(process, $
                        VALUE = "Reselect area graphically", $
                        UVALUE = viewindex, EVENT_PRO= 'reselect2_area2')
        ENDFOR

	controlbase = WIDGET_BASE(srddi2_wid, $
                /ROW, $
                SPACE = 40)


;----------------- the Data controls are defined ------------------

        datcont = WIDGET_BUTTON(controlbase, VALUE='Data', /MENU )
        id_2 = WIDGET_BUTTON(datcont, VALUE='Load', UVALUE='LOAD' )
        id_2 = WIDGET_BUTTON(datcont, VALUE='Save', /MENU )
        id_3 = WIDGET_BUTTON(id_2, VALUE='to SRD buffer', /MENU )
        id_4 = WIDGET_BUTTON(id_3, VALUE='new measurement', $
				 UVALUE='SAVEBUFF_NEW' )
        id_4 = WIDGET_BUTTON(id_3, VALUE='same measurement', $
				 UVALUE='SAVEBUFF' )
        id_3 = WIDGET_BUTTON(id_2, VALUE='to PIA internal file', $
                                 UVALUE='SAVEI' )
        id_3 = WIDGET_BUTTON(id_2, VALUE='to FITS external file', $
                                UVALUE='SAVEF' )
        id_2 = WIDGET_BUTTON(datcont, VALUE='Show Data', UVALUE='SHOWD' )

;---------------- the Selection controls are defined -----------------

        selcont = WIDGET_BUTTON(controlbase, VALUE='Selection', /MENU )
        id_2 = WIDGET_BUTTON(selcont, VALUE='Discard Signals', $
				UVALUE='SLDISC')

;---------------- the Correction controls are defined -----------------

        corrcont = WIDGET_BUTTON(controlbase, VALUE='Correction', /MENU )
        id_2 = WIDGET_BUTTON(corrcont, VALUE='Reset interval corr.', $
        	UVALUE='RINT')
         
        id_2 = WIDGET_BUTTON(corrcont, VALUE='Deglitching', /MENU)
	id_3 = WIDGET_BUTTON(id_2,  $ 
	         VALUE=' Perform it ', $
	         UVALUE ='DEGL')
	id_3 = WIDGET_BUTTON(id_2,  $ 
	         VALUE=' Customize ', $
	         UVALUE ='DEGL_PAR')

	id_2 = WIDGET_BUTTON(corrcont, $
	  VALUE='Dark Current Subtr. (orbital dep)', /MENU)
	id_3 = WIDGET_BUTTON(id_2,  $ 
	         VALUE=' Perform it ', $
	         UVALUE ='DARKC_ORB')
	id_3 = WIDGET_BUTTON(id_2,  $ 
	         VALUE=' Customize ', $
	         UVALUE ='DARKC_ORB_PAR')

        id_2 = WIDGET_BUTTON(corrcont, VALUE='Linearization', UVALUE='RLIN')

        id_2 = WIDGET_BUTTON(corrcont, VALUE='Set RPIDs -> [1,1]', $
        		UVALUE='RPIDSET')


;---------------- the View controls are defined -----------------

        viewcont = WIDGET_BUTTON(controlbase, VALUE='View', /MENU )
        id_2 = WIDGET_BUTTON(viewcont, VALUE='Header Info ', UVALUE='HDR')
        id_2 = WIDGET_BUTTON(viewcont, VALUE='Compact Status ', UVALUE='CS')
        cont2 = WIDGET_BUTTON(viewcont, VALUE='Auxiliary Files', /MENU )
        id_2 = WIDGET_BUTTON(cont2, VALUE='IS Report ', UVALUE='ISREP')
        id_2 = WIDGET_BUTTON(cont2, VALUE='OLP Report ', UVALUE='OLREP')
        id_2 = WIDGET_BUTTON(cont2, VALUE='EOHA ', UVALUE='EOHA')
        id_2 = WIDGET_BUTTON(cont2, VALUE='EOHI ', UVALUE='EOHI')

;---------------- the Array controls are defined -----------------

        arraycont = WIDGET_BUTTON(controlbase, VALUE='Array', /MENU )
        id_2 = WIDGET_BUTTON(arraycont, VALUE='Time evolution', /MENU)
        IF STRMID(tmpdata.det,0,1) EQ 'P' THEN $
                        WIDGET_CONTROL, id_2, SENSITIVE=0
        id_3 = WIDGET_BUTTON(id_2, VALUE='Time slices ', UVALUE='SLICES')
        id_3 = WIDGET_BUTTON(id_2, VALUE='3-D view ', UVALUE='SLICES_3D')

        
;---------------- the Processing controls are defined -----------------

        proccont = WIDGET_BUTTON(controlbase, VALUE='Process', /MENU)
        id_2 = WIDGET_BUTTON(proccont, VALUE=' no drift handling   ', $
				UVALUE='PROC' )
        id_2 = WIDGET_BUTTON(proccont, VALUE=' with drift handling ', $
				UVALUE='PROC_DRFT' )
        id_2b = WIDGET_BUTTON(proccont, VALUE=' Dynamic Response ', $
                              UVALUE='PROC_DYNR')
        id_2 = WIDGET_BUTTON(proccont, VALUE=' Dynamic Calibration (direct mode)', $
				/MENU)
        id_3 = WIDGET_BUTTON(id_2, VALUE=' Perform  ', $
				UVALUE='PROC_DYNCAL' )
        id_3 = WIDGET_BUTTON(id_2, VALUE=' Customize & Perform ', $
				UVALUE='PROC_DYNCAL_CUSTO' )
	;check that dynamic calibration is only applied to PHT-S
	IF tmpdata.det NE 'SL' THEN WIDGET_CONTROL, id_2, SENSITIVE=0
	;check that dynamic calibration is only applied to staring 
	;observations
	atttyp = FXPAR(tmpdata.hdr,'ATTTYPE')
	IF STRPOS(atttyp,'R') NE -1 THEN BEGIN
	       WIDGET_CONTROL, id_2, SENSITIVE=0
               WIDGET_CONTROL, id_2b, SENSITIVE=0
	ENDIF       
	;check chopped observations
	IF MAX(tmpdata.step) GT 1 THEN WIDGET_CONTROL, id_2, SENSITIVE=0

        id_2 = WIDGET_BUTTON(proccont, VALUE='Ramps pattern ', /MENU)
        id_3 = WIDGET_BUTTON(id_2, VALUE='Proceed ', UVALUE='PATTERN')
;        id_3 = WIDGET_BUTTON(id_2, VALUE='Customize ', UVALUE='PATT_CUST')
	patt = FXPAR(newheader, 'PR_PATT', count=count)
	IF patt EQ 0 THEN WIDGET_CONTROL, id_2, sensitive=0



;---------------- the Pixel Choice controls are defined -----------------

        pixcont = WIDGET_BUTTON(controlbase, VALUE='Pixels', $
				/MENU)
        pixch = WIDGET_BUTTON(pixcont, VALUE=' Individual choice ', $
				UVALUE='PIXCH' )
        pixch = WIDGET_BUTTON(pixcont, VALUE=' Serial increment  ', $
				UVALUE='PIXCHSER' )
        pixch = WIDGET_BUTTON(pixcont, VALUE=' Serial decrement  ', $
				UVALUE='PIXCHSERD' )
        IF STRMID(tmpdata.det,0,1) EQ 'P' THEN $
        	WIDGET_CONTROL, pixcont, SENSITIVE=0

;---------------- the number of views controls is defined -----------------

        nvbut = cw_bselector(controlbase, $
                        /FRAME, SET_VALUE=NVIEWS-1, $
                        UVALUE = 'NVIEWS', $
                        ['1 Plot', $
                        '2 Plots', $
                        '3 Plots', $
                        '4 Plots'])

;---------------- the Serendipity Mode controls are defined ------------
                
       srmcont = WIDGET_BUTTON(controlbase, VALUE='Serendipity', $
                              /MENU)
       srmch = WIDGET_BUTTON(srmcont, VALUE='Default Responsivities', $
                              UVALUE='SRM0')
       srmch = WIDGET_BUTTON(srmcont, VALUE='Responsivities from FCS', $
                              UVALUE='SRM1')
       srmch2 = WIDGET_BUTTON(srmcont, VALUE='Responsivities from orbit', $
                              UVALUE='SRM2')

;----------------------------------------------------------------------


       hkbutton=widget_button(controlbase,value=' HK ', uvalue ='HK')

;----------------------------------------------------------------------

; Look into the selection criteria

        get_sigdisc, tmpdata, /ENCODE_FLAG
	get_validflag, tmpdata.flag, 'SRD', redflag, $
	  det=tmpdata.det, /allpix

	sig_disc = redflag
	disc_set = 1


; Realize widget

	WIDGET_CONTROL, srddi2_wid, /REALIZE, /HOURGLASS


	FOR i = 0, nviews - 1 DO BEGIN
		WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
		view(i).windownum = temp
		pia_reset2view2, i, view(i).controlid
           IF STRMID(tmpdata.det,0,1) EQ 'C' THEN BEGIN
;		txtval = STRTRIM(STRING(i+1),2); Replacing numbers by 
	  	txtval = cmap_wind_text(i)                ; letters
                WIDGET_CONTROL, pixbut(pixcho(i)), SET_VALUE = txtval
           ENDIF
	ENDFOR

; make the serendipity button appear when the detector is C200

	if STRMID(tmpdata.det,0,2) EQ 'C2' then $
	  widget_control, srmcont, sensitive = 1 $
	else widget_control, srmcont, sensitive = 0

; Serendipity: Responsivities from orbit not implemented so far
        widget_control, srmch2, sensitive = 0

	XManager, No_BLOCK=1, "pia_dis2srd", srddi2_wid, $
		EVENT_HANDLER = "pia_dsrd2_event", GROUP_LEADER=GROUP


	RETURN
END
