;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_disp_cs
;
; PURPOSE:
;       Displays the converted Compact Status contents
;       
; CALLING SEQUENCE:
;       PIA_disp_cs, measname
;
; INPUT PARAMETERS:
;       measname: e.g. 'C102003102'
;
; OUTPUT PARAMETERS:
;       widget
;
; COMMON BLOCKS:
;		phtcs
;		pia_disp_cs_cmn (internal)
;
; PROCEDURE:
;	reads CS buffer, converts data in readable
;	information and xdisplays detector data onto screen
;
; PROCEDURES USED:
;	PIA LIB:
;		conv_cs
;		decode_admn
;		read_cs
;		pia_disp_print_file
;
; MODIFICATION HISTORY:
;       Written by: Thorsten Reimann 		10/94
;	Modified by: (CG)			November 1996
;	V5.x
;	Simplified through use of PIA_DISP_PRINT_FILE (CG)	Feb.97
;	V6.1			
;-

;*****************************************************************************
;main program
;*****************************************************************************

pro pia_disp_cs, measname, GROUP=group

on_error, 2
@phtcs


lines=55
out=strarr(lines)

; - change -> shape4
psta_file='PSTA'+strmid(measname,4,8)+'.FITS'
read_cs,psta_file,header,csun

; return to caller if compact status not found

if csun EQ -1 then begin
	msg = 'Compact Status: ' + psta_file + ' not found!'
	message, /info, msg
        RETURN
endif

conv_cs,phtcs(csun),convcs
handle_value,convcs.handle,cst

;calculate index
detshort = STRMID(measname,0,2)
IF detshort EQ 'SS' THEN detshort = 'SL'

index_arr=where(strmid(cst.subs,0,2) eq detshort,count)

if count eq 0 then begin
  MESSAGE, /INFO,'CS Not available!'
  RETURN
endif else begin
  in=index_arr(fix(strmid(measname,2,2)))

  out( 0)=string('TIMES:')
  out( 1)=string('UTK Start time: ',cst.ukst(in))
  out( 2)=string('UTK End   time: ',cst.uken(in))
  out( 3)=string('ITK Start time: ',cst.ikst(in))
  out( 4)=string('ITK End   time: ',cst.iken(in))
  pia_conv_date, cst.utst(0,in), utst_dat
  out( 5)=string('Universal time for start of period: ',utst_dat)
  pia_conv_date, cst.uten(0,in), uten_dat
  out( 6)=string('Universal time for end   of period: ',uten_dat)
;  out( 5)=string('Universal time for start of period: ',cst.utst(0,in),$
;  	' ',cst.uten(1,in))
;  out( 6)=string('Universal time for end   of period: ',cst.uten(0,in),$
;  	' ',cst.uten(1,in))
  out( 7)=string('----------------------------------------------------------------')
  out( 8)=string('WHEEL CONFIGURATION:')
  out( 9)=string('CHW1 position (select):    ',cst.c1ps(in))
  out(10)=string('CHW2 position (select):    ',cst.c2ps(in))
  out(11)=string('CHW3 position (select):    ',cst.c3ps(in))
  out(12)=string('Measurement position CHW1: ',cst.mpc1(in))
  out(13)=string('Measurement position CHW2: ',cst.mpc2(in))
  out(14)=string('Measurement position CHW3: ',cst.mpc3(in))
  out(15)=string('----------------------------------------------------------------')
  out(16)=string('ROT PARAMETERS:')
  out(17)=string('Integration time:    ',cst.intt(in))
  out(18)=string('No. NDRs:            ',cst.nndr(in))
  out(19)=string('No. DRs:             ',cst.ndr (in))
  out(20)=string('Measurement time:    ',cst.meat(in))
  out(21)=string('Data reduction size: ',cst.drs (in))
  out(22)=string('Frequencies:         ',cst.freq(in))
  out(23)=string('----------------------------------------------------------------')
  out(24)=string('CHOPPER CONFIGURATION:')
  out(25)=string('Chopper mode:         ',cst.cmod(in))
  out(26)=string('Chopper amplitude:    ',cst.camp(in))
  out(27)=string('Chopper step:         ',cst.cste(in))
  out(28)=string('Chopper increment:    ',cst.cinc(in))
  out(29)=string('Chopper OPF Override: ',cst.opfo(in))
  out(30)=string('----------------------------------------------------------------')
  out(31)=string('FCS CONFIGURATION:')
  out(32)=string('Sel. TRS(FCS1):  ',cst.f1ts(in))
  out(33)=string('Sel. TRS(FCS2):  ',cst.f2ts(in))
  out(34)=string('FCS1 power sel.: ',cst.f1ps(in))
  out(35)=string('FCS2 power sel.: ',cst.f2ps(in))
  out(36)=string('----------------------------------------------------------------')
  out(37)=string('ELECTRONIC CONFIGURATION:')
  out(38)=string('CRE switched on: ',cst.cres(in))
  out(39)=string('Assembly on:     ',cst.deta(in))
  out(40)=string('MUX1 line:       ',cst.mux1(in))
  out(41)=string('MUX2 line:       ',cst.mux2(in))
  out(42)=string('Cross status:    ',cst.xsta(in))
  out(43)=string('----------------------------------------------------------------')
  OUT(44)=STRING('DETECTOR CONFIGURATION:')
  out(45)=string('DIE1 offset: ',cst.d1of(in))
  out(46)=string('DIE1 gain:   ',cst.d1ga(in))
  out(47)=string('DIE2 offset: ',cst.d2of(in))
  out(48)=string('DIE2 gain:   ',cst.d2ga(in))
  out(49)=string('Measured EEU temperature: ',cst.met (in))
endelse

decode_admn, measname, decname
title = 'Measurement Configuration for '+decname
junk = '----------------------------------------------------------------'
junk2 = '      '

junk3 = 'Detector used:  '+cst.subs(in)
out = [title, junk, junk2, junk3, junk2, out]

font = '-*-courier-bold-*-*-*-14-*'
PIA_DISP_PRINT_FILE, measname+'_CS', TITLE=title, $
	TEXT=out, HEIGHT=40, FONT=font 

RETURN
END

