;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_disp_hdr
;
; PURPOSE:
;       Displays header contents
;       
; CATEGORY:
;          PIA - graphics
;
; CALLING SEQUENCE:
;       PIA_disp_hdr, header, admn, level
;
; INPUT PARAMETERS:
;	header: The header to be displayed
;       admn:	A measurement name (PIA admn convention) 
;	level:	Level of processing, e.g. SRD
;
; KEYWORD PARAMETERS:
;	GROUP=group: Group leader
;
; COMMON BLOCKS:
;	pia_disp_hdr_cmn (internal)
;	
; PROCEDURES USED:
;       INTERNAL:
;		pia_disp_hdr_event
;
; MODIFICATION HISTORY:
;       Written by: Carlos GABRIEL (ESA/ESTEC)		Dec. 94
;	Oct 95 Version 3.5
;	Free_lun instead of close - get_lun used (CG)	May 1996
;	Print_dir bug fixed (CG)			July 1996
;	Simplified through use of PIA_DISP_PRINT_FILE (CG)	Feb.97
;	V6.1			
;			
;-

;*****************************************************************************
;main program
;*****************************************************************************

pro pia_disp_hdr, header, admn, level, GROUP=group

COMMON pia_disp_hdr_cmn, hdrtxt, lines, filnam

;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 3 THEN MESSAGE, $
          'Syntax:  PIA_disp_hdr, header, admn, level, [GROUP=group]'


	decode_admn, admn, decname

	title = 'Header of '+decname+'    Level: '+level
	junk = '----------------------------------------------------------------'
	junk2 = '      '

	hdrtxt = [title, junk, junk2, header]
	lines = N_ELEMENTS(hdrtxt)
        filnam = admn+'_'+level+'_hdr'
	font='-*-courier-bold-*-*-*-14-*'
	
	PIA_DISP_PRINT_FILE, filnam, TITLE=title, TEXT=hdrtxt, $
		HEIGHT=40, FONT=font

RETURN
END

