;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_DISP_ISR
;
; PURPOSE:
;	Read the Instrument station report from FITSDIR and 
;	display/print contents
;
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;	PIA_DISP_ISR, tdtnr
;
; INPUTS:
;	tdtnr:		TDT number for which IS report shall be displayed
;
; KEYWORD PARAMETERS:
;	ERROR : 	returns an error condition:
;			0 = no error
;			1 = could not successfully read the PISR file
;
; PROCEDURES USED:
;	PIA Procedure(s):
;		pia_disp_print_file
;
; MODIFICATION HISTORY:
;	Written by: 	I. Heinrichsen, MPIK/Heidelberg	December 1995
;                       I. H.: Header corrected          March   1997
;-

PRO PIA_DISP_ISR, tdtnr, ERROR=error

; initialize error condition

error = 1

; define the filename
filename = strcompress(!fitdir+'PISR'+tdtnr+'.FITS', /REMOVE_ALL)

; open the PISR file
OPENR, lun, /GET_LUN, filename, /BLOCK, ERROR=err
IF err NE 0 THEN goto, no_pisr

; read the FITS header and diplay file

READHDR, lun, header, ERROR=err
yname="Instrument Station Report    PISR"+tdtnr
pia_disp_print_file, 'PISR'+tdtnr, title=yname, text=header


; normal exit

error = 0
FREE_LUN, lun
RETURN

; error conditions:

no_pisr:
MESSAGE, /INFO, "PISR file not available: "+filename
RETURN

END


