;+
;  NAME:
;	PIA_Disp_Photom
;
;  PURPOSE:
;	Displays the photometric table
;
;  CATEGORY:
;	PIA - I/O
;
;  CALLING SEQUENCE:
;	PIA_Disp_AAP, Text, Observation
;
;  INPUTS:
;	Text: Array of text lines 
;	Observation: An observation string derived from the TDT and OBS
;
;  OUTPUTS:
;	None
;
;  RESTRICTIONS:
; 	None
;
;  PROCEDURES USED:
;	None
;
;  MODIFICATION HISTORY
;	Written by:	Huw Morris
;	Oct 95 Version ?.?
;	Modified by:	Huw Morris
;	Unit number 1 replaced by /get_lun  (CG)		Jan 96 
;	Free_lun instead of close (CG)				May 1996
;-
;--------------------------------------------------------------------------
;  Event handling routine
;--------------------------------------------------------------------------

PRO pia_disp_photom_event, event

	COMMON disp_photom_cmn, Txt, Obs

	WIDGET_CONTROL, event.id, GET_UVALUE = uvalue

; Exit if 'EXIT' button pressed
	IF (UValue eq 'QUIT') THEN BEGIN
	  WIDGET_CONTROL, event.top, /DESTROY
	ENDIF

; Check for 'PRINT' or 'FILE' buttons
	IF (UValue eq 'PRINT' or UValue eq 'FILE') THEN BEGIN
	  
          Filename = Obs + '_photom.txt'

	  IF (UValue eq 'PRINT') THEN Filename = '_'+Filename

	  OPENW, unit, !PIA_PRINTDIR+Filename, /get_lun
          PRINTF, unit

	  FOR i = 0, N_ELEMENTS(Txt)-1 DO BEGIN
	    PRINTF, unit, Txt(i)
	  ENDFOR

	  PRINTF, unit, STRING(12B)

	  FREE_LUN, unit
	
          IF (UValue eq 'PRINT') THEN BEGIN
	    IF !VERSION.OS ne 'vms' THEN BEGIN
	      SPAWN, 'lpr -P$pslaser '+!PIA_PRINTDIR+Filename
	      SPAWN, 'rm '+!PIA_PRINTDIR+Filename
	    ENDIF ELSE BEGIN
	      SPAWN, 'print/queue=pslaser/notify/delete '+!PIA_PRINTDIR+Filename
	    ENDELSE
	  ENDIF
	
	ENDIF	
END

;---------------------------------------------------------------------------
;  Main program
;---------------------------------------------------------------------------

PRO PIA_Disp_photom, Text, Observation

	COMMON disp_photom_cmn, Txt, Obs

	ON_ERROR, 2 	           ; Return to calling procedure

	Txt = Text
	Obs = Observation

; Widget definitions

; Base for whole widget
	photombase = WIDGET_BASE(TITLE='Photometry table', /COLUMN )

; Base for the menu line
	menbase = WIDGET_BASE(photombase, /ROW)

; Exit Button
	quit_id = WIDGET_BUTTON(menbase, VALUE=' QUIT ', /FRAME, $
	                     UVALUE='QUIT')
; Button to print contents
	print_id  = WIDGET_BUTTON(menbase, VALUE=' PRINT ', /FRAME, $
	                       UVALUE='PRINT')

; Button to save contents to a file
	file_id = WIDGET_BUTTON(menbase, VALUE=' FILE ', /FRAME, $
	                     UVALUE='FILE')

; Area to display the contents
	text_id = WIDGET_TEXT(photombase, /SCROLL, XSIZE=65, YSIZE=38, $
	                   VALUE=Txt, UVALUE='', $
	                   font='-*-courier-bold-*-*-*-14-*')

	WIDGET_CONTROL, photombase, /REALIZE

	xMANAGER,No_BLOCK=1, "PIA_Disp_photom", photombase, GROUP=group

	RETURN
	END
