;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_DISP_STAT
; PURPOSE:
;	Display information comprised in the phtdrift structure
; 
; CATEGORY:
;	PIA - graphics
;                
; CALLING SEQUENCE:
;	PIA_DISP_STAT, admname
;
; INPUT PARAMETERS:
;	admname: 	the internal measurement name
;	
; KEYWORDS:
;	DRIFT: 		If set, drift analysis statistics showed
;	STAB:  		If set, stability analysis ("mann") statistics showed
;	SLOPV:  	If set, slope variation analysis statistics showed
;	NO_SHOWSTR:	If set, NO simultaneous structure display activated
;
;
; RESTRICTIONS:
;
; METHOD:
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phtdrift
;       PIA Procedure(s):
;               pia_disp_print_file
;		pia_showstr
;
; MODIFICATION HISTORY:
;	Written by: C. Gabriel - ESA/SAI		December 1996
;	V5.5
;	Parameter bug fixed (CG)			January 1997
;	Widget access to structure added (CG)		February 1997
;	V6.1 
;-
PRO pia_disp_stat, admname, DRIFT=drift, STAB=stab, SLOPV=slopv, $
	NO_SHOWSTR=NO_SHOWSTR

COMMON DFFUNCT_INFO, funct_info
@phtdrift

	ind = WHERE(phtdrift.admn EQ admname, nind)
	
	IF nind EQ 0 THEN BEGIN
RETURNING:
               XDISPLAYFILE, "", $
                    TITLE = "Not Allowed ", $
                    WIDTH = 50, $
                    HEIGHT = 12, $
                          TEXT = [" No required statistics present ", $
                                  " for this measurement - returning"]                  
                          RETURN
        ENDIF
                                 	   
 
 	decode_admn, phtdrift(ind).admn, admis
	IF nind GT 1 THEN BEGIN		  
		pia_multchoice, index, $
			elemnames = 'Processed: '+phtdrift(ind).proct
	ENDIF ELSE index = 0
	
	IF KEYWORD_SET(stab) THEN BEGIN
 	  handle_value, phtdrift(ind(index)).stab, stab
	  type = size(stab)
	  IF type(2) NE 8 THEN GOTO, RETURNING
	
		stability = ['Completely stable ', $
			     'Partially stable  ', $
			     'Not stable  ', $
			     'No valid points  ',$
			     'Valid points < required']

	  TEXT = ['Stability analysis for measurement ' +  admis(0), $
		'~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~' ,$
		' ', '    Parameters used: ', '   ~~~~~~~~~~~~', $
		'Confidence level for trend:  '+STRTRIM(1-stab.mann_par(0),2), $
		'Interval division chosen:    '+STRTRIM(stab.mann_par(1),2), $
		'Minimum number of points:    '+STRTRIM(stab.mann_par(2),2), $  
		'Minimum time in seconds:     '+STRTRIM(stab.mann_par(3),2), $
		' ', $
		'Number of chopper plateaux/ raster combinations found = ' + $
		 STRTRIM(N_ELEMENTS(stab.aver(0,*)),2), $
		 ' ']

	  FOR IPIX = 0, N_ELEMENTS(stab.aver(*,0))-1 DO BEGIN

	   TEXT = [TEXT, '        Pixel  ' + $
	   		STRTRIM(Ipix+1,2), $
	   		 '        ~~~~~~~~~~']
	  
	   FOR I=1,N_ELEMENTS(stab.aver(0,*)) DO BEGIN
	     TEXT = [TEXT, 'Chopper plateaux/ raster combination nr. ' + $
	   		STRTRIM(I,2), ' ', $
		     'Characterisation: ' + $
			 stability(stab.stabflag(ipix,i-1)), '', $
			'Number of points taken: ' +  $
			 STRTRIM(stab.tpoints(ipix,i-1),2), $
			'Average result: '+$
			 STRTRIM(stab.aver(ipix,i-1),2) + ' +/- ' + $
			 STRTRIM(stab.avun(ipix,i-1),2) + $
			 	' [V/s]', $
			'Slopes variation/minute:  ' + $
			 STRTRIM(stab.slopvar(ipix,i-1),2)+ $
			  	' [V/s/min]', ' ', $
			'Total result: '+$
			 STRTRIM(stab.aver_all(ipix,i-1),2) + ' +/- ' + $
			 STRTRIM(stab.avun_all(ipix,i-1),2)+ $
			 	' [V/s]', ' ', ' ']
	     	   
            ENDFOR
           ENDFOR
	  	
	  PIA_disp_print_file, 'Stability_Stats_'+admname, $
	  		Title='Stability Analysis (Mann)', $
	  		TEXT=text

	  IF not KEYWORD_SET(no_showstr) THEN PIA_SHOWSTR, stab
	
	ENDIF ELSE IF KEYWORD_SET(drift) THEN BEGIN

 	  handle_value, phtdrift(ind(index)).drift, drift
	  ind_funct = WHERE(STRTRIM(funct_info.lst(1,*),2) EQ  $
	  			STRTRIM(drift.mod_func,2), nindf)
	  IF nindf EQ 1 THEN ind_funct = ind_funct(0) ELSE ind_funct = 0
	  flabel = funct_info.parlabel.(ind_funct)
	  
	  type = size(drift)
	  IF type(2) NE 8 THEN GOTO, RETURNING

	

	  TEXT = ['Drift modelling results for measurement ' +  admis(0), $
		'~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~' ,$
		' ', 'Function used: ' + funct_info.lst(0,ind_funct) +  $
		'  with ' + sTRTRIM(drift.nparams,2) + ' parameters']
		
	  TEXT = [TEXT, ' ', 'General parameters: ', $
		'Chi-square tolerance:        '+STRTRIM(drift.chisqtol,2), $
		'Minimum number of points:    '+STRTRIM(drift.minp_ext,2), ' ',$  
		'Number of chopper plateaux/ raster combinations found = ' + $
		 STRTRIM(N_ELEMENTS(drift.neff_steps),2), $
		 ' ']

	  TXTALT = ['  No convergence',$
		       		  '  Parameter(s) out of limits', $
		       		  '  Chi-square too high   ', $
		       		  '  Function specific constraint violated', $
		       		  '  Function specific constraint violated']
	  IF STRPOS('Fouks',funct_info.lst(0,ind_funct)) NE -1 THEN $
		TXTALT(3:4) = ['  Violation of cond.: S_ini - Beta*S(t) > 0 ',$
		       	      '  Temperature condition violated '] 

	  FOR IPIX = 0, N_ELEMENTS(drift.chisq(*,0)) - 1 DO BEGIN

	   TEXT = [TEXT, '  ', '        Pixel  ' + $
	   		STRTRIM(Ipix+1,2), $
	   		 '        ~~~~~~~~~~', '  ', 'Parameters:']
	  

	   FOR ipar=0,drift.nparams-1 DO BEGIN
		IF (drift.a_var(ipix,0,ipar)) THEN $
	  	 TEXT = [TEXT, flabel(ipar) + ':   free'] ELSE $
	  	 TEXT = [TEXT, flabel(ipar) + ':  fixed'] 
	   ENDFOR
	   
	   TEXT = [TEXT, 'Signal weighting method:     '+ drift.weightm(ipix)]
	   TEXT = [TEXT, 'Fraction left out at begin:  '+ $
	       STRTRIM(drift.fract_left(ipix),2)]
	   

	   FOR I=1, drift.neff_steps DO BEGIN
	     TEXT = [TEXT, ' ', 'Chopper plateaux / raster combination nr. ' + $
	   		STRTRIM(I,2), ' ', $
		     'Modelling flag: ' + $
			 STRTRIM(drift.flag(ipix,i-1),2),$
		     'Chi-square:     ' + STRTRIM(drift.chisq(ipix,i-1),2)]
	     CASE drift.flag(ipix,i-1) OF
	       	0: text = [text,'','Modelling done succesfully ' ]
		ELSE :  BEGIN
		       	text = [text,'Problem(s) with modelling:']
		       	decode_flag, drift.flag(ipix,i-1), 5, flarr
			indfl = WHERE(flarr NE 0,nfl)
		       	IF nfl EQ 0 THEN BEGIN
		       	  PRINT,'ERROR in Flag system' 
		       	  RETURN
		       	ENDIF
		       	text = [text, txtalt(indfl)] 
		       END
		ENDCASE 
	     
	     FOR ipar=0,drift.nparams-1 DO BEGIN
		TEXT=[TEXT, 'Param. '+STRTRIM(ipar+1,2)+': '+ $
			STRTRIM(drift.param(ipix,i-1,ipar),2) + ' +/- ' + $
			STRTRIM(drift.sg_param(ipix,i-1,ipar),2)]
	     ENDFOR

	     	   
            ENDFOR
           ENDFOR
	  	
	  PIA_disp_print_file, 'Drift_Stats_'+admname, $
	  		Title='Drift Modelling', $
	  		TEXT=text

	  IF not KEYWORD_SET(no_showstr) THEN PIA_SHOWSTR, drift
	
	 ENDIF ELSE IF KEYWORD_SET(slopv) THEN BEGIN
	  
 	  handle_value, phtdrift(ind(index)).slopv, slopv
	  type = size(slopv)
	  IF type(2) NE 8 THEN GOTO, RETURNING

	

	  TEXT = ["Slopes' variation results for measurement " +  admis(0), $
		'~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~' ,$
		' ']
	  
		
	  FOR IPIX = 0, N_ELEMENTS(slopv.avrg(*,0)) - 1 DO BEGIN

	   TEXT = [TEXT, '        Pixel  ' + $
	   		STRTRIM(Ipix+1,2), $
	   		 '        ~~~~~~~~~~']
	   rpch = N_ELEMENTS(slopv.sini(0,*)) 

	   FOR irpch = 0, rpch-1 DO BEGIN
	      TEXT = [TEXT, ' ','Step '+STRTRIM(irpch+1,2)+ ':', $
	      			'Initial signal:   ' + $
		  		STRTRIM(slopv.sini(ipix,irpch),2) + '[V/s]', $ 
				'Final signal:     ' + $
		  		STRTRIM(slopv.sfin(ipix,irpch),2) + '[V/s]', $
		  		' ']
	   ENDFOR
	  
	   FOR I=0, N_ELEMENTS(slopv.timeslots)-1 DO BEGIN

		TEXT = [TEXT, ' Timeslot to ' + STRTRIM(slopv.timeslots(i),2)+$
			' sec ', ' ~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ' ]
		TEXT = [TEXT, 	'Average signal:   ' + $
		  		STRTRIM(slopv.avrg(ipix,i),2) + '[V/s]', $ 
				'Analyisis Flag:   ' + $
		  		STRTRIM(slopv.flag(ipix,i),2), $ 
				'Signal slope:   ' + $
		  		STRTRIM(slopv.slop(ipix,i),2) + ' +/-' + $
		  		STRTRIM(slopv.slun(ipix,i),2) + ' [V/s / min]'] 
	   ENDFOR
	  ENDFOR
	  PIA_disp_print_file, 'Slopes_var_Stats_'+admname, $
	  		Title='Slopes variation', $
	  		TEXT=text

	  IF not KEYWORD_SET(no_showstr) THEN PIA_SHOWSTR, slopv
	
	 ENDIF 

	 RETURN
	 END
