;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_DISPAAP
;
; PURPOSE:
;	Menu for PIA AAP Data display.
;	This is a fourth level menu in the PIA hierarchy.
;
;	This routine should only be called by the PIA Display Data routine
;	and should not be called directly from the command line.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_DISPAAP
;
; KEYWORD PARAMETERS:
;	GROUP:	The group leader of the widget hirarchy
;       DATA:   An element of the PHTAAP dynamical structure
;       NV:     Number of Views (1 <= NV <= 4)
;       REDRAW:	To redraw same data
;
; COMMON BLOCKS:
;	adm
;	colour_indices
;	phtacc
;	phtcs
;	phtaap
;	pia_dispaap_cmn (internal)
;	pia_dspch6_cmn (internal)
;	dspaap_widg (internal)
;	pia_dspchz_cmn (internal)
;	aap_nacc (internal)
;	tmpvalues6 (internal)
;	aapatt (internal)
;	dispcust_cmn (internal)
;	pia_widget_info (internal)
;
; PROCEDURES USED:
;	PIA LIB:
;		decode_admn
;		get_convwh
;		get_pht_hk
;		get_spddisc
;		pia_bcksubt
;		pia_cimage_spd
;		pia_dis2aap
;		pia_disp_cs
;		pia_disp_hdr
;		pia_dispcust
;		pia_get_step
;		pia_load_iaap
;		pia_multchoice
;		pia_multmeas
;		pia_oplot
;		pia_pixchoice
;		pia_plot
;		pia_print_spdval
;		pia_showstr
;		pia_spddisc
;		pia_spect
;		pia_spect_aar
;		pia_write_ispd
;		pia_xplot
;		pickmeas
;		read_irph
;		weight_mean
;		write_spd
;		xdisp_hk
;       ASTRO LIB:
;		getfiles
;       INTERNAL:	
;		pixbutevent6
;		viewevent6
;		averagechop6
;		averagenonch6
;		averageevent6
;		medianchop6
;		mediannonch6
;		medianevent6
;		zoomevent6
;		zoomfourier6
;		zoomsync6
;		zoomnsync6
;		zoomit6
;		pia_resetview6
;		pia_daap_event
;
; MODIFICATION HISTORY:
;       Written by: C.Gabriel (ESA/ESTEC)               September 1994
;	Modified (last) by: cg				November 1996
;	Version 5.x
;	Saving internal file upgraded  +
;	 direct discrimination for measurement selection +
;	 auxiliary files display added (EOH*, OLR) (CG) May 1997
;	V6.3
;	Added possibility to save corrections in phtaap 
;	 buffer  (JAc)   				October 1997
;	Measurements concatenation implemented (CG)	December 1997
;	V6.6
;	Chopper frequency correction (OK) added (CG)	March 1998
;	V7.1 
;	Discarded points taken from tmp.flag (CG)	August 1998
;	V7.3
;	Widget problem (INT instead of LON) fixed (CG)	February 1999
;	Concatenated measurements displayed OK (CG)	February 1999
;	Saving AAP FITS files for PHT-S added (CG)	February 1999
;	PIA_ff_med_smooth call w. /modal (CG)		March 1999
;	Update according to bitflag system (CG)		May 1999
;	Display of decoded flags included (JAC)         June 1999
;	V7.4
;	First quartile FF included (CG)			July 1999
;	V7.9
;	Avoiding crash by cancel of meas.subtr.(CG)	October 1999
;	Including PHT-S off-centre correction (CG)	October 1999
;	V8.1
;	Exit including possibility of saving meas. +
;	replacing numbers by letters in pixel ind. (CG)	January 2000
;	V8.2
;			
;-

; *********************************************************************
; *
; *********************************************************************
pro pixbutevent6, event

COMMON pia_dispaap_cmn, tmpdata, aapps, view, viewsize, nviews, viewoptions, $
   overid, redflag
COMMON pia_dspch6_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON dspaap_widg, pixbut

        WIDGET_CONTROL, event.id, GET_UVALUE = new_pixbut

        ind = WHERE(pixcho eq new_pixbut(0))
        ind = ind(0)

	text = ["A", "B", "C", "D"]
        IF ind LT 0 or ind GE nviews THEN BEGIN

          pixcount = pixcount+1
          IF pixcount GE nviews THEN pixcount = 0

          old_pixcho = pixcho(pixcount)
          pixcho(pixcount) = new_pixbut(0)

          view(pixcount).viewtype = 0
          pia_resetview6, pixcount, view(pixcount).controlid

;	  txtval = STRTRIM(STRING(pixcount+1),2) ; Replacing numbers by 
	  txtval = text(pixcount)                ; letters
          WIDGET_CONTROL, pixbut(old_pixcho), $
                                SET_VALUE = ' '
          WIDGET_CONTROL, pixbut(pixcho(pixcount)), $
                        SET_VALUE = txtval
        ENDIF
END

; *********************************************************************
; *
; *********************************************************************
pro viewevent6, event

COMMON pia_dispaap_cmn, tmpdata, aapps, view, viewsize, nviews, viewoptions, $
   overid, redflag 
COMMON pia_dspch6_cmn, pixcho, pixop, pixres, psymch, pixcount

	; get index of individual window choice
	viewchoindexid = WIDGET_INFO(event.id, /PARENT)
	WIDGET_CONTROL, viewchoindexid, GET_UVALUE = setting_choi
	setting_choi = setting_choi(0)
	; get index of window
        viewindexid = WIDGET_INFO(viewchoindexid,/PARENT)
	WIDGET_CONTROL, viewindexid, GET_UVALUE = viewindex

	IF N_ELEMENTS(viewindex) EQ 0 THEN BEGIN
	  viewindex = setting_choi
	  viewindexid = viewchoindexid
 	  WIDGET_CONTROL, event.id, GET_UVALUE = setting
	  setting = setting(0)

          IF (view(viewindex(0)).viewtype NE setting) THEN BEGIN
                view(viewindex(0)).viewtype = setting
                pia_resetview6, viewindex, viewindexid
          ENDIF
	ENDIF ELSE BEGIN
	; get value of setting 
 	  WIDGET_CONTROL, event.id, GET_UVALUE = setting
	  setting = setting(0)

	  IF (view(viewindex(0)).viewtype NE setting_choi OR $
	    view(viewindex(0)).viewtype_sub NE setting) THEN BEGIN
		view(viewindex(0)).viewtype_sub = setting
		view(viewindex(0)).viewtype = setting_choi
		pia_resetview6, viewindex, viewindexid
	  ENDIF
	ENDELSE

END

; *********************************************************************
; *
; *********************************************************************
pro averagechop6, event

COMMON pia_dispaap_cmn, tmpdata, aapps, view, viewsize, nviews, viewoptions, $
   overid, redflag
COMMON pia_dspch6_cmn, pixcho, pixop, pixres, psymch, pixcount

        WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        WIDGET_CONTROL, event.top, /HOURGLASS

	averageevent6, windowindex, chopped=1

	END

; *********************************************************************
; *
; *********************************************************************
pro averagenonch6, event

COMMON pia_dispaap_cmn, tmpdata, aapps, view, viewsize, nviews, viewoptions, $
   overid, redflag
COMMON pia_dspch6_cmn, pixcho, pixop, pixres, psymch, pixcount

        WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        WIDGET_CONTROL, event.top, /HOURGLASS

	averageevent6, windowindex

	END

; *********************************************************************
; *
; *********************************************************************
pro averageevent6, windowindex, chopped=chopped

COMMON pia_dispaap_cmn, tmpdata, aapps, view, viewsize, nviews, viewoptions, $
   overid, redflag
COMMON pia_dspch6_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON aap_nacc, aap_disc, disc_set, astrflag, bck_sel
COMMON tmpvalues6, tmprpid, tmprpid_name

	wtype = view(windowindex).viewtype 

        ytitle = viewoptions(wtype).viewylab

	notacc = 0
	
        CASE wtype OF

          0: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.mnfl(pixch,*)
                unc = tmpdata.mnfu(pixch,*)
		str = 'Average of Averages Pixel '+STRTRIM(STRING(pixch+1),2)

		IF disc_set THEN $ 
			indnacc = WHERE(aap_disc(pixch,*) ne 0, notacc)

           END
          1: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.mdfl(pixch,*)
                unc = data * 0 + 0.01
		str = 'Average of Medians Pixel '+STRTRIM(STRING(pixch+1),2)
		IF disc_set THEN $ 
			indnacc = WHERE(aap_disc(pixch,*) ne 0, notacc)

	  END 
          2: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.q1fl(pixch,*)
                unc = data * 0 + 0.01
		str = 'Average of 1st Quartile Pixel '+STRTRIM(STRING(pixch+1),2)
		IF disc_set THEN $ 
			indnacc = WHERE(aap_disc(pixch,*) ne 0, notacc)

	  END 
          3: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.q3fl(pixch,*)
                unc = data * 0 + 0.01
		str = 'Average of 3rd Quartile Pixel '+STRTRIM(STRING(pixch+1),2)
		IF disc_set THEN $ 
			indnacc = WHERE(aap_disc(pixch,*) ne 0, notacc)

	  END 
          4: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.mnbr(pixch,*)
                unc = tmpdata.mnbu(pixch,*)
		str = 'Average of Averages Pixel '+STRTRIM(STRING(pixch+1),2)
		IF disc_set THEN $ 
			indnacc = WHERE(aap_disc(pixch,*) ne 0, notacc)

           END
          5: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.mdbr(pixch,*)
                unc = data * 0 + 0.01
		str = 'Average of Medians Pixel '+STRTRIM(STRING(pixch+1),2)
		IF disc_set THEN $ 
			indnacc = WHERE(aap_disc(pixch,*) ne 0, notacc)

	  END 
          6: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.q1br(pixch,*)
                unc = data * 0 + 0.01
		str = 'Average of 1st Quartile Pixel '+STRTRIM(STRING(pixch+1),2)
		IF disc_set THEN $ 
			indnacc = WHERE(aap_disc(pixch,*) ne 0, notacc)

	  END 
          7: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.q3br(pixch,*)
                unc = data * 0 + 0.01
		str = 'Average of 3rd Quartile Pixel '+STRTRIM(STRING(pixch+1),2)
		IF disc_set THEN $ 
			indnacc = WHERE(aap_disc(pixch,*) ne 0, notacc)
	  END 

          8: BEGIN
                data = tmpdata.flag
                unc = data * 0 + 0.01
		str = 'Flag Averages'
		notacc = 0
          END
          9: BEGIN
                data = tmpdata.cpos
                unc = data * 0 + 0.01
		str = 'Chopper Position Averages'
		notacc = 0
          END
          10: BEGIN
                data = tmpdata.rpid
                unc = data * 0 + 0.01
		str = tmprpid_name + ' Averages'
		notacc = 0
          END
          11: BEGIN
                data = tmpdata.dec
                unc = data * 0 + 0.01
		str = 'Declination Averages'
		notacc = 0
          END
          12: BEGIN
                data = tmpdata.ra
                unc = data * 0 + 0.01
		str = 'Right Ascension Averages'
		notacc = 0
          END
          13: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.decp(pixch,*)
                unc = data * 0 + 0.01
		str = 'Declination Median: '+STRTRIM(STRING(pixch+1),2)
		IF disc_set THEN $ 
			indnacc = WHERE(aap_disc(pixch,*) ne 0, notacc)
          END
          14: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.rap(pixch,*)
                unc = data * 0 + 0.01
		str = 'Right Ascension Median ' +STRTRIM(STRING(pixch+1),2)
		IF disc_set THEN $ 
			indnacc = WHERE(aap_disc(pixch,*) ne 0, notacc)
          END
          ELSE: MESSAGE, /INFO, 'Not allowed CASE'

        ENDCASE

; Prepare a Byte array to accomodate all strings including carriage returns
	bytstr = [BYTE(str),10b,13b,10b,13b]

	
	accarr = INTARR(N_ELEMENTS(data))

	IF((wtype LE 3 OR wtype GE 9) AND notacc GT 0) $
		  THEN  accarr(indnacc) = 1

	IF KEYWORD_SET(chopped) THEN BEGIN 

; Chopped Case 
	  step = tmpdata.cstp
	  nrst = 1
	  i = 0
	  WHILE nrst NE 0 DO BEGIN
	   i = i + 1
	   indstp = WHERE(step eq i AND accarr EQ 0, nrst)
	   IF nrst ne 0 THEN BEGIN
	        weight_mean, data(indstp), unc(indstp), avr, sig
	        str = 'Step '+STRTRIM(STRING(I),2)+' position: '+$
		STRING(avr)+'    +/-'+STRING(sig)              
	        bytstr = [bytstr,BYTE(str),10b,13b]
	   ENDIF
	  ENDWHILE
	ENDIF ELSE BEGIN			

; Not chopped Case
           indacc = WHERE(accarr EQ 0, nrst)
	   IF nrst NE 0 THEN BEGIN
	     weight_mean, data(indacc), unc(indacc), avr, sig
	     str = 'Full measurement average: '+$
		STRING(avr)+'    +/-'+STRING(sig)								
	     bytstr = [bytstr,BYTE(str),10b,13b]
	   ENDIF
        ENDELSE

; Now get the text and display it

        text = STRING(bytstr)

        XDISPLAYFILE, "", $
            TITLE = "Average", $
                  WIDTH = 100, $
                  HEIGHT = 10, $
                  TEXT = [text]

END

; *********************************************************************
; *
; *********************************************************************
pro medianchop6, event

COMMON pia_dispaap_cmn, tmpdata, aapps, view, viewsize, nviews, viewoptions, $
   overid, redflag
COMMON pia_dspch6_cmn, pixcho, pixop, pixres, psymch, pixcount

        WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        WIDGET_CONTROL, event.top, /HOURGLASS

	medianevent6, windowindex, chopped=1

	END

; *********************************************************************
; *
; *********************************************************************
pro mediannonch6, event

COMMON pia_dispaap_cmn, tmpdata, aapps, view, viewsize, nviews, viewoptions, $
   overid, redflag
COMMON pia_dspch6_cmn, pixcho, pixop, pixres, psymch, pixcount

        WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        WIDGET_CONTROL, event.top, /HOURGLASS

	medianevent6, windowindex

	END

; *********************************************************************
; *
; *********************************************************************
pro medianevent6, windowindex, chopped=chopped

COMMON pia_dispaap_cmn, tmpdata, aapps, view, viewsize, nviews, viewoptions, $
   overid, redflag
COMMON pia_dspch6_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON aap_nacc, aap_disc, disc_set, astrflag, bck_sel
COMMON tmpvalues6, tmprpid, tmprpid_name

        ytitle = viewoptions(view(windowindex).viewtype).viewylab

	wtype = view(windowindex).viewtype
	notacc = 0
	
        CASE wtype OF
          0: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.mnfl(pixch,*)
                unc = tmpdata.mnfu(pixch,*)
		str = 'Median of Averages Pixel '+STRTRIM(STRING(pixch+1),2)
		IF disc_set THEN $ 
			indnacc = WHERE(aap_disc(pixch,*) ne 0, notacc)

           END
          1: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.mdfl(pixch,*)
                unc = 0
		str = 'Median of Medians Pixel '+STRTRIM(STRING(pixch+1),2)
		IF disc_set THEN $ 
			indnacc = WHERE(aap_disc(pixch,*) ne 0, notacc)

	  END 
          2: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.q1fl(pixch,*)
                unc = 0
		str = 'Median of 1st Quartile Pixel '+STRTRIM(STRING(pixch+1),2)
		IF disc_set THEN $ 
			indnacc = WHERE(aap_disc(pixch,*) ne 0, notacc)

	  END 
          3: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.q3fl(pixch,*)
                unc = 0
		str = 'Median of 3rd Quartile Pixel '+STRTRIM(STRING(pixch+1),2)
		IF disc_set THEN $ 
			indnacc = WHERE(aap_disc(pixch,*) ne 0, notacc)

	  END 
          4: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.mnbr(pixch,*)
                unc = 0
		str = 'Median of mean surface Brightness '+STRTRIM(STRING(pixch+1),2)
		IF disc_set THEN $ 
			indnacc = WHERE(aap_disc(pixch,*) ne 0, notacc)

	  END 
          5: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.mdbr(pixch,*)
                unc = 0
		str = 'Median of median surface Brightness '+STRTRIM(STRING(pixch+1),2)
		IF disc_set THEN $ 
			indnacc = WHERE(aap_disc(pixch,*) ne 0, notacc)

	  END 
          6: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.q1br(pixch,*)
                unc = 0
		str = 'Median of 1st Quartile Pixel Br '+STRTRIM(STRING(pixch+1),2)
		IF disc_set THEN $ 
			indnacc = WHERE(aap_disc(pixch,*) ne 0, notacc)

	  END 
          7: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.q3br(pixch,*)
                unc = 0
		str = 'Median of 3rd Quartile Pixel Br '+STRTRIM(STRING(pixch+1),2)
		IF disc_set THEN $ 
			indnacc = WHERE(aap_disc(pixch,*) ne 0, notacc)
	  END 
          9: BEGIN
                data = tmpdata.cpos
                unc = 0
		str = 'Chopper Position Median'
          END
          8: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.flag(pixch,*)
                unc = 0
		str = 'Flag Median: Pixel ' +STRTRIM(STRING(pixch+1),2)
          END
          11: BEGIN
                data = tmpdata.dec
                unc = 0
		str = 'Declination Median'
          END
          12: BEGIN
                data = tmpdata.ra
                unc = 0
		str = 'Right Ascension Median'
          END
          13: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.decp(pixch,*)
                unc = 0
		str = 'Declination Median: '+STRTRIM(STRING(pixch+1),2)
		IF disc_set THEN $ 
			indnacc = WHERE(aap_disc(pixch,*) ne 0, notacc)
          END
          14: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.rap(pixch,*)
                unc = 0
		str = 'Right Ascension Median ' +STRTRIM(STRING(pixch+1),2)
		IF disc_set THEN $ 
			indnacc = WHERE(aap_disc(pixch,*) ne 0, notacc)
          END
         ELSE: MESSAGE, /INFO, 'Not allowed CASE'

        ENDCASE

; Prepare a Byte array to accomodate all strings including carriage returns
	bytstr = [BYTE(str),10b,13b,10b,13b]

	accarr = INTARR(N_ELEMENTS(data))

	IF(wtype EQ 0 or wtype EQ 1 OR wtype EQ 8 OR wtype EQ 9 OR $
	   wtype EQ 10 or wtype EQ 11) AND $ 
		(notacc GT 0)   THEN  accarr(indnacc) = 1

	IF KEYWORD_SET(chopped) THEN BEGIN 

; Chopped Case (not calibration involved)
	   step = tmpdata.cstp
	   nrst = 1
	   i = 0
	   WHILE nrst NE 0 DO BEGIN 
                   i = i + 1
	      indstp = WHERE(step eq i AND accarr EQ 0, nrst)     
	      IF nrst ne 0 THEN BEGIN
	   	avr = median(data(indstp))
	   	ind = where(data(indstp) LT avr, nbelo)
	   	IF nbelo GT 0 THEN $
	   	 q1 = median(data(indstp(ind))) ELSE q1 = 0.
	   	ind = where(data(indstp) GE avr, nabo)
	   	IF nabo GT 0 THEN $
	   	 q3 = median(data(indstp(ind))) ELSE q3 = 0
	   	str = 'Step '+STRTRIM(STRING(I),2)+' position: '+$
	   	   STRING(avr)+'  1st Quart'+STRING(q1) +$
	   	   	'  3rd Quart'+STRING(q3)	   	   	   	   
	   	bytstr = [bytstr,BYTE(str),10b,13b]
	      ENDIF	   
	   ENDWHILE
	ENDIF ELSE BEGIN	   	

; Not chopped Case

          indacc = WHERE(accarr EQ 0, nrst)
	  IF nrst NE 0 THEN BEGIN
	     avr = median(data(indacc))
	     ind = where(data(indacc) LT avr, nbelo)
	     IF nbelo GT 0 THEN $
	      q1 = median(data(indacc(ind))) ELSE q1 = 0.
	     ind = where(data(indacc) GE avr, nabo)
	     IF nabo GT 0 THEN $
	      q3 = median(data(indacc(ind))) ELSE q3 = 0.
	     str = 'Full measurement median: '+$
		STRING(avr)+'  1st Quart'+STRING(q1) +$
					'  3rd Quart'+STRING(q3)								
	     bytstr = [bytstr,BYTE(str),10b,13b]
	  ENDIF
        ENDELSE

; Now get the text and display it

        text = STRING(bytstr)

        XDISPLAYFILE, "", $
           TITLE = "Median Calculation", $
                  WIDTH = 100, $
                  HEIGHT = 10, $
                  TEXT = [text]
END

; *********************************************************************
; *
; *********************************************************************
pro zoomevent6, event

COMMON pia_dispaap_cmn, tmpdata, aapps, view, viewsize, nviews, viewoptions, $
   overid, redflag 
COMMON pia_dspch6_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices

	WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
	zoomit6, windowindex        
END

; *********************************************************************
; *
; *********************************************************************
pro zoomfourier6, event

COMMON pia_dispaap_cmn, tmpdata, aapps, view, viewsize, nviews, viewoptions, $
   overid, redflag
COMMON pia_dspch6_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices

        WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        zoomit6, windowindex, fourier = 1
END

; *********************************************************************
; *
; *********************************************************************
pro zoomsync6, event

COMMON pia_dispaap_cmn, tmpdata, aapps, view, viewsize, nviews, viewoptions, $
   overid, redflag 
COMMON pia_dspch6_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices

	WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
	zoomit6, windowindex, overplot = 1        

END

; *********************************************************************
; *
; *********************************************************************
pro zoomnsync6, event

COMMON pia_dispaap_cmn, tmpdata, aapps, view, viewsize, nviews, viewoptions, $
   overid, redflag 
COMMON pia_dspch6_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices

	WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
	zoomit6, windowindex, overplot = -1        

END

; *********************************************************************
; *
; *********************************************************************
pro zoomit6, windowindex, overplot=overplot, fourier=fourier

COMMON pia_dispaap_cmn, tmpdata, aapps, view, viewsize, nviews, viewoptions, $
   overid, redflag 
COMMON pia_dspaap_flg_cmn, nflag_active, flag_active_lex, flag_active_label  
COMMON pia_dspch6_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
COMMON aap_nacc, aap_disc, disc_set, astrflag, bck_sel
COMMON tmpvalues6, tmprpid, tmprpid_name
@colour_indices

	IF (KEYWORD_SET(overplot)) THEN overplot = overplot ELSE overplot = 0
        IF (KEYWORD_SET(fourier)) THEN fourier = 1 ELSE fourier = 0

	xtitle = viewoptions(view(windowindex).viewtype).viewxlab
	ytitle = viewoptions(view(windowindex).viewtype).viewylab
	menuchoi = view(windowindex).viewtype_sub

	decode_admn, tmpdata.admn, title
	title = title + '  ' + tmpdata.admn

        get_convwh, tmpdata.admn, wheels, chmod, champ
        anntmp = title + $
		'  [' + wheels(0) + '  ' + wheels(1) + '  ' + $
		wheels(2) + ']  [' + chmod + '  ' + champ + ']'

        anntmp = anntmp+' (AAP level)'

        ytype = 0

	charsize = 1.10

	IF overplot NE 0 THEN BEGIN
		IF zoom_color EQ -1 THEN zoom_color = green ELSE $
			zoom_color = zoom_color + 1
		IF zoom_color EQ 9 then zoom_color = 4
		zoom_psymch = zoom_psymch + 1
		IF zoom_psymch GT 8 then zoom_psymch = 1
	ENDIF ELSE BEGIN
		zoom_color = -1
		zoom_psymch = psymch 
        ENDELSE

	concat = fxpar(tmpdata.hdr, 'PRA_CN1', count=count)
	IF count GT 0 THEN BEGIN
		  xind = indgen(N_ELEMENTS(tmpdata.time)) 
		  xtitle = 'Concatenation index' 
	ENDIF ELSE BEGIN
		  xind = tmpdata.time
;		  xtitle = xtitle
	ENDELSE

                IF fourier eq 1 THEN BEGIN

                        xtitle = 'Frequency       [Hz]'
                        ytitle = 'FFT of '+ytitle
                        ytype = 1
                ENDIF
	
	IF STRMID(tmpdata.det,0,1) EQ 'C' THEN flux_label = '[Jy / beam]' $
				ELSE flux_label = '[Jy]'
	CASE view(windowindex).viewtype OF

;Plot power mean
	  0: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Mean Flux Density: Pixel '+str_pixch+'  '+flux_label 
		ytitle = str_pixch 

		IF disc_set THEN $ 
			indno = WHERE(aap_disc(pixch,*) ne 0, nn)

                IF fourier eq 1 THEN BEGIN
                        xtitle = 'Frequency       [Hz]'
                        ytitle = 'FFT of '+ytitle
                        ytype = 1
                ENDIF
		
		pia_xplot, xind, $
			tmpdata.mnfl(pixch,*), $
			tmpdata.mnfu(pixch,*), $
			psym = zoom_psymch, xtitle=xtitle, fourier=fourier, $
			ytitle=ytitle, ytype=ytype,                $
			title=title, subtitle=subtitle,            $
			overplot = overplot,                       $
			charsize = charsize, color = zoom_color,   $     
                        xstyle=xstyle, ystyle=ystyle,              $
                        legend=ytitle,                             $
                        annotation=anntmp                      
                                                                     

		IF disc_set eq 1 and fourier EQ 0 THEN BEGIN
                        IF nn GT 0 THEN $
			  PIA_XPLOT, xind(indno), $
			  tmpdata.mnfl(pixch,indno), $
			  psym = 7, color=red, overplot=99, $
                          legend=' discarded points'
                ENDIF

    	  END
;Plot medians of pixel signals
	  1: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Median Flux Density: Pixel '+str_pixch+'  '+flux_label 
		ytitle = str_pixch 

		IF disc_set THEN $ 
			indno = WHERE(aap_disc(pixch,*) ne 0, nn)

                IF fourier eq 1 THEN BEGIN
                        xtitle = 'Frequency       [Hz]'
                        ytitle = 'FFT of '+ytitle
                        ytype = 1
                ENDIF
		
		pia_xplot, xind, $
			tmpdata.mdfl(pixch,*), $
			psym = zoom_psymch, xtitle=xtitle, fourier=fourier,  $
			ytitle=ytitle, ytype=ytype,                          $
			title=title, subtitle=subtitle,                      $
			overplot = overplot,                                 $
			charsize = charsize, color = zoom_color,             $     
                        xstyle=xstyle, ystyle=ystyle,                        $
                        legend=ytitle,                                       $
                        annotation=anntmp                       

                for II=0,N_ELEMENTS(xind)-1 DO $
                        pia_xplot, [xind(II), xind(II)], $
                           [tmpdata.q1fl(pixch,II),tmpdata.q3fl(pixch,II)], $
                           overplot=99, color=zoom_color, psym=0

		IF disc_set eq 1 AND fourier EQ 0 THEN BEGIN
                        IF nn GT 0 THEN $
			  PIA_XPLOT, xind(indno), $
			  tmpdata.mdfl(pixch,indno), $
			  psym = 7, color=red, overplot=99, $
                          legend=' discarded points'
                ENDIF

    	  END
;Plot first quartiles of flux density
	  2: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'First Quartile Flux density: Pixel '+str_pixch+ $
		     '  ' + flux_label 
		ytitle = str_pixch 

		IF disc_set THEN $ 
			indno = WHERE(aap_disc(pixch,*) ne 0, nn)

                IF fourier eq 1 THEN BEGIN
                        xtitle = 'Frequency       [Hz]'
                        ytitle = 'FFT of '+ytitle
                        ytype = 1
                ENDIF
		pia_xplot, xind, tmpdata.q1fl(pixch,*), $
			psym = zoom_psymch, $
			xtitle=xtitle, fourier=fourier, ytitle = ytitle,   $
			title=title, subtitle=subtitle,                    $
			overplot = overplot,                               $
			charsize = charsize, color = zoom_color,           $   
			ytype=ytype,                                       $     
                        xstyle=xstyle, ystyle=ystyle,                      $
                        legend=ytitle,                                     $
                        annotation=anntmp                        
		IF disc_set eq 1 AND fourier EQ 0 THEN BEGIN
                        IF nn GT 0 THEN $
			  PIA_XPLOT, xind(indno), $
			  tmpdata.q1fl(pixch,indno), $
			  psym = 7, color=red, overplot=99, $
                          legend=' discarded points'
		ENDIF
          END

;Plot first quartiles  of flux density

	  3: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Third Quartile Flux density: Pixel '+str_pixch+  $
		     '  '+flux_label 
		ytitle = str_pixch 

		IF disc_set THEN $ 
			indno = WHERE(aap_disc(pixch,*) ne 0, nn)

                IF fourier eq 1 THEN BEGIN
                        xtitle = 'Frequency       [Hz]'
                        ytitle = 'FFT of '+ytitle
                        ytype = 1
                ENDIF
		pia_xplot, xind, tmpdata.q3fl(pixch,*), $ 
			psym = zoom_psymch, $
			xtitle=xtitle, fourier=fourier, ytitle = ytitle, $
			title=title, subtitle=subtitle, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,     $       
			ytype=ytype, $     
                        xstyle=xstyle, ystyle=ystyle, $
                        legend=ytitle, $
                        annotation=anntmp                        
		IF disc_set eq 1 AND fourier EQ 0 THEN BEGIN
                        IF nn GT 0 THEN $
			  PIA_XPLOT, xind(indno), $
			  tmpdata.q3fl(pixch,indno), $
			  psym = 7, color=red, overplot=99, $
                          legend=' discarded points'           
		ENDIF
          END

;Plot mean surface brightness
	   4: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
	str_pixch = 'Mean Surface Brightness: Pixel '+str_pixch+'  [MJy/sr]' 
		ytitle = str_pixch 

		indno = WHERE(aap_disc(pixch,*) NE 0, nn)

                IF fourier eq 1 THEN BEGIN
                        xtitle = 'Frequency       [Hz]'
                        ytitle = 'FFT of '+ytitle
                        ytype = 1
                ENDIF
		
		pia_xplot, xind, $
			tmpdata.mnbr(pixch,*), $
			tmpdata.mnbu(pixch,*), $
			psym = zoom_psymch, xtitle=xtitle, fourier=fourier, $
			ytitle=ytitle, ytype=ytype, $
			title=title, subtitle=subtitle, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color, $     
                        xstyle=xstyle, ystyle=ystyle, $
                        legend=ytitle, $
                        annotation=anntmp                      
                                                                     

		IF disc_set eq 1 and fourier EQ 0 THEN BEGIN
                        IF nn GT 0 THEN $
			  PIA_XPLOT, xind(indno), $
			  tmpdata.mnbr(pixch,indno), $
			  psym = 7, color=red, overplot=99, $
                          legend=' discarded points'
                ENDIF

    	  END

;Plot median surface brightness
	  5: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Median Surface Brightness: Pixel '+str_pixch+' [W]' 
		ytitle = str_pixch 

		indno = WHERE(aap_disc(pixch,*) NE 0, nn)
		IF disc_set THEN $ 
			indno = WHERE(aap_disc(pixch,*) ne 0, nn)

                IF fourier eq 1 THEN BEGIN
                        xtitle = 'Frequency       [Hz]'
                        ytitle = 'FFT of '+ytitle
                        ytype = 1
                ENDIF
		
		pia_xplot, xind, $
			tmpdata.mdbr(pixch,*), $
			psym = zoom_psymch, xtitle=xtitle, fourier=fourier, $
			ytitle=ytitle, ytype=ytype, $
			title=title, subtitle=subtitle, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color, $     
                        xstyle=xstyle, ystyle=ystyle, $
                        legend=ytitle, $
                        annotation=anntmp                       

                for II=0,N_ELEMENTS(xind)-1 DO $
                        pia_xplot, [xind(II), xind(II)], $
                           [tmpdata.q1br(pixch,II),tmpdata.q3br(pixch,II)], $
                           overplot=99, color=zoom_color, psym=0

		IF disc_set eq 1 AND fourier EQ 0 THEN BEGIN
                        IF nn GT 0 THEN $
			  PIA_XPLOT, xind(indno), $
			  tmpdata.mdbr(pixch,indno), $
			  psym = 7, color=red, overplot=99, $
                          legend=' discarded points'
                ENDIF
    	  END


;Plot first quartiles of surface brightness
	  6: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Surface Brightness 1st Quartile: Pixel '+str_pixch 
		IF title NE '' THEN title = str_pixch 

		pia_xplot, xind, $
			tmpdata.q1br(pixch,*), $
			psym = psymch, xtitle=xtitle, $
			ytitle = ytitle, xmargin=xmargin, $
			charsize = charsize, symsize = symsize

		IF disc_set THEN $ 
			indno = WHERE(aap_disc(pixch,*) ne 0, nn)

                IF nn GE 1 THEN BEGIN
			  time = xind
			  medi = tmpdata.q1br
			  PIA_OPLOT, time(indno), $
			  medi(pixch,indno), $
			  psym = 7, color=red, symsize=1.5
                ENDIF

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  
         
    	  END

;Plot third quartiles of surface brightness
	  7: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Surface Brightness 3rd Quartile: Pixel '+str_pixch 
		IF title NE '' THEN title = str_pixch 

		pia_xplot, xind, $
			tmpdata.q3br(pixch,*), $
			psym = psymch, xtitle=xtitle, $
			ytitle = ytitle, xmargin=xmargin, $
			charsize = charsize, symsize = symsize

		IF disc_set THEN $ 
			indno = WHERE(aap_disc(pixch,*) ne 0, nn)

                IF nn GE 1 THEN BEGIN
			  time = xind
			  medi = tmpdata.q3br
			  PIA_OPLOT, time(indno), $
			  medi(pixch,indno), $
			  psym = 7, color=red, symsize=1.5
                ENDIF

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  
         
    	  END


;Plot flag
	  8: BEGIN
	    	elemnames =  flag_active_label   
		pixch = pixcho(windowindex)
		str_pixch = 'Flag ' + elemnames(menuchoi)+ ': Pixel '+ $
		   STRTRIM(pixch+1,2)
		IF title NE '' THEN title = str_pixch 
		;select flag depending on the choice
		IF flag_active_lex(menuchoi) EQ 'ENCODE' THEN        $
		    tmpflag = tmpdata.flag(pixch,*)                  $
		ELSE decode_piaflag,'AAP',flag_active_lex(menuchoi), $ 
		    tmpdata.flag(pixch,*),tmpflag
		ytitle = 'Flag' 

		pia_xplot, xind, tmpflag, psym = zoom_psymch, $
			xtitle=xtitle, fourier=fourier, ytitle = ytitle, $
			title=title, subtitle=subtitle, ytype=ytype, $
			overplot = overplot, charsize = charsize,  $
			color = zoom_color, xstyle=xstyle, ystyle=ystyle, $
                        legend=strmid(str_pixch,5,25), annotation=anntmp     
          END


;Plot chopper position
	  9: BEGIN
		pia_xplot, xind, tmpdata.cpos, psym = zoom_psymch, $
			xtitle=xtitle, fourier=fourier, ytitle = ytitle, $
			title=title, subtitle=subtitle, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,     $       
			ytype=ytype, $     
                        xstyle=xstyle, ystyle=ystyle, $
                        legend=ytitle, $
                        annotation=anntmp             
          END

;Plot raster point
	 10: BEGIN
		elemnames = ['Raster Point ID 1', 'Raster Point ID 2']
		tmprpid = tmpdata.rpid(menuchoi,*)
		tmprpid_name = elemnames(menuchoi)
		
		pia_xplot, xind, tmprpid, psym = zoom_psymch, $
			xtitle=xtitle, fourier=fourier, ytitle = tmprpid_name, $
			title=title, subtitle=subtitle, ytype=ytype, $
			overplot = overplot, charsize = charsize,  $
			color = zoom_color, xstyle=xstyle, ystyle=ystyle, $
                        legend=strmid(ytitle,0,18), annotation=anntmp         
          END

;Plot DEC
	  11: BEGIN
		pia_xplot, xind, tmpdata.dec, psym = zoom_psymch, $
			xtitle=xtitle, fourier=fourier, ytitle = ytitle, $
			title=title, subtitle=subtitle, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,     $       
			ytype=ytype, $     
                        xstyle=xstyle, ystyle=ystyle, $
                        legend=ytitle, $
                        annotation=anntmp             
          END

;Plot RA
	  12: BEGIN
		pia_xplot, xind, tmpdata.ra, psym = zoom_psymch, $
			xtitle=xtitle, fourier=fourier, ytitle = ytitle, $
			title=title, subtitle=subtitle, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,   $       
			ytype=ytype, $     
                        xstyle=xstyle, ystyle=ystyle, $
                        legend=ytitle, $
                        annotation=anntmp             
	  END
;Plot DECP
	  13: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Declination: Pixel '+str_pixch
		ytitle = str_pixch 
		pia_xplot, xind, tmpdata.decp(pixch,*) , psym = zoom_psymch, $
			xtitle=xtitle, fourier=fourier, ytitle = ytitle, $
			title=title, subtitle=subtitle, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,     $       
			ytype=ytype, $     
                        xstyle=xstyle, ystyle=ystyle, $
                        legend=ytitle, $
                        annotation=anntmp             
          END

;Plot RAP
	  14: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Right ascension: Pixel '+str_pixch
		ytitle = str_pixch 
		pia_xplot, xind, tmpdata.rap(pixch,*), psym = zoom_psymch, $
			xtitle=xtitle, fourier=fourier, ytitle = ytitle, $
			title=title, subtitle=subtitle, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,   $       
			ytype=ytype, $     
                        xstyle=xstyle, ystyle=ystyle, $
                        legend=ytitle, $
                        annotation=anntmp             
	  END

	  ELSE: MESSAGE, /INFO, 'Unsupported View'
          ENDCASE

END


; *********************************************************************
; *
; *********************************************************************
pro pia_resetview6, windowindex, UPDATE_LABEL

COMMON pia_dispaap_cmn, tmpdata, aapps, view, viewsize, nviews, viewoptions, $
   overid, redflag 
COMMON pia_dspaap_flg_cmn, nflag_active, flag_active_lex, flag_active_label  
COMMON pia_dspch6_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON aap_nacc, aap_disc, disc_set, astrflag, bck_sel
COMMON tmpvalues6, tmprpid, tmprpid_name
@colour_indices

	wset, view(windowindex).windownum         ;set to draw in 

	ERASE, color = 100                        ;erase the view


	IF NOT (KEYWORD_SET(UPDATE_LABEL)) THEN $
	  UPDATE_LABEL = 0


        charsize = 0.8
        symsize = 1.

        title = viewoptions(view(windowindex).viewtype).viewname
	xtitle = viewoptions(view(windowindex).viewtype).viewxlab
	ytitle = viewoptions(view(windowindex).viewtype).viewylab
	menuchoi = view(windowindex).viewtype_sub

	xmargin = [15,3]

	concat = fxpar(tmpdata.hdr, 'PRA_CN1', count=count)
	IF count GT 0 THEN BEGIN
		  xind = indgen(N_ELEMENTS(tmpdata.time)) 
		  xtitle = 'Concatenation index' 
	ENDIF ELSE BEGIN
		  xind = tmpdata.time
;		  xtitle = xtitle
	ENDELSE
		
	CASE view(windowindex).viewtype OF


;Plot averages of pixel signals
	  0: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Mean Flux Density: Pixel '+str_pixch 
		IF title NE '' THEN title = str_pixch 
		
		
		pia_plot, xind, $
			tmpdata.mnfl(pixch,*), $
			yerr=tmpdata.mnfu(pixch,*), $
			psym = psymch, xtitle=xtitle, $
			ytitle = ytitle, xmargin=xmargin, $
			charsize = charsize, symsize = symsize

		IF disc_set THEN $ 
			indno = WHERE(aap_disc(pixch,*) ne 0, nn)

                IF nn GE 1 THEN BEGIN
			  time = xind
			  av = tmpdata.mnfl
			  PIA_OPLOT, time(indno), $
			  av(pixch,indno), $
			  psym = 7, color=red, symsize=symsize
                ENDIF

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  
         
    	  END

;Plot medians of pixel signals
	  1: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Median Flux Density: Pixel '+str_pixch 
		IF title NE '' THEN title = str_pixch 

		y0 = min(tmpdata.q1fl(pixch,*))
		y1 = max(tmpdata.q3fl(pixch,*))
		yrange = [y0-abs(y0)*0.2 , y1+y1*abs(y1)*0.2]  

		
		pia_plot, xind, $
			tmpdata.mdfl(pixch,*), yrange=yrange, $
			psym = psymch, xtitle=xtitle, $
			ytitle = ytitle, xmargin=xmargin, $
			charsize = charsize, symsize = symsize
		pia_oplot, xind, $
                           tmpdata.q1fl(pixch,*), psym=2, color=white
		pia_oplot, xind, $
                           tmpdata.q3fl(pixch,*), psym=2, color=white

		IF disc_set THEN $ 
			indno = WHERE(aap_disc(pixch,*) ne 0, nn)

                IF nn GE 1 THEN BEGIN
			  time = xind
			  medi = tmpdata.mdfl
			  PIA_OPLOT, time(indno), $
			  medi(pixch,indno), $
			  psym = 7, color=red, symsize=symsize
                ENDIF

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  
         
    	  END

;Plot first quartiles of flux density
	  2: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = '1st Quartile: Pixel '+str_pixch 
		IF title NE '' THEN title = str_pixch 

		pia_plot, xind, $
			tmpdata.q1fl(pixch,*), $
			psym = psymch, xtitle=xtitle, $
			ytitle = ytitle, xmargin=xmargin, $
			charsize = charsize, symsize = symsize

		IF disc_set THEN $ 
			indno = WHERE(aap_disc(pixch,*) ne 0, nn)

                IF nn GE 1 THEN BEGIN
			  time = tmpdata.time
			  medi = tmpdata.q1fl
			  PIA_OPLOT, time(indno), $
			  medi(pixch,indno), $
			  psym = 7, color=red, symsize=1.5
                ENDIF

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  
         
    	  END

;Plot third quartiles of flux density
	  3: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = '3rd Quartile: Pixel '+str_pixch 
		IF title NE '' THEN title = str_pixch 

		pia_plot, xind, $
			tmpdata.q3fl(pixch,*), $
			psym = psymch, xtitle=xtitle, $
			ytitle = ytitle, xmargin=xmargin, $
			charsize = charsize, symsize = symsize

		IF disc_set THEN $ 
			indno = WHERE(aap_disc(pixch,*) ne 0, nn)

                IF nn GE 1 THEN BEGIN
			  time = xind
			  medi = tmpdata.q3fl
			  PIA_OPLOT, time(indno), $
			  medi(pixch,indno), $
			  psym = 7, color=red, symsize=1.5
                ENDIF

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  
         
    	  END



;Plot Surface Brightness
	   4: BEGIN 
		 pixch = pixcho(windowindex)
		 str_pixch = STRTRIM(STRING(pixch+1),2)
		 IF title NE '' THEN $
			title = 'Surface Brightness: Pixel '+str_pixch 

		   pia_plot, xind, tmpdata.mnbr(pixch,*), $
			yerr=tmpdata.mnbu(pixch,*), psym = psymch, $
			xtitle = xtitle, ytitle = ytitle, xmargin=xmargin, $
			charsize = charsize, symsize = symsize

		   IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = 'Surface Brightness (Avrg)' 

		   indno = WHERE(aap_disc(pixch,*) GT 0, nn)

                   IF nn GE 1 THEN BEGIN
			  time = xind
			  flux = tmpdata.mnbr
			  PIA_OPLOT, time(indno), $
			  flux(pixch,indno), $
			  psym = 7, color=red, symsize=symsize
                   ENDIF
          END

;Plot medians of surface brightness
	  5: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Median Surface brightness: Pixel '+str_pixch 
		IF title NE '' THEN title = str_pixch 

		y0 = min(tmpdata.q1br(pixch,*))
		y1 = max(tmpdata.q3br(pixch,*))
		yrange = [y0-abs(y0)*0.2 , y1+y1*abs(y1)*0.2]  
		pia_plot, xind, $
			tmpdata.mdbr(pixch,*), yrange=yrange, $
			psym = psymch, xtitle=xtitle, $
			ytitle = ytitle, xmargin=xmargin, $
			charsize = charsize, symsize = symsize
		pia_oplot, xind, $
                           tmpdata.q1br(pixch,*), psym=2, color=white
		pia_oplot, xind, $
                           tmpdata.q3br(pixch,*), psym=2, color=white

		IF disc_set THEN $ 
			indno = WHERE(aap_disc(pixch,*) ne 0, nn)

                IF nn GE 1 THEN BEGIN
			  time = xind
			  medi = tmpdata.mdbr
			  PIA_OPLOT, time(indno), $
			  medi(pixch,indno), $
			  psym = 7, color=red, symsize=symsize
                ENDIF

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  
         
    	  END

;Plot first quartiles of surface brightness
	  6: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = '1st Quartile: Pixel '+str_pixch 
		IF title NE '' THEN title = str_pixch 

		pia_plot, xind, $
			tmpdata.q1br(pixch,*), $
			psym = psymch, xtitle=xtitle, $
			ytitle = ytitle, xmargin=xmargin, $
			charsize = charsize, symsize = symsize

		IF disc_set THEN $ 
			indno = WHERE(aap_disc(pixch,*) ne 0, nn)

                IF nn GE 1 THEN BEGIN
			  time = xind
			  medi = tmpdata.q1br
			  PIA_OPLOT, time(indno), $
			  medi(pixch,indno), $
			  psym = 7, color=red, symsize=1.5
                ENDIF

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  
         
    	  END

;Plot third quartiles of surface brightness
	  7: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = '3rd Quartile: Pixel '+str_pixch 
		IF title NE '' THEN title = str_pixch 

		pia_plot, xind, $
			tmpdata.q3br(pixch,*), $
			psym = psymch, xtitle=xtitle, $
			ytitle = ytitle, xmargin=xmargin, $
			charsize = charsize, symsize = symsize

		IF disc_set THEN $ 
			indno = WHERE(aap_disc(pixch,*) ne 0, nn)

                IF nn GE 1 THEN BEGIN
			  time = xind
			  medi = tmpdata.q3br
			  PIA_OPLOT, time(indno), $
			  medi(pixch,indno), $
			  psym = 7, color=red, symsize=1.5
                ENDIF

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  
         
    	  END


;Plot flag
	  8: BEGIN
	    	elemnames =  flag_active_label   
		pixch = pixcho(windowindex)
		str_pixch = 'Flag ' + elemnames(menuchoi)+ ': Pixel '+ $
		   STRTRIM(pixch+1,2)
		IF title NE '' THEN title = str_pixch 
		;select flag depending on the choice
		IF flag_active_lex(menuchoi) EQ 'ENCODE' THEN        $
		    tmpflag = tmpdata.flag(pixch,*)                  $
		ELSE decode_piaflag,'AAP',flag_active_lex(menuchoi), $ 
		    tmpdata.flag(pixch,*),tmpflag


		pia_plot, xind, tmpflag, psym = psymch, $
			xtitle=xtitle, ytitle = ytitle, xmargin=xmargin, $
			charsize = charsize, symsize = symsize

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value =  str_pixch 

          END

;Plot chopper positions
	  9: BEGIN
		pia_plot, xind, tmpdata.cpos, psym = psymch, $
			xtitle=xtitle, ytitle = ytitle, xmargin=xmargin, $
			charsize = charsize, symsize = symsize

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = 'Chopper position'  

          END

;Plot raster point
	  10: BEGIN
		elemnames = ['Raster Point ID 1', 'Raster Point ID 2']
		
		tmprpid = tmpdata.rpid(menuchoi,*)
		tmprpid_name = elemnames(menuchoi)

		pia_plot, xind, tmprpid, psym = psymch, $
			xtitle=xtitle, ytitle = tmprpid_name, xmargin=xmargin, $
			charsize = charsize, symsize = symsize

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = tmprpid_name

          END

;Plot DEC
	  11: BEGIN 
	  	pia_plot, xind, tmpdata.dec, psym = psymch, $
			xtitle = xtitle, ytitle = ytitle, xmargin=xmargin, $
			charsize = charsize, symsize = symsize
		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = 'Declination'
          END
          
;Plot RA
	 12: BEGIN 
	 	pia_plot, xind, tmpdata.ra, psym = psymch, $
			xtitle = xtitle, ytitle = ytitle, xmargin=xmargin, $
			charsize = charsize, symsize = symsize

		   IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = 'Right Ascension' 
          END

;Plot DECP
	  13: BEGIN 
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'DEC point: Pixel '+str_pixch 
		IF title NE '' THEN title = str_pixch 
	  	pia_plot, xind, tmpdata.decp(pixch,*), psym = psymch, $
			xtitle = xtitle, ytitle = ytitle, xmargin=xmargin, $
			charsize = charsize, symsize = symsize
		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = 'DEC per point'
          END
          
;Plot RAP
	 14: BEGIN 		
	 	pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'RA point: Pixel '+str_pixch 
		IF title NE '' THEN title = str_pixch 
		pia_plot, xind, tmpdata.rap(pixch,*), psym = psymch, $
			xtitle = xtitle, ytitle = ytitle, xmargin=xmargin, $
			charsize = charsize, symsize = symsize

		   IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = 'RA per point' 
          END

	  ELSE: WIDGET_CONTROL, UPDATE_LABEL, $
				set_value = 'Unsupported View'
          ENDCASE

END


; ***************************************************************************
;  Event handling routine for PIA display menu
; ****************************************************************************

PRO pia_daap_event, event

@adm
@phtcs
@phtaap
@phtacc

COMMON pia_dispaap_cmn, tmpdata, aapps, view, viewsize, nviews, viewoptions, $
   overid, redflag 
COMMON pia_dspch6_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON aapatt, dattext_id, newheader, chopcor_id
COMMON dispcust_cmn, psym, line
COMMON dspaap_widg, pixbut
COMMON aap_bckflag, bck_flag
COMMON aap_nacc, aap_disc, disc_set, astrflag, bck_sel
COMMON pia_widget_info, extfil_wid, intfil_wid, buffil_wid, $
                        erddi1_wid, erddi2_wid, srddi1_wid, srddi2_wid, $
                        scpdi1_wid, scpdi2_wid, spddi1_wid, spddi2_wid, $
                        aapdi1_wid, aapdi2_wid


	WIDGET_CONTROL, event.id, get_uvalue = uvalue
        WIDGET_CONTROL, event.top, /HOURGLASS

	cmap_wind_text=["A","B","C","D"]
	
	CASE uvalue OF


 	  "EXIT":  BEGIN
		    WIDGET_CONTROL, event.top, /DESTROY 
		  END

 	  "SAVEXIT":  BEGIN
	  	    fill_aap, tmpdata, newheader, REPLACE=aapps
		    WIDGET_CONTROL, event.top, /DESTROY 
		  END


          "HELP":  BEGIN
	   	IF !VERSION.OS NE 'vms' THEN $
		spawn, '$w3net $PIA_HTML/um/aap_window.html &' ELSE $
		spawn, 'w3net /pia_dsk/pia/html/um/aap_window.html'
		END
                   
	  "CUST": BEGIN
			pia_dispcust, GROUP=event.top
			psymch = psym
			 FOR I=0,NVIEWS-1 DO BEGIN
			    pia_resetview6, i, view(i).controlid
			 ENDFOR
          END

	  "LOAD": BEGIN
; search for same file and detector type
		    newdata = pickmeas(FTYPE="AAP", DTYPE=tmpdata.det, POSI=posi)
		    IF newdata NE '' THEN BEGIN

                     datind = WHERE(phtaap.admn eq newdata, count)

                     IF count EQ 0 THEN $
                        MESSAGE, /INFO, 'Measurement not found!'

                     IF count NE 0 THEN BEGIN 

			disc_set = 0

			aapps = datind(posi(0))
		    	pia_load_iaap, phtaap(aapps), tmpdata		

        	get_spddisc, tmpdata, /ENCODE_FLAG
		get_validflag, tmpdata.flag, 'AAP', redflag, $
			  det=tmpdata.det, /allpix
        	aap_disc = redflag
        	disc_set = 1
	
; header update
			newheader = tmpdata.hdr

			obj = FXPAR(tmpdata.hdr,'OBJECT')
			attra = FXPAR(tmpdata.hdr,'ATTRA')
			attdec = FXPAR(tmpdata.hdr,'ATTDEC')
			dattext = dec_admn(tmpdata.admn)
			more_text = 'OBJ:' + obj +  ' ' + give_sradec(attra, attdec)
			dattext = 'AAP '+dattext+ ' - '+ $
				' - ' + more_text

			WIDGET_CONTROL, dattext_id, SET_VALUE = dattext  
			
; update widget status
			WIDGET_CONTROL, event.top, GET_UVALUE=ids
; Signal losses in chopped measurements: 
			res = fxpar(tmpdata.hdr, 'PRC_SUBT', count=count)
			res = fxpar(tmpdata.hdr, 'PRD_SUBT', count=count2)
			res = fxpar(tmpdata.hdr, 'PRA_SUBT', count=count3)
			count = count+count2+count3
			IF count NE 1 THEN $
				WIDGET_CONTROL, ids.id_chopcor, SENSITIVE=0     $ 
    				ELSE WIDGET_CONTROL, ids.id_chopcor, SENSITIVE=1

        		inda = WHERE(tmpdata.cstp EQ 2, nrstp)
			aot = STRTRIM(fxpar(tmpdata.hdr, 'EOHAAOTN'),2)	
        		IF nrstp EQ 0 OR aot EQ 'P32' THEN $
        		 WIDGET_CONTROL, ids.id_subtr, SENSITIVE=0 ELSE $
        		 WIDGET_CONTROL, ids.id_subtr, SENSITIVE=1
		        for i=0, NVIEWS - 1 do pia_resetview6, i
                     ENDIF
		    ENDIF
		  END	                  	

	  "SAVEBUFF": fill_aap, tmpdata, newheader, REPLACE=aapps

	  "SAVEBUFF_NEW": BEGIN
	               aapps = N_ELEMENTS(phtaap)
                       fill_aap, tmpdata, newheader
                   END

	  "SAVEI": BEGIN
	  	    change_tmphdr, tmpdata, 'AAP', newheader, tmpout
	  	    PCONT_SAVEINT, junk, 'AAP', tmpdata=tmpout
		  END

	  "SAVEF_S": BEGIN
		  tfile = tmpdata.admn + '_AAP.FITS'
		  filename = pia_pickfile(file = tfile, $
		    path = !intdir, filter='*_AAP.FITS', get_path=newpath,$
		    /write, /overwrite)

		  if filename NE '' then begin

  	  	     write_aap_SL, tmpdata, newheader, filename=filename
		  endif

	  	    
		  END

	  "SAVEF": BEGIN
		  tfile = tmpdata.admn + '_AAP.FITS'
		  filename = pia_pickfile(file = tfile, $
		    path = !intdir, filter='*_AAP.FITS', get_path=newpath,$
		    /write, /overwrite)

		  if filename NE '' then begin
		  
		   fill_aap, tmpdata, newheader
		   
; have to fill it in buffer, because required by write_aap_multi

		   posi = N_ELEMENTS(phtaap) - 1
		   
		   list = [ $
			   	"Pixel number", $
			   	"Aperture_Y in arcsec (zero means a circular aperture)", $
				"Aperture_Z in arcsec (diameter if Aperture_Y is zero)", $
				"Wavelength in um", $
				"Uncertainty in wavelength in um", $
				"Mean flux in Jy", $
				"Mean flux uncertainty in Jy", $
				"Median flux in Jy", $
				"Mean brightness in MJy/sr", $
				"Mean brightness uncertainty in MJy/sr", $
				"Median brightness in MJy/sr", $
				"Raster point ID in Y", $
				"Raster point ID in Z", $
				"Declination in degrees", $
				"Right Ascension in degrees", $
				"Roll Angle in degrees", $
				"Flag"]
		    pia_sellist, list, mask, type=" Variables to be used"
		    
		    mask = [0,mask] ; meas-id should not be there
		    
		    write_aap_multi, posi, accvector=mask, filename=filename
		    
		    aap_init, index=posi
		    
		  endif

	  	    
		  END

	  ;"PRINT": PIA_PRINT_SPDVAL, tmpdata 

	  "PRINT_FLUX": PIA_PRINT_AAPVAL, tmpdata 
	  
	  "SHOWD": PIA_showstr, tmpdata, VALNAMES=phtaap_desc, GROUP=event.top

	  ;"SLDISC": BEGIN 

	;	nchp = tmpdata.dims
; Use the same menu for discarding chopper plateaux as SCP level
	;	PIA_AAPDISC, nchp = nchp  
				
; Fill aap_disc with discarded chopper plateaux 
	;	get_aapdisc, tmpdata, spddisc
         ;       aap_disc = spddisc

	;	disc_set = 1

	;	FOR i=0, NVIEWS - 1 do pia_resetview6, i
	 ; END		   

	  "ASTRO": BEGIN
	  	add_coordinates, tmpdata
	  	astrflag = 1
	  END
 
	  "BCKSEL_ALLP": BEGIN 
	         mnbr = tmpdata.mnbr
	         mnbu = tmpdata.mnbu
	         time = tmpdata.time
		 aap_disc, tmpdata, flag
	         IF NOT bck_sel THEN bck_flag = flag*0
	         tmp_bckflag = bck_flag
	         pia_aap_bcksel, time, mnbr, mnbu, tmp_bckflag, FLAG = flag
	         bck_flag = tmp_bckflag
	         bck_sel = 1
	                 
	  END

	  "CHOPFREQ": BEGIN
	      res = fxpar(newheader, 'PRC_CFCF', count=count)
	      res = fxpar(newheader, 'PRD_CFCF', count=count2)
	      res = fxpar(newheader, 'PRA_CFCF', count=count3)
	      count = count+count2+count3
	      IF count NE 0 THEN $
		    	XDISPLAYFILE, "", $
                    		GROUP = event.top, $
                    		TITLE = "Already performed ", $
                    		WIDTH = 30, $
                    		HEIGHT = 6, $
                    		TEXT = [" The chopper frequency correction ", $
                                        " has been already performed "] $
              ELSE $
              	      CHOP_FREQ_CORR, tmpdata, newheader=newheader, /AAP
	      
	    FOR I=0,NVIEWS-1 DO BEGIN
			    pia_resetview6, i, view(i).controlid
	    ENDFOR

	  END

          "HDR": BEGIN
                IF N_ELEMENTS(newheader) EQ 0 THEN $
                        MESSAGE, /INFO, 'No header defined' ELSE $
                        pia_disp_hdr, newheader, tmpdata.admn, 'PHTAAP'
          END

          "CS": PIA_DISP_CS, tmpdata.admn

	  "ISREP": PIA_disp_isr,STRMID(tmpdata.admn,4,8)

	  "OLREP": PIA_disp_olr,STRMID(tmpdata.admn,4,8)

	  "EOHA": PIA_disp_eoha,STRMID(tmpdata.admn,4,8)

	  "EOHI": PIA_disp_eohi,STRMID(tmpdata.admn,4,8)

	  "SLICES": BEGIN

		npix = pixel_det(tmpdata.det, /IS_AAP)

		nslice = N_ELEMENTS(tmpdata.mnfl(0,*))

		decode_admn, tmpdata.admn, tmpmeas

		yt='Flux Density  [Jy]' 
	  	PIA_XPLOT, indgen(npix) + 1, tmpdata.mnfl(0:npix-1,0), $
	  		TITLE='Time development of Flux density - '+tmpmeas, $
	  		xtitle=' Pixel # ', ytitle=yt, $
	  		psym=10

		zoom_color = 1

		IF nslice GT 1 THEN BEGIN
	  	 FOR I=1, nslice-1 DO BEGIN
			zoom_color = zoom_color + 1
			IF zoom_color EQ 9 then zoom_color = 1
	  	 	WAIT,0.5
	  	 	PIA_XPLOT, indgen(npix) + 1, tmpdata.mnfl(0:npix-1,i),$
	  	 	/overplot, color=zoom_color, psym=10
	  	 ENDFOR
	  	ENDIF 
	  END	  	 	

	  "SLICES_3D": BEGIN

		npix = pixel_det(tmpdata.det, /IS_AAP)

		decode_admn, tmpdata.admn, tmpmeas


		yt='Flux density  [Jy]'	
		PIA_XSurface, tmpdata.mnfl(0:npix-1,*), $
			title='Time evol. of In-band Power - '+tmpmeas, $
			xtitle=' Pixel # ', ytitle='Time    [s]', $
			ztitle=yt, charsize=1.25, wlego=1

	  END	  	 	

          "IMAGE": BEGIN
		rpid_ch = [1B,1B]
		npoints = FIX(max(tmpdata.rpid(0,*)))
		nlines = FIX(max(tmpdata.rpid(1,*)))


		IF (npoints * nlines) GT 1 THEN $
			pia_get_rpid, [npoints,nlines], rpid_ch
					
                steps = max(tmpdata.cstp)
                mulch = 0
		
                IF steps GT 1 AND steps NE min(tmpdata.cstp) THEN BEGIN
			   pia_get_step, steps
			   mulch = 1
		ENDIF

                PIA_CIMAGE_SPD, tmpdata, steps, mulch, rpid_ch, /AAP
          END

          "JSPECT": BEGIN
		rpid_ch = [1B,1B]
		npoints = FIX(max(tmpdata.rpid(0,*)))
		nlines = FIX(max(tmpdata.rpid(1,*)))

		IF (npoints * nlines) GT 1 THEN $
			pia_get_rpid, [npoints,nlines], rpid_ch

                steps = max(tmpdata.cstp)
		mulch = 0

                IF steps GT 1 AND steps NE min(tmpdata.cstp) THEN BEGIN
			   pia_get_step, steps
			   mulch = 1
		ENDIF

                PIA_SPECT_aar, tmpdata, steps, mulch, rpid_ch, overplot=0
          END

          "JSPESY": BEGIN
		rpid_ch = [1B,1B]
		npoints = FIX(max(tmpdata.rpid(0,*)))
		nlines = FIX(max(tmpdata.rpid(1,*)))

		IF (npoints * nlines) GT 1 THEN $
			pia_get_rpid, [npoints,nlines], rpid_ch

                steps = max(tmpdata.cstp)
                mulch = 0
		
                IF steps GT 1 AND steps NE min(tmpdata.cstp) THEN BEGIN
			   pia_get_step, steps
			   mulch = 1
                ENDIF

                PIA_SPECT_aar, tmpdata, steps, mulch, rpid_ch, overplot=1
          END

          "JSPENSY": BEGIN
		rpid_ch = [1B,1B]
		npoints = FIX(max(tmpdata.rpid(0,*)))
		nlines = FIX(max(tmpdata.rpid(1,*)))

		IF (npoints * nlines) GT 1 THEN $
			pia_get_rpid, [npoints,nlines], rpid_ch

                steps = max(tmpdata.cstp)
                mulch = 0

                IF steps GT 1 AND steps NE min(tmpdata.cstp) THEN BEGIN
			   pia_get_step, steps
			   mulch = 1
		ENDIF

                PIA_SPECT_aar, tmpdata, steps, mulch, rpid_ch, overplot=-1
          END

          "MJSPECT": BEGIN
		rpid_ch = [1B,1B]
		npoints = FIX(max(tmpdata.rpid(0,*)))
		nlines = FIX(max(tmpdata.rpid(1,*)))

		IF (npoints * nlines) GT 1 THEN $
			pia_get_rpid, [npoints,nlines], rpid_ch

                steps = max(tmpdata.cstp)
		mulch = 0

                IF steps GT 1 AND steps NE min(tmpdata.cstp) THEN BEGIN
			   pia_get_step, steps
			   mulch = 1
		ENDIF

                PIA_SPECT_aar, tmpdata, steps, mulch, rpid_ch, overplot=0, /Mjy
          END

          "MJSPESY": BEGIN
		rpid_ch = [1B,1B]
		npoints = FIX(max(tmpdata.rpid(0,*)))
		nlines = FIX(max(tmpdata.rpid(1,*)))

		IF (npoints * nlines) GT 1 THEN $
			pia_get_rpid, [npoints,nlines], rpid_ch

                steps = max(tmpdata.cstp)
                mulch = 0
		
                IF steps GT 1 AND steps NE min(tmpdata.cstp) THEN BEGIN
			   pia_get_step, steps
			   mulch = 1
                ENDIF

                PIA_SPECT_aar, tmpdata, steps, mulch, rpid_ch, overplot=1, /Mjy
          END

          "MJSPENSY": BEGIN
		rpid_ch = [1B,1B]
		npoints = FIX(max(tmpdata.rpid(0,*)))
		nlines = FIX(max(tmpdata.rpid(1,*)))

		IF (npoints * nlines) GT 1 THEN $
			pia_get_rpid, [npoints,nlines], rpid_ch

                steps = max(tmpdata.cstp)
                mulch = 0

                IF steps GT 1 AND steps NE min(tmpdata.cstp) THEN BEGIN
			   pia_get_step, steps
			   mulch = 1
		ENDIF

                PIA_SPECT_aar, tmpdata, steps, mulch, rpid_ch, overplot=-1,/Mjy
          END

          "BCKSBT": BEGIN

                PIA_BCKSUBT, tmpdata, newheader, /AAP

          END

          "BCKSBT_MEAS": BEGIN

		bckmeas = pickmeas(FTYPE='AAP', DTYPE=tmpdata.det, POSI=posi, $
		  TITLE="Measurement to be subtracted", GROUP=event.top)
		ind = WHERE(phtaap.admn EQ bckmeas, ncount)
		IF ncount EQ 0 or ind(0) EQ 0 THEN RETURN

		pia_load_iaap, phtaap(ind(posi(0))), bckmeas
                subtr_meas, tmpdata, bckmeas, tmpsubt, /AAP

          END

	  "GLUEMEAS_MNBR": BEGIN
	  	tmpval = 1
	  	GOTO, GLUEMEAS
	  END

	  "GLUEMEAS_MNFL": BEGIN
	  	tmpval = 2
	  	GOTO, GLUEMEAS
	  END

	  "GLUEMEAS_MDBR": BEGIN
	  	tmpval = 3
	  	GOTO, GLUEMEAS
	  END

	  "GLUEMEAS_MDFL": BEGIN
	  	tmpval = 4
	  	GOTO, GLUEMEAS
	  END

	  "GLUEMEAS": BEGIN
		tmpval = 0
GLUEMEAS:
		newdata = $
		 pickmeas(FTYPE="AAP",DTYPE=tmpdata.det,POSI=posi,/multi )
		IF newdata(0) NE '' THEN BEGIN

		count = N_ELEMENTS(newdata) 
 
                IF count NE 0 THEN BEGIN 

		  FOR imeas=0,count-1 DO BEGIN

		        IF imeas EQ 0 THEN orig_pos= N_ELEMENTS(phtaap) 

			disc_set = 0

			datind = WHERE(phtaap.admn eq newdata(imeas))
			aapps2 = datind(posi(imeas))
		    	pia_load_iaap, phtaap(aapps2), tmpdata2		
		    	 
	  	 	npix = N_ELEMENTS(tmpdata.mnbr(*,0))
	  	 	mednorm = fltarr(npix) + 1.
	  	 	CASE tmpval OF
	  	    	 1: for i=0,npix-1 DO $
	  	       		mednorm(i) = median(tmpdata.mnbr(i,*)) / $
	  	       			median(tmpdata2.mnbr(i,*))
	  	    	 2: for i=0,npix-1 DO $
	  	       		mednorm(i) = median(tmpdata.mnfl(i,*)) / $
	  	       			median(tmpdata2.mnfl(i,*))
	  	    	 3: for i=0,npix-1 DO $
	  	       		mednorm(i) = median(tmpdata.mdbr(i,*)) / $
	  	       			median(tmpdata2.mdbr(i,*))
	  	    	 4: for i=0,npix-1 DO $
	  	       		mednorm(i) = median(tmpdata.mdfl(i,*)) / $
	  	       			median(tmpdata2.mdfl(i,*))
	  	    	 ELSE: 
	  	 	ENDCASE
	  	    
		  	IF tmpval GT 0 AND count EQ 1 THEN $
		    	 PIA_disp_print_file, '', TITLE="Normalization factors used",$
		    	   TEXT= ["The normalization factors for concatenating are:",$
		    	   STRTRIM(indgen(npix)+1,2) + ':  ' + $
		    	   STRTRIM(mednorm,2) ]
		    	    
	  	  	GLUE_AAP, tmpdata, tmpdata2, aapps_glue, error=error, $
	  	   		mednorm=mednorm
	  	  	IF NOT ERROR THEN BEGIN 
			 pia_load_iaap, phtaap(aapps_glue), tmpdata
; header update
		get_validflag, tmpdata.flag, 'AAP', redflag, $
			  det=tmpdata.det, /allpix
        	aap_disc = redflag
        	disc_set = 1
			 aapps = aapps_glue
			 newheader = tmpdata.hdr
		   	ENDIF
		   ENDFOR
		   
		ENDIF

		IF count GT 1 THEN BEGIN 
		 posis = indgen(N_ELEMENTS(phtaap)-orig_pos) + orig_pos
		 aap_init, index=posis
		 pia_in_buffer, tmpdata
		ENDIF 
		 
		obj = FXPAR(tmpdata.hdr,'OBJECT')
		attra = FXPAR(tmpdata.hdr,'ATTRA')
		attdec = FXPAR(tmpdata.hdr,'ATTDEC')
		dattext = dec_admn(tmpdata.admn)
		more_text = 'OBJ:' + obj + ' ' + give_sradec(attra, attdec)
		dattext = 'AAP '+dattext+ ' - '+ $
				' - ' + more_text

		WIDGET_CONTROL, dattext_id, SET_VALUE = dattext  
			
		for i=0, NVIEWS - 1 do pia_resetview6, i

	      ENDIF
	  END   
	  
	  "FQ_MNBR": BEGIN
	  	FIRSTQ_FF, tmpdata, ff, hdr=newheader, use_var=0
	      for i=0, NVIEWS - 1 do pia_resetview6, i
	  END
	  	  
	  "FQ_MNFL": BEGIN
	  	FIRSTQ_FF, tmpdata, ff, hdr=newheader, use_var=1
	      for i=0, NVIEWS - 1 do pia_resetview6, i
	  END
	  	  
	  "FQ_MDBR": BEGIN
	  	FIRSTQ_FF, tmpdata, ff, hdr=newheader, use_var=2
	      for i=0, NVIEWS - 1 do pia_resetview6, i
	  END

	  "FQ_MDFL": BEGIN
	  	FIRSTQ_FF, tmpdata, ff, hdr=newheader, use_var=3
	      for i=0, NVIEWS - 1 do pia_resetview6, i
	  END
	         
	  "MEDFILT_MNBR": BEGIN
	  	tmpval = 1
	  	mnbr = tmpdata.mnbr
	  	mnbu = tmpdata.mnbu
	  	GOTO, MEDFILT
	  END

	  "MEDFILT_MNFL": BEGIN
	  	tmpval = 2
	  	mnbr = tmpdata.mnfl
	  	mnbu = tmpdata.mnfu
	  	GOTO, MEDFILT
	  END

	  "MEDFILT_MDBR": BEGIN
	  	tmpval = 3
	  	mnbr = tmpdata.mdbr
	  	mnbu = tmpdata.mnbu
	  	GOTO, MEDFILT
	  END

	  "MEDFILT_MDFL": BEGIN
	  	tmpval = 4
	  	mnbr = tmpdata.mdfl
	  	mnbu = tmpdata.mnfu
	  	GOTO, MEDFILT
	  END

	  "MEDFILT": BEGIN
MEDFILT:	  	
	      AAP_DISC, tmpdata, flag
	      PIA_FF_MED_SMOOTH, mnbr, mnbu, tmp_bright, flag=flag, $
	      	/modal
	      CASE tmpval OF
	  	1: BEGIN
	  		tmpdata.mnbu= tmpdata.mnbu * tmp_bright/tmpdata.mnbr
	  		tmpdata.mnbr=tmp_bright
		END
	  	2: BEGIN
	  		tmpdata.mnfu= tmpdata.mnfu * tmp_bright/tmpdata.mnfl
	  		tmpdata.mnfl=tmp_bright
		END
	  	3: BEGIN
	  		tmpdata.mnbu= tmpdata.mnbu * tmp_bright/tmpdata.mdbr
	  		tmpdata.mdbr=tmp_bright
		END
	  	4: BEGIN
	  		tmpdata.mnfu= tmpdata.mnfu * tmp_bright/tmpdata.mdfl
	  		tmpdata.mdfl=tmp_bright
		END
	      ENDCASE

	      for i=0, NVIEWS - 1 do pia_resetview6, i
	  	  
	  END
	  
	  "SOFF": pia_correct_s_offset, tmpdata, newheader
	  
	  "PIXCH": BEGIN
			old_pixcho = pixcho
			new_pixc = pia_pixchoice(GROUP=event.top, PIXC=pixcho)
			maxpix = max(new_pixc)
                        minpix = min(new_pixc)
			junk = 0
			IF (tmpdata.det EQ 'C1' AND maxpix gt 8) OR $
			   (tmpdata.det EQ 'C2' AND maxpix gt 3) OR $
			   (tmpdata.det EQ 'SS' AND maxpix gt 127) OR $
			   (tmpdata.det EQ 'SL' AND maxpix gt 127) OR $
			   (minpix lt 0)  THEN BEGIN
		    		XDISPLAYFILE, "", $
                    		GROUP = event.top, $
                    		TITLE = "Warning ", $
                    		WIDTH = 30, $
                    		HEIGHT = 6, $
                    		TEXT = [" Your pixel choice is not valid ", $
                                        " and will not be taken "]
		                junk = 1
			ENDIF
			IF junk NE 1 THEN BEGIN  			
			 FOR I=0,NVIEWS-1 DO BEGIN
			  IF new_pixc(i) NE old_pixcho(i) THEN BEGIN
			    pixcho(i) = new_pixc(i)
			    WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
			    view(i).windownum = temp
			    pia_resetview6, i, view(i).controlid
                            IF STRMID(tmpdata.det,0,1) EQ 'C' THEN BEGIN
                              txtval = cmap_wind_text(i)
                              junk = where(new_pixc eq old_pixcho(i), count)
                              IF count EQ 0 THEN $
                                 WIDGET_CONTROL, pixbut(old_pixcho(i)), $
                                        SET_VALUE = ' '
                              WIDGET_CONTROL, pixbut(pixcho(i)), $
                                        SET_VALUE = txtval
                            ENDIF
                          ENDIF
			 ENDFOR
			ENDIF
          END

	  "PIXCHSER": BEGIN
			old_pixcho = pixcho
			new_pixc = old_pixcho + nviews
			CASE STRMID(tmpdata.det,0,2) OF
				'C1': npix = 9
				'C2': npix = 4
				'SL': npix = 64
				'SS': npix = 64
				'P1': RETURN
				'P2': RETURN
				'P3': RETURN
			ENDCASE  
			new_pixc = new_pixc mod npix
			
			FOR I=0,NVIEWS-1 DO BEGIN
			  IF new_pixc(i) NE old_pixcho(i) THEN BEGIN
			    pixcho(i) = new_pixc(i)
			    WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
			    view(i).windownum = temp
			    pia_resetview6, i, view(i).controlid
			    IF STRMID(tmpdata.det,0,1) EQ 'C' THEN BEGIN 
			      txtval = cmap_wind_text(i)
			      junk = where(new_pixc eq old_pixcho(i), count)
			      IF count EQ 0 THEN $
			         WIDGET_CONTROL, pixbut(old_pixcho(i)), $
					SET_VALUE = ' '
			      WIDGET_CONTROL, pixbut(pixcho(i)), $
					SET_VALUE = txtval
			    ENDIF 
                          ENDIF
			ENDFOR
          END

	  "PIXCHSERD": BEGIN
			old_pixcho = pixcho
			new_pixc = old_pixcho - nviews
			CASE STRMID(tmpdata.det,0,2) OF
				'C1': npix = 9
				'C2': npix = 4
				'SL': npix = 128
				'SS': npix = 128
				'P1': RETURN
				'P2': RETURN
				'P3': RETURN
			ENDCASE 
			ind=WHERE(new_pixc LT 0,nind)
			IF nind GT 0 THEN new_pixc(ind) = npix+new_pixc(ind)  
			
			FOR I=0,NVIEWS-1 DO BEGIN
			  IF new_pixc(i) NE old_pixcho(i) THEN BEGIN
			    pixcho(i) = new_pixc(i)
			    WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
			    view(i).windownum = temp
			    pia_resetview6, i, view(i).controlid
			    IF STRMID(tmpdata.det,0,1) EQ 'C' THEN BEGIN 
			      txtval = cmap_wind_text(i)
			      junk = where(new_pixc eq old_pixcho(i), count)
			      IF count EQ 0 THEN $
			         WIDGET_CONTROL, pixbut(old_pixcho(i)), $
					SET_VALUE = ' '
			      WIDGET_CONTROL, pixbut(pixcho(i)), $
					SET_VALUE = txtval
			    ENDIF 
                          ENDIF
			ENDFOR
          END

        "NVIEWS": BEGIN

                newviews = event.value + 1
		!PIA_NVIEWS = 1 > newviews < 4
                IF newviews NE nviews THEN BEGIN
                        WIDGET_CONTROL, aapdi1_wid, /DESTROY
                        pia_dispaap, NV = newviews, /redraw
                ENDIF
         END

       "HK" : begin
                get_pht_hk,tmpdata.admn,phtcs_redu
                xdisp_hk
              end


	ENDCASE
	
RETURN
END

; ****************************************************************************
;  PIA Dispaap - menu definition procedure
; ****************************************************************************

PRO pia_dispAAP, GROUP=group, DATA=DATA, NV = NV, REDRAW=redraw


COMMON pia_dispaap_cmn, tmpdata, aapps, view, viewsize, nviews, viewoptions, $
   overid, redflag 
COMMON pia_dspaap_flg_cmn, nflag_active, flag_active_lex, flag_active_label  
COMMON pia_dspch6_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON aapatt, dattext_id, newheader, chopcor_id
COMMON dspaap_widg, pixbut
COMMON aap_bckflag, bck_flag
COMMON aap_nacc, aap_disc, disc_set, astrflag, bck_sel 
COMMON pia_widget_info, extfil_wid, intfil_wid, buffil_wid, $
                        erddi1_wid, erddi2_wid, srddi1_wid, srddi2_wid, $
                        scpdi1_wid, scpdi2_wid, spddi1_wid, spddi2_wid, $
                        aapdi1_wid, aapdi2_wid
COMMON dispcust_cmn, psym, line

@phtaap
COMMON piaflag_info, piaflag_str

; If already registered, start second AAP display

        IF Xregistered("pia_dispaap") NE 0 THEN BEGIN
                pia_dis2aap, group=group, data=data
                RETURN
        END

        IF NOT KEYWORD_SET(redraw) THEN BEGIN
; load data from dynamical buffers into temporary structure
                aapps = data
		PIA_LOAD_IAAP, phtaap(aapps), tmpdata 
; set selection and vignetting correction to not in the beginning
		disc_set = 1
; look if astronomical coordinates are present
		ind = WHERE(tmpdata.dec NE -99, n)
		IF n GT 0 THEN astrflag = 1 ELSE astrflag = 0
; header into temporary header variable
		newheader = tmpdata.hdr
        ENDIF

; initialize views and pixels chosen

        IF KEYWORD_SET(NV) THEN NVIEWS = nv ELSE nviews = !PIA_NVIEWS
        IF nviews GT 4 THEN nviews = 4
        pixcount = -1


	IF N_ELEMENTS(psym) EQ 0 THEN psymch = 4 ELSE $
		psymch = psym	

	CASE STRMID(tmpdata.det, 0,1) of 
          'P': BEGIN 
		pixcho = [0,0,0,0]
		flux_label = '[Jy]'
	  END
          ELSE: BEGIN  
	         CASE STRMID(tmpdata.det,0,2) of
	           'C1': BEGIN
			pixcho = [0,2,4,6]
			flux_label = '[Jy / beam]'
		   END
	           'C2': BEGIN
			pixcho = [1,2,3,0]
			flux_label = '[Jy / beam]'
		   END
	           'SS': BEGIN
			pixcho = [0,20,40,63]
			flux_label = '[Jy]'
		   END
	           'SL': BEGIN
			pixcho = [0,20,40,63]
			flux_label = '[Jy]'
		   END
		  ELSE: BEGIN
			pixcho = [10,40,90,120]
			flux_label = '[Jy]'
		   END
	 	  ENDCASE		
	  END
        ENDCASE

	indflag_active = WHERE(piaflag_str.aap.lex NE 'DUMMY',nflag_active)
	
	nflag_active = nflag_active +1
	
	flag_active_lex = ['ENCODE',piaflag_str.aap.lex(indflag_active)]
	flag_active_label = ['Encode',piaflag_str.aap.expla(indflag_active)]

	viewsize = 220
	xsize = viewsize * 4 / nviews
	ysize = viewsize

	;structure for each view
	viewinstance = {        viewtype:0b, 		$	
				viewtype_sub:0b, 	$       
				controlid:0L,		$       
				windowid:0L,		$
				windownum:0}	

        view = REPLICATE(viewinstance, NVIEWS)		; array of view struct.

        IF STRMID(tmpdata.det, 0,1) eq 'P' THEN $
                FOR i=0,nviews-1 DO view(i).viewtype = i

	instance = {viewname:'',viewid:0, viewxlab:'',viewylab:'',  $
		viewmenu:0, viewmenuchoi:0,viewmenulabel:STRARR(nflag_active) }
	NVIEWOPTS = 15                           	

	viewoptions = REPLICATE(instance, NVIEWOPTS)    

	viewoptions(0).viewname = "Mean Flux Density   "+ flux_label 
	viewoptions(0).viewid = 0
	viewoptions(0).viewylab = "Mean Flux Density   "+ flux_label
	viewoptions(0).viewxlab = "Time       [s]"
	viewoptions(1).viewname = "Median Flux Density   "+ flux_label 
	viewoptions(1).viewid = 1
	viewoptions(1).viewylab = "Median Flux Density   "+ flux_label
	viewoptions(1).viewxlab = "Time       [s]"
	viewoptions(2).viewname = "First Quartile Flux Density"+ flux_label 
	viewoptions(2).viewid = 2
	viewoptions(2).viewylab = "First Quartile Flux Density"+ flux_label
	viewoptions(2).viewxlab = "Time       [s]"
	viewoptions(3).viewname = "Third Quartile Flux Density"+ flux_label 
	viewoptions(3).viewid = 3
	viewoptions(3).viewylab = "Third Quartile Flux Density"+ flux_label
	viewoptions(3).viewxlab = "Time       [s]"
	viewoptions(4).viewname = "Mean Surface Brightness  [MJy/sr]" 
	viewoptions(4).viewid = 4
	viewoptions(4).viewylab = "Mean Surface Brightness    [MJy/sr]"
	viewoptions(4).viewxlab = "Time       [s]"
	viewoptions(5).viewname = "Median Surface Brightness  [MJy/sr]" 
	viewoptions(5).viewid = 5
	viewoptions(5).viewylab = "Median Surface Brightness    [MJy/sr]"
	viewoptions(5).viewxlab = "Time       [s]"
	viewoptions(6).viewname = "First Quartile Surface Brightness  [MJy/sr]" 
	viewoptions(6).viewid = 6
	viewoptions(6).viewylab = "First Quartile Surface Brightness  [MJy/sr]"
	viewoptions(6).viewxlab = "Time       [s]"
	viewoptions(7).viewname = "Third Quartile Surface Brightness  [MJy/sr]" 
	viewoptions(7).viewid = 7
	viewoptions(7).viewylab = "Third Quartile Surface Brightness  [MJy/sr]"
	viewoptions(7).viewxlab = "Time       [s]"
	viewoptions(8).viewname = "Flag   "
	viewoptions(8).viewid = 8
        viewoptions(8).viewmenu = 1
        viewoptions(8).viewmenuchoi = nflag_active
        viewoptions(8).viewmenulabel = flag_active_label
	viewoptions(8).viewylab = "Flag Value"
	viewoptions(8).viewxlab = "Time       [s]"
	viewoptions(9).viewname = "Chopper Position"
	viewoptions(9).viewid = 9
	viewoptions(9).viewylab = "Chopper position      [arcsec]"
	viewoptions(9).viewxlab = "Time       [s]"
	viewoptions(10).viewname = "Raster Point ID"
	viewoptions(10).viewid = 10
        viewoptions(10).viewmenu = 1
        viewoptions(10).viewmenuchoi = 2
        viewoptions(10).viewmenulabel = ['1','2']
	viewoptions(10).viewylab = "Raster Point ID "
	viewoptions(10).viewxlab = "Time       [s]"
	viewoptions(11).viewname = "Declination   "
	viewoptions(11).viewid = 11
	viewoptions(11).viewylab = "Declination   "
	viewoptions(11).viewxlab = "Time       [s]"
	viewoptions(12).viewname = "Right Ascension"
	viewoptions(12).viewid = 12
	viewoptions(12).viewylab = "Right Ascension"
	viewoptions(12).viewxlab = "Time       [s]"
	viewoptions(13).viewname = "Dec per point "
	viewoptions(13).viewid = 13
	viewoptions(13).viewylab = "Dec per point "
	viewoptions(13).viewxlab = "Time       [s]"
	viewoptions(14).viewname = "RA per point"
	viewoptions(14).viewid = 14
	viewoptions(14).viewylab = "RA per point"
	viewoptions(14).viewxlab = "Time       [s]"


; top base

	aapdi1_wid = WIDGET_BASE( TITLE="PIA AAP Data Display", /COLUMN, $
				XPAD = 20, YPAD = 20, SPACE = 20)

; control windows

	control = WIDGET_BASE(aapdi1_wid, /ROW)

	control_exit = WIDGET_BUTTON(control, VALUE="    Exit    ",$
					 /ALIGN_CENTER, /MENU)
	save_quit = WIDGET_BUTTON(control_exit, $
		VALUE="Save modified measurement into buffer and Quit",$
					 UVALUE="SAVEXIT")
	simple_quit = WIDGET_BUTTON(control_exit, $
		VALUE="Quit without saving modified measurement into buffer",$
					 UVALUE="EXIT")
	control_help = WIDGET_BUTTON(control, VALUE="    Help    ",$
					 /ALIGN_CENTER, UVALUE="HELP")
	control_cust = WIDGET_BUTTON(control, VALUE="  Customize ",$
					 /ALIGN_CENTER, UVALUE="CUST")


	junk = WIDGET_LABEL(control, VALUE = '      ')

	obj = FXPAR(tmpdata.hdr,'OBJECT')
	attra = FXPAR(tmpdata.hdr,'ATTRA')
	attdec = FXPAR(tmpdata.hdr,'ATTDEC')
	decode_admn, tmpdata.admn, dattext
	more_text = 'OBJ:' + obj + ' ' + give_sradec(attra, attdec)
	dattext = 'AAP '+dattext+ ' - '+tmpdata.admn+ ' - ' + more_text

	dattext_id = WIDGET_LABEL(control, VALUE = dattext)  

;------------------- the C mapping windows -------------------------

        junk = WIDGET_LABEL(control, VALUE = '     ')

        IF STRMID(tmpdata.det, 0,1) eq 'C' THEN BEGIN

        pixver = WIDGET_BASE(control, /COLUMN)
	junk = WIDGET_LABEL(pixver, VALUE='^ +Z')

        pixhor = WIDGET_BASE(pixver,/ROW)

          IF STRMID(tmpdata.det, 1,1) eq '1' THEN BEGIN
                pixbut = lonarr(9)
                FOR i=0,2 DO pixbut(i*3+2) = $
                        WIDGET_BUTTON(pixhor, VALUE=' ',$
                                XOFFSET=3*i, $,
                                UVALUE=i*3+2,$
                                EVENT_PRO = 'pixbutevent6')
                pixhor = WIDGET_BASE(pixver,/ROW,YOFFSET=10)
                FOR i=0,2 DO pixbut(i*3+1) = $
                        WIDGET_BUTTON(pixhor, VALUE=' ',$
                                XOFFSET=3*i, $
                                UVALUE=i*3+1,$
                                EVENT_PRO = 'pixbutevent6')
                pixhor = WIDGET_BASE(pixver,/ROW,YOFFSET=10)
                FOR i=0,2 DO pixbut(i*3) = $
                        WIDGET_BUTTON(pixhor, VALUE=' ',$
                                XOFFSET=3*i, $
                                UVALUE=i*3,$
                                EVENT_PRO = 'pixbutevent6')
          ENDIF ELSE $
          IF STRMID(tmpdata.det, 1,1) eq '2' THEN BEGIN
                pixbut = lonarr(4)
                FOR i=0,1 DO pixbut(i+2) = $
                        WIDGET_BUTTON(pixhor, VALUE=' ',$
                                XOFFSET=3*i, $
                                UVALUE=i+2,$
                                EVENT_PRO = 'pixbutevent6')
                pixhor = WIDGET_BASE(pixver,/ROW,YOFFSET=10)
                FOR i=1,0,-1 DO pixbut(i) = $
                        WIDGET_BUTTON(pixhor, VALUE=' ',$
                                XOFFSET=3*i, $
                                UVALUE=i,$
                                EVENT_PRO = 'pixbutevent6')
          ENDIF
	junk = WIDGET_LABEL(pixhor, VALUE='> +Y')
        ENDIF

;----------------- the View windows are defined ------------------

	viewbase = WIDGET_BASE(aapdi1_wid, /ROW, SPACE=1)

	viewstorageids = LONARR(NVIEWS)
	overid = lonarr(NVIEWS)	   

	cmap_wind_text=["A","B","C","D"]
	
        FOR viewindex = 0, NVIEWS - 1 DO BEGIN
	  viewbase_sub = WIDGET_BASE(viewbase, /FRAME, /COLUMN)
	  junk = WIDGET_LABEL(viewbase_sub, $
	       VALUE="Window "+cmap_wind_text(viewindex))
	  tempbase = WIDGET_BASE(viewbase_sub, /COLUMN, $
				EVENT_PRO = 'viewevent6')
	  view(viewindex).controlid = WIDGET_BUTTON(tempbase, VALUE="   ",$
				MENU = 2, UVALUE = viewindex, $
				EVENT_PRO = 'viewevent6')
	  view(viewindex).windowid = WIDGET_DRAW(tempbase, $
				XSIZE = xsize, YSIZE = ysize, $
				RETAIN = 2) 
		FOR i = 0, NVIEWOPTS - 1 DO BEGIN
     			dummy = WIDGET_BUTTON(view(viewindex).controlid, $
                	VALUE = viewoptions(i).viewname, $
                	UVALUE = viewoptions(i).viewid,                    $
			MENU=viewoptions(i).viewmenu)
			IF viewoptions(i).viewmenu THEN BEGIN
			   FOR ichoi=0,viewoptions(i).viewmenuchoi-1 DO    $
			   dummy1 = WIDGET_BUTTON(dummy,                   $
			     VALUE=viewoptions(i).viewmenulabel(ichoi),    $
			     UVALUE=ichoi)
			ENDIF
		ENDFOR

	  zoombase = WIDGET_BASE(tempbase, /FRAME, /ROW)

          zoom = WIDGET_BUTTON(zoombase, $
                        VALUE = "Zoom & Print", $
                        UVALUE = viewindex, MENU = 2)

          dummy = WIDGET_BUTTON(zoom, $
                        VALUE = "New Plot", $
                        UVALUE = viewindex, EVENT_PRO = 'zoomevent6')


          synch = WIDGET_BUTTON(zoom, $
                        VALUE = "Overplot, same y-axis  ", $
                        UVALUE = viewindex, EVENT_PRO = 'zoomsync6')
          nsynch = WIDGET_BUTTON(zoom, $
                        VALUE = "Overplot, new y-axis", $
                        UVALUE = viewindex, EVENT_PRO = 'zoomnsync6')


          process = WIDGET_BUTTON(zoombase, $
                        VALUE = "Test processing", $
                        UVALUE = viewindex, MENU = 2)

          fourier = WIDGET_BUTTON(process, $
                        VALUE = "Fourier", $
                        UVALUE = viewindex, EVENT_PRO = 'zoomfourier6')

          aver = WIDGET_BUTTON(process, $
                        VALUE = "Average", $
                        UVALUE = viewindex, MENU = 2)

          average = WIDGET_BUTTON(aver, $
                        VALUE = "Chopper ", $
                        UVALUE = viewindex, EVENT_PRO = 'averagechop6')

          average = WIDGET_BUTTON(aver, $
                        VALUE = "Non-Chopper", $
                        UVALUE = viewindex, EVENT_PRO = 'averagenonch6')

          medi = WIDGET_BUTTON(process, $
                        VALUE = "Median", $
                        UVALUE = viewindex, MENU = 2)

          median = WIDGET_BUTTON(medi, $
                        VALUE = "Chopper", $
                        UVALUE = viewindex, EVENT_PRO = 'medianchop6')

          median = WIDGET_BUTTON(medi, $
                        VALUE = "Non-Chopper", $
                        UVALUE = viewindex, EVENT_PRO = 'mediannonch6')


        ENDFOR

	controlbase = WIDGET_BASE(aapdi1_wid, $
                /ROW, $
                SPACE = 40)


;----------------- the Data controls are defined ------------------

        datcont = WIDGET_BUTTON(controlbase, VALUE=' Data ', /MENU )
        id_2 = WIDGET_BUTTON(datcont, VALUE='Load', UVALUE='LOAD' )
        id_2 = WIDGET_BUTTON(datcont, VALUE='Save', /MENU )
        id_3 = WIDGET_BUTTON(id_2, VALUE='to AAP buffer', /MENU )
        id_4 = WIDGET_BUTTON(id_3, VALUE='new measurement', $
				 UVALUE='SAVEBUFF_NEW' )
        id_4 = WIDGET_BUTTON(id_3, VALUE='same measurement', $
				 UVALUE='SAVEBUFF' )
        id_3 = WIDGET_BUTTON(id_2, VALUE='to PIA internal file ', $
				UVALUE='SAVEI' )
        id_3 = WIDGET_BUTTON(id_2, VALUE='to FITS external file ', $
				UVALUE='SAVEF' )
        id_3 = WIDGET_BUTTON(id_2, VALUE='to special PHT-S FITS ', $
				UVALUE='SAVEF_S' )
	IF STRMID(tmpdata.det,0,1) NE 'S' THEN $
	   WIDGET_CONTROL, id_4, sensitive=0
        ;id_2 = WIDGET_BUTTON(datcont, VALUE='Print AAP Values', UVALUE='PRINT' )
        id_2 = WIDGET_BUTTON(datcont, VALUE='Print Flux Values', $\
        	UVALUE='PRINT_FLUX' )
        id_2 = WIDGET_BUTTON(datcont, VALUE='Show Data', UVALUE='SHOWD' )

;---------------- the Selection controls are defined -----------------

;        selcont = WIDGET_BUTTON(controlbase, VALUE='Selection', /MENU )
;        id_2 = WIDGET_BUTTON(selcont, VALUE='Discard Chopper Plateaux', $
;				UVALUE='SLDISC')
;        id_2 = WIDGET_BUTTON(selcont, VALUE='Select background region', $
;				UVALUE='BCKSEL_ALLP')

;---------------- the Correction controls are defined -----------------

        corrcont = WIDGET_BUTTON(controlbase, VALUE='Corrections', /MENU )
	id_2 = WIDGET_BUTTON(corrcont, VALUE=' Assign Astr. Coordinates',$
			UVALUE='ASTRO')
	id_chopcor = WIDGET_BUTTON(corrcont, $
	   VALUE=' Signal losses in Chopped meas. ',UVAL='CHOPFREQ')
; Correction Signal losses in chopped measurements can be 
	res = fxpar(tmpdata.hdr, 'PRC_SUBT', count=count)
	res = fxpar(tmpdata.hdr, 'PRD_SUBT', count=count2)
	count = count + count2
	IF count NE 1 THEN WIDGET_CONTROL, id_chopcor, SENSITIVE=0     $ 
    		ELSE WIDGET_CONTROL, id_chopcor, SENSITIVE=1

 	id_2 = WIDGET_BUTTON(corrcont, $
	   VALUE='Flat fielding: median filtering + background', /MENU)
	id_3 = WIDGET_BUTTON(id_2, VALUE='Use mean brightness',$   
			UVALUE='MEDFILT_MNBR')
	id_3 = WIDGET_BUTTON(id_2, VALUE='Use mean flux',$   
			UVALUE='MEDFILT_MNFL')
	id_3 = WIDGET_BUTTON(id_2, VALUE='Use median brightness',$   
			UVALUE='MEDFILT_MDBR')
	id_3 = WIDGET_BUTTON(id_2, VALUE='Use median flux',$   
			UVALUE='MEDFILT_MDFL')
	
 	id_2 = WIDGET_BUTTON(corrcont, $
	   VALUE='Flat fielding: normalizing with 1st quartile', /MENU)
	id_3 = WIDGET_BUTTON(id_2, VALUE='Use mean brightness',$   
			UVALUE='FQ_MNBR')
	id_3 = WIDGET_BUTTON(id_2, VALUE='Use mean flux',$   
			UVALUE='FQ_MNFL')
	id_3 = WIDGET_BUTTON(id_2, VALUE='Use median brightness',$   
			UVALUE='FQ_MDBR')
	id_3 = WIDGET_BUTTON(id_2, VALUE='Use median flux',$   
			UVALUE='FQ_MDFL')
	
	id_2 = WIDGET_BUTTON(corrcont, $
	   VALUE='PHT-S Pointing correction', UVALUE='SOFF') 
	IF STRMID(tmpdata.det,0,1) NE 'S' THEN WIDGET_CONTROL, id_2, sensitive=0

;---------------- the View controls are defined -----------------

        viewcont = WIDGET_BUTTON(controlbase, VALUE='View', /MENU )
        id_2 = WIDGET_BUTTON(viewcont, VALUE='Header Info ', UVALUE='HDR')
        id_2 = WIDGET_BUTTON(viewcont, VALUE='Compact Status ', UVALUE='CS')
        cont2 = WIDGET_BUTTON(viewcont, VALUE='Auxiliary Files', /MENU )
        id_2 = WIDGET_BUTTON(cont2, VALUE='IS Report ', UVALUE='ISREP')
        id_2 = WIDGET_BUTTON(cont2, VALUE='OLP Report ', UVALUE='OLREP')
        id_2 = WIDGET_BUTTON(cont2, VALUE='EOHA ', UVALUE='EOHA')
        id_2 = WIDGET_BUTTON(cont2, VALUE='EOHI ', UVALUE='EOHI')

;---------------- the Array controls are defined -----------------

        arrcont = WIDGET_BUTTON(controlbase, VALUE='Array', /MENU )

        id_1 = WIDGET_BUTTON(arrcont, VALUE=' Images ', UVALUE='IMAGE')
        IF STRMID(tmpdata.det,0,1) NE 'C' THEN $
                        WIDGET_CONTROL, id_1, SENSITIVE=0

        id_1 = WIDGET_BUTTON(arrcont, VALUE=' Spectra ', /MENU)
        IF STRMID(tmpdata.det,0,1) NE 'S' THEN $
                        WIDGET_CONTROL, id_1, SENSITIVE=0
        id_2 = WIDGET_BUTTON(id_1, VALUE=' Flux Density ', /MENU)
        id_3 = WIDGET_BUTTON(id_2, VALUE=' New ', UVALUE='JSPECT')
        id_3 = WIDGET_BUTTON(id_2, VALUE=' Overplot ', /MENU)
        id_4 = WIDGET_BUTTON(id_3, VALUE=' Synchronized ', UVALUE='JSPESY')
        id_4 = WIDGET_BUTTON(id_3, VALUE=' Not Synchronized ', UVALUE='JSPENSY')
        id_2 = WIDGET_BUTTON(id_1, VALUE=' Surface Brightness ', /MENU)
        id_3 = WIDGET_BUTTON(id_2, VALUE=' New ', UVALUE='MJSPECT')
        id_3 = WIDGET_BUTTON(id_2, VALUE=' Overplot ', /MENU)
        id_4 = WIDGET_BUTTON(id_3, VALUE=' Synchronized ', UVALUE='MJSPESY')
        id_4 = WIDGET_BUTTON(id_3, VALUE=' Not Synchronized ', UVALUE='MJSPENSY')

        id_2 = WIDGET_BUTTON(arrcont, VALUE='Time evolution', /MENU)
        IF STRMID(tmpdata.det,0,1) EQ 'P' THEN $
                        WIDGET_CONTROL, id_2, SENSITIVE=0
        id_3 = WIDGET_BUTTON(id_2, VALUE='Time slices ', UVALUE='SLICES')
        id_3 = WIDGET_BUTTON(id_2, VALUE='3-D view ', UVALUE='SLICES_3D')

;---------------- the Processing controls are defined -----------------

        proccont = WIDGET_BUTTON(controlbase, VALUE='Process', $
                                /MENU )
        ;id_2 = WIDGET_BUTTON(proccont, VALUE=' Extract Flux Density ', $
	;		UVALUE='FLUXDENS')

        id_2 = WIDGET_BUTTON(proccont, VALUE=' Fit 2-dim Gaussian ', $
			UVALUE='FITGAUS')
WIDGET_CONTROL, id_2, SENSITIVE=0

; Background subtraction 
        id_2 = WIDGET_BUTTON(proccont, VALUE=' Background Subtraction', $
                               /MENU)
; within this measurement only possible if several chopper steps present
; which are not P32 !
        id_subtr = WIDGET_BUTTON(id_2, VALUE='within measurement ', $
                               UVALUE='BCKSBT')
        inda = WHERE(tmpdata.cstp EQ 2, nrstp)

	aot = STRTRIM(fxpar(tmpdata.hdr, 'EOHAAOTN'),2)
        IF nrstp EQ 0 OR aot EQ 'P32' THEN WIDGET_CONTROL, id_subtr, SENSITIVE=0

        id_3 = WIDGET_BUTTON(id_2, VALUE='another measurement ', $
                               UVALUE='BCKSBT_MEAS')
; Concatenate measurements 
        id_2 = WIDGET_BUTTON(proccont, VALUE=' Concatenate with a measurement', $
                              /MENU)
        id_3 = WIDGET_BUTTON(id_2, VALUE=' as given ', $
                               UVALUE="GLUEMEAS")
        id_3 = WIDGET_BUTTON(id_2, VALUE=' using median normalization by', $
                               /MENU)
	id_4 = WIDGET_BUTTON(id_3, VALUE='mean brightness',$   
			UVALUE='GLUEMEAS_MNBR')
	id_4 = WIDGET_BUTTON(id_3, VALUE='mean flux',$   
			UVALUE='GLUEMEAS_MNFL')
	id_4 = WIDGET_BUTTON(id_3, VALUE='median brightness',$   
			UVALUE='GLUEMEAS_MDBR')
	id_4 = WIDGET_BUTTON(id_3, VALUE='median flux',$   
			UVALUE='GLUEMEAS_MDFL')
        
;---------------- the Pixel Choice controls are defined -----------------

        pixcont = WIDGET_BUTTON(controlbase, VALUE='Pixels Choice', $
				/MENU)
        pixch = WIDGET_BUTTON(pixcont, VALUE=' Individual choice ', $
				UVALUE='PIXCH' )
        pixch = WIDGET_BUTTON(pixcont, VALUE=' Serial increment  ', $
				UVALUE='PIXCHSER' )
        pixch = WIDGET_BUTTON(pixcont, VALUE=' Serial decrement  ', $
				UVALUE='PIXCHSERD' )
        IF STRMID(tmpdata.det,0,1) EQ 'P' THEN $
        	WIDGET_CONTROL, pixcont, SENSITIVE=0

;---------------- the number of views controls is defined -----------------

        nvbut = cw_bselector(controlbase, $
                        /FRAME, SET_VALUE=NVIEWS-1, $
                        UVALUE = 'NVIEWS', $
                        ['1 Plot', $
                        '2 Plots', $
                        '3 Plots', $
                        '4 Plots'])

;----------------------------------------------------------------------

       hkbutton=widget_button(controlbase,value=' HK ', uvalue ='HK')

;----------------------------------------------------------------------

; Look into the selection criteria

 
        get_spddisc, tmpdata, /ENCODE_FLAG
	get_validflag, tmpdata.flag, 'AAP', redflag, $
			  det=tmpdata.det, /allpix
        aap_disc = redflag
        disc_set = 1
	

        bck_sel = 0

; Realize widget

	ids = {id_subtr:id_subtr, id_chopcor:id_chopcor}	
;	ids = {id_chopcor:id_chopcor}	
	WIDGET_CONTROL, aapdi1_wid, /REALIZE, /HOURGLASS, SET_UVALUE=ids


	FOR i = 0, nviews - 1 DO BEGIN
		WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
		view(i).windownum = temp
		pia_resetview6, i, view(i).controlid
           IF STRMID(tmpdata.det,0,1) EQ 'C' THEN BEGIN
	  	txtval = cmap_wind_text(i)               
                WIDGET_CONTROL, pixbut(pixcho(i)), SET_VALUE = txtval
           ENDIF
	ENDFOR

	xMANAGER,No_BLOCK=1, "pia_dispaap", aapdi1_wid, $
		EVENT_HANDLER = "pia_daap_event", GROUP_LEADER=GROUP


	RETURN
END
