;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_DISPCUST
;
; PURPOSE:
;	Menu for PIA drawing customization.
;	This is a display dependant level menu in the PIA hierarchy.
;
;	This routine should only be called by the PIA display menues
;	and should not be called directly from the command line.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_DISPCUST
;
; KEYWORD PARAMETERS:
;	GROUP:	The group leader of the widget hirarchy
;	
; COMMON BLOCKS:
;	dispcust_cmn (internal)
;
; PROCEDURES USED:
;       INTERNAL:
;		pia_dispcust_event
;	
; MODIFICATION HISTORY:
;	Written by C.Gabriel (ESA/ESTEC)		August 1994
;	Oct 95 Version 3.5
;	Extension for new symbols (CG)			November 1995
;	Avoiding crashes if no selection (CG)		February 1996
;	Choice of lines taken out (CG)			May 1996
;	/Modal use according to IDL >=5.0 (CG)		January 1999
;	V7.3
;			
;-

; ****************************************************************************
;  Event handling routine for PIA pixels selection 
; ****************************************************************************

PRO pia_dispcust_event, event

COMMON dispcust_cmn, psymch, linech

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue OF

          'ACCEPT': BEGIN
		
		IF N_ELEMENTS(psymch) EQ 0 THEN psymch = 4
                WIDGET_CONTROL, event.top, /DESTROY

          END

          'CANCEL': BEGIN

		IF N_ELEMENTS(psymch) EQ 0 THEN psymch = 4
                WIDGET_CONTROL, event.top, /DESTROY

          END

	  'SYMB': BEGIN
			psymch = event.index
			IF psymch GT 8 THEN BEGIN
				makesym, psymch
				psymch = 8
			ENDIF
			IF N_ELEMENTS(linech) EQ 1 AND linech GT -1 THEN $
				psymch = -(abs(psymch))
 	  END

	  'LINE': BEGIN
                        linech = event.index - 1
                        IF linech EQ -1 THEN psymch = abs(psymch)
 	  END
       	ENDCASE
	RETURN
END

; ****************************************************************************
;  PIA dispcust - menu definition procedure
; ****************************************************************************

PRO pia_dispcust, GROUP=group

COMMON dispcust_cmn, psymch, linech
	
        symbols = ['None','Plus','Asterisk','Dot','Diamond','Triangle',$
                   'Square','X','Histogram','Circle','Filled Circle',  $
                   'Filled Diamond', 'Filled Triangle', 'Filled Square', $
                   'Star','Filled Star','Pentagon','Filled Pentagon', $
                   'Hexagon','Filled Hexagon']

        linestyles = ['None','Solid','Dotted','Dashed','Dash-Dot',$
                      'Dash-Dot-Dot-Dot','Long Dashes']

	IF N_ELEMENTS(linech) EQ 0 THEN linech = -1

	dispbase = WIDGET_BASE(TITLE = 'PIA Symbol Choice Menu', XSIZE=150, $ 
		 		/COLUMN, /modal, group=group)


	junkbase = WIDGET_BASE(dispbase, /ROW)

	symb_id = WIDGET_LIST(junkbase, VALUE=symbols, UVALUE='SYMB', $
				XSIZE=20, YSIZE=8)


        control = WIDGET_BASE(dispbase,/ROW)

        accept = WIDGET_BUTTON(control, VALUE = '  OK  ', $
                        /FRAME, UVALUE = 'ACCEPT')
        cancel = WIDGET_BUTTON(control, VALUE = '  Cancel  ', $
                        /FRAME, UVALUE = 'CANCEL')

        WIDGET_CONTROL, dispbase, /REALIZE, TLB_SET_XOFFSET=150, $
                        TLB_SET_YOFFSET=150

        xMANAGER,No_BLOCK=1, "pia_dispcust", dispbase, GROUP=group
	
RETURN
END

