;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_DISPDATA
;
; PURPOSE:
;	PIA Data display menu selector.
;	Calls the display menu corresponding to the data level (ftype)
;	passing the internal measurement name (filename)
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_dispdata, filename, ftype [,tmppos=tmppos] 
;
; INPUTS:
;	filename: internal name (*.admn) of the chosen measurement
;	ftype: 	  data level type  
;	
; KEYWORD PARAMETERS:
;	tmppos:	Exact position within the array of dynamical structures
;	GROUP:	The widget ID of the group leader of the widget.  If this 
;		keyword is specified, the death of the group leader results in
;		the death of PIA_disp_print_file.
;
; COMMON BLOCKS:
;	adm
;	phtcs
;	phterd
;	phtscp
;	phtsmc
;	phtspd
;	phtsrd
;	pia_dspcho_cmn (internal)
;
; PROCEDURES USED:
;	PIA LIB:
;		pia_disperd
;		pia_dispscp
;		pia_dispspd
;		pia_dispsrd
;		pia_multmeas
;		pia_sm
;		pia_sm_dispsmc
;
; MODIFICATION HISTORY:
;	Written by: Carlos GABRIEL (ESA/ESTEC)			July 1994
;	Modified (last) by SB					October 1996
;	V5.x
;	tmppos keyword added (CG)				May 1997
;	V6.3
;	Calling sequence to pia_dispsrd, pia_dispscp, 
;	 pia_dispspd  (JAc)					October 1997
;	V6.6
;	
;			
;-
; *********************************************************************
; * 
; *
; *
; *********************************************************************
PRO pia_dispdata, filename, ftype, GROUP=group, tmppos=tmppos
@adm
@phterd
@phtsrd
@phtsmc
@phtscp
@phtspd
@phtaap
@phtcla
@phtcs
COMMON pia_dspcho_cmn, pixcho, pixop, pixres, psymch, pixcount

        ON_ERROR, 2

;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 2 THEN MESSAGE, $
          'Syntax:  PIA_DISP_DATA, NAME, TYP'

	ftype = STRTRIM(ftype(0),2)
	filename = STRTRIM(filename(0),2)

	CASE ftype of

 	 'ERD': BEGIN
		IF KEYWORD_SET(tmppos) THEN BEGIN
		   PIA_DISPERD, DATA=tmppos, $
				NV=!PIA_NVIEWS, GROUP=group
		
		ENDIF ELSE BEGIN
		 datind = WHERE(phterd.admn eq filename, count)
		 IF count EQ 0 THEN $
			MESSAGE, /INFO, 'Measurement not found!'
		 IF count GT 1 THEN BEGIN
			measlist = phterd(datind).admn
                        pia_multmeas, measlist

			datind = datind(measlist)
		 ENDIF

                 IF count NE 0 THEN  $
			PIA_DISPERD, DATA=datind(0), $
				NV=!PIA_NVIEWS, GROUP=group
		ENDELSE
	 END

 	 'SRD': BEGIN
 	  

		IF KEYWORD_SET(tmppos) THEN BEGIN
		   PIA_DISPSRD, DATA=tmppos, $
				NV=!PIA_NVIEWS, GROUP=group
		
		ENDIF ELSE BEGIN

		 datind = WHERE(phtsrd.admn eq filename, count)
		 IF count EQ 0 THEN $
			MESSAGE, /INFO, 'Measurement not found!'
		 IF count GT 1 THEN BEGIN
			measlist = phtsrd(datind).admn
                        pia_multmeas, measlist

			datind = datind(measlist)
		 ENDIF
                 IF count NE 0 THEN  $
			PIA_DISPSRD, DATA=datind(0), $
				NV=!PIA_NVIEWS, GROUP=group
		ENDELSE
	 END

         'SMC': BEGIN
 
		IF KEYWORD_SET(tmppos) THEN BEGIN
		   PIA_SM_DISPSMC, DATA=phtsmc(tmppos), $
				NV=!PIA_NVIEWS, GROUP=group
		
		ENDIF ELSE BEGIN

                 datind = WHERE(phtsmc.admn eq filename, count)
                 IF count EQ 0 THEN $
                        MESSAGE, /INFO, 'Measurement not found!'
 
                 IF count GT 1 THEN BEGIN
                        measlist = phtsmc(datind).admn
                        pia_multmeas, measlist
  
                        datind = datind(measlist)
                 ENDIF
 
                 IF count NE 0 THEN  $
                        PIA_SM_DISPSMC, DATA=phtsmc(datind(0)), $
                        	NV=!PIA_NVIEWS, GROUP=group
                ENDELSE
         END

 	 'SCP': BEGIN

		IF KEYWORD_SET(tmppos) THEN BEGIN
		   PIA_DISPSCP, DATA= tmppos, $
				NV=!PIA_NVIEWS, GROUP=group
		
		ENDIF ELSE BEGIN

		 datind = WHERE(phtscp.admn eq filename, count)
		 IF count EQ 0 THEN $
			MESSAGE, /INFO, 'Measurement not found!'

		 IF count GT 1 THEN BEGIN
			measlist = phtscp(datind).admn
                        pia_multmeas, measlist

			datind = datind(measlist) 
		 ENDIF

                 IF count NE 0 THEN  $
			PIA_DISPSCP, DATA= datind(0), $
				NV=!PIA_NVIEWS, GROUP=group
		ENDELSE
	 END

 	 'CLA': BEGIN

		IF KEYWORD_SET(tmppos) THEN BEGIN
		   PIA_DISPSCP, DATA= tmppos, $
				NV=!PIA_NVIEWS, GROUP=group, /CALA
		
		ENDIF ELSE BEGIN

		 datind = WHERE(phtcla.admn eq filename, count)
		 IF count EQ 0 THEN $
			MESSAGE, /INFO, 'Measurement not found!'

		 IF count GT 1 THEN BEGIN
			measlist = phtcla(datind).admn
                        pia_multmeas, measlist

			datind = datind(measlist) 
		 ENDIF

                 IF count NE 0 THEN  $
			PIA_DISPSCP, DATA= datind(0), GROUP=group, /cala
		ENDELSE
	 END

 	 'SPD': BEGIN

		IF KEYWORD_SET(tmppos) THEN BEGIN
		   PIA_DISPSPD, DATA= tmppos, $
				NV=!PIA_NVIEWS, GROUP=group
		
		ENDIF ELSE BEGIN

		 datind = WHERE(phtspd.admn eq filename, count)
		 IF count EQ 0 THEN $
			MESSAGE, /INFO, 'Measurement not found!'

		 IF count GT 1 THEN BEGIN
			measlist = phtspd(datind).admn
                        pia_multmeas, measlist

			datind = datind(measlist)
		 ENDIF

                 IF count NE 0 THEN  $
			PIA_DISPSPD, DATA= datind(0), $
				NV=!pia_NVIEWS, GROUP=group
		ENDELSE
	 END

 	 'AAP': BEGIN

		IF KEYWORD_SET(tmppos) THEN BEGIN
		   PIA_DISPAAP, DATA= tmppos, $
				NV=!PIA_NVIEWS, GROUP=group
		
		ENDIF ELSE BEGIN

		 datind = WHERE(phtaap.admn eq filename, count)
		 IF count EQ 0 THEN $
			MESSAGE, /INFO, 'Measurement not found!'

		 IF count GT 1 THEN BEGIN
			measlist = phtaap(datind).admn
                        pia_multmeas, measlist

			datind = datind(measlist)
		 ENDIF

                 IF count NE 0 THEN  $
			PIA_DISPAAP, DATA= datind(0), $
				NV=!pia_NVIEWS, GROUP=group
		ENDELSE
	 END

	'AAR':  XDISPLAYFILE, "", GROUP=group, $
                TITLE = "Measurement display on a different level ", $
                WIDTH = 60, $
                HEIGHT = 6, $
                TEXT = ["Astrophysical applications are accessed directly via",$
		   "a menu under Applications in top level window in which",$
		   "plotting is done according to the chosen intention. ", $
			" ", $
		   "Plotting of AA variables possible on SPD level I/F or",$
		   "using the 'Show Data Values' menu"]

         ELSE: MESSAGE, /INFO, 'Function not yet implemented!'

	ENDCASE

	RETURN
END
