;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_DISPERD
;
; PURPOSE:
;	Menu for PIA ERD Data display.
;	This is a fourth level menu in the PIA hierarchy.
;
;	This routine should only be called by the PIA Display Data routine
;	and should not be called directly from the command line.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_DISPERD
;
; KEYWORD PARAMETERS:
;	GROUP:	The group leader of the widget hirarchy
;	DATA:	An element of the PHTERD dynamical structure
;	NV:	Number of Views (1 <= NV <= 4)
;	REDRAW:	To redraw same data 
;	TMPSTR: To use instead of DATA a temporary structure
;	NEWH:	To use instead of tmpstr.hdr a different header
;	
; RESTRICTIONS:
;	DATA must be a valid element of PHTERD dynamical structure
;	
; COMMON BLOCKS:
;	adm
;	colour_indices
;	phtacc
;	phtcs
;	phterd
;	phtsrd
;	splitramp_par
;	pia_dsperd_cmn (internal)
;	pia_dspcho_cmn (internal)
;	dsperd_widg (internal)
;	pia_dspchz_cmn (internal)
;	pia_plot_over_cmn (internal)
;	tmpvalues (internal)
;	flg_acc (internal)
;	erdtext (internal)
;	dispcust_cmn (internal)
;	dsperd_widg (internal)
;	pia_widget_info (internal)
;		
; PROCEDURES USED:
;	PIA LIB:
;		decode_admn
;		get_convwh
;		get_pht_hk
;		get_rodisc
;		lin_voltages
;		pia_dis2erd
;		pia_disp_cs
;		pia_disp_hdr
;		pia_dispcust
;		pia_dispsrd
;		pia_load_ierd
;		pia_multchoice
;		pia_multmeas
;		pia_oplot
;		pia_pixchoice
;		pia_plot
;		pia_plot_over
;		pia_rodisc
;		pia_satlev
;		pia_showstr
;		pia_write_ierd
;		pia_xplot
;		pickmeas
;		process_tmperd
;		process_pixel
;		xdisp_hk
;       ASTRO LIB:
;		avg
;		fxpar
;		sigma
;       INTERNAL:
;	 	pixbutevent
;		viewevent
;		fitram1
;	 	fitram2
;	 	fitram3
;	 	fitramps
;		fitrams
;	 	process_pixel
;	 	averageevent
;	 	medianevent
;	 	zoomevent
;	 	zoomfourier
;	 	zoomsync
;	 	zoomnsync
;	 	zoomit
;	 	pia_resetview
;	 	pia_derd_event
;
; MODIFICATION HISTORY:
;	Written by: C.Gabriel (ESA/ESTEC)		June 1994
;	Modified (last) by: cg				October 1996
;	Full TDT Housekeeping data access added	(CG)	April 1997
;	V6.2
;	Graphical signal discarding added +
;	 saving internal file upgraded  + 
;	 ramp subdivision using CB splitramp_par & testing included +
;	 direct discrimination for measurement selection +
;	 keywords TMPSTR and NEWH added +
;	 auxiliary files display added (EOH*, OLR) (CG) May 1997	
;	V6.3
;	Allowing for graph. multi de(re)-selection (CG)	September 1997 
;	V6.5
;	Using process_tmperd instead of process_erd, 
;	 pairdeglitching added (CG)			November 1997
;       Change the calling sequence to pia_dispsrd (JA) October 1997
;	V6.6
;	Widget problem (INT instead of LON) fixed (CG)	February 1999
;	Display of decoded pia flags included (JA)	June 1999
;	V7.4
;	Extension of "pattern proc" to sawtooth (CG) +	July 1999
;	Wrong initialisation for 2-Thr. Degl fixed (CG)
;	V8.0
;	Exit including possibility of saving meas. +
;	replacing numbers by letters in pixel ind. (CG)	January 2000
;	V8.2
;	Refresh windows after changing saturation limits is included
;	  (JAcosta) 					July 2000
;			
;-
; *********************************************************************
; *
; *********************************************************************
pro discard_area, event
COMMON pia_dsperd_cmn, tmpdata, erdps, view, viewsize, nviews, viewoptions, $
   overid 
COMMON pia_dspcho_cmn, pixcho, pixop, pixres, psymch, pixcount
common flg_acc_cmn, erd_disc, disc_set, fitflg, rpchopend1, rampend1
COMMON zoom_discareas, disc_area, all_disc_areas

        WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        WIDGET_CONTROL, event.top, /HOURGLASS


        pixch = pixcho(windowindex)
	tmpvolt = reform(tmpdata.conp(pixch,*))
	
	pia_xplot, tmpdata.time, $
		   tmpvolt, flagged=erd_disc(pixch,*), $
		   title= 'Discarding area by pixel '+STRTRIM(pixch+1,2),$
		   ytitle='Voltage    [V]',xtitle='Time     [s]',$
		   psym=psymch, /disc_area

	siz= size(all_disc_areas)
	IF siz(0) EQ 0 THEN RETURN
	
; use only pixel we are interested in -> don't put detector
	decode_piaflag, 'ERD', 'MANDISC', tmpdata.flag(pixch,*), manflag
	
	FOR I=0,N_ELEMENTS(all_disc_areas)-1 DO BEGIN
	  p1 = all_disc_areas(i).pos1
	  p2 = all_disc_areas(i).pos2
	  IF p1(1) NE 0. or p2(1) NE 0. THEN BEGIN
	     ind = WHERE(tmpvolt GE p1(1) AND $
	     		 tmpvolt LE p2(1) AND $
			 tmpdata.time GE p1(0) AND $
			 tmpdata.time LE p2(0), ndisc)
	     IF ndisc GT 0 THEN BEGIN
	       manflag(ind) = 1
	       encode_piaflag, 'ERD', 'MANDISC', tmpdata.flag(pixch,*), tmpflag, $
	        manflag
	       tmpdata.flag(pixch,*) = tmpflag  
	     ENDIF
	  ENDIF
	ENDFOR
	get_validflag, tmpdata.flag, 'ERD', redflag, $
	  det=tmpdata.det, /allpix
	erd_disc = redflag
	
	pia_resetview, windowindex

END

	
; *********************************************************************
; *
; *********************************************************************
pro reselect_area, event
COMMON pia_dsperd_cmn, tmpdata, erdps, view, viewsize, nviews, viewoptions, $
    overid 
COMMON pia_dspcho_cmn, pixcho, pixop, pixres, psymch, pixcount
common flg_acc_cmn, erd_disc, disc_set, fitflg, rpchopend1, rampend1
COMMON zoom_discareas, disc_area, all_disc_areas

        WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        WIDGET_CONTROL, event.top, /HOURGLASS


        pixch = pixcho(windowindex)
	tmpvolt = reform(tmpdata.conp(pixch,*))
	
	pia_xplot, tmpdata.time, $
		   tmpvolt, flagged=erd_disc(pixch,*), $
		   title= 'Reselecting area by pixel '+STRTRIM(pixch+1,2),$
		   ytitle='Voltage    [V]',xtitle='Time     [s]',$
		   psym=psymch, /disc_area

	siz= size(all_disc_areas)
	IF siz(0) EQ 0 THEN RETURN
	
; use only pixel we are interested in -> don't put detector
	decode_piaflag, 'ERD', 'MANDISC', tmpdata.flag(pixch,*), manflag
	
	FOR I=0,N_ELEMENTS(all_disc_areas)-1 DO BEGIN
	  p1 = all_disc_areas(i).pos1
	  p2 = all_disc_areas(i).pos2
	  IF p1(1) NE 0. or p2(1) NE 0. THEN BEGIN
	     ind = WHERE(tmpvolt GE p1(1) AND $
	     		 tmpvolt LE p2(1) AND $
			 tmpdata.time GE p1(0) AND $
			 tmpdata.time LE p2(0), ndisc)
	     IF ndisc GT 0 THEN BEGIN
	        manflag(ind) = 0
		encode_piaflag, 'ERD', 'MANDISC', tmpdata.flag(pixch,*), tmpflag, $
	          manflag
		tmpdata.flag(pixch,*) = tmpflag  
	     ENDIF
	  ENDIF
	ENDFOR
  
	get_validflag, tmpdata.flag, 'ERD', redflag, $
	  det=tmpdata.det, /allpix
	erd_disc = redflag

	pia_resetview, windowindex

END

	

; *********************************************************************
; *
; *********************************************************************
pro pixbutevent, event

COMMON pia_dsperd_cmn, tmpdata, erdps, view, viewsize, nviews, viewoptions, $
     overid 
COMMON pia_dspcho_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON dsperd_widg, pixbut

	WIDGET_CONTROL, event.id, GET_UVALUE = new_pixbut

        ind = WHERE(pixcho eq new_pixbut(0))
        ind = ind(0)

	text = ["A", "B", "C", "D"]
	IF ind LT 0 or ind GE nviews THEN BEGIN  
	
	  pixcount = pixcount+1
	  IF pixcount GE nviews THEN pixcount = 0 

	  old_pixcho = pixcho(pixcount)
	  pixcho(pixcount) = new_pixbut(0)

	  view(pixcount).viewtype = 0
	  pia_resetview, pixcount, view(pixcount).controlid

;	  txtval = STRTRIM(STRING(pixcount+1),2) ; Replacing numbers by 
	  txtval = text(pixcount)                ; letters
	  
	  WIDGET_CONTROL, pixbut(old_pixcho), $
				SET_VALUE = ' '
	  WIDGET_CONTROL, pixbut(pixcho(pixcount)), $
			SET_VALUE = txtval
	ENDIF
END
; *********************************************************************
; *
; *********************************************************************
pro deglitch_test, event

COMMON pia_dsperd_cmn, tmpdata, erdps, view, viewsize, nviews, viewoptions, $
    overid 
COMMON pia_dspcho_cmn, pixcho, pixop, pixres, psymch, pixcount
common flg_acc_cmn, erd_disc, disc_set, fitflg, rpchopend1, rampend1

	WIDGET_CONTROL, event.id, GET_UVALUE = winindex
	pixnr = pixcho(winindex(0))

	PIA_RODEGL, tmpdata, pixnr, erd_disc(pixnr,*), rampend1, $ 
	   GROUP=event.top
	
END

; *********************************************************************
; *
; *********************************************************************
pro pair_deglitch_test, event

COMMON pia_dsperd_cmn, tmpdata, erdps, view, viewsize, nviews, viewoptions, $
    overid 
COMMON pia_dspcho_cmn, pixcho, pixop, pixres, psymch, pixcount
common flg_acc_cmn, erd_disc, disc_set, fitflg, rpchopend1, rampend1

	WIDGET_CONTROL, event.id, GET_UVALUE = winindex
	pixnr = pixcho(winindex(0))

	PIA_pairDEGL, tmpdata, pixnr, erd_disc, GROUP=event.top
	
END


; *********************************************************************
; *
; *********************************************************************
pro viewevent, event

COMMON pia_dsperd_cmn, tmpdata, erdps, view, viewsize, nviews, viewoptions, $
    overid 
COMMON pia_dspcho_cmn, pixcho, pixop, pixres, psymch, pixcount

	; get index of individual window choice
	viewchoindexid = WIDGET_INFO(event.id, /PARENT)
	WIDGET_CONTROL, viewchoindexid, GET_UVALUE = setting_choi
	setting_choi = setting_choi(0)
	; get index of window
        viewindexid = WIDGET_INFO(viewchoindexid,/PARENT)
	WIDGET_CONTROL, viewindexid, GET_UVALUE = viewindex

	IF N_ELEMENTS(viewindex) EQ 0 THEN BEGIN
	  viewindex = setting_choi
	  viewindexid = viewchoindexid
 	  WIDGET_CONTROL, event.id, GET_UVALUE = setting
	  setting = setting(0)

          IF (view(viewindex(0)).viewtype NE setting) THEN BEGIN
                view(viewindex(0)).viewtype = setting
                pia_resetview, viewindex, viewindexid
          ENDIF
	ENDIF ELSE BEGIN
	; get value of setting 
 	  WIDGET_CONTROL, event.id, GET_UVALUE = setting
	  setting = setting(0)

	  IF (view(viewindex(0)).viewtype NE setting_choi OR $
	    view(viewindex(0)).viewtype_sub NE setting) THEN BEGIN
		view(viewindex(0)).viewtype_sub = setting
		view(viewindex(0)).viewtype = setting_choi
		pia_resetview, viewindex, viewindexid
	  ENDIF
	ENDELSE

END

; *********************************************************************
; *
; *********************************************************************
pro fitrams, event
COMMON pia_dsperd_cmn, tmpdata, erdps, view, viewsize, nviews, viewoptions, $
    overid 

	WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        WIDGET_CONTROL, event.top, /HOURGLASS
	pia_pseudo_rd, tmpdata.nndr+1, rampdiv
	IF rampdiv.model NE -1 THEN $  
	  fitramps, 1, windowindex, /div_ramp

END


; *********************************************************************
; *
; *********************************************************************
pro fitram1, event

	WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        WIDGET_CONTROL, event.top, /HOURGLASS
	fitramps, 1, windowindex

END

; *********************************************************************
; *
; *********************************************************************
pro fitram2, event

	WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        WIDGET_CONTROL, event.top, /HOURGLASS
	fitramps, 2, windowindex

END

; *********************************************************************
; *
; *********************************************************************
pro fitram3, event

	WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        WIDGET_CONTROL, event.top, /HOURGLASS
	fitramps, 3, windowindex

END


; *********************************************************************
; *
; *********************************************************************
pro fitramps, ndeg, windex, div_ramp=div_ramp

@colour_indices
COMMON pia_dsperd_cmn, tmpdata, erdps, view, viewsize, nviews, viewoptions, $
    overid 
COMMON pia_dspcho_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
COMMON pia_plot_over_cmn, pl_ids, state
COMMON pia_widget_info, extfil_wid, intfil_wid, buffil_wid, $
			erddi1_wid, erddi2_wid, srddi1_wid, srddi2_wid, $
                        scpdi1_wid, scpdi2_wid, spddi1_wid, spddi2_wid, $
                        aapdi1_wid, aapdi2_wid

	pixch = pixcho(windex)
	
	IF KEYWORD_SET(div_ramp) THEN div_ramp=1 ELSE div_ramp=0
        process_pixel, tmpdata, pixch, ndeg, time, slop, serr, sflag, $
         div_ramp=div_ramp

	state = 0
	IF Xregistered("PIA_XPLOT") NE 0 THEN BEGIN

	   pia_plot_over, group=erddi1_wid				

        ENDIF

        IF state EQ 2 THEN state = -1

	IF state NE 0 THEN BEGIN
		IF zoom_color EQ -1 THEN zoom_color = green ELSE $
			zoom_color = zoom_color + 1
			IF zoom_color EQ 9 then zoom_color = 1
		zoom_psymch = zoom_psymch + 1
		IF zoom_psymch GT 8 THEN zoom_psymch = 1
		title = ''
	ENDIF ELSE BEGIN
		zoom_color = -1
		zoom_psymch = psymch
        ENDELSE


	str_pixch = STRTRIM(STRING(pixch+1),2)
	ytitle = 'Fitted Signal: Pixel '+str_pixch+'    [Volt/s]' 
	xtitle = ' Ramp central time    [s] '
	title = 'Fitted Slopes'

        get_convwh, tmpdata.admn, wheels, chmod, champ
        anntmp = title + tmpdata.unit + $
		'  [' + wheels(0) + '  ' + wheels(1) + '  ' + $
                wheels(2) + ']  [' + chmod + '  ' + champ + ']'

	PIA_XPLOT, time, slop, serr, $
		psym = zoom_psymch, xtitle = xtitle, ytitle = ytitle, $
		title = title, overplot = state, $
		charsize = charsize, $
		color = zoom_color, legend='Fitted S.: Pixel '+str_pixch, $
		annotation=anntmp 

	indno = WHERE(sflag gt 1, nn)
                        IF nn GT 0 THEN $
			  PIA_XPLOT, time(indno), $
			  slop(indno), $
			  psym = 7, color=red, overplot=99, $
			  legend=' discarded points' 

END


; *********************************************************************
; *
; *********************************************************************
pro averageevent, event

COMMON pia_dsperd_cmn, tmpdata, erdps, view, viewsize, nviews, viewoptions, $
    overid 
COMMON pia_dspcho_cmn, pixcho, pixop, pixres, psymch, pixcount
common tmpvalues, tmppixf, tmppixf_name, tmprpid, tmprpid_name

	WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        WIDGET_CONTROL, event.top, /HOURGLASS

	ytitle = viewoptions(view(windowindex).viewtype).viewylab


	CASE view(windowindex).viewtype OF

	  0: BEGIN
		pixch = pixcho(windowindex)
		avr = avg(tmpdata.conp(pixch,*))
		sig = sigma(tmpdata.conp(pixch,*))
	  END
	  1: BEGIN
		pixch = pixcho(windowindex)
		avr = avg(tmpdata.rawp(pixch,*))
		sig = sigma(tmpdata.rawp(pixch,*))
	  END
	  2: BEGIN
		avr = avg(tmpdata.chop)
		sig = sigma(tmpdata.chop)
	  END
	  3: BEGIN
		pixch = pixcho(windowindex)
		dimtemp = size(tmpdata.temp)
		IF dimtemp(0) EQ 2 THEN BEGIN
		   IF pixch GT 63 THEN temptmp = tmpdata.temp(1,*) ELSE $
		   temptmp = tmpdata.temp(0,*) 
		ENDIF ELSE temptmp = tmpdata.temp
		avr = avg(temptmp)
		sig = sigma(temptmp)
	  END
	  4: BEGIN
		avr = avg(tmpdata.fcs1)
		sig = sigma(tmpdata.fcs1)
	  END
	  5: BEGIN
		avr = avg(tmpdata.fcs2)
		sig = sigma(tmpdata.fcs2)
	  END
	  6: BEGIN
		avr = avg(tmpdata.tkey)
		sig = sigma(tmpdata.tkey)
	  END
	  7: BEGIN
		avr = avg(tmprpid)
		sig = sigma(tmprpid)
		ytitle = tmprpid_name
	  END
	  8: BEGIN
		avr = avg(tmppixf)
		sig = sigma(tmppixf)
		ytitle = tmppixf_name
	  END
	  9: BEGIN
		pixch = pixcho(windowindex)
		avr = avg(tmpdata.fitv(pixch,*))
		sig = sigma(tmpdata.fitv(pixch,*))
	  END
	  10: BEGIN
		avr = avg(tmpdata.conp(pixop,*))
		sig = sigma(tmpdata.conp(pixop,*))
	  END
	  11: BEGIN
		avr = avg(tmpdata.conp(pixres,*))
		sig = sigma(tmpdata.conp(pixres,*))
	  END
	  12: BEGIN
		avr = avg(tmpdata.conp(pixop+2,*))
		sig = sigma(tmpdata.conp(pixop+2,*))
	  END
	  13: BEGIN
		avr = avg(tmpdata.conp(pixres+2,*))
		sig = sigma(tmpdata.conp(pixres+2,*))
	  END
	  ELSE: MESSAGE, /INFO, 'Not allowed CASE'
				
	ENDCASE

	TEXT = 'Average of '+ytitle+'   is:  '+strtrim(string(avr),2)+$
			'  +/-   '+strtrim(string(sig),2)

        XDISPLAYFILE, "", $
                  GROUP = event.top, $
                  TITLE = "Average Calculation", $
                  WIDTH = 100, $
                  HEIGHT = 4, $
                  TEXT = [TEXT] 

END

; *********************************************************************
; *
; *********************************************************************
pro medianevent, event

COMMON pia_dsperd_cmn, tmpdata, erdps, view, viewsize, nviews, viewoptions, $
    overid 
COMMON pia_dspcho_cmn, pixcho, pixop, pixres, psymch, pixcount
common tmpvalues, tmppixf, tmppixf_name, tmprpid, tmprpid_name

	WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        WIDGET_CONTROL, event.top, /HOURGLASS

	ytitle = viewoptions(view(windowindex).viewtype).viewylab


	CASE view(windowindex).viewtype OF

	  0: BEGIN
		pixch = pixcho(windowindex)
		avr = median(tmpdata.conp(pixch,*))
		sig = sigma(tmpdata.conp(pixch,*))
	  END
	  1: BEGIN
		pixch = pixcho(windowindex)
		avr = median(tmpdata.rawp(pixch,*))
		sig = sigma(tmpdata.rawp(pixch,*))
	  END
	  2: BEGIN
		avr = median(tmpdata.chop)
		sig = sigma(tmpdata.chop)
	  END
	  3: BEGIN
		pixch = pixcho(windowindex)
		dimtemp = size(tmpdata.temp)
		IF dimtemp(0) EQ 2 THEN BEGIN
		   IF pixch GT 63 THEN temptmp = tmpdata.temp(1,*) ELSE $
		   temptmp = tmpdata.temp(0,*) 
		ENDIF ELSE temptmp = tmpdata.temp
		avr = median(temptmp)
		sig = sigma(temptmp)
	  END
	  4: BEGIN
		avr = median(tmpdata.fcs1)
		sig = sigma(tmpdata.fcs1)
	  END
	  5: BEGIN
		avr = median(tmpdata.fcs2)
		sig = sigma(tmpdata.fcs2)
	  END
	  6: BEGIN
		avr = median(tmpdata.tkey)
		sig = sigma(tmpdata.tkey)
	  END
	  7: BEGIN
		avr = median(tmprpid)
		sig = sigma(tmprpid)
		ytitle = tmprpid_name
	  END
	  8: BEGIN
		avr = median(tmppixf)
		sig = sigma(tmppixf)
		ytitle = tmppixf_name
	  END
	  9: BEGIN
		pixch = pixcho(windowindex)
		avr = median(tmpdata.fitv(pixch,*))
		sig = sigma(tmpdata.fitv(pixch,*))
	  END
	  10: BEGIN
		avr = median(tmpdata.conp(pixop,*))
		sig = sigma(tmpdata.conp(pixop,*))
	  END
	  11: BEGIN
		avr = median(tmpdata.conp(pixres,*))
		sig = sigma(tmpdata.conp(pixres,*))
	  END
	  12: BEGIN
		avr = median(tmpdata.conp(pixop+2,*))
		sig = sigma(tmpdata.conp(pixop+2,*))
	  END
	  13: BEGIN
		avr = median(tmpdata.conp(pixres+2,*))
		sig = sigma(tmpdata.conp(pixres+2,*))
	  END
	  ELSE: MESSAGE, /INFO, 'Not allowed CASE'
				
	ENDCASE

	TEXT = 'Median of '+ytitle+'   is:  '+strtrim(string(avr),2)+$
			'  +/-   '+strtrim(string(sig),2)+'   (sigma taken)'

        XDISPLAYFILE, "", $
                  GROUP = event.top, $
                  TITLE = "Median Calculation", $
                  WIDTH = 100, $
                  HEIGHT = 4, $
                  TEXT = [TEXT] 

END

; *********************************************************************
; *
; *********************************************************************
pro zoomevent, event

COMMON pia_dsperd_cmn, tmpdata, erdps, view, viewsize, nviews, viewoptions, $
    overid 
COMMON pia_dspcho_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices

	WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
	zoomit, windowindex        
END

; *********************************************************************
; *
; *********************************************************************
pro zoomfourier, event

COMMON pia_dsperd_cmn, tmpdata, erdps, view, viewsize, nviews, viewoptions, $
    overid 
COMMON pia_dspcho_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices

	WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
	zoomit, windowindex, fourier = 1        
END

; *********************************************************************
; *
; *********************************************************************
pro zoomsync, event

COMMON pia_dsperd_cmn, tmpdata, erdps, view, viewsize, nviews, viewoptions, $
    overid 
COMMON pia_dspcho_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices

	WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
	zoomit, windowindex, overplot = 1        

END

; *********************************************************************
; *
; *********************************************************************
pro zoomnsync, event

COMMON pia_dsperd_cmn, tmpdata, erdps, view, viewsize, nviews, viewoptions, $
    overid 
COMMON pia_dspcho_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices

	WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
	zoomit, windowindex, overplot = -1        

END

; *********************************************************************
; *
; *********************************************************************
pro zoomit, windowindex, overplot=overplot, fourier=fourier

COMMON pia_dsperd_cmn, tmpdata, erdps, view, viewsize, nviews, viewoptions, $
    overid 
COMMON pia_dsperd_flg_cmn, nflag_active, flag_active_lex, flag_active_label  
COMMON pia_dspcho_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
common flg_acc_cmn, erd_disc, disc_set, fitflg, rpchopend1, rampend1
common tmpvalues, tmppixf, tmppixf_name, tmprpid, tmprpid_name

@colour_indices

	IF (KEYWORD_SET(overplot)) THEN overplot = overplot ELSE overplot = 0
	IF (KEYWORD_SET(fourier)) THEN fourier = 1 ELSE fourier = 0


	xtitle = viewoptions(view(windowindex).viewtype).viewxlab
	ytitle = viewoptions(view(windowindex).viewtype).viewylab
	menuchoi = view(windowindex).viewtype_sub

	ytype = 0

	decode_admn, tmpdata.admn, title
	title = title + '   '+ tmpdata.unit
        get_convwh, tmpdata.admn, wheels, chmod, champ
        anntmp = title + $
		'  [' + wheels(0) + '  ' + wheels(1) + '  ' + $
                wheels(2) + ']  [' + chmod + '  ' + champ + ']'
        anntmp = anntmp+' (ERD level)'


	IF fourier eq 1 THEN BEGIN
			xtitle = 'Frequency       [Hz]'
			ytitle = 'FFT of '+ytitle
			ytype = 1
        ENDIF

	charsize = 1.10

	IF overplot NE 0 THEN BEGIN
		IF zoom_color EQ -1 THEN zoom_color = green ELSE $
			zoom_color = zoom_color + 1
			IF zoom_color EQ 9 then zoom_color = 1
		zoom_psymch = zoom_psymch + 1
		IF zoom_psymch GT 8 THEN zoom_psymch = 1
		title = ''
	ENDIF ELSE BEGIN
		zoom_color = -1
		zoom_psymch = psymch
        ENDELSE
	
	CASE view(windowindex).viewtype OF

;Plot pixel voltages
	  0: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Raw Data: Pixel '+str_pixch+'    [Volt]' 
		ytitle = str_pixch 

		IF fourier eq 1 THEN BEGIN
			xtitle = 'Frequency       [Hz]'
			ytitle = 'FFT of '+ytitle
			ytype = 1
                ENDIF

		PIA_XPLOT, tmpdata.time, tmpdata.conp(pixch,*), $
			psym = zoom_psymch, xtitle = xtitle, ytitle = ytitle, $
			title = title, overplot = overplot, $
			charsize = charsize, $
			color = zoom_color,  $
                        fourier = fourier, ytype = ytype, $
			legend=strmid(ytitle,0,20), $
			annotation=anntmp               

               IF disc_set AND fourier EQ 0 THEN BEGIN
			indno = WHERE(erd_disc(pixch,*) eq 1, nn)
                        IF nn GT 0 THEN $
			  PIA_XPLOT, tmpdata.time(indno), $
			  tmpdata.conp(pixch,indno), $
			  psym = 7, color=red, overplot=99, $
			  legend=' discarded points'       
               ENDIF
	       
	       decode_piaflag, 'ERD', 'GLITCH', tmpdata.flag(pixch,*), glflg
	       			
		indf = WHERE(glflg EQ 1, nfl)
		IF nfl GT 0 THEN BEGIN
			  PIA_XPLOT, tmpdata.time(indf), $
			  tmpdata.conp(pixch,indf), $
			  psym = 2, color=blue, overplot=99, $
			  legend=' Deglitch flagged'
	        ENDIF
    	  END
;Plot raw data               
	  1: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Digital Data: Pixel '+str_pixch+'  [DN]' 
		ytitle = str_pixch 

		IF fourier eq 1 THEN BEGIN
			xtitle = 'Frequency       [Hz]'
			ytitle = 'FFT of '+ytitle
			ytype = 1
                ENDIF

		pia_xplot, tmpdata.time, tmpdata.rawp(pixch,*), $ 
			psym = zoom_psymch, xtitle = xtitle, ytitle = ytitle, $
			title = title, overplot = overplot, $
			 charsize = charsize, $
			color = zoom_color,  $
			fourier = fourier, ytype = ytype, $
			legend=strmid(ytitle,0,20), $
			annotation=anntmp                    
   
                IF disc_set AND fourier EQ 0 THEN BEGIN
			indno = WHERE(erd_disc(pixch,*) eq 1, nn)
                        IF nn GT 0 THEN $
			  PIA_XPLOT, tmpdata.time(indno), $
			  tmpdata.rawp(pixch,indno), $
			  psym = 7, color=red, overplot=99, $
			  legend=' discarded points'      
                ENDIF
       END
;Plot chopper positions
	  2: BEGIN
		pia_xplot, tmpdata.time, tmpdata.chop, psym = zoom_psymch, $
			xtitle = xtitle, ytitle = ytitle, title = title, $
			overplot = overplot,           $
			charsize = charsize, color = zoom_color,         $       
			fourier = fourier, ytype = ytype, $
			legend=strmid(ytitle,0,20), $
			annotation=anntmp                          
          END
;Plot temperatures
	  3: BEGIN
		pixch = pixcho(windowindex)
		dimtemp = size(tmpdata.temp)
		IF dimtemp(0) EQ 2 THEN BEGIN
		   IF pixch GT 63 THEN temptmp = tmpdata.temp(1,*) ELSE $
		   temptmp = tmpdata.temp(0,*) 
		ENDIF ELSE temptmp = tmpdata.temp
		pia_xplot, tmpdata.time, temptmp, psym = zoom_psymch, $
			xtitle = xtitle, ytitle = ytitle, title = title, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,         $       
			fourier = fourier, ytype = ytype, $
			legend=strmid(ytitle,0,20), $
			annotation=anntmp                                     
          END
;Plot FCS1 electrical powers
	  4: BEGIN
		pia_xplot, tmpdata.time, tmpdata.fcs1, psym = zoom_psymch, $
			xtitle = xtitle, ytitle = ytitle, title = title, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,         $       
			fourier = fourier, ytype = ytype, $
			legend=strmid(ytitle,0,20), $
			annotation=anntmp                                    
          END
;Plot FCS2 electrical powers
	  5: BEGIN
		pia_xplot, tmpdata.time, tmpdata.fcs2, psym = zoom_psymch, $
			xtitle = xtitle, ytitle = ytitle, title = title, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,         $       
			fourier = fourier, ytype = ytype, $
			legend=strmid(ytitle,0,20), $
			annotation=anntmp                                   
          END
;Plot time keys
	  6: BEGIN
		pia_xplot, tmpdata.time, tmpdata.tkey, psym = zoom_psymch, $
			xtitle = xtitle, ytitle = ytitle, title = title, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,         $       
			fourier = fourier, ytype = ytype, $
			legend=strmid(ytitle,0,20), $
			annotation=anntmp                                   
          END
;Plot raster point ID
	  7: BEGIN
		pia_xplot, tmpdata.time, tmprpid, psym = zoom_psymch, $
			xtitle = xtitle, ytitle = tmprpid_name, title = title, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,         $       
			fourier = fourier, ytype = ytype, $
			legend=strmid(ytitle,0,20), $
			annotation=anntmp                                   
	  END

;Plot bit coded word PIXF
	  8: BEGIN
		pia_xplot, tmpdata.time, tmppixf, psym = zoom_psymch, $
			xtitle = xtitle, ytitle = tmppixf_name, title = title, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,         $       
			fourier = fourier, ytype = ytype, $
			legend=strmid(ytitle,0,20), $
			annotation=anntmp                                   
          END

;Fitted Values
	  9: BEGIN
		IF fitflg NE 0 THEN BEGIN
                  pixch = pixcho(windowindex)
                  str_pixch = STRTRIM(STRING(pixch+1),2)
                  str_pixch = 'Fitted Readouts: Pixel '+str_pixch+'  [V]'
                  ytitle = str_pixch
                  pia_xplot, tmpdata.time, $
                        tmpdata.fitv(pixch,*), $
                        psym = zoom_psymch, xtitle = xtitle, $
                        ytitle=tmppixf_name, subtitle=subtitle, $
                        title = title, charsize = charsize, overplot=overplot, $
			color = zoom_color, fourier=fourier, $
			legend=strmid(ytitle,0,20), $
			annotation=anntmp               
		ENDIF ELSE $
		  XDISPLAYFILE, "", $
                    TITLE = "Data not available", $
                    WIDTH = 50, $
                    HEIGHT = 4, $
                    TEXT = [" The data has not been yet fitted - ", $
                          " Process and come again, please "]
		
               END

;Zoom Readout flag
	  10: BEGIN
	    	elemnames =  flag_active_label   
		pixch = pixcho(windowindex)
		str_pixch = 'Flag ' + elemnames(menuchoi)+ ': Pixel '+ $
		   STRTRIM(pixch+1,2)
		IF title NE '' THEN title = str_pixch 
		;select flag depending on the choice
		IF flag_active_lex(menuchoi) EQ 'ENCODE' THEN        $
		    tmpflag = tmpdata.flag(pixch,*)                  $
		ELSE decode_piaflag,'ERD',flag_active_lex(menuchoi), $ 
		    tmpdata.flag(pixch,*),tmpflag
		ytitle = 'Flag' 

                IF fourier eq 1 THEN BEGIN
                        xtitle = 'Frequency       [Hz]'
                        ytitle = 'FFT of '+ytitle
                        ytype = 1
                ENDIF
		
		pia_xplot, tmpdata.time, tmpflag, psym = zoom_psymch,        $
			xtitle=xtitle, fourier=fourier, ytitle=ytitle,       $
			subtitle=subtitle, title=title, ytype=ytype,         $
			overplot = overplot, charsize = charsize,            $
			color = zoom_color, xstyle=xstyle, ystyle=ystyle,    $
			legend=strmid(str_pixch,5,25), annotation=anntmp              
              END
                      
;Open Pixel
	  11: BEGIN
		pia_xplot, tmpdata.time, tmpdata.conp(pixop,*), $
			psym = zoom_psymch, $
			xtitle = xtitle, ytitle = ytitle, title = title, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,         $       
			fourier = fourier, ytype = ytype, $
			legend=strmid(ytitle,0,20), $
			annotation=anntmp                                   

                IF disc_set AND fourier EQ 0 THEN BEGIN
			indno = WHERE(erd_disc(pixop,*) eq 1, nn)
                        IF nn GT 0 THEN $
			  PIA_XPLOT, tmpdata.time(indno), $
			  tmpdata.conp(pixop,indno), $
			  psym = 7, color=red, overplot=99, $
			  legend=' discarded points'                           
                ENDIF
          END

;Resistor Pixel
	  12: BEGIN
		pia_xplot, tmpdata.time, tmpdata.conp(pixres,*), $
			psym = zoom_psymch, $
			xtitle = xtitle, ytitle = ytitle, title = title, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,         $       
			fourier = fourier, ytype = ytype, $
			legend=strmid(ytitle,0,20), $
			annotation=anntmp                                   

                        IF disc_set and fourier EQ 0 THEN BEGIN
			   indno = WHERE(erd_disc(pixres,*) eq 1, nn)
                           IF nn GT 0 THEN $
			  	PIA_XPLOT, tmpdata.time(indno), $
			  	tmpdata.conp(pixres,indno), $
			  	psym = 7, color=red, overplot=99, $
			  legend=' discarded points'      
                        ENDIF


          END

;Open Pixel 2 - (SL only)
	  13: BEGIN
		pia_xplot, tmpdata.time, tmpdata.conp(pixop+2,*), $
			psym = zoom_psymch, $
			xtitle = xtitle, ytitle = ytitle, title = title, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,         $       
			fourier = fourier, ytype = ytype, $
			legend=strmid(ytitle,0,20), $
			annotation=anntmp                                   

                        IF disc_set and fourier EQ 0 THEN BEGIN
			   indno = WHERE(erd_disc(pixop+2,*) eq 1, nn)
                           IF nn GT 0 THEN $
			  	PIA_XPLOT, tmpdata.time(indno), $
			  	tmpdata.conp(pixop+2,indno), $
			  	psym = 7, color=red, overplot=99, $
			  legend=' discarded points'      
			ENDIF
                 END

;Resistor Pixel 2 - (SL only)
	  14: BEGIN
		pia_xplot, tmpdata.time, reform(tmpdata.conp(pixres+2,*)), $
			psym = zoom_psymch, $
			xtitle = xtitle, ytitle = ytitle, title = title, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,         $  
			fourier = fourier, ytype = ytype, $
			legend=strmid(ytitle,0,20), $
			annotation=anntmp                                   

                        IF disc_set and fourier EQ 0 THEN BEGIN
			   indno = WHERE(erd_disc(pixres+2,*) eq 1, nn)
                           IF nn GT 0 THEN $
			  	PIA_XPLOT, tmpdata.time(indno), $
			  	tmpdata.conp(pixres+2,indno), $
			  	psym = 7, color=red, overplot=99, $
			  legend=' discarded points'      
			ENDIF
              END

	  ELSE: WIDGET_CONTROL, UPDATE_LABEL, $
				set_value = 'Unsupported View'
          ENDCASE

END


; *********************************************************************
; *
; *********************************************************************
pro pia_resetview, windowindex, UPDATE_LABEL

COMMON pia_dsperd_cmn, tmpdata, erdps, view, viewsize, nviews, viewoptions, $
    overid 
COMMON pia_dsperd_flg_cmn, nflag_active, flag_active_lex, flag_active_label  
COMMON pia_dspcho_cmn, pixcho, pixop, pixres, psymch, pixcount
common tmpvalues, tmppixf, tmppixf_name, tmprpid, tmprpid_name
common flg_acc_cmn, erd_disc, disc_set, fitflg, rpchopend1, rampend1
@colour_indices

	wset, view(windowindex).windownum         ;set to draw in 

	ERASE, color = 100                        ;erase the view


	IF NOT (KEYWORD_SET(UPDATE_LABEL)) THEN $
	  UPDATE_LABEL = 0


	charsize = 1.0
	symsize = 0.5
	xtitle = viewoptions(view(windowindex).viewtype).viewxlab
	ytitle = viewoptions(view(windowindex).viewtype).viewylab
	menuchoi = view(windowindex).viewtype_sub
	IF tmpdata.dims GT 20000 THEN loc_psymch=3 ELSE loc_psymch = psymch
	
	CASE view(windowindex).viewtype OF

;Plot pixel voltages
	  0: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Raw Data: Pixel '+str_pixch+'  [Volt]' 
		PIA_PLOT, tmpdata.time, tmpdata.conp(pixch,*), psym = loc_psymch, $
			xtitle = xtitle, ytitle = ytitle, $
			charsize = charsize, symsize = symsize
		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  

		IF disc_set THEN BEGIN
			indno = WHERE(erd_disc(pixch,*) eq 1, nn)
			IF loc_psymch EQ 3 THEN osymch=3 ELSE osymch=7
                        IF nn GT 0 THEN $
			  PIA_OPLOT, tmpdata.time(indno), $
			  tmpdata.conp(pixch,indno), $
			  psym = osymch, color=red
                ENDIF
	        
		decode_piaflag, 'ERD', 'GLITCH', tmpdata.flag(pixch,*), glflg
		indf = WHERE(glflg EQ 1, nfl)

		IF nfl GT 0 THEN BEGIN
			  PIA_OPLOT, tmpdata.time(indf), $
			  tmpdata.conp(pixch,indf), $
			  psym = 2, color=blue
	        ENDIF
			
	  END
;Plot raw data
	  1: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Digital Data: Pixel '+str_pixch+'  [DN]' 
		pia_plot, tmpdata.time, tmpdata.rawp(pixch,*), psym = loc_psymch, $
			xtitle = xtitle, ytitle = ytitle, $
			charsize = charsize, symsize = symsize                
		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  
 
		IF disc_set THEN BEGIN
			indno = WHERE(erd_disc(pixch,*) eq 1, nn)
			IF loc_psymch EQ 3 THEN osymch=3 ELSE osymch=7
                        IF nn GT 0 THEN $
			  PIA_OPLOT, tmpdata.time(indno), $
			  tmpdata.rawp(pixch,indno), $
			  psym = osymch, color=red
                ENDIF
         END
;Plot chopper positions
	  2: BEGIN
		pia_plot, tmpdata.time, tmpdata.chop, psym = loc_psymch, $
			xtitle = xtitle, ytitle = ytitle, $
			charsize = charsize, symsize = symsize                 
		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = 'Chopper Position  [arcsec]'  
          END
;Plot temperatures
	  3: BEGIN
		pixch = pixcho(windowindex)
		dimtemp = size(tmpdata.temp)
		IF dimtemp(0) EQ 2 THEN BEGIN
		   IF pixch GT 63 THEN temptmp = tmpdata.temp(1,*) ELSE $
		   temptmp = tmpdata.temp(0,*) 
		ENDIF ELSE temptmp = tmpdata.temp
		pia_plot, tmpdata.time, temptmp, psym = loc_psymch, $
			xtitle = xtitle, ytitle = ytitle, $
			charsize = charsize, symsize = symsize                 
		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = 'Temperature [K]'  
          END
;Plot FCS1 electrical powers
	  4: BEGIN
		pia_plot, tmpdata.time, tmpdata.fcs1, psym = loc_psymch, $
			xtitle = xtitle, ytitle = ytitle, $
			charsize = charsize, symsize = symsize                
		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = 'FCS1 Power [mW]'  
          END
;Plot FCS2 electrical powers
	  5: BEGIN
		pia_plot, tmpdata.time, tmpdata.fcs2, psym = loc_psymch, $
			xtitle = xtitle, ytitle = ytitle, $
			charsize = charsize, symsize = symsize                
		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = 'FCS2 electrical Power [mW]'  
          END
;Plot time keys
	  6: BEGIN
		pia_plot, tmpdata.time, tmpdata.tkey, psym = loc_psymch, $
			xtitle = xtitle, ytitle = ytitle, $
			charsize = charsize, symsize = symsize                
		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = 'Time Key'  
          END
;Plot raster point ID
	  7: BEGIN
		elemnames = ['Raster Point ID 1', 'Raster Point ID 2']
		
		tmprpid = tmpdata.rpid(menuchoi,*)
		tmprpid_name = elemnames(menuchoi)
		
		pia_plot, tmpdata.time, tmprpid, psym = loc_psymch, $
			xtitle = xtitle, ytitle = tmprpid_name, $
			charsize = charsize, symsize = symsize                
		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = tmprpid_name 
	  END

;Plot bit coded word PIXF
	  8: BEGIN
		elemnames = ['Suspicious Flag', 'Chopper on Position', $
			'Chopper Sign', 'Read-out Status', 'On-target flag',$
			'Automatic Data Reduction']
		list = indgen(N_ELEMENTS(elemnames))
		pia_multchoice, list, elemnames=elemnames

		decode_pixf, tmpdata.pixf, susp, ch, cho, rds, otf, aut

		tmppixf_name = elemnames(list)
		
		CASE list of
		 0: tmppixf = susp
		 1: tmppixf = ch
		 2: tmppixf = cho
		 3: tmppixf = rds
		 4: tmppixf = otf
		 5: tmppixf = aut
		ENDCASE
		
		pia_plot, tmpdata.time, tmppixf, psym = loc_psymch, $
			xtitle = xtitle, ytitle = tmppixf_name, $
			charsize = charsize, symsize = symsize                
		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = 'Bit Flags' 

          END

;Fitted Values
	  9: BEGIN
                pixch = pixcho(windowindex)
		IF fitflg NE 0 THEN BEGIN
                  pia_plot, tmpdata.time, $
                        tmpdata.fitv(pixch,*), $
                        psym = loc_psymch, xtitle = xtitle, $
                        ytitle=ytitle, symsize = symsize, $
                        charsize = charsize
		  IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = 'Fitted Values [V]' 
		ENDIF ELSE $
		  XDISPLAYFILE, "", $
                    TITLE = "Data not available", $
                    WIDTH = 50, $
                    HEIGHT = 4, $
                    TEXT = [" The data has not been yet fitted - ", $
                          " Process and come again, please "]
		
               END

;Plot Readout flags
	  10: BEGIN
	    	elemnames =  flag_active_label   
		pixch = pixcho(windowindex)
		str_pixch = 'Flag ' + elemnames(menuchoi)+ ': Pixel '+ $
		   STRTRIM(pixch+1,2)
		title = str_pixch 
		;select flag depending on the choice
		IF flag_active_lex(menuchoi) EQ 'ENCODE' THEN        $
		    tmpflag = tmpdata.flag(pixch,*)                  $
		ELSE decode_piaflag,'ERD',flag_active_lex(menuchoi), $ 
		    tmpdata.flag(pixch,*),tmpflag
		    
		pia_plot, tmpdata.time, tmpflag, psym = psymch, $
			xtitle=xtitle, ytitle=ytitle, $
			charsize = charsize, symsize = symsize

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  

              END
                      
;Open Pixel
	  11: BEGIN
		pia_plot, tmpdata.time, tmpdata.conp(pixop,*),               $
			psym = loc_psymch, xtitle = xtitle, ytitle = ytitle, $
			charsize = charsize, symsize = symsize                
		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = 'Raw Data: Open Pixel  [V]' 

		IF disc_set THEN BEGIN
			indno = WHERE(erd_disc(pixop,*) eq 1, nn)
			IF loc_psymch EQ 3 THEN osymch=3 ELSE osymch=7
                        IF nn GT 0 THEN $
			  PIA_OPLOT, tmpdata.time(indno), $
			  tmpdata.conp(pixop,indno), $
			  psym = osymch, color=red
                ENDIF
          END

;Resistor Pixel
	  12: BEGIN
		pia_plot, tmpdata.time, tmpdata.conp(pixres,*), $
			psym = loc_psymch, xtitle = xtitle, ytitle = ytitle, $
			charsize = charsize, symsize = symsize                
		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = 'Raw Data: Resistor  [V]' 

		IF disc_set THEN BEGIN
			indno = WHERE(erd_disc(pixres,*) eq 1, nn)
			IF loc_psymch EQ 3 THEN osymch=3 ELSE osymch=7
                        IF nn GT 0 THEN $
			  PIA_OPLOT, tmpdata.time(indno), $
			  tmpdata.conp(pixres,indno), $
			  psym = osymch, color=red
                ENDIF

          END

;Open Pixel 2 - (SL only)
	  13: BEGIN
		pia_plot, tmpdata.time, tmpdata.conp(pixop+2,*), $
			psym = loc_psymch, $
			xtitle = xtitle, ytitle = ytitle, $
			charsize = charsize, symsize = symsize                 

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = 'Raw Data: Open Pixel SL [V]' 

		IF disc_set THEN BEGIN
			indno = WHERE(erd_disc(pixop+2,*) eq 1, nn)
			IF loc_psymch EQ 3 THEN osymch=3 ELSE osymch=7
                        IF nn GT 0 THEN $
			  PIA_OPLOT, tmpdata.time(indno), $
			  tmpdata.conp(pixop+2,indno), $
			  psym = osymch, color=red
                ENDIF
          END

;Resistor Pixel 2 - (SL only)
	  14: BEGIN
		pia_plot, tmpdata.time, tmpdata.conp(pixres+2,*), $
			psym = loc_psymch, $
			xtitle = xtitle, ytitle = ytitle, $
			charsize = charsize, symsize = symsize                 

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = 'Raw Data: Resistor SL [V]' 

		IF disc_set THEN BEGIN
			indno = WHERE(erd_disc(pixres+2,*) eq 1, nn)
			IF loc_psymch EQ 3 THEN osymch=3 ELSE osymch=7
                        IF nn GT 0 THEN $
			  PIA_OPLOT, tmpdata.time(indno), $
			  tmpdata.conp(pixres+2,indno), $
			  psym = osymch, color=red
                ENDIF


              END

	  ELSE: WIDGET_CONTROL, UPDATE_LABEL, $
				set_value = 'Unsupported View'
          ENDCASE
END


; ****************************************************************************
;  Event handling routine for PIA display menu
; ****************************************************************************

PRO pia_derd_event, event

COMMON degl_ramps_cmn, fsig, niter, minp
COMMON pdegl_str, pdegl_str

@adm
@phtcs
@phterd
@phtsrd
@phtacc
@splitramp_par

COMMON pia_dsperd_cmn, tmpdata, erdps, view, viewsize, nviews, viewoptions, $
    overid 
COMMON pia_dspcho_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON erdtext, erdattext_id, newheader
COMMON dispcust_cmn, psym, line
COMMON dsperd_widg, pixbut
common flg_acc_cmn, erd_disc, disc_set, fitflg, rpchopend1, rampend1
COMMON pia_widget_info, extfil_wid, intfil_wid, buffil_wid, $
			erddi1_wid, erddi2_wid, srddi1_wid, srddi2_wid, $
                        scpdi1_wid, scpdi2_wid, spddi1_wid, spddi2_wid, $
                        aapdi1_wid, aapdi2_wid
COMMON degl_summary, deglsum
COMMON pia_rodis_out, pia_rodis_err
COMMON phtpatt, patt_str


	WIDGET_CONTROL, event.id, get_uvalue = uvalue
        WIDGET_CONTROL, event.top, /HOURGLASS

	cmap_wind_text = ["A","B","C","D"]

	CASE uvalue OF


 	  "EXIT":  BEGIN
		    WIDGET_CONTROL, event.top, /DESTROY 
		  END

 	  "SAVEXIT":  BEGIN
	  	    fill_erd, tmpdata, newheader, REPLACE=erdps
		    WIDGET_CONTROL, event.top, /DESTROY 
		  END


          "HELP":  BEGIN
	   	IF !VERSION.OS NE 'vms' THEN $
		spawn, '$w3net $PIA_HTML/um/erd_window.html &' ELSE $
		spawn, 'w3net /pia_dsk/pia/html/um/erd_window.html'
		END

	  "CUST": BEGIN
			pia_dispcust, GROUP=event.top
			psymch = psym
			 FOR I=0,NVIEWS-1 DO BEGIN
			    pia_resetview, i, view(i).controlid
			 ENDFOR
          END

	  "LOAD": BEGIN
; search for same file and detector type
		    newdata = pickmeas(FTYPE="ERD", DTYPE=tmpdata.det, POSI=posi)
		    IF newdata NE '' THEN BEGIN

                     datind = WHERE(phterd.admn eq newdata, count)

                     IF count EQ 0 THEN $
                        MESSAGE, /INFO, 'Measurement not found!'

                     ;;IF count GT 1 THEN datind=datind(posi(0))

                     IF count NE 0 THEN BEGIN 
                     
                        erdps = datind(posi(0))

			pia_load_ierd, phterd(erdps), tmpdata		
; Decode pixf, produce DR
	                decode_pixf, tmpdata.pixf, susp, chpon, chps, dr, otf
; Look into the selection criteria

                        get_rodisc, tmpdata, /ENCODE_FLAG, DR=dr , OTF=oft 

; Flag also the saturated voltages (only for real pixels)
	                get_accvolt, tmpdata, dr, /ENCODE_FLAG
 
; Get all severe flags 
	                get_validflag, tmpdata.flag, 'ERD', redflag, $
	                  det=tmpdata.det, /allpix

                        erd_disc = redflag
                        disc_set = 1

; Look for different rastersteps and chopper plateaux, plus end of ramps
                        get_rastersteps, tmpdata.rpid, raststeps
                        get_rpchopstep, raststeps, tmpdata.step, rpchopstep, $
			   JUMP=rpchopend
                        rpchopend1 = rpchopend
	  
; get index with the ramp ends
			GIVE_CS, tmpdata, cst, record 
                        GET_RAMPEND, tmpdata.time, dr, tmpdata.tint, rampflag,$
			 rampend, datred=cst.drs(record)
	                rampend1 = rampend


; header update
			newheader = tmpdata.hdr
			
; window labelling update			
			obj = FXPAR(tmpdata.hdr,'OBJECT')
			attra = FXPAR(tmpdata.hdr,'ATTRA')
			attdec = FXPAR(tmpdata.hdr,'ATTDEC')
			decode_admn, tmpdata.admn, dattext
			more_text = 'OBJ:' + obj + ' ' + give_sradec(attra,attdec) 
			dattext = 'ERD '+dattext+ ' - '+$
				tmpdata.unit+ ' - ' + more_text

			WIDGET_CONTROL, erdattext_id, SET_VALUE = dattext 

 		        FOR i=0, NVIEWS - 1 do pia_resetview, i
		     END
		    ENDIF
		  END	                  	

	  "SAVE": BEGIN
	  	    change_tmphdr, tmpdata, 'ERD', newheader, tmpout
	  	    PCONT_SAVEINT, junk, 'ERD', tmpdata=tmpout
;		    PIA_WRITE_IERD, tmpdata 
;		    indcs = WHERE(phtcs.unit EQ STRMID(tmpdata.admn,4,8), count)
;		    IF count GT 0 THEN BEGIN
;		      PIA_LOAD_ICS, phtcs(indcs(0)), tmpcs
;		      PIA_WRITE_ICS, tmpcs
;		    ENDIF ELSE MESSAGE, /INFO, $
;		    	'Compact Status not found in common, not saved' 
		  END

	  "SAVEBUFF": fill_erd, tmpdata, newheader, REPLACE=erdps

	  "SAVEBUFF_NEW": BEGIN
	               erdps = N_ELEMENTS(phterd)
                       fill_erd, tmpdata, newheader
                   END

	  "SHOWD": PIA_SHOWSTR, tmpdata, VALNAMES=phterd_desc, GROUP=event.top 

	  "RODISC":BEGIN
			PIA_RODISC, NNDR=tmpdata.nndr
 			IF pia_rodis_err THEN RETURN
			
        		WIDGET_CONTROL, event.top, /HOURGLASS
			get_rodisc, tmpdata, /ENCODE_FLAG

			get_validflag, tmpdata.flag, 'ERD', redflag, $
		  		det=tmpdata.det, /allpix

			erd_disc = redflag
	        	disc_set = 1

                       FOR j=0,nviews-1 DO pia_resetview, j
                   END

	  "RAMPRECON": BEGIN
	  	REBUILD_TMPERD, tmpdata, newconp, newflag
		tmpdata.conp = newconp
		tmpdata.flag = newflag
		FOR j=0,nviews-1 DO pia_resetview, j
	  END


	  "PAARDEGL": BEGIN
	  
		indsevere_deglitch = set_indsevere('ERD',['GLITCH'],$
		     /DELETE)
		get_validflag, tmpdata.flag, 'ERD', redflag, $
		   INDSEVERE = indsevere_deglitch,det=tmpdata.det,/allpix
	  
		RAMP_2T_DEGLITCH, tmpdata, redflag, newheader, $
			/ENCODE_FLAG
; reset the windows
		FOR I=0,NVIEWS-1 DO BEGIN
			    WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
			    view(i).windownum = temp
			    pia_resetview, i, view(i).controlid
		ENDFOR
	  END
	  	
	  "RODEGL": BEGIN
		ramp_deglitch, tmpdata, newheader,erd_disc, rampend1, $
		  /ENCODE_FLAG

; reset the windows
		FOR I=0,NVIEWS-1 DO BEGIN
			    WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
			    view(i).windownum = temp
			    pia_resetview, i, view(i).controlid
		ENDFOR
	  
	  END
	  "NLCORR": BEGIN
; check: if linearity correction already applied return		
		done = fxpar(newheader,'PR_LINC')
		IF done NE 0 THEN BEGIN
			XDISPLAYFILE, "", $
                    	  GROUP = event.top, $
                    	  TITLE = "Not Allowed ", $
                    	  WIDTH = 50, $
                    	  HEIGHT = 12, $
                    	  TEXT = [" Linearity correction for this", $
                            	  " measurement was already applied "]
			RETURN
		ENDIF
		
; check: if deglitching correction already applied warn the user		
		done = fxpar(newheader,'PR_DGLF')
		IF done NE 0 THEN BEGIN
			XDISPLAYFILE, "", $
                    	  GROUP = event.top, $
                    	  TITLE = "Warning ", $
                    	  WIDTH = 50, $
                    	  HEIGHT = 12, $
                    	TEXT = [" You require a linearity correction for this", $
                            	"measurement after deglitching - This might", $
                            	"change incorrectly the 'deglitched' voltages "]
		ENDIF

		lin_voltages, tmpdata, newheader

; fill in the dynamical structures
; put the new elements into the dynamical structure
;		index = WHERE(phterd.admn EQ tmpdata.admn, count)
;
;               IF count EQ 0 THEN BEGIN
;                        MESSAGE, /INFO, 'Measurement not found!, returning'
;			RETURN
;		ENDIF
;
;                IF count GT 1 THEN BEGIN
;			measlist = phterd(index).admn
;                        pia_multmeas, measlist
;			index = index(measlist)
;		ENDIF
;		
;		index = index(0)

; fill in the dynamical structures
;		HANDLE_VALUE, phterd(index).conp, tmpdata.conp, /SET
;		HANDLE_VALUE, phterd(index).hdr, newheader, /SET

		FOR I=0,NVIEWS-1 DO BEGIN
			    WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
			    view(i).windownum = temp
			    pia_resetview, i, view(i).controlid
		ENDFOR
	  END	    
 
	  "SATCORR": BEGIN 
	        PIA_SATLEV, pia_satlev_err
		IF pia_satlev_err THEN RETURN
      	        WIDGET_CONTROL, event.top, /HOURGLASS
                ; change flag for the saturated voltages (only for real pixels)
	        decode_pixf, tmpdata.pixf, susp, chpon, chps, dr, otf
	        get_accvolt, tmpdata, dr, /ENCODE_FLAG
	  
                ; Reset  discard flags 
	        get_validflag, tmpdata.flag, 'ERD', redflag, $
	                det=tmpdata.det, /allpix
                erd_disc = redflag

	        ;reset window views
		FOR I=0,NVIEWS-1 DO BEGIN
			    WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
			    view(i).windownum = temp
			    pia_resetview, i, view(i).controlid
		ENDFOR
		    
	  END    

	  "RPIDSET": BEGIN
	  	tmpdata.rpid = tmpdata.rpid * 0 + 1b
		FXADDPAR, newheader, 'PR_RPID0', 'RPID change', $
		       "All RPID's set to [1b,1b] ", BEFORE='XTENSION'

;		index = WHERE(phterd.admn EQ tmpdata.admn, count)
;
;               IF count EQ 0 THEN BEGIN
;                       MESSAGE, /INFO, 'Measurement not found!, returning'
;			RETURN
;		ENDIF
;
;                IF count GT 1 THEN BEGIN
;			measlist = phterd(index).admn
;                        pia_multmeas, measlist
;			index = index(measlist)
;		ENDIF
;		
;		index = index(0)

; fill in the dynamical structures
;		HANDLE_VALUE, phterd(index).rpid, tmpdata.rpid, /SET
;		HANDLE_VALUE, phterd(index).hdr, newheader, /SET
	  END
	  	

	  "HDR": BEGIN
		header = newheader
		IF N_ELEMENTS(header) EQ 0 THEN $
			MESSAGE, /INFO, 'No header defined' ELSE $
			pia_disp_hdr, header, tmpdata.admn, 'PHTERD'
	  END	    
		      
	  "CS": PIA_disp_cs,tmpdata.admn

	  "ISREP": PIA_disp_isr,STRMID(tmpdata.admn,4,8)

	  "OLREP": PIA_disp_olr,STRMID(tmpdata.admn,4,8)

	  "EOHA": PIA_disp_eoha,STRMID(tmpdata.admn,4,8)

	  "EOHI": PIA_disp_eohi,STRMID(tmpdata.admn,4,8)

	  "DEGSTAT": BEGIN
		decode_admn, tmpdata.admn, meastxt
		length = STRLEN(meastxt)
		IF N_ELEMENTS(deglsum) EQ 0 THEN deglsum=STRARR(1) 
		IF meastxt EQ STRMID(deglsum(0),0,length) THEN $
	  	   PIA_DISP_PRINT_FILE, 'degl_stat_'+tmpdata.admn, $
	  	   	TITLE='Deglitching Statistics',$
	  		TEXT=deglsum  ELSE $
	  	   Xdisplayfile, '', TITLE='Not deglitched yet?', $
	  	   	TEXT=['Deglitch data and try again ...']
	  END

	  "DIVRAMPS": BEGIN 
		    readouts = tmpdata.nndr + 1
		    pia_pseudo_rd, readouts, fct
		    IF fct.model EQ -1 THEN RETURN
		    splitramp_par = fct
		    
;		    FXADDPAR, newheader, 'PR_SEPAR', fct, $
;		       ' Number of read-outs used for pseudo-ramp', BEFORE='XTENSION'
        	    WIDGET_CONTROL, event.top, /HOURGLASS
		    process_tmperd, tmpdata, 1, newheader, srdpos, $
		    	/div_ramp
;		    handle_value, phterd(erdps).fitv, fitv
;		    tmpdata.fitv = fitv
;		    fitflg = 1
		    PIA_DISPSRD, data = srdpos
	  END	    

	  "POL1": BEGIN 
		    process_tmperd, tmpdata, 1, newheader, srdpos
;		    handle_value, phterd(erdps).fitv, fitv
;		    tmpdata.fitv = fitv
		    fitflg = 1
		    PIA_DISPSRD, data = srdpos
	  END	    

	  "POL2": BEGIN 
		    process_tmperd, tmpdata, 2, newheader, srdpos
;		    handle_value, phterd(erdps).fitv, fitv
;		    tmpdata.fitv = fitv
		    fitflg = 1
		    PIA_DISPSRD, data = srdpos
	  END	    

	  "POL3": BEGIN 
		    process_tmperd, tmpdata, 3, newheader, srdpos
;		    handle_value, phterd(erdps).fitv, fitv
;		    tmpdata.fitv = fitv
		    fitflg = 1
		    PIA_DISPSRD, data = srdpos
	  END	    

	  "PATTERN": BEGIN
	  	    IF N_ELEMENTS(patt_str) EQ 0 THEN pia_patt_defin
	  	    process_erd_to_pattern, tmpdata, $
	  	      newhdr=newheader, srdpos=srdpos,$
	  	      disc_framp=patt_str.disc_framp, $
	  	      log_ramps=patt_str.log_ramps
                    
                    IF sig1acc OR sigtnacc.chop_meas NE 0. THEN BEGIN
                       sig1acc=0
                       sigtnacc.chop_meas=0.
                       PRINT, 'Changing defaults for discarding signals'
                    ENDIF
                    PIA_DISPSRD, data = srdpos
 	   END	  	    
	  	    	  	
	  "PATT_CUST": pia_patt_defin
	  	    
	  "PIXCH": BEGIN
			old_pixcho = pixcho
			new_pixc = $
			  pia_pixchoice(GROUP=event.top, PIXC=pixcho, nv=nviews)
			maxpix = max(new_pixc)
			minpix = min(new_pixc)
			junk = 0
			IF (tmpdata.det EQ 'C1' AND maxpix gt 8) OR $
			   (tmpdata.det EQ 'C2' AND maxpix gt 3) OR $
			   (tmpdata.det EQ 'SS' AND maxpix gt 127) OR $
			   (tmpdata.det EQ 'SL' AND maxpix gt 127) OR $
			   (minpix lt 0) THEN BEGIN
		    		XDISPLAYFILE, "", $
                    		GROUP = event.top, $
                    		TITLE = "Warning ", $
                    		WIDTH = 30, $
                    		HEIGHT = 6, $
                    		TEXT = [" Your pixel choice is not valid ", $
                                        " and will not be taken "]
		                junk = 1
			ENDIF
			IF junk NE 1 THEN BEGIN  			
			 FOR I=0,NVIEWS-1 DO BEGIN
			  IF new_pixc(i) NE old_pixcho(i) THEN BEGIN
			    pixcho(i) = new_pixc(i)
			    WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
			    view(i).windownum = temp
			    pia_resetview, i, view(i).controlid
			    IF STRMID(tmpdata.det,0,1) EQ 'C' THEN BEGIN 
			      txtval = cmap_wind_text(i)
			      junk = where(new_pixc eq old_pixcho(i), count)
			      IF count EQ 0 THEN $
			         WIDGET_CONTROL, pixbut(old_pixcho(i)), $
					SET_VALUE = ' '
			      WIDGET_CONTROL, pixbut(pixcho(i)), $
					SET_VALUE = txtval
			    ENDIF 
                          ENDIF
			 ENDFOR
			ENDIF
          END

	  "PIXCHSER": BEGIN
			old_pixcho = pixcho
			new_pixc = old_pixcho + nviews
			CASE STRMID(tmpdata.det,0,2) OF
				'C1': npix = 9
				'C2': npix = 4
				'SL': npix = 128
				'SS': npix = 128
				'P1': RETURN
				'P2': RETURN
				'P3': RETURN
			ENDCASE  
			new_pixc = new_pixc mod npix
			
			FOR I=0,NVIEWS-1 DO BEGIN
			  IF new_pixc(i) NE old_pixcho(i) THEN BEGIN
			    pixcho(i) = new_pixc(i)
			    WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
			    view(i).windownum = temp
			    pia_resetview, i, view(i).controlid
			    IF STRMID(tmpdata.det,0,1) EQ 'C' THEN BEGIN 
			      txtval = cmap_wind_text(i)
			      junk = where(new_pixc eq old_pixcho(i), count)
			      IF count EQ 0 THEN $
			         WIDGET_CONTROL, pixbut(old_pixcho(i)), $
					SET_VALUE = ' '
			      WIDGET_CONTROL, pixbut(pixcho(i)), $
					SET_VALUE = txtval
			    ENDIF 
                          ENDIF
			ENDFOR
          END

	  "PIXCHSERD": BEGIN
			old_pixcho = pixcho
			new_pixc = old_pixcho - nviews
			CASE STRMID(tmpdata.det,0,2) OF
				'C1': npix = 9
				'C2': npix = 4
				'SL': npix = 128
				'SS': npix = 128
				'P1': RETURN
				'P2': RETURN
				'P3': RETURN
			ENDCASE  
			ind=WHERE(new_pixc LT 0,nind)
			IF nind GT 0 THEN new_pixc(ind) = npix+new_pixc(ind)  
						
			FOR I=0,NVIEWS-1 DO BEGIN
			  IF new_pixc(i) NE old_pixcho(i) THEN BEGIN
			    pixcho(i) = new_pixc(i)
			    WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
			    view(i).windownum = temp
			    pia_resetview, i, view(i).controlid
			    IF STRMID(tmpdata.det,0,1) EQ 'C' THEN BEGIN 
			      txtval = cmap_wind_text(i)
			      junk = where(new_pixc eq old_pixcho(i), count)
			      IF count EQ 0 THEN $
			         WIDGET_CONTROL, pixbut(old_pixcho(i)), $
					SET_VALUE = ' '
			      WIDGET_CONTROL, pixbut(pixcho(i)), $
					SET_VALUE = txtval
			    ENDIF 
                          ENDIF
			ENDFOR
          END

	"NVIEWS": BEGIN

		newviews = event.value + 1
		!PIA_NVIEWS = 1 > newviews < 4
		IF newviews NE nviews THEN BEGIN
			WIDGET_CONTROL, erddi1_wid, /DESTROY
			pia_disperd, NV=newviews, /redraw
		ENDIF
         END

       "HK" : begin
		get_pht_hk,tmpdata.admn,phtcs_redu
		xdisp_hk
              end

       "HK_FULL" : begin
		get_pht_hk,tmpdata.admn,phtcs_redu, /FULL_TDT
		xdisp_hk
              end
	ENDCASE
	
RETURN
END

; ****************************************************************************
;  PIA DispERD - menu definition procedure
; ****************************************************************************

PRO pia_dispERD, GROUP=group, DATA=DATA, NV = NV, REDRAW=redraw, $
	tmpstr=tmpstr, newh=newh


COMMON pia_dsperd_cmn, tmpdata, erdps, view, viewsize, nviews, viewoptions, $
   overid 
COMMON pia_dsperd_flg_cmn, nflag_active, flag_active_lex, flag_active_label  
COMMON pia_dspcho_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON erdtext, erdattext_id, newheader
COMMON dsperd_widg, pixbut
common flg_acc_cmn, erd_disc, disc_set, fitflg, rpchopend1, rampend1
COMMON pia_widget_info, extfil_wid, intfil_wid, buffil_wid, $
			erddi1_wid, erddi2_wid, srddi1_wid, srddi2_wid, $
                        scpdi1_wid, scpdi2_wid, spddi1_wid, spddi2_wid, $
                        aapdi1_wid, aapdi2_wid
COMMON dispcust_cmn, psym, line
COMMON pdegl_str, pdegl_str

@phterd
COMMON piaflag_info, piaflag_str

; If already registered, start second ERD display

        IF Xregistered("pia_disperd") NE 0 THEN BEGIN
                pia_dis2erd, group=group, data=data
                RETURN
        END


; load data from dynamical buffers into temporary structure

	IF NOT KEYWORD_SET(redraw) AND NOT KEYWORD_SET(tmpstr) THEN BEGIN
; load data from dynamical buffers into temporary structure
 	        erdps = data
		PIA_LOAD_IERD, phterd(erdps), tmpdata 
                newheader = tmpdata.hdr
;set selection to not in the beginning
                disc_set=0
; look if fitted values are present
                ind = WHERE(tmpdata.fitv NE -99, n)
                IF n GT 0 THEN fitflg = 1 ELSE fitflg = 0
	ENDIF
; Use temporary structure 
	IF KEYWORD_SET(tmpstr) THEN BEGIN
	  tmpdata=tmpstr
	  IF KEYWORD_SET(newh) THEN newheader=newh ELSE newheader=tmpdata.hdr
; look if fitted values are present
                ind = WHERE(tmpdata.fitv NE -99, n)
                IF n GT 0 THEN fitflg = 1 ELSE fitflg = 0
	ENDIF

	npix = pixel_det(tmpdata.det)
	nele = tmpdata.dims

        ; Decode pixf, produce DR
	decode_pixf, tmpdata.pixf, susp, chpon, chps, dr, otf
	
; Look into the selection criteria

        get_rodisc, tmpdata, /ENCODE_FLAG, DR=dr , OTF=otf 

; Flag also the saturated voltages (only for real pixels)
        
	get_accvolt, tmpdata, dr, /ENCODE_FLAG
        		
; Look for different rastersteps and chopper plateaux, plus end of ramps
        get_rastersteps, tmpdata.rpid, raststeps
        get_rpchopstep, raststeps, tmpdata.step, rpchopstep, JUMP=rpchopend
          rpchopend1 = rpchopend
	  
; get index with the ramp ends
	  GIVE_CS, tmpdata, cst, record, conv_cst 
          GET_RAMPEND, tmpdata.time, dr, tmpdata.tint, rampflag, rampend,$
	    datred=cst.drs(record)
	  rampend1 = rampend
	  
; Get all severe flags 
	get_validflag, tmpdata.flag, 'ERD', redflag, $
	  det=tmpdata.det, /allpix

        erd_disc = redflag
        disc_set = 1

; initialize views and pixels chosen
	IF KEYWORD_SET(NV) THEN NVIEWS = nv ELSE nviews = !PIA_NVIEWS
	IF nviews GT 4 THEN nviews = 4
	pixcount = -1

	IF N_ELEMENTS(psym) EQ 0 THEN psymch = 4 ELSE $
		psymch = psym	

	IF n_elements(pdegl_str) EQ 0 THEN pdegl_str_init

	CASE STRMID(tmpdata.det, 0,1) of 
          'P': BEGIN 
		pixcho = [0,0,0,0]
		pixop = 0
		pixres = 0
	  END
          ELSE: BEGIN  
	         CASE STRMID(tmpdata.det,0,2) of
	           'C1': BEGIN
			pixcho = [0,2,4,6]
			pixop = 9
			pixres = 10
		   END
	           'C2': BEGIN
			pixcho = [1,2,3,0]
			pixop = 4
			pixres = 5
		   END
	           'SS': BEGIN
			pixcho = [10,40,90,120]
			pixop = 128
			pixres = 129
		   END
	           'SL': BEGIN
			pixcho = [10,40,90,120]
			pixop = 128
			pixres = 129
		   END
	 	  ENDCASE		
	  END
        ENDCASE

	indflag_active = WHERE(piaflag_str.erd.lex NE 'DUMMY',nflag_active)
	
	nflag_active = nflag_active +1
	
	flag_active_lex = ['ENCODE',piaflag_str.erd.lex(indflag_active)]
	flag_active_label = ['Encode',piaflag_str.erd.expla(indflag_active)]

	viewsize = 220
	xsize = viewsize * 4 / nviews
	ysize = viewsize

	;structure for each view
	viewinstance = { 	viewtype:0b, 		$	   
				viewtype_sub:0b, 	$       
				controlid:0L,		$       
				windowid:0L,		$
				windownum:0}	

        view = REPLICATE(viewinstance, NVIEWS)		; array of view struct.
	
        IF STRMID(tmpdata.det, 0,1) eq 'P' THEN $
		FOR i=0,nviews-1 DO view(i).viewtype = i  

	;structures describing each type of view 
	instance = {viewname:'', viewid:0, viewxlab:'', viewylab:'', $
		 viewmenu:0, viewmenuchoi:0,viewmenulabel:STRARR(nflag_active) }
	NVIEWOPTS = 15                           	 

	viewoptions = REPLICATE(instance, NVIEWOPTS)    

	viewoptions(0).viewname = "Raw Pixel Data      [Volt]" 
	viewoptions(0).viewid = 0
	viewoptions(0).viewylab = "Raw Data   [V]"
	viewoptions(0).viewxlab = "Time       [s]"
	viewoptions(1).viewname = "Unconverted Data      [DN]"
	viewoptions(1).viewid = 1
	viewoptions(1).viewylab = "Digital Data  [DN]"
	viewoptions(1).viewxlab = "Time       [s]"
	viewoptions(2).viewname = "Chopper Position    [arcsec]"
	viewoptions(2).viewid = 2
	viewoptions(2).viewylab = "Chopper position    [arcsec]"
	viewoptions(2).viewxlab = "Time       [s]"
	viewoptions(3).viewname = "Temperature            [K]"
	viewoptions(3).viewid = 3
	viewoptions(3).viewylab = "Measured temperature   [K]"
	viewoptions(3).viewxlab = "Time       [s]"
	viewoptions(4).viewname = "FCS1 electrical Power [mW]"
	viewoptions(4).viewid = 4
	viewoptions(4).viewylab = "Electrical Power      [mW]"
	viewoptions(4).viewxlab = "Time       [s]"
	viewoptions(5).viewname = "FCS2 electrical Power [mW]"
	viewoptions(5).viewid = 5
	viewoptions(5).viewylab = "Electrical Power      [mW]"
	viewoptions(5).viewxlab = "Time       [s]"
	viewoptions(6).viewname = "Time Key"
	viewoptions(6).viewid = 6
	viewoptions(6).viewylab = "Instrument Time Key "
	viewoptions(6).viewxlab = "Time       [s]"
	viewoptions(7).viewname = "Raster Point ID"
	viewoptions(7).viewid = 7
        viewoptions(7).viewmenu = 1
        viewoptions(7).viewmenuchoi = 2
        viewoptions(7).viewmenulabel = ['1','2']
	viewoptions(7).viewylab = "Raster Point ID "
	viewoptions(7).viewxlab = "Time       [s]"
	viewoptions(8).viewname = "Bit Flags"
	viewoptions(8).viewid = 8
	viewoptions(8).viewylab = "PIXF coded word "
	viewoptions(8).viewxlab = "Time       [s]"
        viewoptions(9).viewname = "Fitted Readout Values  [V]"
        viewoptions(9).viewid = 9
        viewoptions(9).viewylab = "Fitted Data           [V]"
        viewoptions(9).viewxlab = "Time       [s]"
	viewoptions(10).viewname = "Readout Flags"
	viewoptions(10).viewid = 10
        viewoptions(10).viewmenu = 1
        viewoptions(10).viewmenuchoi = nflag_active
        viewoptions(10).viewmenulabel = flag_active_label
	viewoptions(10).viewylab = "Flag         "
	viewoptions(10).viewxlab = "Time       [s]"
	viewoptions(11).viewname = "Open Pixel Data     [Volt]"
	viewoptions(11).viewid = 11
	viewoptions(11).viewylab = "Raw Data Open Pixel   [V] "
	viewoptions(11).viewxlab = "Time       [s]"
	viewoptions(12).viewname = "Resistor Pixel Data [Volt]"
	viewoptions(12).viewid = 12
	viewoptions(12).viewylab = "Raw Data Resistor     [V] "
	viewoptions(12).viewxlab = "Time       [s]"
	viewoptions(13).viewname = "Open Pixel Data SL  [Volt]"
	viewoptions(13).viewid = 13
	viewoptions(13).viewylab = "Raw Data Open Pixel SL  [V] "
	viewoptions(13).viewxlab = "Time       [s]"
	viewoptions(14).viewname = "Resistor Pixel Data SL [Volt]"
	viewoptions(14).viewid = 14
	viewoptions(14).viewylab = "Raw Data Resistor SL    [V] "
	viewoptions(14).viewxlab = "Time       [s]"

; top base

	erddi1_wid = WIDGET_BASE( TITLE="PIA ERD Data Display", /COLUMN, $
				XPAD = 20, YPAD = 20, SPACE = 20)

;------------------- the Control windows -------------------------

	control = WIDGET_BASE(erddi1_wid, /ROW)

	control_exit = WIDGET_BUTTON(control, VALUE="    Exit    ",$
					 /ALIGN_CENTER, /MENU)
	save_quit = WIDGET_BUTTON(control_exit, $
		VALUE="Save modified measurement into buffer and Quit",$
					 UVALUE="SAVEXIT")
	simple_quit = WIDGET_BUTTON(control_exit, $
		VALUE="Quit without saving modified measurement into buffer",$
					 UVALUE="EXIT")
	control_help = WIDGET_BUTTON(control, VALUE="    Help    ",$
					 /ALIGN_CENTER, UVALUE="HELP")
	control_cust = WIDGET_BUTTON(control, VALUE="  Customize ",$
					 /ALIGN_CENTER, UVALUE="CUST")


	junk = WIDGET_LABEL(control, VALUE = '  ')

	obj = FXPAR(tmpdata.hdr,'OBJECT')
	attra = FXPAR(tmpdata.hdr,'ATTRA')
	attdec = FXPAR(tmpdata.hdr,'ATTDEC')
	decode_admn, tmpdata.admn, dattext
	more_text = 'OBJ:' + obj + ' ' + give_sradec(attra, attdec)
	dattext = 'ERD '+dattext+ ' - '+tmpdata.unit+ ' - ' + more_text

	erdattext_id = WIDGET_LABEL(control, VALUE = dattext)  

;------------------- the C mapping windows -------------------------

	junk = WIDGET_LABEL(control, VALUE = '    ')

	IF STRMID(tmpdata.det, 0,1) eq 'C' THEN BEGIN 

	pixver = WIDGET_BASE(control, /COLUMN)
	junk = WIDGET_LABEL(pixver, VALUE='^ +Z')

	pixhor = WIDGET_BASE(pixver,/ROW)

	  IF STRMID(tmpdata.det, 1,1) eq '1' THEN BEGIN
                pixbut = lonarr(9)
		FOR i=0,2 DO pixbut(i*3+2) = $
			WIDGET_BUTTON(pixhor, VALUE=' ',$
				XOFFSET=3*i, $,
				UVALUE=i*3+2,$
				EVENT_PRO = 'pixbutevent')
		pixhor = WIDGET_BASE(pixver,/ROW,YOFFSET=10)
		FOR i=0,2 DO pixbut(i*3+1) = $
			WIDGET_BUTTON(pixhor, VALUE=' ',$
				XOFFSET=3*i, $
				UVALUE=i*3+1,$
				EVENT_PRO = 'pixbutevent')
		pixhor = WIDGET_BASE(pixver,/ROW,YOFFSET=10)
		FOR i=0,2 DO pixbut(i*3) = $
			WIDGET_BUTTON(pixhor, VALUE=' ',$
				XOFFSET=3*i, $
				UVALUE=i*3,$
				EVENT_PRO = 'pixbutevent')
          ENDIF ELSE $      
	  IF STRMID(tmpdata.det, 1,1) eq '2' THEN BEGIN
                pixbut = lonarr(4)
		FOR i=0,1 DO pixbut(i+2) = $
			WIDGET_BUTTON(pixhor, VALUE=' ',$
				XOFFSET=3*i, $
				UVALUE=i+2,$
				EVENT_PRO = 'pixbutevent')
		pixhor = WIDGET_BASE(pixver,/ROW,YOFFSET=10)
		FOR i=1,0,-1 DO pixbut(i) = $
			WIDGET_BUTTON(pixhor, VALUE=' ',$
				XOFFSET=3*i, $
				UVALUE=i,$
				EVENT_PRO = 'pixbutevent')
          ENDIF      
	junk = WIDGET_LABEL(pixhor, VALUE='> +Y')
        ENDIF

;----------------- the View windows are defined ------------------

	viewbase = WIDGET_BASE(erddi1_wid, /ROW, SPACE=1)

	viewstorageids = LONARR(NVIEWS)
	overid = lonarr(NVIEWS)	   
	
; Provide for Open and Resistor pixels only if necessary
	IF STRMID(tmpdata.det, 0,1) NE 'S' THEN NVIEWOPTS = NVIEWOPTS - 2
	IF STRMID(tmpdata.det, 0,1) EQ 'P' THEN NVIEWOPTS = NVIEWOPTS - 2

        cmap_wind_text = ["A","B","C","D"]

        FOR viewindex = 0, NVIEWS - 1 DO BEGIN
	  viewbase_sub = WIDGET_BASE(viewbase, /FRAME, /COLUMN)
	  junk = WIDGET_LABEL(viewbase_sub, $
	       VALUE="Window "+cmap_wind_text(viewindex))
	  tempbase = WIDGET_BASE(viewbase_sub, /COLUMN, $
				EVENT_PRO = 'viewevent')
	  view(viewindex).controlid = WIDGET_BUTTON(tempbase, VALUE="   ",$
				MENU = 2, UVALUE = viewindex, $
				EVENT_PRO = 'viewevent')
	  view(viewindex).windowid = WIDGET_DRAW(tempbase, $
				XSIZE = xsize, YSIZE = ysize, $
				RETAIN = 2) 
		FOR i = 0, NVIEWOPTS - 1 DO BEGIN
     			dummy = WIDGET_BUTTON(view(viewindex).controlid, $
                	VALUE = viewoptions(i).viewname, $
                	UVALUE = viewoptions(i).viewid,                    $
			MENU=viewoptions(i).viewmenu)
			IF viewoptions(i).viewmenu THEN BEGIN
			   FOR ichoi=0,viewoptions(i).viewmenuchoi-1 DO    $
			   dummy1 = WIDGET_BUTTON(dummy,                   $
			     VALUE=viewoptions(i).viewmenulabel(ichoi),    $
			     UVALUE=ichoi)
			ENDIF     

		ENDFOR

	  zoombase = WIDGET_BASE(tempbase, /FRAME, /ROW)

     	  zoom = WIDGET_BUTTON(zoombase, $
                  	VALUE = "Zoom & Print", $
                	UVALUE = viewindex, MENU = 2)

     	  dummy = WIDGET_BUTTON(zoom, $
                  	VALUE = "New Plot ", $
                	UVALUE = viewindex, EVENT_PRO = 'zoomevent')

          synch = WIDGET_BUTTON(zoom, $
                        VALUE = "Overplot, same y-axis  ", $
                        UVALUE = viewindex, EVENT_PRO = 'zoomsync')
          nsynch = WIDGET_BUTTON(zoom, $
                        VALUE = "Overplot, new y-axis", $
                        UVALUE = viewindex, EVENT_PRO = 'zoomnsync')


     	  process = WIDGET_BUTTON(zoombase, $
                  	VALUE = "Test processing", $
                	UVALUE = viewindex, MENU = 2)

     	  fitid = WIDGET_BUTTON(process, $
                  	VALUE = "Fit Ramps", $
                	UVALUE = viewindex, MENU = 2)

     	  fit1 = WIDGET_BUTTON(fitid, $
                  	VALUE = '1st Order Pol.', $
                	UVALUE = viewindex, EVENT_PRO = 'fitram1' )

     	  fit2 = WIDGET_BUTTON(fitid, $
                  	VALUE = '2nd Order Pol.', $
                	UVALUE = viewindex, EVENT_PRO = 'fitram2' )

     	  fit3 = WIDGET_BUTTON(fitid, $
                  	VALUE = '3rd Order Pol.', $
                	UVALUE = viewindex, EVENT_PRO = 'fitram3' )

     	  fits = WIDGET_BUTTON(fitid, $
                  	VALUE = 'Ramp sub-division', $
                	UVALUE = viewindex, EVENT_PRO = 'fitrams' )

     	  fourier = WIDGET_BUTTON(process, $
                  	VALUE = "Fourier", $
                	UVALUE = viewindex, EVENT_PRO = 'zoomfourier')
	  
     	  average = WIDGET_BUTTON(process, $
                  	VALUE = "Average", $
                	UVALUE = viewindex, EVENT_PRO = 'averageevent')
	  
     	  median = WIDGET_BUTTON(process, $
                  	VALUE = "Median", $
                	UVALUE = viewindex, EVENT_PRO = 'medianevent')
	  
     	  degl = WIDGET_BUTTON(process, $
                  	VALUE = "Test deglitching (Single Threshold)", $
                	UVALUE = viewindex, EVENT_PRO = 'deglitch_test')

     	  degl = WIDGET_BUTTON(process, $
                  	VALUE = "Test deglitching (2 Threshold method)", $
                	UVALUE = viewindex, EVENT_PRO = 'pair_deglitch_test')

          discar = WIDGET_BUTTON(process, $
                        VALUE = "Discard area graphically", $
                        UVALUE = viewindex, EVENT_PRO= 'discard_area')

          resel = WIDGET_BUTTON(process, $
                        VALUE = "Reselect area graphically", $
                        UVALUE = viewindex, EVENT_PRO= 'reselect_area')
        ENDFOR

	controlbase = WIDGET_BASE(erddi1_wid, $
                /ROW, $
                SPACE = 40)


;----------------- the Data controls are defined ------------------

        datcont = WIDGET_BUTTON(controlbase, VALUE='    Data    ', /MENU )
        id_2 = WIDGET_BUTTON(datcont, VALUE='Load', UVALUE='LOAD' )
        id_2 = WIDGET_BUTTON(datcont, VALUE='Save', /MENU)
        id_3 = WIDGET_BUTTON(id_2, VALUE='to ERD buffer',/MENU)
        id_4 = WIDGET_BUTTON(id_3, VALUE='new measurement', $
				UVALUE = 'SAVEBUFF_NEW')
	id_4 = WIDGET_BUTTON(id_3, VALUE='same measurement', $
				 UVALUE='SAVEBUFF' )
	id_3 = WIDGET_BUTTON(id_2, VALUE='to PIA internal file',UVALUE='SAVE')
        id_2 = WIDGET_BUTTON(datcont, VALUE='Show Data', UVALUE='SHOWD' )

;---------------- the Selection controls are defined -----------------

        selcont = WIDGET_BUTTON(controlbase, VALUE='  Selection ', /MENU )
        id_2 = WIDGET_BUTTON(selcont, VALUE='Discard Read-outs', $
				UVALUE='RODISC')

;---------------- the Correction controls are defined -----------------

        corrcont = WIDGET_BUTTON(controlbase, VALUE='  Correction  ', /MENU )
        id_2 = WIDGET_BUTTON(corrcont, VALUE='Non-linearity', UVALUE='NLCORR')
        id_2 = WIDGET_BUTTON(corrcont, VALUE='Read-out simple deglitching', $
        		UVALUE='RODEGL')
        id_2 = WIDGET_BUTTON(corrcont, VALUE='2 Threshold deglitching', $
        		UVALUE='PAARDEGL')
         id_2 = WIDGET_BUTTON(corrcont, VALUE='Reconstruct ramps', $
        		UVALUE='RAMPRECON')
       id_2 = WIDGET_BUTTON(corrcont, VALUE='Change Saturation Params', $
        		UVALUE='SATCORR')
        id_2 = WIDGET_BUTTON(corrcont, VALUE='Set RPIDs -> [1,1]', $
        		UVALUE='RPIDSET')

;---------------- the View controls are defined -----------------

        viewcont = WIDGET_BUTTON(controlbase, VALUE='  View  ', /MENU )
        id_2 = WIDGET_BUTTON(viewcont, VALUE='Header Info ', UVALUE='HDR')
        id_2 = WIDGET_BUTTON(viewcont, VALUE='Compact Status ', UVALUE='CS')
        cont2 = WIDGET_BUTTON(viewcont, VALUE='Auxiliary Files', /MENU )
        id_2 = WIDGET_BUTTON(cont2, VALUE='IS Report ', UVALUE='ISREP')
        id_2 = WIDGET_BUTTON(cont2, VALUE='OLP Report ', UVALUE='OLREP')
        id_2 = WIDGET_BUTTON(cont2, VALUE='EOHA ', UVALUE='EOHA')
        id_2 = WIDGET_BUTTON(cont2, VALUE='EOHI ', UVALUE='EOHI')
        id_2 = WIDGET_BUTTON(viewcont, VALUE='Deglitching Statistics ', $
        		UVALUE='DEGSTAT')

;---------------- the Processing controls are defined -----------------

        proccont = WIDGET_BUTTON(controlbase, VALUE=' Process Meas.', /MENU )
        id_2 = WIDGET_BUTTON(proccont, VALUE='Fit Ramps ', /MENU)
        id_3 = WIDGET_BUTTON(id_2, VALUE='1st order Pol.', UVALUE='POL1')
        id_3 = WIDGET_BUTTON(id_2, VALUE='2nd order Pol.', UVALUE='POL2')
        id_3 = WIDGET_BUTTON(id_2, VALUE='3rd order Pol. ', UVALUE='POL3')
        id_3 = WIDGET_BUTTON(id_2, VALUE='use subdivided ramps ', $
        		UVALUE='DIVRAMPS')
        id_2 = WIDGET_BUTTON(proccont, VALUE='Ramps pattern ', /MENU)
        id_3 = WIDGET_BUTTON(id_2, VALUE='Proceed ', UVALUE='PATTERN')
        id_3 = WIDGET_BUTTON(id_2, VALUE='Customize ', UVALUE='PATT_CUST')
	
	IF conv_cst.cmod(record) NE 'Rectangular' AND $
	    conv_cst.cmod(record) NE 'Scan triangular' AND $
	    conv_cst.cmod(record) NE 'FCS1<->FCS2' THEN $	
				 WIDGET_CONTROL, id_2, sensitive=0
	IF conv_cst.cmod(record) EQ 'Scan sawtooth' AND $
		   conv_cst.cste(record) EQ '1' THEN $
		   	WIDGET_CONTROL, id_2, sensitive=1


;---------------- the Pixel Choice controls are defined -----------------

        pixcont = WIDGET_BUTTON(controlbase, VALUE='  Pixels Choice   ', $
				/MENU)
        pixch = WIDGET_BUTTON(pixcont, VALUE=' Individual choice ', $
				UVALUE='PIXCH' )
        pixch = WIDGET_BUTTON(pixcont, VALUE=' Serial increment  ', $
				UVALUE='PIXCHSER' )
        pixch = WIDGET_BUTTON(pixcont, VALUE=' Serial decrement  ', $
				UVALUE='PIXCHSERD' )
        IF STRMID(tmpdata.det,0,1) EQ 'P' THEN $
        	WIDGET_CONTROL, pixcont, SENSITIVE=0

;---------------- the number of views controls is defined -----------------

        nvbut = cw_bselector(controlbase, $
                        /FRAME, SET_VALUE=NVIEWS-1, $
                        UVALUE = 'NVIEWS', $
                        ['1 Plot', $
			'2 Plots', $ 
			'3 Plots', $ 
			'4 Plots'])

;----------------------------------------------------------------------

       hkbutton=widget_button(controlbase,value=' HK ', /MENU)
       id_1=widget_button(hkbutton, value=' Single measurement ',uvalue ='HK')
       id_1=widget_button(hkbutton, value=' Full TDT data ',uvalue ='HK_FULL')

;----------------------------------------------------------------------


; Realize widget

	WIDGET_CONTROL, erddi1_wid, /REALIZE, /HOURGLASS

	text = ["A", "B", "C", "D"]

	FOR i = 0, nviews - 1 DO BEGIN
	   WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
	   view(i).windownum = temp
	   pia_resetview, i, view(i).controlid
	   IF STRMID(tmpdata.det,0,1) EQ 'C' THEN BEGIN 
;		txtval = STRTRIM(STRING(i+1),2); Replacing numbers by 
	  	txtval = text(i)                ; letters
		WIDGET_CONTROL, pixbut(pixcho(i)), SET_VALUE = txtval
	   ENDIF
	ENDFOR

	xMANAGER,No_BLOCK=1, "pia_disperd", erddi1_wid, $
		EVENT_HANDLER = "pia_derd_event", GROUP_LEADER=GROUP


	RETURN
END
