;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_DISPSCP
;
; PURPOSE:
;	Menu for PIA SCP Data display.
;	This is a fourth level menu in the PIA hierarchy.
;
;	This routine should only be called by the PIA Display Data routine
;	and should not be called directly from the command line.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_DISPSCP
;	
; KEYWORD PARAMETERS:
;	GROUP:	The group leader of the widget hirarchy
;       DATA:   An element of the PHTSRD dynamical structure
;       NV:	Number of Views (1 <= NV <= 4)
;       REDRAW: To redraw same data
;	CALA:	To display Cal A data
;
; COMMON BLOCKS:
;	adm
;	colour_indices
;	phtacc
;	phtcs
;	phtscp
;	phtspd
;	phtvignet
;	pia_dspscp_cmn (internal)
;	pia_dspch3_cmn (internal)
;	dspscp_widg (internal)
;	scp_nac (internal)
;	tmpvalues3 (internal)
;	pia_dspchz_cmn (internal)
;	scpattext (internal)
;	dispcust_cmn (internal)
;	dspscp_widg (internal)
;	pia_widget_info 
;       pia_resetcontrol_cmn
;		
; PROCEDURES USED:
;	PIA LIB:
;		get_convwh
;		get_pht_hk
;		get_scpdisc
;		pia_base_drift
;		pia_bcksubt
;		pia_cimage
;		pia_corr_vign
;		pia_def_resporb
;		pia_dis2scp
;		pia_disp_cs
;		pia_disp_hdr
;		pia_dispcust
;		pia_dispspd
;		pia_get_step
;		pia_load_iscp
;		pia_multchoice
;		pia_multmeas
;		pia_oplot
;		pia_pixchoice
;		pia_plot
;		pia_respons
;		pia_scpdisc
;		pia_showstr
;		pia_spect
;		pia_write_iscp
;		pia_xplot
;		pickmeas
;		process_scp
;		weight_mean
;		write_scp
;		xdisp_hk
;       ASTRO LIB:
;		avg
;		fxpar
;       INTERNAL:
;		 pixbutevent3
;		 viewevent3
;		 averagechop3
;		 averagenonch3
;		 averageevent3
;		 medianchop3
;		 mediannonch3
;		 medianevent3
;		 zoomevent3
;		 zoomfourier3
;		 zoomsync3
;		 zoomnsync3
;		 zoomit3
;		 pia_resetview3
;		 pia_dscp_event
;		 basel_drift
;		 pia_resetcorrcontrol3
;
; MODIFICATION HISTORY:
;       Written by: C.Gabriel (ESA/ESTEC)               July 1994
;	Modified (last) by: cg				December 1996
;	Version 5.4
;	Straylight and Dark Current measurement subtraction added (CG)
;							December 1996
;	Version 5.5
;	Bug fixed (index of FCS cal interpolation) (CG)	March 1997
;	V6.2
;	Saving internal file upgraded  +
;	 direct discrimination for measurement selection +
;	 auxiliary files display added (EOH*, OLR) (CG) May 1997
;	V6.3
;	Processing with baseline drift graphical handling
;	 added (CG)					July 1997
;	V6.4
;	Added possibility to save corrections in phtscp 
;	 buffer + calling sequence to pia_dispspd (JAc) October 1997
;	 and graphical selection capability (CG)	November 1997
;	Orbital position dependant dark current 
;	 subtraction added (CG)				December 1997
;	V6.6
;	Chopper frequency correction for subtracted 
;	 measurements 	+   default
;	 response orbit dep. correction added (CG)	January 1998
;	Average actual responsivities included (JAc)    January 1998
;	New routine pia_resetcorrcontrol3 used to avoid
;	 redrawing the whole screen after loading new
;	 measurements	(JAc)				February 1998
;	V7.0
;	Flux calibration is now possible for FCS (JAc)  June 1998
;	Jump directly to pia_dispaap when doing flux 
;	calibration (JAc)				August 1998
;	Plotting also flags (CG)			November 1998
;	V7.3
;	Modified to include direct calib of chopped 
;	PHT-S measurements (JAc - IAC) 			February 1999  
;	Widget problem (INT instead of LON) fixed (CG)  February 1999
;	Update according to bitflag system (CG)		May 1999
;	Display of decoded flags included (JAC)		June 1999
;	Actual responsivity info added (CG)		July 1999
;	V7.4
;	Background subtraction disabled for P32 (CG)	July 1999
;	V8.0
;	Call to calib_choppmeas_sl includes t_on (CG)	September 1999
;	V8.1
;	Exit including possibility of saving meas. +
;	replacing numbers by letters in pixel ind. (CG)	January 2000
;	V8.2
;			
;-
; *********************************************************************
; *
; *********************************************************************
pro pixbutevent3, event

COMMON pia_dspscp_cmn, tmpdata, scpps, view, viewsize, nviews, viewoptions, $
   overid
COMMON pia_dspch3_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON dspscp_widg, pixbut

        WIDGET_CONTROL, event.id, GET_UVALUE = new_pixbut

        ind = WHERE(pixcho eq new_pixbut(0))
        ind = ind(0)

	text = ["A", "B", "C", "D"]
        IF ind LT 0 or ind GE nviews THEN BEGIN

          pixcount = pixcount+1
          IF pixcount GE nviews THEN pixcount = 0

          old_pixcho = pixcho(pixcount)
          pixcho(pixcount) = new_pixbut(0)

          view(pixcount).viewtype = 0
          pia_resetview3, pixcount, view(pixcount).controlid

;	  txtval = STRTRIM(STRING(pixcount+1),2) ; Replacing numbers by 
	  txtval = text(pixcount)                ; letters
          WIDGET_CONTROL, pixbut(old_pixcho), $
                                SET_VALUE = ' '
          WIDGET_CONTROL, pixbut(pixcho(pixcount)), $
                        SET_VALUE = txtval
        ENDIF
END

; *********************************************************************
; *
; *********************************************************************
pro discard_area3, event

COMMON pia_dspscp_cmn, tmpdata, scpps, view, viewsize, nviews, viewoptions, $
   overid 
COMMON scp_nac, cps_disc, disc_set, vign_set 
COMMON pia_dspch3_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON zoom_discareas, disc_area, all_disc_areas

        WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        WIDGET_CONTROL, event.top, /HOURGLASS

        pixch = pixcho(windowindex)
	tmpvolt = reform([tmpdata.aver(pixch,*)])
	
	pia_xplot, tmpdata.time, $
		   tmpvolt, flagged=cps_disc(pixch,*), $
		   title= 'Discarding area by pixel '+STRTRIM(pixch+1,2),$
		   ytitle='Signal per Ch.Plateau [V/s]',xtitle='Time     [s]',$
		   psym=psymch, /disc_area

	siz= size(all_disc_areas)
	IF siz(0) EQ 0 THEN RETURN
	
; use only pixel we are interested in -> don't put detector
	decode_piaflag, 'SCP', 'MANDISC', tmpdata.flag(pixch,*), manflag
	
	FOR I=0,N_ELEMENTS(all_disc_areas)-1 DO BEGIN
	  p1 = all_disc_areas(i).pos1
	  p2 = all_disc_areas(i).pos2
	  IF p1(1) NE 0. or p2(1) NE 0. THEN BEGIN
	     ind = WHERE(tmpvolt GE p1(1) AND $
	     		 tmpvolt LE p2(1) AND $
			 tmpdata.time GE p1(0) AND $
			 tmpdata.time LE p2(0), ndisc)
	     IF ndisc GT 0 THEN BEGIN
	       manflag(ind) = 1
	       encode_piaflag, 'SCP', 'MANDISC', tmpdata.flag(pixch,*), tmpflag, $
	        manflag
	       tmpdata.flag(pixch,*) = tmpflag  
 	     ENDIF 
	  ENDIF
	ENDFOR
	get_validflag, tmpdata.flag, 'SCP', redflag, $
	  det=tmpdata.det, /allpix
	cps_disc = redflag
	
	pia_resetview3, windowindex

END

; *********************************************************************
; *
; *********************************************************************
pro reselect_area3, event

COMMON pia_dspscp_cmn, tmpdata, scpps, view, viewsize, nviews, viewoptions, $
   overid 
COMMON scp_nac, cps_disc, disc_set, vign_set 
COMMON pia_dspch3_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON zoom_discareas, disc_area, all_disc_areas

        WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        WIDGET_CONTROL, event.top, /HOURGLASS

        pixch = pixcho(windowindex)
	tmpvolt = reform([tmpdata.aver(pixch,*)])
	
	pia_xplot, tmpdata.time, $
		   tmpvolt, flagged=cps_disc(pixch,*), $
		   title= 'Reselecting area by pixel '+STRTRIM(pixch+1,2),$
		   ytitle='Signal per Ch.Plateau [V/s]',xtitle='Time     [s]',$
		   psym=psymch, /disc_area

	siz= size(all_disc_areas)
	IF siz(0) EQ 0 THEN RETURN
	
; use only pixel we are interested in -> don't put detector
	decode_piaflag, 'SCP', 'MANDISC', tmpdata.flag(pixch,*), manflag

	FOR I=0,N_ELEMENTS(all_disc_areas)-1 DO BEGIN
	  p1 = all_disc_areas(i).pos1
	  p2 = all_disc_areas(i).pos2
	  IF p1(1) NE 0. or p2(1) NE 0. THEN BEGIN
	     ind = WHERE(tmpvolt GE p1(1) AND $
	     		 tmpvolt LE p2(1) AND $
			 tmpdata.time GE p1(0) AND $
			 tmpdata.time LE p2(0), ndisc)
	     IF ndisc GT 0 THEN BEGIN
	       manflag(ind) = 0
	       encode_piaflag, 'SCP', 'MANDISC', tmpdata.flag(pixch,*), $
	         tmpflag, manflag
	       tmpdata.flag(pixch,*) = tmpflag  
	     ENDIF
	       
	  ENDIF
	ENDFOR
	get_validflag, tmpdata.flag, 'SCP', redflag, $
	  det=tmpdata.det, /allpix
	cps_disc = redflag

	pia_resetview3, windowindex

END


; *********************************************************************
; *
; *********************************************************************
pro basel_drift, event

COMMON pia_dspscp_cmn, tmpdata, scpps, view, viewsize, nviews, viewoptions, $
   overid 
COMMON pia_dspch3_cmn, pixcho, pixop, pixres, psymch, pixcount

        WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
	pixel = pixcho(windowindex(0))
	
	PIA_BASE_DRIFT, tmpdata, bas_drift, pixel=pixel, GROUP_LEADER=event.top

END


; *********************************************************************
; *
; *********************************************************************
pro viewevent3, event

COMMON pia_dspscp_cmn, tmpdata, scpps, view, viewsize, nviews, viewoptions, $
   overid 
COMMON pia_dspch3_cmn, pixcho, pixop, pixres, psymch, pixcount

	; get index of individual window choice
	viewchoindexid = WIDGET_INFO(event.id, /PARENT)
	WIDGET_CONTROL, viewchoindexid, GET_UVALUE = setting_choi
	setting_choi = setting_choi(0)
	; get index of window
        viewindexid = WIDGET_INFO(viewchoindexid,/PARENT)
	WIDGET_CONTROL, viewindexid, GET_UVALUE = viewindex

	IF N_ELEMENTS(viewindex) EQ 0 THEN BEGIN
	  viewindex = setting_choi
	  viewindexid = viewchoindexid
 	  WIDGET_CONTROL, event.id, GET_UVALUE = setting
	  setting = setting(0)

          IF (view(viewindex(0)).viewtype NE setting) THEN BEGIN
                view(viewindex(0)).viewtype = setting
                pia_resetview3, viewindex, viewindexid
          ENDIF
	ENDIF ELSE BEGIN
	; get value of setting 
 	  WIDGET_CONTROL, event.id, GET_UVALUE = setting
	  setting = setting(0)

	  IF (view(viewindex(0)).viewtype NE setting_choi OR $
	    view(viewindex(0)).viewtype_sub NE setting) THEN BEGIN
		view(viewindex(0)).viewtype_sub = setting
		view(viewindex(0)).viewtype = setting_choi
		pia_resetview3, viewindex, viewindexid
	  ENDIF
	ENDELSE
END


; *********************************************************************
; *
; *********************************************************************
pro averagechop3, event

COMMON pia_dspscp_cmn, tmpdata, scpps, view, viewsize, nviews, viewoptions, $
   overid
COMMON pia_dspch3_cmn, pixcho, pixop, pixres, psymch, pixcount

        WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        WIDGET_CONTROL, event.top, /HOURGLASS

	averageevent3, windowindex, chopped=1

	END

; *********************************************************************
; *
; *********************************************************************
pro averagenonch3, event

COMMON pia_dspscp_cmn, tmpdata, scpps, view, viewsize, nviews, viewoptions, $
   overid
COMMON pia_dspch3_cmn, pixcho, pixop, pixres, psymch, pixcount

        WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        WIDGET_CONTROL, event.top, /HOURGLASS

	averageevent3, windowindex

	END

; *********************************************************************
; *
; *********************************************************************
pro averageevent3, windowindex, chopped=chopped

COMMON pia_dspscp_cmn, tmpdata, scpps, view, viewsize, nviews, viewoptions, $
   overid
COMMON pia_dspch3_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON scp_nac, cps_disc, disc_set, vign_set 
COMMON tmpvalues3, tmprpid, tmprpid_name

	wtype = view(windowindex).viewtype 

        ytitle = viewoptions(wtype).viewylab

	notacc=0
	
        CASE wtype OF

          0: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.aver(pixch,*)
                unc = tmpdata.avun(pixch,*)
		str = 'Average of Averages Pixel '+STRTRIM(STRING(pixch+1),2)

		IF disc_set THEN $ 
			indnacc = WHERE(cps_disc(pixch,*) ne 0, notacc)

           END

          1: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.medi(pixch,*)
                unc = (tmpdata.q3me(pixch,*)-tmpdata.q1me(pixch,*)) / 2. 
		str = 'Average of Medians Pixel '+STRTRIM(STRING(pixch+1),2)

		IF disc_set THEN $ 
			indnacc = WHERE(cps_disc(pixch,*) ne 0, notacc)

	  END 
          2: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.flag(pixch,*)
                unc = 0
		str = 'Flag Averages'
          END
          3: BEGIN
                data = tmpdata.chop
                unc = 0
		str = 'Chopper Position Averages'
          END
          4: BEGIN
                data = tmpdata.temp
                unc = 0
		str = 'Temperature Averages'
          END
          5: BEGIN
                data = tmpdata.fcs1
                unc = 0
		str = 'FCS1 el.Power Averages'
          END
          6: BEGIN
                data = tmpdata.fcs2
                unc = 0
		str = 'FCS2 el.Power Averages'
          END
          7: BEGIN
                data = tmpdata.tkey
                unc = 0
		str = 'Time Key Averages'
          END
          8: BEGIN
                data = tmprpid
                unc = 0
		str = tmprpid_name + ' Averages'
          END
          9: BEGIN
                data = tmpdata.aver(pixop,*)
                unc = tmpdata.avun(pixop,*)
		str = 'Average of Averages Open Pixel'

		IF disc_set THEN $ 
			indnacc = WHERE(cps_disc(pixop,*) ne 0, notacc)

          END
          10: BEGIN
                data = tmpdata.medi(pixop,*)
                unc = (tmpdata.q3me(pixop,*)-tmpdata.q1me(pixop,*)) / 2. 
		str = 'Average of Medians Open Pixel'

		IF disc_set THEN $ 
			indnacc = WHERE(cps_disc(pixch,*) ne 0, notacc)

          END
          11: BEGIN
                data = tmpdata.aver(pixres,*)
                unc = tmpdata.avun(pixres,*)
		str = 'Average of Averages Open Pixel'

		IF disc_set THEN $ 
			indnacc = WHERE(cps_disc(pixres,*) ne 0, notacc)

          END
          12: BEGIN
                data = tmpdata.medi(pixres,*)
                unc = (tmpdata.q3me(pixres,*)-tmpdata.q1me(pixres,*)) / 2. 
		str = 'Average of Medians Resistor Pixel'

		IF disc_set THEN $ 
			indnacc = WHERE(cps_disc(pixres,*) ne 0, notacc)

          END
          ELSE: MESSAGE, /INFO, 'Not allowed CASE'

        ENDCASE

; Prepare a Byte array to accomodate all strings including carriage returns
	bytstr = [BYTE(str),10b,13b,10b,13b]

	
	accarr = INTARR(N_ELEMENTS(data))


	IF(wtype EQ 0 or wtype EQ 1 OR wtype EQ 8 OR wtype EQ 9 OR $
	   wtype EQ 10 or wtype EQ 11) AND $ 
		(notacc GT 0)   THEN  accarr(indnacc) = 1

	IF KEYWORD_SET(chopped) THEN BEGIN 

	   indfcs = WHERE(tmpdata.fcsn gt 0, n)

; FCS case - fcsn=1 (FCS1) fcs2=2 (FCS2) fcsn=0 (CFOV, if also FCS1 or FCS2)
	   IF n GT 0 THEN BEGIN

		FOR I=0,2 DO BEGIN
		   indfcs = WHERE(tmpdata.fcsn eq I AND accarr EQ 0, nfcs)     
		   IF nfcs ne 0 THEN BEGIN
			weight_mean, data(indfcs), unc(indfcs), avr, sig
			IF I eq 0 THEN $
			  str = 'CFOV position: '+$
				STRING(avr)+'    +/-'+STRING(sig) $ 								
			ELSE $
			  str = 'FCS'+STRTRIM(STRING(I),2)+' position: '+$
				STRING(avr)+'    +/-'+STRING(sig)								

			bytstr = [bytstr,BYTE(str),10b,13b]
		   ENDIF		
		ENDFOR 
	   ENDIF ELSE BEGIN

; Chopped Case (not calibration involved)
		nrst = 1
		i = 0
		WHILE nrst NE 0 DO BEGIN 
                   i = i + 1
		   indstp = WHERE(tmpdata.step eq i AND accarr EQ 0, nrst)     
		   IF nrst ne 0 THEN BEGIN
			weight_mean, data(indstp), unc(indstp), avr, sig
			str = 'Step '+STRTRIM(STRING(I),2)+' position: '+$
				STRING(avr)+'    +/-'+STRING(sig)								
			bytstr = [bytstr,BYTE(str),10b,13b]
		   ENDIF		
		ENDWHILE
	   ENDELSE 
	ENDIF ELSE BEGIN			

; Not chopped Case
           indacc = WHERE(accarr EQ 0, nrst)
	   IF nrst NE 0 THEN BEGIN
	     weight_mean, data(indacc), unc(indacc), avr, sig
	     str = 'Full measurement average: '+$
		STRING(avr)+'    +/-'+STRING(sig)								
	     bytstr = [bytstr,BYTE(str),10b,13b]
	   ENDIF
        ENDELSE

; Now get the text and display it

        text = STRING(bytstr)

        XDISPLAYFILE, "", $
            TITLE = "Average", $
                  WIDTH = 100, $
                  HEIGHT = 10, $
                  TEXT = [text]

END

; *********************************************************************
; *
; *********************************************************************
pro medianchop3, event

COMMON pia_dspscp_cmn, tmpdata, scpps, view, viewsize, nviews, viewoptions, $
   overid
COMMON pia_dspch3_cmn, pixcho, pixop, pixres, psymch, pixcount

        WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        WIDGET_CONTROL, event.top, /HOURGLASS

	medianevent3, windowindex, chopped=1

	END

; *********************************************************************
; *
; *********************************************************************
pro mediannonch3, event

COMMON pia_dspscp_cmn, tmpdata, scpps, view, viewsize, nviews, viewoptions, $
   overid
COMMON pia_dspch3_cmn, pixcho, pixop, pixres, psymch, pixcount

        WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        WIDGET_CONTROL, event.top, /HOURGLASS

	medianevent3, windowindex

	END

; *********************************************************************
; *
; *********************************************************************
pro medianevent3, windowindex, chopped=chopped

COMMON pia_dspscp_cmn, tmpdata, scpps, view, viewsize, nviews, viewoptions, $
   overid
COMMON pia_dspch3_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON tmpvalues3, tmprpid, tmprpid_name
COMMON scp_nac, cps_disc, disc_set, vign_set 

        ytitle = viewoptions(view(windowindex).viewtype).viewylab

	wtype = view(windowindex).viewtype

	notacc = 0

        CASE wtype OF
          0: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.aver(pixch,*)
                unc = tmpdata.avun(pixch,*)
		str = 'Median of Averages Pixel '+STRTRIM(STRING(pixch+1),2)
		IF disc_set THEN $ 
		indnacc = WHERE(cps_disc(pixch,*) ne 0, notacc)
           END

          1: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.medi(pixch,*)
                unc = (tmpdata.q3me(pixch,*)-tmpdata.q1me(pixch,*)) / 2. 
		str = 'Median of Medians Pixel '+STRTRIM(STRING(pixch+1),2)
		IF disc_set THEN $ 
		indnacc = WHERE(cps_disc(pixch,*) ne 0, notacc)
	  END 
          2: BEGIN
                pixch = pixcho(windowindex)
                data = tmpdata.flag(pixch,*)
                unc = 0
		str = 'Flag Median'
	  END 
          3: BEGIN
                data = tmpdata.chop
                unc = 0
		str = 'Chopper Position Medians'
          END
          4: BEGIN
                data = tmpdata.temp
                unc = 0
		str = 'Temperature Medians'
          END
          5: BEGIN
                data = tmpdata.fcs1
                unc = 0
		str = 'FCS1 el.Power Medians'
          END
          6: BEGIN
                data = tmpdata.fcs2
                unc = 0
		str = 'FCS2 el.Power Medians'
          END
          7: BEGIN
                data = tmpdata.tkey
                unc = 0
		str = 'Time Key Medians'
          END
          8: BEGIN
                data = tmprpid
                unc = 0
		str = tmprpid_name + ' Medians'
          END
          9: BEGIN
                data = tmpdata.aver(pixop,*)
                unc = tmpdata.avun(pixop,*)
		str = 'Median of Averages Open Pixel'
		indnacc = WHERE(cps_disc(pixop,*) ne 0, notacc)
          END
          10: BEGIN
                data = tmpdata.medi(pixop,*)
                unc = (tmpdata.q3me(pixop,*)-tmpdata.q1me(pixop,*)) / 2. 
		str = 'Median of Medians Open Pixel'
		indnacc = WHERE(cps_disc(pixop,*) ne 0, notacc)
          END
          11: BEGIN
                data = tmpdata.aver(pixres,*)
                unc = tmpdata.avun(pixres,*)
		str = 'Median of Averages Open Pixel'
		indnacc = WHERE(cps_disc(pixres,*) ne 0, notacc)
          END
          12: BEGIN
                data = tmpdata.medi(pixres,*)
                unc = (tmpdata.q3me(pixres,*)-tmpdata.q1me(pixres,*)) / 2. 
		str = 'Median of Medians Resistor Pixel'
		indnacc = WHERE(cps_disc(pixres,*) ne 0, notacc)
          END
          ELSE: MESSAGE, /INFO, 'Not allowed CASE'

        ENDCASE

; Prepare a Byte array to accomodate all strings including carriage returns
	bytstr = [BYTE(str),10b,13b,10b,13b]

	accarr = INTARR(N_ELEMENTS(data))

	IF(wtype EQ 0 or wtype EQ 1 OR wtype EQ 8 OR wtype EQ 9 OR $
	   wtype EQ 10 or wtype EQ 11) AND $ 
		(notacc GT 0)   THEN  accarr(indnacc) = 1

	IF KEYWORD_SET(chopped) THEN BEGIN 

	   indfcs = WHERE(tmpdata.fcsn gt 0, n)

; FCS case - fcsn=1 (FCS1) fcsn=2 (FCS2) fcsn=0 (CFOV, if also FCS1 or FCS2)
	   IF n GT 0 THEN BEGIN

		FOR I=0,2 DO BEGIN
		   indfcs = WHERE(tmpdata.fcsn eq I AND accarr EQ 0, nfcs)     
		   IF nfcs ne 0 THEN BEGIN
			avr = median(data(indfcs))
			ind = where(data(indfcs) LT avr, nbel)
			if nbel GT 0 THEN q1 = median(data(indfcs(ind))) $
				ELSE q1 = 0.
			ind = where(data(indfcs) GE avr, nabo)
			IF nabo GT 0 THEN q3 = median(data(indfcs(ind))) $
				ELSE q3 = 0
			IF I eq 0 THEN $
			  str = 'CFOV position: '+$
				STRING(avr)+'  1st Quart'+STRING(q1) +$
					'  3rd Quart'+STRING(q3) $
 			ELSE $
			  str = 'FCS'+STRTRIM(STRING(I),2)+' position: '+$
				STRING(avr)+'  1st Quart'+STRING(q1) +$
					'  3rd Quart'+STRING(q3)

			bytstr = [bytstr,BYTE(str),10b,13b]
		   ENDIF		
		ENDFOR 
	   ENDIF ELSE BEGIN

; Chopped Case (not calibration involved)
		nrst = 1
		i = 0
		WHILE nrst NE 0 DO BEGIN 
                   i = i + 1
		   indstp = WHERE(tmpdata.step eq i AND accarr EQ 0, nrst)     
		   IF nrst ne 0 THEN BEGIN
			avr = median(data(indstp))
			ind = where(data(indstp) LT avr, nbelo)
			IF nbelo GT 0 THEN $
			 q1 = median(data(indstp(ind))) ELSE q1 = 0.
			ind = where(data(indstp) GE avr, nabo)
			IF nabo GT 0 THEN $
			 q3 = median(data(indstp(ind))) ELSE q3 = 0.
			str = 'Step '+STRTRIM(STRING(I),2)+' position: '+$
				STRING(avr)+'  1st Quart'+STRING(q1) +$
					'  3rd Quart'+STRING(q3)								
			bytstr = [bytstr,BYTE(str),10b,13b]
		   ENDIF		
		ENDWHILE
	   ENDELSE 
	ENDIF ELSE BEGIN			

; Not chopped Case

           indacc = WHERE(accarr EQ 0, nrst)
	   IF nrst NE 0 THEN BEGIN
	     avr = median(data(indacc))
	     ind = where(data(indacc) LT avr, nbelo)
	     IF nbelo GT 0 THEN $
	      q1 = median(data(indacc(ind))) ELSE q1 = 0.
	     ind = where(data(indacc) GE avr, nabo)
	     IF nabo GT 0 THEN $
	      q3 = median(data(indacc(ind))) ELSE q3 = 0.
	     str = 'Full measurement median: '+$
		STRING(avr)+'  1st Quart'+STRING(q1) +$
					'  3rd Quart'+STRING(q3)								
	     bytstr = [bytstr,BYTE(str),10b,13b]
	   ENDIF
        ENDELSE

; Now get the text and display it

        text = STRING(bytstr)

        XDISPLAYFILE, "", $
           TITLE = "Median Calculation", $
                  WIDTH = 100, $
                  HEIGHT = 10, $
                  TEXT = [text]
END

; *********************************************************************
; *
; *********************************************************************
pro zoomevent3, event

COMMON pia_dspscp_cmn, tmpdata, scpps, view, viewsize, nviews, viewoptions, $
   overid 
COMMON pia_dspch3_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices

	WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
	zoomit3, windowindex        
END

; *********************************************************************
; *
; *********************************************************************
pro zoomfourier3, event

COMMON pia_dspscp_cmn, tmpdata, scpps, view, viewsize, nviews, viewoptions, $
   overid
COMMON pia_dspch3_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices

        WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
        zoomit3, windowindex, fourier = 1
END

; *********************************************************************
; *
; *********************************************************************
pro zoomsync3, event

COMMON pia_dspscp_cmn, tmpdata, scpps, view, viewsize, nviews, viewoptions, $
   overid 
COMMON pia_dspch3_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices

	WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
	zoomit3, windowindex, overplot = 1        

END

; *********************************************************************
; *
; *********************************************************************
pro zoomnsync3, event

COMMON pia_dspscp_cmn, tmpdata, scpps, view, viewsize, nviews, viewoptions, $
   overid 
COMMON pia_dspch3_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices

	WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
	zoomit3, windowindex, overplot = -1        

END

; *********************************************************************
; *
; *********************************************************************
pro zoomit3, windowindex, overplot=overplot, fourier=fourier

COMMON pia_dspscp_cmn, tmpdata, scpps, view, viewsize, nviews, viewoptions, $
   overid 
COMMON pia_dspscp_flg_cmn, nflag_active, flag_active_lex, flag_active_label  
COMMON pia_dspch3_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
COMMON scp_nac, cps_disc, disc_set, vign_set 
COMMON tmpvalues3, tmprpid, tmprpid_name
@colour_indices

	IF (KEYWORD_SET(overplot)) THEN overplot = overplot ELSE overplot = 0
        IF (KEYWORD_SET(fourier)) THEN fourier = 1 ELSE fourier = 0

	xtitle = viewoptions(view(windowindex).viewtype).viewxlab
	ytitle = viewoptions(view(windowindex).viewtype).viewylab
	menuchoi = view(windowindex).viewtype_sub

	decode_admn, tmpdata.admn, title
	title = title + '  ' + tmpdata.unit

        get_convwh, tmpdata.admn, wheels, chmod, champ
        anntmp = title + $
		'  [' + wheels(0) + '  ' + wheels(1) + '  ' + $
		wheels(2) + ']  [' + chmod + '  ' + champ + ']'

        anntmp = anntmp+' (SCP level)'


        ytype = 0

	charsize = 1.10
	IF overplot NE 0 THEN BEGIN
		xstyle = 0
		ystyle = 0
		IF zoom_color EQ -1 THEN zoom_color = green ELSE $
			zoom_color = zoom_color + 1
		IF zoom_color EQ 9 then zoom_color = 4
		zoom_psymch = zoom_psymch + 1
		IF zoom_psymch GT 8 then zoom_psymch = 1

		title = ''
	ENDIF ELSE BEGIN
		xstyle = 0
		ystyle = 0
		zoom_color = -1
		zoom_psymch = psymch
        ENDELSE

                IF fourier eq 1 THEN BEGIN
                        xtitle = 'Frequency       [Hz]'
                        ytitle = 'FFT of '+ytitle
                        ytype = 1
                ENDIF
	

	CASE view(windowindex).viewtype OF

;Plot averages of pixel signals
	  0: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Avrg S/Ch.Pl.: Pixel '+str_pixch+'  [V/s]' 
		ytitle = str_pixch 

		IF disc_set THEN $ 
			indno = WHERE(cps_disc(pixch,*) ne 0, nn)

                IF fourier eq 1 THEN BEGIN
                        xtitle = 'Frequency       [Hz]'
                        ytitle = 'FFT of '+ytitle
                        ytype = 1
                ENDIF
		
		pia_xplot, tmpdata.time, $
			tmpdata.aver(pixch,*), $
			tmpdata.avun(pixch,*), $
			psym = zoom_psymch, xtitle=xtitle, fourier=fourier, $
			ytitle=ytitle, ytype=ytype, $
			title=title, subtitle=subtitle, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,         $       
			xstyle=xstyle, ystyle=ystyle, $
                        legend=strmid(ytitle,0,20), $
                        annotation=anntmp                    

		IF disc_set eq 1 and fourier EQ 0 THEN BEGIN
                        IF nn GT 0 THEN $
			  PIA_XPLOT, tmpdata.time(indno), $
			  tmpdata.aver(pixch,indno), $
			  psym = 7, color=red, overplot=99, $
                          legend=' discarded points'
                ENDIF

    	  END
;Plot medians of pixel signals
	  1: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Medians S/Ch.Pl.: Pixel '+str_pixch+'  [V/s]' 
		ytitle = str_pixch 

		IF disc_set THEN $ 
			indno = WHERE(cps_disc(pixch,*) ne 0, nn)

                IF fourier eq 1 THEN BEGIN
                        xtitle = 'Frequency       [Hz]'
                        ytitle = 'FFT of '+ytitle
                        ytype = 1
                ENDIF
		
		pia_xplot, tmpdata.time, $
			tmpdata.medi(pixch,*), $
			psym = zoom_psymch, xtitle=xtitle, fourier=fourier, $
			ytitle=ytitle, ytype=ytype, $
			title=title, subtitle=subtitle, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,     $       
			xstyle=xstyle, ystyle=ystyle, $
                        legend=strmid(ytitle,0,20), $
                        annotation=anntmp                   

		
		PIA_XPLOT, tmpdata.time, $
			  tmpdata.q1me(pixch,*), $
			  psym = 2, color=green, overplot=99, $
                          legend='First quartiles'

		PIA_XPLOT, tmpdata.time, $
			  tmpdata.q3me(pixch,*), $
			  psym = 2, color=blue, overplot=99, $
                          legend='Third quartiles'

;		for II=0,N_ELEMENTS(tmpdata.time)-1 DO $
;			pia_xplot, [tmpdata.time(II), tmpdata.time(II)], $
;			   [tmpdata.q1me(pixch,II),tmpdata.q3me(pixch,II)], $
;			   overplot=99, color=zoom_color, psym=0

		IF disc_set eq 1 AND fourier EQ 0 THEN BEGIN
                        IF nn GT 0 THEN $
			  PIA_XPLOT, tmpdata.time(indno), $
			  tmpdata.medi(pixch,indno), $
			  psym = 7, color=red, overplot=99, $
                          legend=' discarded points'
                ENDIF

    	  END
;Plot flag values
	  2: BEGIN
	    	elemnames =  flag_active_label   
		pixch = pixcho(windowindex)
		str_pixch = 'Flag ' + elemnames(menuchoi)+ ': Pixel '+ $
		   STRTRIM(pixch+1,2)
		IF title NE '' THEN title = str_pixch 
		;select flag depending on the choice
		IF flag_active_lex(menuchoi) EQ 'ENCODE' THEN        $
		    tmpflag = tmpdata.flag(pixch,*)                  $
		ELSE decode_piaflag,'SCP',flag_active_lex(menuchoi), $ 
		    tmpdata.flag(pixch,*),tmpflag
		ytitle = 'Flag' 

                IF fourier eq 1 THEN BEGIN
                        xtitle = 'Frequency       [Hz]'
                        ytitle = 'FFT of '+ytitle
                        ytype = 1
                ENDIF
		
		pia_xplot, tmpdata.time, tmpflag, psym = zoom_psymch, $
			xtitle=xtitle, ytitle=ytitle, fourier=fourier, $
			subtitle=subtitle, title=title, ytype=ytype,  $
			overplot = overplot, charsize = charsize,     $
			color = zoom_color, xstyle=xstyle, ystyle=ystyle, $
			legend=strmid(str_pixch,5,25), annotation=anntmp              
          END
;Plot chopper positions
	  3: BEGIN
		pia_xplot, tmpdata.time, tmpdata.chop, psym = zoom_psymch, $
			xtitle=xtitle, fourier=fourier, ytitle = ytitle, $
			title=title, subtitle=subtitle, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,     $       
			xstyle=xstyle, ystyle=ystyle, ytype=ytype, $
                        legend=strmid(ytitle,0,20), $
                        annotation=anntmp             
          END
;Plot temperatures
	  4: BEGIN
		pia_xplot, tmpdata.time, tmpdata.temp, psym = zoom_psymch, $
			xtitle=xtitle, fourier=fourier, ytitle = ytitle, $
			title=title, subtitle=subtitle, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,     $       
			xstyle=xstyle, ystyle=ystyle, ytype=ytype, $
                        legend=strmid(ytitle,0,20), $
                        annotation=anntmp             
          END
;Plot FCS1 electrical powers
	  5: BEGIN
		pia_xplot, tmpdata.time, tmpdata.fcs1, psym = zoom_psymch, $
			xtitle=xtitle, fourier=fourier, ytitle = ytitle, $
			title=title, subtitle=subtitle, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,     $       
			xstyle=xstyle, ystyle=ystyle, ytype=ytype, $
                        legend=strmid(ytitle,0,20), $
                        annotation=anntmp             
          END
;Plot FCS2 electrical powers
	  6: BEGIN
		pia_xplot, tmpdata.time, tmpdata.fcs2, psym = zoom_psymch, $
			xtitle=xtitle, fourier=fourier, ytitle = ytitle, $
			title=title, subtitle=subtitle, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,     $       
			xstyle=xstyle, ystyle=ystyle, ytype=ytype, $
                        legend=strmid(ytitle,0,20), $
                        annotation=anntmp             
          END
;Plot time keys
	  7: BEGIN
		pia_xplot, tmpdata.time, tmpdata.tkey, psym = zoom_psymch, $
			xtitle=xtitle, fourier=fourier, ytitle = ytitle, $
			title=title, subtitle=subtitle, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,     $       
			xstyle=xstyle, ystyle=ystyle, ytype=ytype, $
                        legend=strmid(ytitle,0,20), $
                        annotation=anntmp             
          END
;Plot raster point ID
	  8: BEGIN
		elemnames = ['Raster Point ID 1', 'Raster Point ID 2']
		tmprpid = tmpdata.rpid(menuchoi,*)
		tmprpid_name = elemnames(menuchoi)
		pia_xplot, tmpdata.time, tmprpid, psym = zoom_psymch, $
			xtitle=xtitle, fourier=fourier, ytitle = tmprpid_name, $
			title=title, subtitle=subtitle, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,   $       
			xstyle=xstyle, ystyle=ystyle, ytype=ytype, $
                        legend=strmid(ytitle,0,20), $
                        annotation=anntmp             
	  END
;Open Pixel - Averages
          9: BEGIN

		IF disc_set THEN $ 
			indno = WHERE(cps_disc(pixop,*) ne 0, nn)

		pia_xplot, tmpdata.time, $
			tmpdata.aver(pixop,*), $
			tmpdata.avun(pixop,*), $
			psym = zoom_psymch, xtitle=xtitle, fourier=fourier, $
			ytitle = ytitle, $
			title=title, subtitle=subtitle, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,       $       
			xstyle=xstyle, ystyle=ystyle, ytype=ytype, $
                        legend=strmid(ytitle,0,20), $
                        annotation=anntmp                               

		IF disc_set eq 1 AND fourier EQ 0 THEN BEGIN
                        IF nn GT 0 THEN $
			  PIA_XPLOT, tmpdata.time(indno), $
			  tmpdata.aver(pixop,indno), $
			  psym = 7, color=red, overplot=99, $
                          legend=' discarded points'
                ENDIF
          END

;Open Pixel - Medians
          10: BEGIN

		IF disc_set THEN $ 
			indno = WHERE(cps_disc(pixop,*) ne 0, nn)

		pia_xplot, tmpdata.time, $
			tmpdata.medi(pixop,*), $
			psym = zoom_psymch, xtitle=xtitle, fourier=fourier, $
			ytitle = ytitle, $
			title=title, subtitle=subtitle, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,      $       
			xstyle=xstyle, ystyle=ystyle, ytype=ytype, $
                        legend=strmid(ytitle,0,20), $
                        annotation=anntmp                               

		for II=0,N_ELEMENTS(tmpdata.time)-1 DO $
			pia_xplot, [tmpdata.time(II), tmpdata.time(II)], $
			   [tmpdata.q1me(pixop,II),tmpdata.q3me(pixop,II)], $
			   overplot=99, color=zoom_color, psym=0

		IF disc_set eq 1 AND fourier EQ 0 THEN BEGIN
                        IF nn GT 0 THEN $
			  PIA_XPLOT, tmpdata.time(indno), $
			  tmpdata.medi(pixop,indno), $
			  psym = 7, color=red, overplot=99, $
                          legend=' discarded points'
                ENDIF
          END

;Resistor Pixel - Averages
          11: BEGIN

		IF disc_set THEN $ 
			indno = WHERE(cps_disc(pixres,*) ne 0, nn)

		pia_xplot, tmpdata.time, $
			tmpdata.aver(pixres,*), $
			tmpdata.avun(pixres,*), $
			psym = zoom_psymch, xtitle=xtitle, fourier=fourier, $
			ytitle = ytitle, $
			title=title, subtitle=subtitle, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,     $       
			xstyle=xstyle, ystyle=ystyle, ytype=ytype, $
                        legend=strmid(ytitle,0,20), $
                        annotation=anntmp                               

		IF disc_set eq 1 and fourier EQ 0 THEN BEGIN  
                        IF nn GT 0 THEN $
			  PIA_XPLOT, tmpdata.time(indno), $
			  tmpdata.aver(pixch,indno), $
			  psym = 7, color=red, overplot=99, $
                          legend=' discarded points'
                ENDIF
          END

;Resistor Pixel - Medians
          12: BEGIN

		IF disc_set THEN $ 
			indno = WHERE(cps_disc(pixres,*) ne 0, nn)

		pia_xplot, tmpdata.time, $
			tmpdata.medi(pixres,*), $
			psym = zoom_psymch, xtitle=xtitle, fourier=fourier, $
			ytitle = ytitle, $
			title=title, subtitle=subtitle, $
			overplot = overplot,  $
			charsize = charsize, color = zoom_color,   $       
			xstyle=xstyle, ystyle=ystyle, ytype=ytype, $
                        legend=strmid(ytitle,0,20), $
                        annotation=anntmp                         

		for II=0,N_ELEMENTS(tmpdata.time)-1 DO $
			pia_xplot, [tmpdata.time(II), tmpdata.time(II)], $
			   [tmpdata.q1me(pixres,II),tmpdata.q3me(pixres,II)], $
			   overplot=99, color=zoom_color, psym=0

		IF disc_set eq 1 AND fourier EQ 0 THEN BEGIN
                        IF nn GT 0 THEN $
			  PIA_XPLOT, tmpdata.time(indno), $
			  tmpdata.medi(pixres,indno), $
			  psym = 7, color=red, overplot=99, $
                          legend=' discarded points'
                ENDIF
          END


	  ELSE: MESSAGE, /INFO, 'Unsupported View'
          ENDCASE

END

; *********************************************************************
; * pia_resetcorrcontrol3
; *********************************************************************
PRO pia_resetcorrcontrol3, tmpdata, is_cala
COMMON pia_resetcontrol_cmn, id_proccont, id_powcal, id_absphot, id_respcal, $
   id_bckint, id_stray, id_contstray, id_bl, id_vignet, id_chopcor


inda = WHERE(tmpdata.fcsn eq 0, nnfcs)
indfcs = WHERE(tmpdata.fcsn NE 0, nfcs)

;------------------- Correction control -------------------
; vignetting correction is not possible for FCS
IF nnfcs EQ 0 THEN WIDGET_CONTROL, id_vignet, SENSITIVE=0      $ 
    ELSE WIDGET_CONTROL, id_vignet, SENSITIVE=1

; Correction Signal losses in chopped measurements can be 
res = fxpar(tmpdata.hdr, 'PRC_SUBT', count=count)
IF count NE 1 THEN WIDGET_CONTROL, id_chopcor, SENSITIVE=0     $ 
    ELSE WIDGET_CONTROL, id_chopcor, SENSITIVE=1
    
; straylight subtraction for FCS
IF nfcs EQ 0 THEN WIDGET_CONTROL, id_contstray, SENSITIVE=0     $ 
    ELSE WIDGET_CONTROL, id_contstray, SENSITIVE=1

; baseline modelling can only be done with more than 5
IF N_ELEMENTS(tmpdata.aver(0,*)) LT 6 THEN WIDGET_CONTROL, id_bl, SENSITIVE=0 $ 
    ELSE WIDGET_CONTROL, id_bl, SENSITIVE=1


;------------------- Processing control -------------------
; No processing is possible for CAL A files
IF is_cala THEN WIDGET_CONTROL, id_proccont, SENSITIVE=0     $ 
    ELSE WIDGET_CONTROL, id_proccont, SENSITIVE=1

;; Flux Calibration only possible if FOV points present
;IF nnfcs EQ 0 THEN WIDGET_CONTROL, id_powcal, SENSITIVE=0     $ 
;    ELSE WIDGET_CONTROL, id_powcal, SENSITIVE=1

; Absolute Photometry only possible if FOV AND FCS points present
IF nfcs EQ 0 THEN WIDGET_CONTROL, id_absphot, SENSITIVE=0     $ 
    ELSE WIDGET_CONTROL, id_absphot, SENSITIVE=1

; Responsivity Calculation only possible if FCS points present
IF nfcs EQ 0 THEN WIDGET_CONTROL, id_respcal, SENSITIVE=0     $ 
    ELSE WIDGET_CONTROL, id_respcal, SENSITIVE=1

; Background subtraction within same meas. is only possible for chopped meas.
; which are not P32 !
inda = WHERE(tmpdata.step EQ 2, nrstp)
aot = STRTRIM(fxpar(tmpdata.hdr, 'EOHAAOTN'),2)	
IF nrstp EQ 0 OR aot EQ 'P32' THEN WIDGET_CONTROL, id_bckint, SENSITIVE=0     $ 
    ELSE WIDGET_CONTROL, id_bckint, SENSITIVE=1 

; Straylight measurement subtraction from an independent meas. only for FCS
IF nfcs EQ 0 THEN WIDGET_CONTROL, id_stray, SENSITIVE=0     $ 
    ELSE WIDGET_CONTROL, id_stray, SENSITIVE=1

END

; *********************************************************************
; *
; *********************************************************************
pro pia_resetview3, windowindex, UPDATE_LABEL

COMMON pia_dspscp_cmn, tmpdata, scpps, view, viewsize, nviews, viewoptions, $
   overid 
COMMON pia_dspscp_flg_cmn, nflag_active, flag_active_lex, flag_active_label  
COMMON pia_dspch3_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON scp_nac, cps_disc, disc_set, vign_set 
COMMON tmpvalues3, tmprpid, tmprpid_name
@colour_indices

	wset, view(windowindex).windownum         ;set to draw in 

	ERASE, color = 100                        ;erase the view


	IF NOT (KEYWORD_SET(UPDATE_LABEL)) THEN $
	  UPDATE_LABEL = 0


        charsize = 1.0
        symsize = 1.

        title = viewoptions(view(windowindex).viewtype).viewname
	xtitle = viewoptions(view(windowindex).viewtype).viewxlab
	ytitle = viewoptions(view(windowindex).viewtype).viewylab
	menuchoi = view(windowindex).viewtype_sub

	CASE view(windowindex).viewtype OF


;Plot averages of pixel signals
	  0: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Avrg S/Ch.Pl.: Pixel '+str_pixch 
		IF title NE '' THEN title = str_pixch 

		pia_plot, tmpdata.time, $
			tmpdata.aver(pixch,*), $
			yerr=tmpdata.avun(pixch,*), $
			psym = psymch, xtitle=xtitle, $
			ytitle = ytitle, $
			charsize = charsize, symsize = symsize

		IF disc_set THEN $ 
			indno = WHERE(cps_disc(pixch,*) ne 0, nn)

                IF nn GE 1 THEN BEGIN
			  time = tmpdata.time
			  av = tmpdata.aver
			  PIA_OPLOT, time(indno), $
			  av(pixch,indno), $
			  psym = 7, color=red, symsize=symsize
                ENDIF

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  
         
    	  END
;Plot medians of pixel signals
	  1: BEGIN
		pixch = pixcho(windowindex)
		str_pixch = STRTRIM(STRING(pixch+1),2)
		str_pixch = 'Medians S/Ch.Pl.: Pixel '+str_pixch 
		IF title NE '' THEN title = str_pixch 

		pia_plot, tmpdata.time, $
			tmpdata.medi(pixch,*), $
			psym = psymch, xtitle=xtitle, $
			ytitle = ytitle, $
			charsize = charsize, symsize = symsize

                pia_oplot, tmpdata.time, $
                           tmpdata.q1me(pixch,*), psym=2, color=white
                pia_oplot, tmpdata.time, $
                           tmpdata.q3me(pixch,*), psym=2, color=white

		IF disc_set THEN $ 
			indno = WHERE(cps_disc(pixch,*) ne 0, nn)

                IF nn GE 1 THEN BEGIN
			  time = tmpdata.time
			  medi = tmpdata.medi
			  PIA_OPLOT, time(indno), $
			  medi(pixch,indno), $
			  psym = 7, color=red, symsize=1.5
                ENDIF

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  
         
    	  END
;Plot flags
	  2: BEGIN
	    	elemnames =  flag_active_label   
		pixch = pixcho(windowindex)
		str_pixch = 'Flag ' + elemnames(menuchoi)+ ': Pixel '+ $
		   STRTRIM(pixch+1,2)
		IF title NE '' THEN title = str_pixch 
		;select flag depending on the choice
		IF flag_active_lex(menuchoi) EQ 'ENCODE' THEN        $
		    tmpflag = tmpdata.flag(pixch,*)                  $
		ELSE decode_piaflag,'SCP',flag_active_lex(menuchoi), $ 
		    tmpdata.flag(pixch,*),tmpflag

		pia_plot, tmpdata.time, tmpflag, psym = psymch, $ 
		        xtitle=xtitle, ytitle = ytitle,         $
			charsize = charsize, symsize = symsize

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = str_pixch  
         
    	  END
;Plot chopper positions
	  3: BEGIN
		pia_plot, tmpdata.time, tmpdata.chop, psym = psymch, $
			xtitle=xtitle, ytitle = ytitle, $
			charsize = charsize, symsize = symsize

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = 'Chopper position'  

          END
;Plot temperatures
	  4: BEGIN
		pia_plot, tmpdata.time, tmpdata.temp, psym = psymch, $
			xtitle=xtitle, ytitle = ytitle, $
			charsize = charsize, symsize = symsize

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = 'Temperature'  

          END
;Plot FCS1 electrical powers
	  5: BEGIN
		pia_plot, tmpdata.time, tmpdata.fcs1, psym = psymch, $
			xtitle = xtitle, ytitle = ytitle, $
			charsize = charsize, symsize = symsize

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = 'FCS1 Power'  

          END
;Plot FCS2 electrical powers
	  6: BEGIN
		pia_plot, tmpdata.time, tmpdata.fcs2, psym = psymch, $
			xtitle = xtitle, ytitle = ytitle, $
			charsize = charsize, symsize = symsize

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = 'FCS2 Power' 

          END
;Plot time keys
	  7: BEGIN
		pia_plot, tmpdata.time, tmpdata.tkey, psym = psymch, $
			xtitle = xtitle, ytitle = ytitle, $
			charsize = charsize, symsize = symsize

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value = 'Instrument Time Key'

          END
;Plot raster point ID
	  8: BEGIN
		elemnames = ['Raster Point ID 1', 'Raster Point ID 2']
		
		tmprpid = tmpdata.rpid(menuchoi,*)
		tmprpid_name = elemnames(menuchoi)

		pia_plot, tmpdata.time, tmprpid, psym = psymch, $
			xtitle = xtitle, ytitle = tmprpid_name, $
			charsize = charsize, symsize = symsize

		IF(keyword_set(UPDATE_LABEL)) then $
			WIDGET_CONTROL, update_label, $
				set_value =  tmprpid_name
	  END
;Open Pixel
          9: BEGIN
                pia_plot, tmpdata.time, tmpdata.aver(pixop,*), psym = psymch, $
			yerr=tmpdata.avun(pixop,*), $
                        xtitle = xtitle, ytitle = ytitle, $
                        charsize = charsize, symsize = symsize

		IF disc_set THEN $ 
			indno = WHERE(cps_disc(pixop,*) ne 0, nn)

                IF nn GE 1 THEN BEGIN
                          time = tmpdata.time
			  av = tmpdata.aver
			  PIA_OPLOT, time(indno), $
			  av(pixop,indno), $
			  psym = 7, color=red, symsize=1.5
                ENDIF

                IF(keyword_set(UPDATE_LABEL)) then $
                        WIDGET_CONTROL, update_label, $
                        set_value = 'Avges S/Ch.Pl.: Open Pix'
          END

;Open Pixel - Medians
          10: BEGIN
                pia_plot, tmpdata.time, tmpdata.medi(pixop,*), psym = psymch, $
                        xtitle = xtitle, ytitle = ytitle,  $
                        charsize = charsize, symsize = symsize

                pia_oplot, tmpdata.time, $
                           tmpdata.q1me(pixop,*), psym=2, color=white
                pia_oplot, tmpdata.time, $
                           tmpdata.q3me(pixop,*), psym=2, color=white


		IF disc_set THEN $ 
			indno = WHERE(cps_disc(pixop,*) ne 0, nn)

                IF nn GE 1 THEN BEGIN
			  time = tmpdata.time
			  medi = tmpdata.medi
			  PIA_OPLOT, time(indno), $
			  medi(pixop,indno), $
			  psym = 7, color=red, symsize=1.5
                ENDIF

                IF(keyword_set(UPDATE_LABEL)) then $
                        WIDGET_CONTROL, update_label, $
                        set_value = 'Medians S/Ch.Pl.: Open Pix'
          END

;Resistor Pixel
          11: BEGIN
                pia_plot, tmpdata.time, tmpdata.aver(pixres,*), psym = psymch, $
			yerr=tmpdata.avun(pixres,*), $
                        xtitle = xtitle, ytitle = ytitle, $
                        charsize = charsize, symsize = symsize

		IF disc_set THEN $ 
			indno = WHERE(cps_disc(pixres,*) ne 0, nn)

                IF nn GE 1 THEN BEGIN
			  time = tmpdata.time
			  av = tmpdata.aver
			  PIA_OPLOT, time(indno), $
			  av(pixres,indno), $
			  psym = 7, color=red, symsize=1.5
		ENDIF

                IF(keyword_set(UPDATE_LABEL)) then $
                        WIDGET_CONTROL, update_label, $
                        set_value = 'Avrges S/Ch.Pl.: Resistor'
          END

;Resistor Pixel - Medians
          12: BEGIN
                pia_plot, tmpdata.time, tmpdata.medi(pixres,*), psym = psymch, $
                        xtitle = xtitle, ytitle = ytitle, $
                        charsize = charsize, symsize = symsize

                pia_oplot, tmpdata.time, $
                           tmpdata.q1me(pixres,*), psym=2, color=white
                pia_oplot, tmpdata.time, $
                           tmpdata.q3me(pixres,*), psym=2, color=white

		IF disc_set THEN $ 
			indno = WHERE(cps_disc(pixres,*) ne 0, nn)

                IF nn GE 1 THEN BEGIN
			  time = tmpdata.time
			  medi = tmpdata.medi
			  PIA_OPLOT, time(indno), $
			  medi(pixres,indno), $
			  psym = 7, color=red, symsize=1.5
		ENDIF

                IF(keyword_set(UPDATE_LABEL)) then $
                        WIDGET_CONTROL, update_label, $
                        set_value = 'Medians S/Ch.Pl.: Resistor '
          END



	  ELSE: WIDGET_CONTROL, UPDATE_LABEL, $
				set_value = 'Unsupported View'
          ENDCASE

END


; ***************************************************************************
;  Event handling routine for PIA display menu
; ****************************************************************************

PRO pia_dscp_event, event

@adm
@phtcs
@phtscp
@phtcla
@phtspd
@phtacc
@phtvignet
@phtresporb

COMMON pia_get_strayl_res, strayl, strayl_unc
COMMON pht_mann_st, conflvl, intdiv, minp, tmann_min
COMMON pht_drift_st, drift_stats
COMMON pia_dspscp_cmn, tmpdata, scpps, view, viewsize, nviews, viewoptions, $
   overid 
COMMON pia_dspch3_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON scpattext, dattext_id, newheader, is_cala
COMMON dispcust_cmn, psym, line
COMMON dspscp_widg, pixbut
COMMON scp_nac, cps_disc, disc_set, vign_set 
COMMON pia_widget_info, extfil_wid, intfil_wid, buffil_wid, $
                        erddi1_wid, erddi2_wid, srddi1_wid, srddi2_wid, $
                        scpdi1_wid, scpdi2_wid, spddi1_wid, spddi2_wid, $
                        aapdi1_wid, aapdi2_wid


	WIDGET_CONTROL, event.id, get_uvalue = uvalue
        WIDGET_CONTROL, event.top, /HOURGLASS

	cmap_wind_text = ["A","B","C","D"]
	
	CASE uvalue OF


 	  "EXIT":  BEGIN
		    WIDGET_CONTROL, event.top, /DESTROY 
		  END

	  "SAVEXIT":  BEGIN
	  	    fill_scp, tmpdata, newheader, REPLACE=scpps
		    WIDGET_CONTROL, event.top, /DESTROY 
		  END

          "HELP":   BEGIN
	   	IF !VERSION.OS NE 'vms' THEN $
		spawn, '$w3net $PIA_HTML/um/scp_window.html &' ELSE $
		spawn, 'w3net /pia_dsk/pia/html/um/scp_window.html'
		END


	  "CUST": BEGIN
			pia_dispcust, GROUP=event.top
			psymch = psym
			 FOR I=0,NVIEWS-1 DO BEGIN
			    pia_resetview3, i, view(i).controlid
			 ENDFOR
          END

	  "LOAD": BEGIN
; search for same file and detector type
		    newdata = pickmeas(FTYPE="SCP", DTYPE=tmpdata.det, POSI=posi)
		    IF newdata NE '' THEN BEGIN

                     datind = WHERE(phtscp.admn eq newdata, count)

                     IF count EQ 0 THEN $
                        MESSAGE, /INFO, 'Measurement not found!'

; More than one measurement with same admn in buffer

                     ;;IF count GT 1 THEN datind=datind(posi(0))

                     IF count NE 0 THEN BEGIN 

			disc_set = 0
			vign_set = 0

			scpps = datind(posi(0))
		    	pia_load_iscp, phtscp(scpps), tmpdata		
			get_scpdisc, tmpdata, /ENCODE_FLAG
; header update
			newheader = tmpdata.hdr
			get_validflag, tmpdata.flag, 'SCP', redflag, $
	  			det=tmpdata.det, /allpix
			cps_disc = redflag
			disc_set = 1

	                IF is_cala THEN BEGIN
	             	  more_text = ' ' 
	             	  tmp = 'Cal A '
	                ENDIF ELSE BEGIN
	             	  obj = FXPAR(tmpdata.hdr,'OBJECT')
	             	  attra = FXPAR(tmpdata.hdr,'ATTRA')
	             	  attdec = FXPAR(tmpdata.hdr,'ATTDEC')
	             	  more_text = 'OBJ:' + obj + ' ' + give_sradec(attra, attdec)
	             	  tmp = 'SCP '
	                ENDELSE
	             	decode_admn, tmpdata.admn, dattext
	             	dattext = tmp +dattext+ ' - '+tmpdata.unit+ ' - ' + $ 
	             	     more_text
         	        WIDGET_CONTROL, dattext_id, SET_VALUE = dattext
         	        ; check possible corrections and processing
                        pia_resetcorrcontrol3, tmpdata, is_cala
                        
                        FOR I=0,NVIEWS-1 DO $
			    pia_resetview3, i, view(i).controlid
  
                     ENDIF
		    ENDIF
		  END	                  	

	  "SAVEBUFF": fill_scp, tmpdata, newheader, REPLACE=scpps

	  "SAVEBUFF_NEW": BEGIN
	               scpps = N_ELEMENTS(phtscp)
                       fill_scp, tmpdata, newheader
                   END

	  "SAVEI": BEGIN
	  	    change_tmphdr, tmpdata, 'SCP', newheader, tmpout
	  	    PCONT_SAVEINT, junk, 'SCP', tmpdata=tmpout
		  END

	  "SAVEF": BEGIN
		    WRITE_SCP, tmpdata, newheader  
		  END

	  "PRINT": PIA_PRINT_SCPVAL, tmpdata 

	  "SHOWD": PIA_showstr, tmpdata, VALNAMES=phtscp_desc, GROUP=event.top 
                   
	  "STRAYL": BEGIN
		
; check: if straylight correction already applied return
                done = fxpar(newheader,'PRC_STRL')
		IF done NE 0 THEN BEGIN
		    	XDISPLAYFILE, "", $
                    		GROUP = event.top, $
                    		TITLE = "Already performed - Not done ", $
                    		WIDTH = 30, $
                    		HEIGHT = 6, $
                    		TEXT = [" The straylight subtraction has ", $
                                        " been already performed - Returning "]
                   	RETURN
                ENDIF

		strayl = 0.
	  	pia_get_strayl, tmpdata.admn, group=event.top
	  	
	  	IF strayl NE 0. THEN BEGIN
	  	   tmpdata.aver = tmpdata.aver - strayl
	  	   tmpdata.medi = tmpdata.medi - strayl
	  	   tmpdata.avun = SQRT(tmpdata.avun^2 + strayl_unc^2)
	  	   tmpdata.q1me = tmpdata.q1me - strayl
	  	   tmpdata.q3me = tmpdata.q3me - strayl
	  	

		   line = 'PRC_STRL=             '+STRING(strayl)+$
                        ' / Straylight subtracted value [V/s] '
		   junk = STRING(REPLICATE(32b, 80))
		   STRPUT, junk, line, 0
		   keyword = STRMID(newheader, 0, 8)
		   xtension = WHERE(keyword eq 'XTENSION')
		   newheader = [ newheader(0:xtension(0)-1), junk, $
		  	 newheader(xtension(0):*)]
		   FOR i=0, NVIEWS - 1 do pia_resetview3, i

		ENDIF ELSE PRINT, 'Straylight: nothing subtracted'

	  END

	  "RINT": BEGIN
; check: if correction already applied return
                done = fxpar(newheader,'PRS_RIN0')
                IF done NE 0 THEN BEGIN
                        XDISPLAYFILE, "", $
                          GROUP = event.top, $
                          TITLE = "Not Allowed ", $
                          WIDTH = 50, $
                          HEIGHT = 12, $
                          TEXT = [" Reset interval correction for this", $
                                  " measurement was already applied "]
                        RETURN
                ENDIF
                
; check: if dark current subtracted give warning
                done = fxpar(newheader,'PRS_DARK')
                IF done NE 0 THEN BEGIN
                        XDISPLAYFILE, "", $
                          GROUP = event.top, $
                          TITLE = "Wrong done, friend ", $
                          WIDTH = 50, $
                          HEIGHT = 12, $
                          TEXT = [" Dark Current subtracion for this", $
                                  " measurement was applied.", $
                                  " Actually reset interval correction ",$
                                  " should be performed before! " ]
                ENDIF
                
		give_cs, tmpdata, cst, in, error=error
		IF error THEN MESSAGE, /INFO, 'Returning'
		

		do_corr_resetint, tmpdata, newheader, /SCP 

                FOR I=0,NVIEWS-1 DO BEGIN
                       WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
                       view(i).windownum = temp
                       pia_resetview3, i, view(i).controlid
                ENDFOR
            END 
               
	  "VIGN": BEGIN

; check: if vignetting correction already applied return
                done = fxpar(newheader,'PRC_VIGN')
		IF done NE 0 THEN BEGIN
		    		XDISPLAYFILE, "", $
                    		GROUP = event.top, $
                    		TITLE = "Already performed - Not done ", $
                    		WIDTH = 30, $
                    		HEIGHT = 6, $
                    		TEXT = [" The vignetting correction has ", $
                                        " been already performed "]
		ENDIF ELSE $
			PIA_CORR_VIGN, tmpdata, newheader, GROUP=group

		FOR i=0, NVIEWS - 1 do pia_resetview3, i

	  END

	  "DARKC_SCP_ORB": BEGIN 
	    darkcur_orb, tmpdata, NEWHEADER = newheader, /SCP, ERROR=error
	    IF error NE "" THEN BEGIN
                        XDISPLAYFILE, "", $
                          GROUP = event.top, $
                          TITLE = "Not Allowed ", $
                          WIDTH = 50, $
                          HEIGHT = 12, $
                          TEXT = error
	    ENDIF ELSE FOR i=0, NVIEWS - 1 do pia_resetview3, i
          END

	  "DARKC_SCP_ORB_PAR": PIA_DEF_DARKORB

	 
; obsolete
	  "DARKC_SCP": BEGIN
	  
	    ; check if dark current subtraction was done
	    done = fxpar(newheader, 'PRS_DARK')
	    IF done NE 0 THEN BEGIN
                        XDISPLAYFILE, "", $
                          GROUP = event.top, $
                          TITLE = "Not Allowed ", $
                          WIDTH = 50, $
                          HEIGHT = 12, $
                          TEXT = [" Dark Current for this", $
                                  " measurement was already applied "]
                        RETURN
             ENDIF
	    
	     CASE tmpdata.det of 
			'C1': detpix = 9
			'C2': detpix = 4
			'SL': detpix = 128
			ELSE: detpix = 1
              ENDCASE

              darkcur, tmpdata.aver(0:detpix-1,*), tmpdata.det, outaver
              darkcur, tmpdata.medi(0:detpix-1,*), tmpdata.det, outmedi
	      darkcur, tmpdata.q1me(0:detpix-1,*), tmpdata.det, outq1me
	      darkcur, tmpdata.q3me(0:detpix-1,*), tmpdata.det, outq3me
              
              ; replace signals, log it into the newheader
		IF (N_ELEMENTS(tmpdata.aver(0:detpix-1,*)) EQ    $
                        N_ELEMENTS(outaver)) THEN BEGIN
                          tmpdata.aver(0:detpix-1,*) = outaver
                          tmpdata.medi(0:detpix-1,*) = outmedi
                          tmpdata.q1me(0:detpix-1,*) = outq1me
                          tmpdata.q3me(0:detpix-1,*) = outq3me

                        JUNK = 'PRS_DARK=          '+$
                                 '          1 / Dark Current subtracted  '

        		newl = STRING(REPLICATE(32B, 80))
        		STRPUT, newl, junk, 0
        		KEYWORD = STRMID(newheader, 0, 8)
        		XTENSION = WHERE(KEYWORD EQ 'XTENSION')
        		hdrlen = N_ELEMENTS(newheader)
        		newheader = [ newheader( 0 : XTENSION(0) - 1), newl, $
        			newheader( XTENSION(0) : HDRLEN - 1 )]


		         FOR i=0, NVIEWS - 1 do pia_resetview3, i

                ENDIF
          END
              
	  "SLDISC": BEGIN 

		nchp = tmpdata.dims
		PIA_SCPDISC, nchp = nchp  
				
; Fill cps_disc with discarded chopper plateaux 
		get_scpdisc, tmpdata, /ENCODE_FLAG
		get_validflag, tmpdata.flag, 'SCP', redflag, $
	  			det=tmpdata.det, /allpix
                cps_disc = redflag
		disc_set = 1

		FOR i=0, NVIEWS - 1 do pia_resetview3, i
	  END		   

          "HDR": BEGIN
                IF N_ELEMENTS(newheader) EQ 0 THEN $
                        MESSAGE, /INFO, 'No header defined' ELSE $
                        pia_disp_hdr, newheader, tmpdata.admn, 'PHTSCP'
          END

          "CS": PIA_DISP_CS, tmpdata.admn

	  "ISREP": PIA_disp_isr,STRMID(tmpdata.admn,4,8)

	  "OLREP": PIA_disp_olr,STRMID(tmpdata.admn,4,8)

	  "EOHA": PIA_disp_eoha,STRMID(tmpdata.admn,4,8)

	  "EOHI": PIA_disp_eohi,STRMID(tmpdata.admn,4,8)

	  "ISMANN": PIA_DISP_stat, tmpdata.admn, /STAB

	  "ISDRIFT": PIA_DISP_stat, tmpdata.admn, /DRIFT
	   
	  "ISSLOPV": PIA_DISP_stat, tmpdata.admn, /SLOPV
	   
	  "SLICES": BEGIN

		npix = N_ELEMENTS(tmpdata.aver(*,0)) - 2
 		IF npix EQ 130 THEN npix = 128

		nslice = N_ELEMENTS(tmpdata.aver(0,*))

		decode_admn, tmpdata.admn, tmpmeas

	  	PIA_XPLOT, indgen(npix) + 1, tmpdata.aver(0:npix-1,0), $
	  		TITLE='Time development of Signal/CP - '+tmpmeas, $
	  		xtitle=' Pixel # ', ytitle='Signal    [V/s]', $
	  		psym=10

		zoom_color = 1

		IF nslice GT 1 THEN BEGIN
	  	 FOR I=1, nslice-1 DO BEGIN
			zoom_color = zoom_color + 1
			IF zoom_color EQ 9 then zoom_color = 1
	  	 	WAIT,0.5
	  	 	PIA_XPLOT, indgen(npix) + 1, tmpdata.aver(0:npix-1,i),$
	  	 	/overplot, color=zoom_color, psym=10
	  	 ENDFOR
	  	ENDIF 
	  END	  	 	

	  "SLICES_3D": BEGIN

		npix = N_ELEMENTS(tmpdata.aver(*,0)) - 2
 		IF npix EQ 130 THEN npix = 128

		decode_admn, tmpdata.admn, tmpmeas

		PIA_XSurface, tmpdata.aver(0:npix-1,*), $
			title='Time evol. of Signal/CP - '+tmpmeas, $
			xtitle=' Pixel # ', ytitle='Time    [s]', $
			ztitle='Signal    [V/s]', charsize=1.25, wlego=1

	  END	  	 	

          "IMAGE": BEGIN
		rpid_ch = [1B,1B]
		npoints = FIX(max(tmpdata.rpid(0,*)))
		nlines = FIX(max(tmpdata.rpid(1,*)))

		IF (npoints * nlines) GT 1 THEN $
			pia_get_rpid, [npoints,nlines], rpid_ch
					
                steps = max(tmpdata.step)
                IF steps GT 1 THEN    pia_get_step, steps

		 
                PIA_CIMAGE, tmpdata, steps, rpid_ch
          END

          "SPECT": BEGIN
		rpid_ch = [1B,1B]
		npoints = FIX(max(tmpdata.rpid(0,*)))
		nlines = FIX(max(tmpdata.rpid(1,*)))

		IF (npoints * nlines) GT 1 THEN $
			pia_get_rpid, [npoints,nlines], rpid_ch

                steps = max(tmpdata.step)
		mulch = 0

                IF steps GT 1 AND steps NE min(tmpdata.step) THEN BEGIN
                           pia_get_step, steps
                           mulch = 1
                ENDIF

                PIA_SPECT, tmpdata, steps, mulch, rpid_ch, overplot=0
          END

          "SPESY": BEGIN
		rpid_ch = [1B,1B]
		npoints = FIX(max(tmpdata.rpid(0,*)))
		nlines = FIX(max(tmpdata.rpid(1,*)))

		IF (npoints * nlines) GT 1 THEN $
			pia_get_rpid, [npoints,nlines], rpid_ch

                steps = max(tmpdata.step)
                mulch = 0

                IF steps GT 1 AND steps NE min(tmpdata.step) THEN BEGIN
                           pia_get_step, steps
                           mulch = 1
                ENDIF

                PIA_SPECT, tmpdata, steps, mulch, rpid_ch, overplot=1
          END

          "SPENSY": BEGIN
		rpid_ch = [1B,1B]
		npoints = FIX(max(tmpdata.rpid(0,*)))
		nlines = FIX(max(tmpdata.rpid(1,*)))

		IF (npoints * nlines) GT 1 THEN $
			pia_get_rpid, [npoints,nlines], rpid_ch

                steps = max(tmpdata.step)
                mulch = 0

                IF steps GT 1 AND steps NE min(tmpdata.step) THEN BEGIN
                           pia_get_step, steps
                           mulch = 1
                ENDIF

                PIA_SPECT, tmpdata, steps, mulch, rpid_ch, overplot=-1
          END

	  "BCKSBT": BEGIN

		PIA_BCKSUBT, tmpdata, newheader

	  END

          "BCKSBT_MEAS": BEGIN

		bckmeas = pickmeas(FTYPE='SCP', DTYPE=tmpdata.det, POSI=posi, $
		  TITLE="Measurement to be subtracted", GROUP=event.top)

		IF bckmeas EQ '' THEN RETURN
		
		ind = WHERE(phtscp.admn EQ bckmeas, ncount)

		IF ncount EQ 0 THEN RETURN
		;;IF ncount GT 1 THEN ind=ind(posi(0))

		pia_load_iscp, phtscp(ind(posi(0))), bckmeas
                subtr_meas, tmpdata, bckmeas, tmpsubt

          END

          "DARKSUBT_MEAS": BEGIN

	    done = fxpar(newheader, 'PRS_DARK')
	    IF done NE 0 THEN BEGIN
                        XDISPLAYFILE, "", $
                          GROUP = event.top, $
                          TITLE = "Not Allowed ", $
                          WIDTH = 50, $
                          HEIGHT = 12, $
                          TEXT = [" Dark Current for this", $
                                  " measurement was already applied "]
                        RETURN
            ENDIF

	    bckmeas = pickmeas(FTYPE='SCP', DTYPE=tmpdata.det, POSI=posi, $
		  TITLE="Measurement to be subtracted", GROUP=event.top)
	    IF bckmeas EQ '' THEN RETURN
		
	    ind = WHERE(phtscp.admn EQ bckmeas, ncount)

	    IF ncount EQ 0 THEN RETURN
	    ;;IF ncount GT 1 THEN ind = ind(posi(0))
	    
	    pia_load_iscp, phtscp(ind(posi(0))), bckmeas
            IF N_ELEMENTS(bckmeas.aver(0,*)) NE 1 THEN BEGIN
                    MESSAGE, /INFO, $
             'Dark Current expected to be a staring measurement, returning ...'
	            RETURN
	    ENDIF
	    tmpdata.aver = tmpdata.aver - bckmeas.aver
	    tmpdata.medi = tmpdata.medi - bckmeas.medi
	    tmpdata.q1me = tmpdata.q1me - bckmeas.q1me
	    tmpdata.q3me = tmpdata.q3me - bckmeas.q3me
	    tmpdata.avun = SQRT(tmpdata.avun^2 + bckmeas.avun^2)
		
	    decode_admn, bckmeas.admn, dstring
		
	    fxaddpar, newheader, 'PRS_DARK', 1, $ 
		 ' Dark Current subtracted: '+dstring, before='XTENSION'

	    FOR I=0,NVIEWS-1 DO BEGIN
			    pia_resetview3, i, view(i).controlid
	    ENDFOR
	     	
		
          END

          "STRYSUBT_MEAS": BEGIN

; check: if straylight correction already applied return
                done = fxpar(newheader,'PRC_STRL')
		IF done NE 0 THEN BEGIN
		    	XDISPLAYFILE, "", $
                    		GROUP = event.top, $
                    		TITLE = "Already performed - Not done ", $
                    		WIDTH = 30, $
                    		HEIGHT = 6, $
                    		TEXT = [" The straylight subtraction has ", $
                                        " been already performed - Returning "]
                   	RETURN
                ENDIF

; check: if dark current correction already applied warn
                done = fxpar(newheader,'PRS_DARK')
		IF done NE 0 THEN BEGIN
		    	XDISPLAYFILE, "", $
                    		GROUP = event.top, $
                    		TITLE = "Warning ... ", $
                    		WIDTH = 30, $
                    		HEIGHT = 6, $
                    		TEXT = [" A straylight subtraction has    " , $
                                        " been required to a dark current " ,$
                                        " subtracted measurement - This is", $
                                        " not completely right.           ", $
                                        " Nevertheless your choice. Performed "]
                ENDIF
	    bckmeas = pickmeas(FTYPE='SCP', DTYPE=tmpdata.det, POSI=posi, $
		  TITLE="Measurement to be subtracted", GROUP=event.top)
	    IF bckmeas EQ '' THEN RETURN
		
	    ind = WHERE(phtscp.admn EQ bckmeas, ncount)

	    IF ncount EQ 0 THEN RETURN
	    ;;IF ncount GT 1 THEN ind = ind(posi(0))

	    pia_load_iscp, phtscp(ind(posi(0))), bckmeas
            IF N_ELEMENTS(bckmeas.aver(0,*)) NE 1 THEN BEGIN
                    MESSAGE, /INFO, $
             'Straylight expected to be a staring measurement, returning ...'
	            RETURN
	    ENDIF
	    tmpdata.aver = tmpdata.aver - bckmeas.aver
	    tmpdata.medi = tmpdata.medi - bckmeas.medi
	    tmpdata.q1me = tmpdata.q1me - bckmeas.q1me
	    tmpdata.q3me = tmpdata.q3me - bckmeas.q3me
	    tmpdata.avun = SQRT(tmpdata.avun^2 + bckmeas.avun^2)
		
	    decode_admn, bckmeas.admn, dstring
		
	    fxaddpar, newheader, 'PRC_STRL', 1, $ 
		 ' Straylight subtracted: '+dstring, before='XTENSION'
	     	
	    fxaddpar, newheader, 'PRS_DARK', 2, $ 
		 ' Dark Current implicitely subtracted ', before='XTENSION' 

	    FOR I=0,NVIEWS-1 DO BEGIN
			    pia_resetview3, i, view(i).controlid
	    ENDFOR
	     	
		
          END

	  "RLIN": BEGIN

		rlin_proc, tmpdata, newhdr=newheader
		
		FOR i=0, NVIEWS - 1 do pia_resetview3, i, view(i).controlid
	  END

	  "CHOPFREQ": BEGIN
	      res = fxpar(newheader, 'PRC_CFCF', count=count)
	      IF count NE 0 THEN $
		    	XDISPLAYFILE, "", $
                    		GROUP = event.top, $
                    		TITLE = "Already performed ", $
                    		WIDTH = 30, $
                    		HEIGHT = 6, $
                    		TEXT = [" The chopper frequency correction ", $
                                        " has been already performed "] $
              ELSE $
              	      CHOP_FREQ_CORR, tmpdata, newheader=newheader
	      
	    FOR I=0,NVIEWS-1 DO BEGIN
			    pia_resetview3, i, view(i).controlid
	    ENDFOR

	  END

	  "DEFRESP": BEGIN
		def_resp = default_response(tmpdata)
		npix = pixel_det(tmpdata.det)
		IF RESPPROAOT THEN protxt = 'for AOT' ELSE protxt = 'for meas.'
		text = ['The default response(s) of measurement ' + $
		 dec_admn(tmpdata.admn), $
		'according to orbital position and interpolated '+protxt+':',' ']
		FOR i=0,npix-1 DO BEGIN
		 thr=AVG(def_resp(i,*,0))
		 thu=AVG(def_resp(i,*,1))
		 text = [text, 'Pixel '+STRTRIM(i+1,2)+$
		 ':  ' + STRTRIM(thr,2) + ' +/- ' + STRTRIM(thu,2) ]
		ENDFOR
		
		PIA_DISP_PRINT_FILE, '', TITLE=' Default Responsivity ',$
		  text=text

	  END
	  
	  "ACTRESP": PIA_PRINT_ACTRESP, tmpdata.det

	  "RESPON": BEGIN
		tmptmpd = tmpdata
		tmphdr = newheader
		PIA_RESPONS, tmptmpd, tmphdr, GROUP=group

	  END

	  "CALDEF_PAR": PIA_DEF_RESPORB
	  
	  "CALDEF": BEGIN

		PROCESS_SCP, tmpdata, newheader, 0, spdpos
		
		IF tmpdata.det eq 'SL' THEN spdpos = [spdpos-1,spdpos]
		FOR ispd=0,N_ELEMENTS(spdpos)-1 DO BEGIN  
		  PIA_LOAD_ISPD, phtspd(spdpos(ispd)), tmpspd
		  newheader = tmpspd.hdr
		  PROCESS_SPD, tmpspd, newheader, tmpaap, aapps
		  PIA_DISPAAP, DATA=aapps
		ENDFOR  
		 
          END

	  ; only valid for PHT-S chopped measurement, after background
	  ; subtraction
	  "CALSL_CHOP": BEGIN   
	        first_corr = 1  ; it should be posible to customize 
		extrapolate = 1 ; it should be posible to customize 
	        sig_subt = FLTARR(128,2)
		sig_subt(*,0) = tmpdata.aver(0:127)
		sig_subt(*,1) = tmpdata.medi(0:127)
		give_cs, tmpdata, cst, in, conv_cst, error=error
		IF not ERROR THEN $
		 t_onchop = FLOAT(conv_cst.ndr(in)) * FLOAT(conv_cst.intt(in)) $
		ELSE t_onchop = 0. 
		calib_choppmeas_sl, sig_subt, flux_subt, flag, sprf_act, $
		t_onchop, FIRST_CORR=first_corr, EXTRAPOLATE=extrapolate, $
		    INFO=info_slchop
		flave = flux_subt(*,0)
		flmed = flux_subt(*,1)
		flunc = tmpdata.avun(0:127)/sprf_act(*,0)
		flq1  = tmpdata.q1me(0:127)/sprf_act(*,1)
		flq3  = tmpdata.q3me(0:127)/sprf_act(*,1)
		fluxstr = {flave:flave,flunc:flunc, flmed:flmed, $
		   flq1:flq1,flq3:flq3,flflag:flag(*,0)}    

		IF N_ELEMENTS(info_slchop) NE 0 THEN $   
		   Xdisplayfile, '', TITLE="Warning", $
		     TEXT=info_slchop, WIDTH=50, HEIGHT=10

	        scp2aap_sl, tmpdata, fluxstr, aapps, NEWHDR=newheader,$
		  INFO = info
		FOR iaap=0,1 DO  PIA_DISPAAP, DATA=aapps(iaap)
          END
		
	  "BDR": BEGIN
; check: if baseline drift correction already applied warn
                done = fxpar(newheader,'PRC_BDRI')
		IF done NE 0 THEN BEGIN
		    	XDISPLAYFILE, "", $
                    		GROUP = event.top, $
                    		TITLE = "Already performed - Danger ", $
                    		WIDTH = 30, $
                    		HEIGHT = 6, $
                    		TEXT = [" The baseline drift graphical ", $
                                        " modelling has been already performed "]
                ENDIF
	  	IF N_ELEMENTS(tmpdata.aver(0,*)) LT 5 THEN BEGIN
	  	   MESSAGE, /INFO, 'Data must have at least 5 points, returning'
	  	   RETURN
	  	ENDIF
		PIA_BASE_DRIFT, tmpdata, basdrift, group_LEADER=event.top
		
	   	ndif = WHERE(basdrift NE 1., nd)
		det_pix = N_ELEMENTS(tmpdata.aver(*,0))	
		IF det_pix GT 1 THEN det_pix = det_pix-2
		IF det_pix GT 40 THEN det_pix = det_pix-2
		aver = tmpdata.aver(0:det_pix-1,*)  	
	   	siz_mnp = size(aver)
	   	siz_bas = size(basdrift)

	   	IF nd EQ 0. THEN $
	      		PRINT, 'No baseline drift correction at all' $
	   	ELSE IF siz_mnp(0) NE siz_bas(0) OR $
	      		siz_mnp(1) NE siz_bas(1) OR $
	      		siz_mnp(2) NE siz_bas(2) THEN $
	      		PRINT, 'Dimensions of arrays and baseline drift do not match' $
	   	ELSE BEGIN
	    	  tmpdata.aver(0:det_pix-1,*) = $
	    	   tmpdata.aver(0:det_pix-1,*) / basdrift
		  tmpdata.avun(0:det_pix-1,*) = $	    	 
		   tmpdata.avun(0:det_pix-1,*) / basdrift
	    	  tmpdata.medi(0:det_pix-1,*) = $
	    	   tmpdata.medi(0:det_pix-1,*) / basdrift
		  tmpdata.q1me(0:det_pix-1,*) = $	    	 
		   tmpdata.q1me(0:det_pix-1,*) / basdrift
		  tmpdata.q3me(0:det_pix-1,*) = $	    	 
		   tmpdata.q3me(0:det_pix-1,*) / basdrift
		  IF done THEN keyw = 'PRC_BDR' + STRTRIM(done+1,2) ELSE $
		      KEYW = 'PRC_BDRI'
	          FXADDPAR, newheader, KEYW, 1, $
	     	    ' Baseline drift correction applied', BEFORE='XTENSION'
	   	ENDELSE
		
	    	FOR I=0,NVIEWS-1 DO BEGIN
			    pia_resetview3, i, view(i).controlid
	    	ENDFOR
		 
          END
		
	  "CALACT": BEGIN
		
		PROCESS_SCP, tmpdata, newheader, 1, spdpos 

		IF tmpdata.det eq 'SL' THEN spdpos = [spdpos-1,spdpos]
		FOR ispd=0,N_ELEMENTS(spdpos)-1 DO BEGIN  
			;PIA_DISPSPD, DATA= spdpos
			PIA_LOAD_ISPD, phtspd(spdpos(ispd)), tmpspd
			newheader = tmpspd.hdr
			PROCESS_SPD, tmpspd, newheader, tmpaap, aapps
			PIA_DISPAAP, DATA=aapps
		ENDFOR	
		 
          END
				
	  "CALACT_INT": BEGIN
				
		comm = [" Please select two (and only two) ", $
                            " FCS measurements to be taken for ", $
                            " interpolating responsivities      "]
		
		fcss = pickmeas(ftype="SCP",DTYPE=tmpdata.det, POSI=posi, $
				/multi, TITLE='Select two FCS measurements', $
				comments=comm)
				
		IF N_ELEMENTS(fcss) NE 2 THEN BEGIN
		      PRINT, 'Wrong choice, returning ...'
		      RETURN
		ENDIF 
		IF fcss(0) EQ fcss(1) THEN BEGIN
		      PRINT, 'Wrong choice, returning ...'
		      RETURN
		ENDIF 
		
		fcs_pos = INTARR(2)
		FOR I=0,1 DO BEGIN
		 ind = WHERE(phtscp.admn EQ fcss(i), ncount)
		 fcs_pos(I) = ind(posi(i))
		 handle_value, phtscp(fcs_pos(i)).fcsn, fcsn
		 affcs = WHERE(fcsn NE 0, fcscount)
		 IF fcscount EQ 0 THEN BEGIN
		    XDISPLAYFILE, "", $
                      GROUP = event.top, $
                      TITLE = "Interrupting ", $
                      WIDTH = 60, $
                      HEIGHT = 6, $
                        TEXT = [" I have asked you for two FCS measurements, ", $
                                " haven't I ???        ", $
                                " Interrupting ...      "]
                    RETURN
                 ENDIF
      		ENDFOR
		
	   	respons_interpol, fcs_pos(0), fcs_pos(1), resps
		
		PROCESS_SCP, tmpdata, newheader, 3, spdpos, respint=resps 

		IF tmpdata.det eq 'SL' THEN spdpos = [spdpos-1,spdpos]
		FOR ispd=0,N_ELEMENTS(spdpos)-1 DO BEGIN  
			;PIA_DISPSPD, DATA= spdpos
			PIA_LOAD_ISPD, phtspd(spdpos(ispd)), tmpspd
			newheader = tmpspd.hdr
			PROCESS_SPD, tmpspd, newheader, tmpaap, aapps
			PIA_DISPAAP, DATA=aapps
		ENDFOR  
		 
          END

	  "CALACT_AVG": BEGIN
		
		comm = 	[" Please select two (and only two) ", $
                            " FCS measurements to be taken for ", $
                            " averaging responsivities      "]
			
		fcss = pickmeas(ftype="SCP",DTYPE=tmpdata.det, POSI=posi, $
				/multi, TITLE='Select two FCS measurements', $
				comments=comm)
				
		IF N_ELEMENTS(fcss) NE 2 THEN BEGIN
		      PRINT, 'Wrong choice, returning ...'
		      RETURN
		ENDIF 
		IF fcss(0) EQ fcss(1) THEN BEGIN
		      PRINT, 'Wrong choice, returning ...'
		      RETURN
		ENDIF 
		
		fcs_pos = INTARR(2)
		FOR I=0,1 DO BEGIN
		 ind = WHERE(phtscp.admn EQ fcss(i), ncount)
		 fcs_pos(I) = ind(posi(i))
		 handle_value, phtscp(fcs_pos(i)).fcsn, fcsn
		 affcs = WHERE(fcsn NE 0, fcscount)
		 IF fcscount EQ 0 THEN BEGIN
		    XDISPLAYFILE, "", $
                      GROUP = event.top, $
                      TITLE = "Interrupting ", $
                      WIDTH = 60, $
                      HEIGHT = 6, $
                        TEXT = [" I have asked you for two FCS measurements, ", $
                                " haven't I ???        ", $
                                " Interrupting ...      "]
                    RETURN
                 ENDIF
      		ENDFOR
		
	   	respons_interpol, fcs_pos(0), fcs_pos(1), resps
		
		PROCESS_SCP, tmpdata, newheader, 1, spdpos 
		
		IF tmpdata.det eq 'SL' THEN spdpos = [spdpos-1,spdpos]
		FOR ispd=0,N_ELEMENTS(spdpos)-1 DO BEGIN  
			;PIA_DISPSPD, DATA= spdpos
			PIA_LOAD_ISPD, phtspd(spdpos(ispd)), tmpspd
			newheader = tmpspd.hdr
			PROCESS_SPD, tmpspd, newheader, tmpaap, aapps
			PIA_DISPAAP, DATA=aapps
		ENDFOR  
		 
          END

	  "CALABS": BEGIN
		
		PROCESS_SCP, tmpdata, newheader, 2, spdpos

		IF tmpdata.det eq 'SL' THEN spdpos = [spdpos-1,spdpos]
		FOR ispd=0,N_ELEMENTS(spdpos)-1 DO BEGIN  
			;PIA_DISPSPD, DATA= spdpos
			PIA_LOAD_ISPD, phtspd(spdpos(ispd)), tmpspd
			newheader = tmpspd.hdr
			PROCESS_SPD, tmpspd, newheader, tmpaap, aapps
			PIA_DISPAAP, DATA=aapps
 		ENDFOR	
         END
		
	  "PIXCH": BEGIN
			old_pixcho = pixcho
			new_pixc = pia_pixchoice(GROUP=event.top, PIXC=pixcho)
			maxpix = max(new_pixc)
                        minpix = min(new_pixc)
			junk = 0
			IF (tmpdata.det EQ 'C1' AND maxpix gt 8) OR $
			   (tmpdata.det EQ 'C2' AND maxpix gt 3) OR $
			   (tmpdata.det EQ 'SS' AND maxpix gt 127) OR $
			   (tmpdata.det EQ 'SL' AND maxpix gt 127) OR $
			   (minpix lt 0)  THEN BEGIN
		    		XDISPLAYFILE, "", $
                    		GROUP = event.top, $
                    		TITLE = "Warning ", $
                    		WIDTH = 30, $
                    		HEIGHT = 6, $
                    		TEXT = [" Your pixel choice is not valid ", $
                                        " and will not be taken "]
		                junk = 1
			ENDIF
			IF junk NE 1 THEN BEGIN  			
			 FOR I=0,NVIEWS-1 DO BEGIN
			  IF new_pixc(i) NE old_pixcho(i) THEN BEGIN
			    pixcho(i) = new_pixc(i)
			    WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
			    view(i).windownum = temp
			    pia_resetview3, i, view(i).controlid
                            IF STRMID(tmpdata.det,0,1) EQ 'C' THEN BEGIN
                              txtval = cmap_wind_text(i)
                              junk = where(new_pixc eq old_pixcho(i), count)
                              IF count EQ 0 THEN $
                                 WIDGET_CONTROL, pixbut(old_pixcho(i)), $
                                        SET_VALUE = ' '
                              WIDGET_CONTROL, pixbut(pixcho(i)), $
                                        SET_VALUE = txtval
                            ENDIF
                          ENDIF
			 ENDFOR
			ENDIF
          END

	  "PIXCHSER": BEGIN
			old_pixcho = pixcho
			new_pixc = old_pixcho + nviews
			CASE STRMID(tmpdata.det,0,2) OF
				'C1': npix = 9
				'C2': npix = 4
				'SL': npix = 128
				'SS': npix = 128
				'P1': RETURN
				'P2': RETURN
				'P3': RETURN
			ENDCASE  
			new_pixc = new_pixc mod npix
			
			FOR I=0,NVIEWS-1 DO BEGIN
			  IF new_pixc(i) NE old_pixcho(i) THEN BEGIN
			    pixcho(i) = new_pixc(i)
			    WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
			    view(i).windownum = temp
			    pia_resetview3, i, view(i).controlid
			    IF STRMID(tmpdata.det,0,1) EQ 'C' THEN BEGIN 
			      txtval = cmap_wind_text(i)
			      junk = where(new_pixc eq old_pixcho(i), count)
			      IF count EQ 0 THEN $
			         WIDGET_CONTROL, pixbut(old_pixcho(i)), $
					SET_VALUE = ' '
			      WIDGET_CONTROL, pixbut(pixcho(i)), $
					SET_VALUE = txtval
			    ENDIF 
                          ENDIF
			ENDFOR
          END

	  "PIXCHSERD": BEGIN
			old_pixcho = pixcho
			new_pixc = old_pixcho - nviews
			CASE STRMID(tmpdata.det,0,2) OF
				'C1': npix = 9
				'C2': npix = 4
				'SL': npix = 128
				'SS': npix = 128
				'P1': RETURN
				'P2': RETURN
				'P3': RETURN
			ENDCASE  
			new_pixc = new_pixc mod npix
			
			FOR I=0,NVIEWS-1 DO BEGIN
			  IF new_pixc(i) NE old_pixcho(i) THEN BEGIN
			    pixcho(i) = new_pixc(i)
			    WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
			    view(i).windownum = temp
			    pia_resetview3, i, view(i).controlid
			    IF STRMID(tmpdata.det,0,1) EQ 'C' THEN BEGIN 
			      txtval = cmap_wind_text(i)
			      junk = where(new_pixc eq old_pixcho(i), count)
			      IF count EQ 0 THEN $
			         WIDGET_CONTROL, pixbut(old_pixcho(i)), $
					SET_VALUE = ' '
			      WIDGET_CONTROL, pixbut(pixcho(i)), $
					SET_VALUE = txtval
			    ENDIF 
                          ENDIF
			ENDFOR
          END

        "NVIEWS": BEGIN

                newviews = event.value + 1
		!PIA_NVIEWS = 1 > newviews < 4
                IF newviews NE nviews THEN BEGIN
                        WIDGET_CONTROL, scpdi1_wid, /DESTROY
                        pia_dispscp, NV = newviews, /redraw
                ENDIF
         END

       "HK" : begin
                get_pht_hk,tmpdata.admn,phtcs_redu
                xdisp_hk
              end


	ENDCASE
	
RETURN
END

; ****************************************************************************
;  PIA DispSCP - menu definition procedure
; ****************************************************************************

PRO pia_dispSCP, GROUP=group, DATA=DATA, NV = NV, REDRAW=redraw, CALA = cala


COMMON pia_dspscp_cmn, tmpdata, scpps, view, viewsize, nviews, viewoptions, $
    overid 
COMMON pia_dspscp_flg_cmn, nflag_active, flag_active_lex, flag_active_label  
COMMON pia_dspch3_cmn, pixcho, pixop, pixres, psymch, pixcount
COMMON scpattext, dattext_id, newheader, is_cala
COMMON dspscp_widg, pixbut
COMMON scp_nac, cps_disc, disc_set, vign_set 
COMMON pia_widget_info, extfil_wid, intfil_wid, buffil_wid, $
                        erddi1_wid, erddi2_wid, srddi1_wid, srddi2_wid, $
                        scpdi1_wid, scpdi2_wid, spddi1_wid, spddi2_wid, $
                        aapdi1_wid, aapdi2_wid
COMMON dispcust_cmn, psym, line
COMMON pia_resetcontrol_cmn, id_proccont, id_powcal, id_absphot, id_respcal, $
   id_bckint, id_stray, id_contstray, id_bl, id_vignet, id_chopcor

@phtscp
@phtcla
COMMON piaflag_info, piaflag_str

; If already registered, start second ERD display

        IF Xregistered("pia_dispscp") NE 0 THEN BEGIN
		IF KEYWORD_SET(cala) THEN cala=1 ELSE cala=0
                pia_dis2scp, group=group, data=data, cala=cala
                RETURN
        END

	IF KEYWORD_SET(cala) THEN is_cala = 1 ELSE is_cala =0

        IF NOT KEYWORD_SET(redraw) THEN BEGIN
; load data from dynamical buffers into temporary structure
	   IF NOT KEYWORD_SET(cala) THEN BEGIN
	        scpps = data
		PIA_LOAD_ISCP, phtscp(scpps), tmpdata 
	   ENDIF ELSE BEGIN 
	        scpps = data
		PIA_LOAD_CALA, phtcla(scpps), tmpdata
	   ENDELSE	 

; set selection and vignetting correction to not in the beginning
		disc_set = 0
		vign_set = 0
; header into temporary header variable
		newheader = tmpdata.hdr
        ENDIF


; initialize views and pixels chosen

        IF KEYWORD_SET(NV) THEN NVIEWS = nv ELSE nviews = !PIA_NVIEWS
        IF nviews GT 4 THEN nviews = 4
        pixcount = -1


	IF N_ELEMENTS(psym) EQ 0 THEN psymch = 4 ELSE $
		psymch = psym	

	CASE STRMID(tmpdata.det, 0,1) of 
          'P': BEGIN 
		pixcho = [0,0,0,0]
		pixop = 0
		pixres = 0
	  END
          ELSE: BEGIN  
	         CASE STRMID(tmpdata.det,0,2) of
	           'C1': BEGIN
			pixcho = [0,2,4,6]
			pixop = 9
			pixres = 10
		   END
	           'C2': BEGIN
			pixcho = [1,2,3,0]
			pixop = 4
			pixres = 5
		   END
	           'SS': BEGIN
			pixcho = [10,40,90,120]
			pixop = 129
			pixres = 130
		   END
	           'SL': BEGIN
			pixcho = [10,40,90,120]
			pixop = 129
			pixres = 130
		   END
		  ELSE: BEGIN
			pixcho = [10,40,90,120]
			pixop = 129
			pixres = 130
		   END
	 	  ENDCASE		
	  END
        ENDCASE

	indflag_active = WHERE(piaflag_str.scp.lex NE 'DUMMY',nflag_active)
	
	nflag_active = nflag_active +1
		
	flag_active_lex = ['ENCODE',piaflag_str.scp.lex(indflag_active)]
	flag_active_label = ['Encode',piaflag_str.scp.expla(indflag_active)]

	viewsize = 220
	xsize = viewsize * 4 / nviews
	ysize = viewsize
       ;structure for each view
	viewinstance = {        viewtype:0b, 		$	   
				viewtype_sub:0b, 	$       
				controlid:0L,		$       	
				windowid:0L,		$
				windownum:0}	

        view = REPLICATE(viewinstance, NVIEWS)		; array of view struct.

        IF STRMID(tmpdata.det, 0,1) eq 'P' THEN $
                FOR i=0,nviews-1 DO view(i).viewtype = i

	;structures describing each type of view 
	instance = {viewname:'', viewid:0, viewxlab:'', viewylab:'', $
		viewmenu:0, viewmenuchoi:0,viewmenulabel:STRARR(nflag_active)} 
	NVIEWOPTS = 13                           	

	viewoptions = REPLICATE(instance, NVIEWOPTS)    

        viewoptions(0).viewname = "Signal Avrg / Ch.Pl.  [V/sec]"
        viewoptions(0).viewid = 0
        viewoptions(0).viewylab = "Signal Average       [V/s]"
        viewoptions(0).viewxlab = "Time       [s]"
        viewoptions(1).viewname = "Signal Median / Ch.Pl.  [V/sec]"
        viewoptions(1).viewid = 1
        viewoptions(1).viewylab = "Signal Median        [V/s]"
        viewoptions(1).viewxlab = "Time       [s]"
        viewoptions(2).viewname = "Signal/CP Flag"
        viewoptions(2).viewid = 2
        viewoptions(2).viewmenu = 1
        viewoptions(2).viewmenuchoi = nflag_active
        viewoptions(2).viewmenulabel = flag_active_label
        viewoptions(2).viewylab = "Flag          "
        viewoptions(2).viewxlab = "Time       [s]"
        viewoptions(3).viewname = "Chopper Position"
        viewoptions(3).viewid = 3
        viewoptions(3).viewylab = "Corrected position   [arcsec]"
        viewoptions(3).viewxlab = "Time       [s]"
        viewoptions(4).viewname = "Temperature     "
        viewoptions(4).viewid = 4
        viewoptions(4).viewylab = "Meas. temperature    [K]"
        viewoptions(4).viewxlab = "Time       [s]"
        viewoptions(5).viewname = "FCS1 electrical Power [mW]"
        viewoptions(5).viewid = 5
        viewoptions(5).viewylab = "Measured Power       [mW]"
        viewoptions(5).viewxlab = "Time       [s]"
        viewoptions(6).viewname = "FCS2 electrical Power [mW]"
        viewoptions(6).viewid = 6
        viewoptions(6).viewylab = "Measured Power        [mW]"
        viewoptions(6).viewxlab = "Time       [s]"
        viewoptions(7).viewname = "Time Key"
        viewoptions(7).viewid = 7
        viewoptions(7).viewylab = "Instrument Time Key "
        viewoptions(7).viewxlab = "Time       [s]"
        viewoptions(8).viewname = "Raster Point ID"
        viewoptions(8).viewid = 8
        viewoptions(8).viewmenu = 1
        viewoptions(8).viewmenuchoi = 2
        viewoptions(8).viewmenulabel = ['1','2']
        viewoptions(8).viewylab = "Raster Point ID "
        viewoptions(8).viewxlab = "Time       [s]"
        viewoptions(9).viewname = "S. Avrg / Ch.Pl. OpenPixel [V/sec]"
        viewoptions(9).viewid = 9
        viewoptions(9).viewylab = "Signal Average        [V/s] "
        viewoptions(9).viewxlab = "Time       [s]"
        viewoptions(10).viewname = "S. Median/Ch.Pl. OpenPixel [V/sec]"
        viewoptions(10).viewid = 10
        viewoptions(10).viewylab = "Signal Median         [V/s] "
        viewoptions(10).viewxlab = "Time       [s]"
        viewoptions(11).viewname = "S. Avrg/Ch.Pl.  Res.Pixel [V/sec]"
        viewoptions(11).viewid = 11
        viewoptions(11).viewylab = "Signal Average       [V/s] "
        viewoptions(11).viewxlab = "Time       [s]"
        viewoptions(12).viewname = "S.Median/Ch.Pl. Res.Pixel [V/sec]"
        viewoptions(12).viewid = 12
        viewoptions(12).viewylab = "Signal Median        [V/s] "
        viewoptions(12).viewxlab = "Time       [s]"


; top base

	scpdi1_wid = WIDGET_BASE( TITLE="PIA SCP Data Display", /COLUMN, $
				XPAD = 20, YPAD = 20, SPACE = 20)

; control windows

	control = WIDGET_BASE(scpdi1_wid, /ROW)

	control_exit = WIDGET_BUTTON(control, VALUE="    Exit    ",$
					 /ALIGN_CENTER, /MENU)
	save_quit = WIDGET_BUTTON(control_exit, $
		VALUE="Save modified measurement into buffer and Quit",$
					 UVALUE="SAVEXIT")
	simple_quit = WIDGET_BUTTON(control_exit, $
		VALUE="Quit without saving modified measurement into buffer",$
					 UVALUE="EXIT")
	control_help = WIDGET_BUTTON(control, VALUE="    Help    ",$
					 /ALIGN_CENTER, UVALUE="HELP")
	control_cust = WIDGET_BUTTON(control, VALUE="  Customize ",$
					 /ALIGN_CENTER, UVALUE="CUST")

	junk = WIDGET_LABEL(control, VALUE = '     ')

; only set when it is not Cal A measurement, WMT, 4/96
	IF keyword_set(CALA) THEN BEGIN
	  more_text = ' ' 
	  tmp = 'Cal A '
	ENDIF ELSE BEGIN
	  obj = FXPAR(tmpdata.hdr,'OBJECT')
	  attra = FXPAR(tmpdata.hdr,'ATTRA')
	  attdec = FXPAR(tmpdata.hdr,'ATTDEC')
	  more_text = 'OBJ:' + obj + ' ' + give_sradec(attra, attdec)
	  tmp = 'SCP '
	ENDELSE
	  decode_admn, tmpdata.admn, dattext
	  dattext = tmp +dattext+ ' - '+tmpdata.unit+ ' - ' + more_text


	dattext_id = WIDGET_LABEL(control, VALUE = dattext)  

;------------------- the C mapping windows -------------------------

        junk = WIDGET_LABEL(control, VALUE = '       ')

        IF STRMID(tmpdata.det, 0,1) eq 'C' THEN BEGIN

        pixver = WIDGET_BASE(control, /COLUMN)
	junk = WIDGET_LABEL(pixver, VALUE='^ +Z')

        pixhor = WIDGET_BASE(pixver,/ROW)

          IF STRMID(tmpdata.det, 1,1) eq '1' THEN BEGIN
                pixbut = lonarr(9)
                FOR i=0,2 DO pixbut(i*3+2) = $
                        WIDGET_BUTTON(pixhor, VALUE=' ',$
                                XOFFSET=3*i, $,
                                UVALUE=i*3+2,$
                                EVENT_PRO = 'pixbutevent3')
                pixhor = WIDGET_BASE(pixver,/ROW,YOFFSET=10)
                FOR i=0,2 DO pixbut(i*3+1) = $
                        WIDGET_BUTTON(pixhor, VALUE=' ',$
                                XOFFSET=3*i, $
                                UVALUE=i*3+1,$
                                EVENT_PRO = 'pixbutevent3')
                pixhor = WIDGET_BASE(pixver,/ROW,YOFFSET=10)
                FOR i=0,2 DO pixbut(i*3) = $
                        WIDGET_BUTTON(pixhor, VALUE=' ',$
                                XOFFSET=3*i, $
                                UVALUE=i*3,$
                                EVENT_PRO = 'pixbutevent3')
          ENDIF ELSE $
          IF STRMID(tmpdata.det, 1,1) eq '2' THEN BEGIN
                pixbut = lonarr(4)
                FOR i=0,1 DO pixbut(i+2) = $
                        WIDGET_BUTTON(pixhor, VALUE=' ',$
                                XOFFSET=3*i, $
                                UVALUE=i+2,$
                                EVENT_PRO = 'pixbutevent3')
                pixhor = WIDGET_BASE(pixver,/ROW,YOFFSET=10)
                FOR i=1,0,-1 DO pixbut(i) = $
                        WIDGET_BUTTON(pixhor, VALUE=' ',$
                                XOFFSET=3*i, $
                                UVALUE=i,$
                                EVENT_PRO = 'pixbutevent3')
          ENDIF
	junk = WIDGET_LABEL(pixhor, VALUE='> +Y')
        ENDIF

;----------------- the View windows are defined ------------------

	viewbase = WIDGET_BASE(scpdi1_wid, /ROW, SPACE=1)

	viewstorageids = LONARR(NVIEWS)
	overid = lonarr(NVIEWS)	   
	
; Provide for Open and Resistor pixels only if necessary
	IF STRMID(tmpdata.det,0,1) EQ 'P' THEN NVIEWOPTS = NVIEWOPTS - 4

	cmap_wind_text = ["A","B","C","D"]
	
        FOR viewindex = 0, NVIEWS - 1 DO BEGIN
	  viewbase_sub = WIDGET_BASE(viewbase, /FRAME, /COLUMN)
	  junk = WIDGET_LABEL(viewbase_sub,                               $
	       VALUE="Window "+cmap_wind_text(viewindex))
	  tempbase = WIDGET_BASE(viewbase_sub, /COLUMN, $
				EVENT_PRO = 'viewevent3')
	  view(viewindex).controlid = WIDGET_BUTTON(tempbase, VALUE="   ",$
				MENU = 2, UVALUE = viewindex, $
				EVENT_PRO = 'viewevent3')
	  view(viewindex).windowid = WIDGET_DRAW(tempbase, $
				XSIZE = xsize, YSIZE = ysize, $
				RETAIN = 2) 
		FOR i = 0, NVIEWOPTS - 1 DO BEGIN
     			dummy = WIDGET_BUTTON(view(viewindex).controlid, $
                	VALUE = viewoptions(i).viewname, $
                	UVALUE = viewoptions(i).viewid,                   $
			MENU=viewoptions(i).viewmenu)
			IF viewoptions(i).viewmenu THEN BEGIN
			   FOR ichoi=0,viewoptions(i).viewmenuchoi-1 DO  $
			   dummy1 = WIDGET_BUTTON(dummy, $
			     VALUE=viewoptions(i).viewmenulabel(ichoi), $
			     UVALUE=ichoi)
			ENDIF     
		ENDFOR

	  zoombase = WIDGET_BASE(tempbase, /FRAME, /ROW)
          zoom = WIDGET_BUTTON(zoombase, $
                        VALUE = "Zoom & Print", $
                        UVALUE = viewindex, MENU = 2)

          dummy = WIDGET_BUTTON(zoom, $
                        VALUE = "New  ", $
                        UVALUE = viewindex, EVENT_PRO = 'zoomevent3')

          synch = WIDGET_BUTTON(zoom, $
                        VALUE = "Overplot, same y-axis  ", $
                        UVALUE = viewindex, EVENT_PRO = 'zoomsync3')
          nsynch = WIDGET_BUTTON(zoom, $
                        VALUE = "Overplot, new y-axis", $
                        UVALUE = viewindex, EVENT_PRO = 'zoomnsync3')

	  
          process = WIDGET_BUTTON(zoombase, $
                        VALUE = "Test processing", $
                        UVALUE = viewindex, MENU = 2)

          base_dr = WIDGET_BUTTON(process, $
                        VALUE = "Baseline drift", $
                        UVALUE = viewindex, EVENT_PRO = 'basel_drift')

          fourier = WIDGET_BUTTON(process, $
                        VALUE = "Fourier", $
                        UVALUE = viewindex, EVENT_PRO = 'zoomfourier3')

          aver = WIDGET_BUTTON(process, $
                        VALUE = "Average", $
                        UVALUE = viewindex, MENU = 2)

          average = WIDGET_BUTTON(aver, $
                        VALUE = "Chopper ", $
                        UVALUE = viewindex, EVENT_PRO = 'averagechop3')

          average = WIDGET_BUTTON(aver, $
                        VALUE = "Non-Chopper", $
                        UVALUE = viewindex, EVENT_PRO = 'averagenonch3')

          medi = WIDGET_BUTTON(process, $
                        VALUE = "Median", $
                        UVALUE = viewindex, MENU = 2)

          median = WIDGET_BUTTON(medi, $
                        VALUE = "Chopper", $
                        UVALUE = viewindex, EVENT_PRO = 'medianchop3')

          median = WIDGET_BUTTON(medi, $
                        VALUE = "Non-Chopper", $
                        UVALUE = viewindex, EVENT_PRO = 'mediannonch3')

          discar = WIDGET_BUTTON(process, $
                        VALUE = "Discard area graphically", $
                        UVALUE = viewindex, EVENT_PRO= 'discard_area3')

          resel = WIDGET_BUTTON(process, $
                        VALUE = "Reselect area graphically", $
                        UVALUE = viewindex, EVENT_PRO= 'reselect_area3')
        ENDFOR

	controlbase = WIDGET_BASE(scpdi1_wid, $
                /ROW, $
                SPACE = 40)


;----------------- the Data controls are defined ------------------

        datcont = WIDGET_BUTTON(controlbase, VALUE='    Data    ', /MENU )
        id_2 = WIDGET_BUTTON(datcont, VALUE='Load', UVALUE='LOAD' )
	;IF KEYWORD_SET(cala) THEN WIDGET_CONTROL, id_2, SENSITIVE=0

        id_2 = WIDGET_BUTTON(datcont, VALUE='Save', /MENU )
        id_3 = WIDGET_BUTTON(id_2, VALUE='to SCP buffer', /MENU )
        id_4 = WIDGET_BUTTON(id_3, VALUE='new measurement', $
				 UVALUE='SAVEBUFF_NEW' )
        id_4 = WIDGET_BUTTON(id_3, VALUE='same measurement', $
				 UVALUE='SAVEBUFF' )
        id_3 = WIDGET_BUTTON(id_2, VALUE='to PIA internal file', $
					UVALUE='SAVEI' )
        id_3 = WIDGET_BUTTON(id_2, VALUE='to FITS external file', $
					UVALUE='SAVEF' )
        id_2 = WIDGET_BUTTON(datcont, VALUE='Print Values', UVALUE='PRINT' )
        id_2 = WIDGET_BUTTON(datcont, VALUE='Show Data', UVALUE='SHOWD' )

;---------------- the Selection controls are defined -----------------

        selcont = WIDGET_BUTTON(controlbase, VALUE='  Selection ', /MENU )
        id_2 = WIDGET_BUTTON(selcont, VALUE='Discard Chopper Plateaux', $
				UVALUE='SLDISC')

;---------------- the Correction controls are defined -----------------

        corrcont = WIDGET_BUTTON(controlbase, VALUE=' Correction ', /MENU )
        id_2 = WIDGET_BUTTON(corrcont, VALUE='Reset interval corr.', $
        	UVALUE='RINT')
        id_vignet = WIDGET_BUTTON(corrcont, VALUE=' Vignetting ', UVALUE='VIGN')
        IF tmpdata.det EQ 'SL' THEN WIDGET_CONTROL, id_vignet, SENSITIVE=0
	id_2 = WIDGET_BUTTON(corrcont, VALUE=' Dark Current Subtr. (obsolete)', $
	         UVALUE ='DARKC_SCP')
	id_2 = WIDGET_BUTTON(corrcont, $
	  VALUE=' Dark Current Subtr. (orbital dep)', /MENU)
	id_3 = WIDGET_BUTTON(id_2,  $ 
	         VALUE=' Perform it ', $
	         UVALUE ='DARKC_SCP_ORB')
	id_3 = WIDGET_BUTTON(id_2,  $ 
	         VALUE=' Customize ', $
	         UVALUE ='DARKC_SCP_ORB_PAR')
        id_chopcor = WIDGET_BUTTON(corrcont,                                 $
        	VALUE=' Signal losses in Chopped meas. ', UVALUE='CHOPFREQ')
        id_2 = WIDGET_BUTTON(corrcont,                                 $
        	VALUE='Signal Linearization', UVALUE='RLIN')
        id_contstray = WIDGET_BUTTON(corrcont,  $
        	VALUE=' Straylight subtraction ', UVALUE='STRAYL')
        id_bl = WIDGET_BUTTON(corrcont, VALUE=' Baseline drift modelling ', $
        	UVALUE='BDR')
        	
;---------------- the View controls are defined -----------------

        viewcont = WIDGET_BUTTON(controlbase, VALUE='  View  ', /MENU )
        id_2 = WIDGET_BUTTON(viewcont, VALUE='Header Info ', UVALUE='HDR')
        id_2 = WIDGET_BUTTON(viewcont, VALUE='Compact Status ', UVALUE='CS')
        defresp = WIDGET_BUTTON(viewcont, VALUE='Default Response',$
           UVALUE='DEFRESP')
        IF STRMID(tmpdata.det,0,1) EQ 'S' THEN $
                        WIDGET_CONTROL, defresp, SENSITIVE=0
        actresp = WIDGET_BUTTON(viewcont, VALUE='Actual Response',$
           UVALUE='ACTRESP')
        IF STRMID(tmpdata.det,0,1) EQ 'S' THEN $
                        WIDGET_CONTROL, actresp, SENSITIVE=0
        cont2 = WIDGET_BUTTON(viewcont, VALUE='Auxiliary Files', /MENU )
        id_2 = WIDGET_BUTTON(cont2, VALUE='IS Report ', UVALUE='ISREP')
        id_2 = WIDGET_BUTTON(cont2, VALUE='OLP Report ', UVALUE='OLREP')
        id_2 = WIDGET_BUTTON(cont2, VALUE='EOHA ', UVALUE='EOHA')
        id_2 = WIDGET_BUTTON(cont2, VALUE='EOHI ', UVALUE='EOHI')
        cont2 = WIDGET_BUTTON(viewcont, VALUE='Statistics Info', /MENU )
        id_2 = WIDGET_BUTTON(cont2, VALUE='Stability Analysis', UVALUE='ISMANN')
        id_2 = WIDGET_BUTTON(cont2, VALUE='Drift modelling ', $
        			UVALUE='ISDRIFT')
        id_2 = WIDGET_BUTTON(cont2, VALUE='Slopes variation ', $
        			UVALUE='ISSLOPV')

;---------------- the Array controls are defined -----------------

        arrcont = WIDGET_BUTTON(controlbase, VALUE=' Array ', /MENU )

        id_2 = WIDGET_BUTTON(arrcont, VALUE=' Images ', UVALUE='IMAGE')
        IF STRMID(tmpdata.det,0,1) NE 'C' THEN $
                        WIDGET_CONTROL, id_2, SENSITIVE=0

        id_2 = WIDGET_BUTTON(arrcont, VALUE=' Spectra ', /MENU )
        IF STRMID(tmpdata.det,0,1) NE 'S' THEN $
                        WIDGET_CONTROL, id_2, SENSITIVE=0
        id_3 = WIDGET_BUTTON(id_2, VALUE=' New ', UVALUE='SPECT')
        id_3 = WIDGET_BUTTON(id_2, VALUE=' Overplot ', /MENU)
        id_4 = WIDGET_BUTTON(id_3, VALUE=' Synchronized ', UVALUE='SPESY')
        id_4 = WIDGET_BUTTON(id_3, VALUE=' Not Synchronized ', UVALUE='SPENSY')

        id_2 = WIDGET_BUTTON(arrcont, VALUE='Time evolution', /MENU)
        IF STRMID(tmpdata.det,0,1) EQ 'P' THEN $
                        WIDGET_CONTROL, id_2, SENSITIVE=0
        id_3 = WIDGET_BUTTON(id_2, VALUE='Time slices ', UVALUE='SLICES')
        id_3 = WIDGET_BUTTON(id_2, VALUE='3-D view ', UVALUE='SLICES_3D')

;---------------- the Processing controls are defined -----------------

        id_proccont = WIDGET_BUTTON(controlbase, VALUE=' Process ', $
                                /MENU )
        id_powcal = WIDGET_BUTTON(id_proccont, VALUE=' Power Calibration', $
                               /MENU )
	id_3 = WIDGET_BUTTON(id_powcal, VALUE=' Default Responses (orbital dep.)',$
		/MENU)
	id_4 = WIDGET_BUTTON(id_3,  $ 
	         VALUE=' Perform it ', $
	         UVALUE ='CALDEF')
	id_4 = WIDGET_BUTTON(id_3,  $ 
	         VALUE=' Customize ', $
	         UVALUE ='CALDEF_PAR')
	id_slchop = WIDGET_BUTTON(id_powcal,  $
	    VALUE=' Chopped SPRF (only for PHT-S)', UVALUE='CALSL_CHOP')
	id_3 = WIDGET_BUTTON(id_powcal, VALUE=' Actual Responses', $ 
	    UVALUE='CALACT')
	id_3 = WIDGET_BUTTON(id_powcal, VALUE=' Interpolate Responses', $
				UVALUE='CALACT_INT')
	id_3 = WIDGET_BUTTON(id_powcal, VALUE=' Average Responses', $
				UVALUE='CALACT_AVG')
	id_absphot = WIDGET_BUTTON(id_powcal, VALUE=' Absolute Photometry', $
				UVALUE='CALABS')
        is_bsub = FXPAR(newheader,'PRC_SUBT')
	IF tmpdata.det NE 'SL' OR is_bsub EQ 0 THEN $
	    WIDGET_CONTROL, id_slchop, SENSITIVE=0		


; Responsivity Calculation only possible if FCS points present
        id_respcal = WIDGET_BUTTON(id_proccont,  $
                            VALUE=' Responsivity Calculation', UVALUE='RESPON')

; Background subtraction 
        id_2 = WIDGET_BUTTON(id_proccont, VALUE=' Background Subtraction', /MENU)
; within this meas only possible if several chopper steps present
        id_bckint = WIDGET_BUTTON(id_2, VALUE='within measurement ', $
                               UVALUE='BCKSBT')
	inda = WHERE(tmpdata.step EQ 2, nrstp)	
        id_3 = WIDGET_BUTTON(id_2, VALUE='another measurement ', $
                               UVALUE='BCKSBT_MEAS')
; Dark current measurement subtraction 
        id_2 = WIDGET_BUTTON(id_proccont, $
        	VALUE='Dark Current Measurement Subtraction', $
        	UVALUE='DARKSUBT_MEAS')
; Straylight measurement subtraction 
        id_stray = WIDGET_BUTTON(id_proccont, $
        	VALUE='Straylight Measurement Subtraction', $
        	UVALUE='STRYSUBT_MEAS')


;---------------- the Pixel Choice controls are defined -----------------

        pixcont = WIDGET_BUTTON(controlbase, VALUE=' Pixels ', $
				/MENU)
        pixch = WIDGET_BUTTON(pixcont, VALUE=' Individual choice ', $
				UVALUE='PIXCH' )
        pixch = WIDGET_BUTTON(pixcont, VALUE=' Serial increment  ', $
				UVALUE='PIXCHSER' )
        pixch = WIDGET_BUTTON(pixcont, VALUE=' Serial decrement  ', $
				UVALUE='PIXCHSERD' )
        IF STRMID(tmpdata.det,0,1) EQ 'P' THEN $
        	WIDGET_CONTROL, pixcont, SENSITIVE=0

;---------------- the number of views controls is defined -----------------

        nvbut = cw_bselector(controlbase, $
                        /FRAME, SET_VALUE=NVIEWS-1, $
                        UVALUE = 'NVIEWS', $
                        ['1 Plot', $
                        '2 Plots', $
                        '3 Plots', $
                        '4 Plots'])

;----------------------------------------------------------------------

       hkbutton=widget_button(controlbase,value=' HK ', uvalue ='HK')

;----------------------------------------------------------------------

; Look into the selection criteria

        get_scpdisc, tmpdata, /ENCODE_FLAG
	get_validflag, tmpdata.flag, 'SCP', redflag, $
			  det=tmpdata.det, /allpix

        cps_disc = redflag
        disc_set = 1        

; check possible corrections and processing
        pia_resetcorrcontrol3, tmpdata, is_cala

; Realize widget

	WIDGET_CONTROL, scpdi1_wid, /REALIZE, /HOURGLASS

	FOR i = 0, nviews - 1 DO BEGIN
		WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
		view(i).windownum = temp
		pia_resetview3, i, view(i).controlid
           IF STRMID(tmpdata.det,0,1) EQ 'C' THEN BEGIN
	  	txtval = cmap_wind_text(i)                
                WIDGET_CONTROL, pixbut(pixcho(i)), SET_VALUE = txtval
           ENDIF
	ENDFOR

	xMANAGER,No_BLOCK=1, "pia_dispscp", scpdi1_wid, $
		EVENT_HANDLER = "pia_dscp_event", GROUP_LEADER=GROUP


	RETURN
END
