;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_FCSPRE_STRUCT_VAL_CHOICE
;
; PURPOSE:
;	Menu for extracting values from the PHT FCS Preselected power Files 
;
; CATEGORY:
;       PIA - graphics
;
; CALLING SEQUENCE:
;       PIA_FCSPRE_STRUCT_VAL_CHOICE
;
; INPUTS:
;	STRFCSPRE
;		The structure to be chosen from
;
; KEYWORD PARAMETERS:
;	GROUP=group: Group leader
;
; OUTPUTS:
;	ACC_INDICES
;		The structure indices corresponding to the selection
; COMMON BLOCKS:
;	pia_varselected_cmn	I/F to pia_select_var
;	
; PROCEDURES USED:
;	PIA Lib: 
;		pia_select_var
;	Astro Lib:
;		match
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel (ESA/VILSPA) 		November 1995
;	STRTRIM used for strings (CG)			February 1996
;
;-
; *****************************************************************
; ***************  choice menu for structure elements
; *****************************************************************
PRO PIA_FCSPRE_STRUCT_VAL_CHOICE, strfcspre, acc_indices

;;COMMON pia_varselected_cmn, vars


; set first the acc_indices to bad
	acc_indices = -1

; data specifications
	data_names = ['Filter', 'Aperture', 'Orbit position', 'Observing Date ',$
		  'TDTnr', 'Source', 'T_int', 'Flag','Processing date']
        data_exa = [strfcspre(0).filt_id, strfcspre(0).aper_id, $
	  STRING(strfcspre(0).orb_pos), strfcspre(0).date, $
	  STRING(strfcspre(0).tdtnr), strfcspre(0).source, $
	  STRING(strfcspre(0).t_int), STRING(strfcspre(0).FLAG), $
	  strfcspre(0).proc_time]
	data_pos = [1,2,3,4,5,6,10,16,17]
	  
; get variables limits
	vartyp=[1,1,0,2,0,1,0,0,2]
	pia_select_var, data_exa, vars, VARNAMES=data_names, $
		VARTYP=vartyp, GROUP=group, STOP = stop_proc
          
        IF STOP_PROC THEN RETURN  
        
        help, vars
	
	nelem = N_ELEMENTS(strfcspre)
	indall = indgen(nelem)


; look first for absolute choices

	indch = WHERE(vars(0,*) NE '' AND vartyp EQ 1, count)

	IF count GT 0 THEN BEGIN
	  FOR I=0,count-1 DO BEGIN
	  	filt = [vars(0,indch(i))]

		indfilt = WHERE(STRTRIM(strfcspre.(data_pos(indch(i))),2) EQ $ 
			STRTRIM(filt(0),2), nfilt)

	     	IF nfilt EQ 0 THEN BEGIN

			text = 'No ' + data_names(indch(i)) + $
				' corresponding to selection'
                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = text
                        RETURN
	     	ENDIF
			  	 	  
		match, indall, indfilt, suba, subb, count=count
		IF count EQ 0 THEN GOTO, nocomb
		indall = indall(suba)
	   ENDFOR
	  ENDIF

; and then for chosen ranges

	indch = WHERE(vars(0,*) NE '' AND vartyp EQ 0, count)

	IF count GT 0 THEN BEGIN
	  FOR I=0,count-1 DO BEGIN
		IF vars(1,indch(i)) EQ '' THEN BEGIN
                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" Incomplete Spec found, returning  "]
			RETURN
		ENDIF			

	  	filt = [vars(0,indch(i)),vars(1,indch(i))]
		indfilt = WHERE(strfcspre.(data_pos(indch(i))) GE filt(0) AND $
				strfcspre.(data_pos(indch(i))) LE filt(1), nfilt)

	     	IF nfilt EQ 0 THEN BEGIN

			text = 'No ' + data_names(indch(i)) + $
				' corresponding to selection'
                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = text
                        RETURN
	     	ENDIF
			  	 	  
		match, indall, indfilt, suba, subb, count=count
		IF count EQ 0 THEN GOTO, nocomb
		indall = indall(suba)
	  ENDFOR
	ENDIF

print,'indall after 2 ',indall
; and then for chosen ranges which need date conversion

	indch = WHERE(vars(0,*) NE '' AND vartyp EQ 2, count)
	print,'indch ',indch
	print,'var ',vars(0,indch)
	IF count GT 0 THEN BEGIN
	  FOR I=0,count-1 DO BEGIN
		IF vars(1,indch(i)) EQ '' THEN BEGIN
                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" Incomplete Spec found, returning  "]
			RETURN
		ENDIF			

	  	filt = [date_conv(vars(0,indch(i))),date_conv(vars(1,indch(i)))]
	  	help,filt
		NEL2CONV = N_ELEMENTS(strfcspre.(data_pos(indch(i))))
		dat_conv = dblarr(NEL2CONV)
		help,dat_conv
		FOR IDAT = 0,NEL2CONV-1 DO $
		 dat_conv(IDAT) = $
		   date_conv(strfcspre(IDAT).(data_pos(indch(i))))

		indfilt = WHERE(dat_conv GE filt(0) AND $
				dat_conv LE filt(1), nfilt)

	     	IF nfilt EQ 0 THEN BEGIN

			text = 'No ' + data_names(indch(i)) + $
				' corresponding to selection'
                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = text
                        RETURN
	     	ENDIF
			  	 	  
		match, indall, indfilt, suba, subb, count=count
		IF count EQ 0 THEN GOTO, nocomb
		indall = indall(suba)
	  ENDFOR
	ENDIF

	acc_indices = indall
	nacc = N_ELEMENTS(indall)
	Text =  ["A total of "+ STRTRIM(STRING(nacc),2) + " observations", $
		 "correspond to the combination selected"]
        XDISPLAYFILE, "", $
                TITLE = "New FCS Table Calculation", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [text]      

	RETURN
NOCOMB: 
        XDISPLAYFILE, "", $
            TITLE = "Input not accepted", $
            WIDTH = 50, $
            HEIGHT = 4, $
            TEXT = [" Combined selection discards all elements "]
        RETURN


END 

