;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_ff_backgr
;
; PURPOSE:
;	Menu for obtaining directly flat field
;	factors from selected data regions. It returns the flat-fielded data.
;	
; CATEGORY:
;	PIA - graphics + processing
;
; CALLING SEQUENCE:
;	PIA_ff_backgr, mnbr, mnbu, ff_mnbr
;
; INPUT:
;	mnbr:		A 2-dim data array 
;	mnbu:		Uncertainties of mnbr
;
; OUTPUT:
;	ff_mnbr:	The modified array (same dims as mnbr) 
;	
; INPUT KEYWORDS:
;	flag:		Flag array (same dimension as mnbr)
;	modal:		For running widget in /modal 
;	group:		Group leader of the widget (mandatory if /modal)
;  
; COMMON BLOCKS:
;	colour_indices
;	pia_dspchz_cmn
;	zoom_discareas
;
; PROCEDURES USED:
;	PIA:
;		ff_bck
;		pia_disp_print_file
;		pia_xplot
;	
; MODIFICATION HISTORY:
;	Written by:	C.Gabriel (ESA/VILSPA-SAI)	August 1999
;	
;-

; ****************************************************************************
;  PIA_ff_backgr_event
; ****************************************************************************


PRO PIA_FF_backgr_event, event

@colour_indices
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
COMMON zoom_discareas, d_flags, all_disc_areas


	WIDGET_CONTROL, event.id, GET_UVALUE=action
	WIDGET_CONTROL, event.top, GET_UVALUE=idsb_handle
	handle_value, idsb_handle, idsb 

	psymch = 4
	
	CASE action OF
	  'ALLPIX': BEGIN
	     npix = N_ELEMENTS(idsb.flag(*,0))
	     FOR I=0,npix-1 DO $
	         idsb.flag(I,*) = idsb.flag(idsb.pix,*) 
	         
	     handle_value, idsb_handle, idsb, /SET
	     WIDGET_CONTROL, event.top, SET_UVALUE=idsb_handle
	  END

	  'DSEL': BEGIN
	     WIDGET_CONTROL, idsb.id_pix, GET_VALUE=pix
	     idsb.pix = pix(0)-1
	     data = idsb.data(idsb.pix,*)
	     unc = idsb.unc(idsb.pix,*)
	     flags = idsb.flag(idsb.pix,*)
	     xind = indgen(N_ELEMENTS(data))
	     PIA_XPLOT, xind, data, unc, flagged=flags, group=event.top,$
	           title= 'Discarding data by pixel '+STRTRIM(idsb.pix+1,2),$
		   xtitle='Index',ytitle='Brightness [MJy/sr]',$
		   psym=psymch, /disc_area, modal=idsb.modal
	     siz= size(all_disc_areas)
	     IF siz(0) EQ 0 THEN RETURN
	     FOR I=0,N_ELEMENTS(all_disc_areas)-1 DO BEGIN
	       p1 = all_disc_areas(i).pos1
	       p2 = all_disc_areas(i).pos2
	       IF p1(1) NE 0. or p2(1) NE 0. THEN BEGIN
	           ind = WHERE(data GE p1(1) AND $
	     		 data LE p2(1) AND $
			 xind GE p1(0) AND $
			 xind LE p2(0), ndisc)
	           IF ndisc GT 0 THEN $
	               idsb.flag(idsb.pix,ind) = 1
	       ENDIF	  
	      ENDFOR
	     WIDGET_CONTROL, idsb.id_all, /sensitive
	     handle_value, idsb_handle, idsb, /SET
	     WIDGET_CONTROL, event.top, SET_UVALUE=idsb_handle
	  END
	  	     
	  'SEL': BEGIN
	     WIDGET_CONTROL, idsb.id_pix, GET_VALUE=pix
	     idsb.pix = pix(0)-1
	     data = idsb.data(idsb.pix,*)
	     unc = idsb.unc(idsb.pix,*)
	     flags = idsb.flag(idsb.pix,*)
	     xind = indgen(N_ELEMENTS(data))
	     PIA_XPLOT, xind, data, unc, flagged=flags, group=event.top, $
	           title= 'Selecting data by pixel '+STRTRIM(idsb.pix+1,2),$
		   xtitle='Index',ytitle='Brightness [MJy/sr]',$
		   psym=psymch, /disc_area, modal=idsb.modal
	     siz= size(all_disc_areas)
	     IF siz(0) EQ 0 THEN RETURN
	     allind = 0
	     FOR I=0,N_ELEMENTS(all_disc_areas)-1 DO BEGIN
	       p1 = all_disc_areas(i).pos1
	       p2 = all_disc_areas(i).pos2
	       IF p1(1) NE 0. or p2(1) NE 0. THEN BEGIN
	           ind = WHERE(data GE p1(1) AND $
	     		 data LE p2(1) AND $
			 xind GE p1(0) AND $
			 xind LE p2(0), ndisc)
	           IF ndisc GT 0 THEN $
	               allind = [allind,ind]
	     
	       ENDIF
	      ENDFOR
	     IF N_ELEMENTS(allind) GT 1 THEN BEGIN
	      idsb.flag(idsb.pix,*) = 1
	      idsb.flag(idsb.pix,allind(1:*)) = 0
	     ENDIF
	     WIDGET_CONTROL, idsb.id_all, /sensitive
	     handle_value, idsb_handle, idsb, /SET
	     WIDGET_CONTROL, event.top, SET_UVALUE=idsb_handle
	     WIDGET_CONTROL, idsb.id_select, sensitive=0
	  END 

	  'RESET': BEGIN
	     all_disc_areas = -1
	     idsb.flag = idsb.flag * 0
	     handle_value, idsb_handle, idsb, /SET
	     WIDGET_CONTROL, idsb.id_select, /sensitive
	  END
	     
	  'CHPAR': BEGIN
		pia_ff_med_smooth_param, med_smooth_par, GROUP_LEADER=event.top
		idsb.fw = med_smooth_par.fw
		idsb.sw = med_smooth_par.sw
		handle_value, idsb_handle, idsb, /SET
		WIDGET_CONTROL, event.top, SET_UVALUE=idsb_handle
	  END
	  
;	  'FFMED': BEGIN
;	    WIDGET_CONTROL, event.top, /hourglass
;	    WIDGET_CONTROL, idsb.id_ffield, GET_VALUE=ffield
;	    IF ffield(0) THEN NO_FF=0 ELSE NO_FF=1
;	    FF_MED_SMOOTH, idsb.data, ff_bright, FLAG=idsb.flag, FF=ff, $
;	      MED_WIDTH=idsb.fw, SMOOTH_WIDTH=idsb.sw, error=error, NO_FF=NO_FF
;	    IF error THEN RETURN
;	    idsb.ff_mnbr = ff_bright
;	    idsb.ff = ff
;	    idsb.method = 0
;	    WIDGET_CONTROL, idsb.id_plotr, /sensitive
;	    WIDGET_CONTROL, idsb.id_accept, /sensitive	    
;	    handle_value, idsb_handle, idsb, /SET
;	    WIDGET_CONTROL, event.top, SET_UVALUE=idsb_handle
;	  END
	  
	  "FFBCK": BEGIN
	    WIDGET_CONTROL, event.top, /hourglass
	    FF_BCK, idsb.data, ff_bright, flag=idsb.flag, FF=ff, $
	      ERROR=error
;	    WIDGET_CONTROL, idsb.id_ffield, GET_VALUE=ffield
;	    IF ffield(0) THEN NO_FF=0 ELSE NO_FF=1
	    NO_FF = 0
	    IF error EQ 0 THEN BEGIN
	     IF NO_FF THEN idsb.ff_mnbr = idsb.data ELSE $
	     idsb.ff_mnbr = ff_bright
	     idsb.ff(0,*) = ff
	     idsb.ff(1,*) = ff * 0.
	     idsb.method = 1
	     WIDGET_CONTROL, idsb.id_plotr, /sensitive
	     WIDGET_CONTROL, idsb.id_accept, /sensitive	    
	     handle_value, idsb_handle, idsb, /SET
	     WIDGET_CONTROL, event.top, SET_UVALUE=idsb_handle
	    ENDIF
	    
	  END
	     
	  'PLOTO': BEGIN
	     WIDGET_CONTROL, event.top, /hourglass
	     WIDGET_CONTROL, idsb.id_pix, GET_VALUE=pix
	     pix = pix(0) - 1
	     xind = indgen(N_ELEMENTS(idsb.data(0,*)))
	     title= 'Data: pixel '+STRTRIM(pix+1,2)
	     PIA_XPLOT, xind, idsb.data(pix,*), idsb.unc(pix,*), $
	           title= title, group=event.top,$
		   xtitle='Index',ytitle='Brightness [MJy/sr]',$
		   psym=psymch, legend=title, modal=idsb.modal	    
	  
	  END   	  

	  'OPLOTO': BEGIN
	     WIDGET_CONTROL, idsb.id_pix, GET_VALUE=pix
	     pix = pix(0) - 1
	     xind = indgen(N_ELEMENTS(idsb.data(0,*)))
		
		IF zoom_color EQ -1 THEN zoom_color = green ELSE $
		  zoom_color = zoom_color + 1
		IF zoom_color EQ 9 then zoom_color = 4
		  zoom_psymch = zoom_psymch + 1
		IF zoom_psymch GE 8 then zoom_psymch = 1

	     PIA_XPLOT, xind, idsb.data(pix,*), idsb.unc(pix,*), $
	        legend= 'Data: pixel '+STRTRIM(pix+1,2),$
	     	PSYM=zoom_psymch, group=event.top, $
		color=zoom_color, overplot=1, modal=idsb.modal
	  END   	  

	  'PRINTR': BEGIN
	     IF idsb.METHOD EQ 0 THEN $
	     Text = ["The derived average flat field factors", $
	     	     "using the median filtered selected areas are:"] ELSE $
	     Text = ["The derived flat field factors using directly the", $
	     	     "quotients of the background selected areas are:"] 
	     pixtxt = "Pixel " + STRTRIM(indgen(N_ELEMENTS(idsb.ff(0,*)))+1,2)$
	     	+ ":     "
	     TEXT = [TEXT, "", $
	     	     pixtxt + $
	     STRTRIM(STRING(format="(F5.3)",reform(idsb.ff(0,*))),2) + ' +/- ' + $
	     STRTRIM(STRING(format="(F5.3)",reform(idsb.ff(1,*))),2)]

	     PIA_DISP_PRINT_FILE, '',text=text, modal=idsb.modal, group=event.top
	  END 

	  'PLOTR': BEGIN
	     WIDGET_CONTROL, idsb.id_pix, GET_VALUE=pix
	     pix = pix(0) - 1
	     xind = indgen(N_ELEMENTS(idsb.data(0,*)))
	     IF idsb.METHOD EQ 0 THEN $
	      title= 'Filtered data: pixel '+STRTRIM(pix+1,2) ELSE $
	      title= 'Flat fielded data: pixel '+STRTRIM(pix+1,2)
	     PIA_XPLOT, xind, idsb.ff_mnbr(pix,*), $
	           title= title, modal=idsb.modal, group=event.top,$
		   xtitle='Index',ytitle='Brightness [MJy/sr]',$
		   psym=psymch, legend=title	    
	  
	  END   	  

	  'OPLOTR': BEGIN
	     WIDGET_CONTROL, idsb.id_pix, GET_VALUE=pix
	     pix = pix(0) - 1
	     xind = indgen(N_ELEMENTS(idsb.data(0,*)))
		
		IF zoom_color EQ -1 THEN zoom_color = green ELSE $
		  zoom_color = zoom_color + 1
		IF zoom_color EQ 9 then zoom_color = 4
		  zoom_psymch = zoom_psymch + 1
		IF zoom_psymch GE 8 then zoom_psymch = 1

	     PIA_XPLOT, xind, idsb.ff_mnbr(pix,*), idsb.unc(pix,*), $
	        legend= 'Filtered data: pixel '+STRTRIM(pix+1,2),$
	     	PSYM=zoom_psymch, modal=idsb.modal, group=event.top,$
		color=zoom_color, overplot=1
	  END  
	  
	  'CANCEL': BEGIN
	  	idsb.ff_mnbr = idsb.data 
	        handle_value, idsb_handle, idsb, /SET
	  	WIDGET_CONTROL, event.top, /DESTROY
	  END
	  
	  'ACCEPT': WIDGET_CONTROL, event.top, /DESTROY
	  
	  ELSE:
	ENDCASE
	RETURN
	END
	 

PRO PIA_FF_backgr, mnbr, mnbu, ff_mnbr, flag=flag, group=group, modal=modal

;	IF Xregistered(PIA_FF_MED_SMOOTH) THEN RETURN
	IF not KEYWORD_SET(modal) THEN modal=0
		
	pixel = 0
	det_pix = N_ELEMENTS(mnbr(*,0)) 
	data = mnbr
	unc = mnbu
	IF not KEYWORD_SET(flag) THEN $
	   flag = FIX(data*0)
	fw = 24
	sw = 9

	IF not KEYWORD_SET(group) THEN group=!PIA_TOP_WID
	base = WIDGET_BASE($
	 TITLE = 'PIA flat-fielding by background choice', $
			/COLUMN, /modal, group=group )

	
	rbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(rbase, $
	  VALUE='Pixel to be used for selection & plotting:     ')
	id_pix = WIDGET_TEXT(rbase, VALUE=STRTRIM(pixel+1,2), UVALUE='JUNK', $
				XSIZE = 6, /EDITABLE)
	
	
	fbase = WIDGET_BASE(base, /COLUMN, /FRAME)
	label = WIDGET_LABEL(fbase, VAL="Graphical Selections")
	rbase = WIDGET_BASE(fbase, /ROW)
	id_select =  WIDGET_BUTTON(rbase,  $
	 VALUE=' Selection ', $
		UVAL="SEL")
	label = WIDGET_LABEL(rbase, VAL="        ")
	id_dselect =  WIDGET_BUTTON(rbase,  $
	 VALUE=' De-Selection ', $
		UVAL="DSEL")
	label = WIDGET_LABEL(rbase, VAL="        ")
	id_reset =  WIDGET_BUTTON(rbase,  $
	 VALUE=' Reset ', $
		UVAL="RESET")
	rbase = WIDGET_BASE(fbase, /ROW)
	label = WIDGET_LABEL(rbase, VALUE='Extend to all pixels: ')
	id_all = WIDGET_BUTTON(rbase, VALUE= ' Now ', UVALUE='ALLPIX')
	
	fbase = WIDGET_BASE(base, /COLUMN, /FRAME)
	label = WIDGET_LABEL(fbase, $
		VAL="Data processing: background FF ")
	rbase = WIDGET_BASE(fbase, /ROW)
;	id_chpar = WIDGET_BUTTON(rbase,    VALUE='Change params ', $
;	   UVALUE='CHPAR')
;	label = WIDGET_LABEL(rbase, VAL="for")
;	id_perform = WIDGET_BUTTON(rbase,  VALUE='Baseline correction', $
;		UVALUE='FFMED')
;	label = WIDGET_LABEL(rbase, VAL=" ------  ")
	id_perform = WIDGET_BUTTON(rbase,  VALUE='Flatfield on bckgr', $
		UVALUE='FFBCK')
;	id_ffield= cw_bgroup(fbase, /NONexclusive,$
;		SET_VALUE=1, UVAL='JUNK', $
;		['USE derived flatfield for correcting the data']) 


	fbase = WIDGET_BASE(base, /COLUMN, /FRAME)
	label = WIDGET_LABEL(fbase, VAL="Plotting")
	rbase = WIDGET_BASE(fbase, /ROW)
	id_ploto = WIDGET_BUTTON(rbase,  VALUE='Plot Original', /MENU)
	id_plnewo = WIDGET_BUTTON(id_ploto,VALUE='Plot ', UVALUE='PLOTO')
	id_oploto = WIDGET_BUTTON(id_ploto,VALUE='Overplot ', UVALUE='OPLOTO')
	label = WIDGET_LABEL(rbase, VAL="        ")
	id_plotr = WIDGET_BUTTON(rbase,  VALUE='Plot/Print Results', /MENU)
	id_plnewr = WIDGET_BUTTON(id_plotr,VALUE='Plot ', UVALUE='PLOTR')
	id_oplotr = WIDGET_BUTTON(id_plotr,VALUE='Overplot ', UVALUE='OPLOTR')
	id_printr = WIDGET_BUTTON(id_plotr,VALUE='Print derived Flatfields ', $
		UVALUE='PRINTR')


	fbase = WIDGET_BASE(base, /COLUMN, /FRAME)
	label = WIDGET_LABEL(fbase, VAL="Leaving")
	rbase = WIDGET_BASE(fbase, /ROW)
	id_cancel = WIDGET_BUTTON(rbase, VALUE='   Cancel    ', UVALUE='CANCEL')
	label = WIDGET_LABEL(rbase, VAL="        ")
	id_accept = WIDGET_BUTTON(rbase, VALUE='Accept & Quit', UVALUE='ACCEPT')

	WIDGET_CONTROL, id_plotr, sensitive=0
	WIDGET_CONTROL, id_accept, sensitive=0
	WIDGET_CONTROL, id_all, sensitive=0
	
	
	idsb = {data:data, unc:unc, id_pix:id_pix, flag:flag, fw:fw, sw:sw,  $
		ff_mnbr:data, pix:pixel, id_plotr:id_plotr, id_all:id_all, $
		id_accept:id_accept, ff:fltarr(2,det_pix), method:-1, $
		id_select:id_select, modal:modal} 
	 
	idsb_handle = handle_create()
	handle_value, idsb_handle, idsb, /SET, /NO_COPY 
	
	WIDGET_CONTROL, base, /realize, SET_UVALUE=idsb_handle
	
	xMANAGER,No_BLOCK=1, "pia_ff_backgr", base

	handle_value, idsb_handle, idsb 
	ff_mnbr = idsb.ff_mnbr
	
	RETURN
	END	
