;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_ff_med_smooth_param
;
; PURPOSE:
;	Simple widget I/F for defining the parameters for median filtering and
;	smoothing by mapping
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_ff_med_smooth_param, med_smooth_par
;
; INPUT:
;	None
;
; OUTPUT:
;	med_smooth_par:	Structure {fw:fw,sw:sw} containing the chosen parameters
;	
; COMMON BLOCKS:
;	none
;
; PROCEDURES USED:
;	none
;	
; MODIFICATION HISTORY:
;	Written by:	C.Gabriel (ESA/VILSPA-SAI)	September 1997
;	Version 6.5
;-

; ****************************************************************************
;  PIA_ff_med_smooth_param
; ****************************************************************************

PRO pia_ff_med_smooth_param, med_smooth_par, GROUP_LEADER=group_LEADER

	med_smooth_par = {fw:24,sw:9}
	IF not KEYWORD_SET(GROUP_LEADER) THEN group_leader=!PIA_TOP_WID
        junkbase = WIDGET_BASE(TITLE=$
          'Parameters for median filtering and smoothing ', $
            /COLUMN, XSIZE=350, /MODAL, GROUP_LEADER=group_leader)
        

	jun2base = WIDGET_BASE(junkbase, /COLUMN, /FRAME)

	jun3base = WIDGET_BASE(jun2base, /ROW)
	label = WIDGET_LABEL(jun3base, $
	  	VAL='Width of median filtering (15 < fw < 301):  ')
	fw_id = WIDGET_TEXT(jun3base, /EDITABLE, XSIZE=6, $
		VAL=STRTRIM(med_smooth_par.fw,2), UVAL='junk')
	label = WIDGET_LABEL(jun2base, $
		VAL='(fw=1 means NO median filtering)')
		
	jun2base = WIDGET_BASE(junkbase, /COLUMN, /FRAME)

	jun3base = WIDGET_BASE(jun2base, /ROW)
	label = WIDGET_LABEL(jun3base, $
		VAL='Width of smoothing window (1 < sw < 16):   ')
	sw_id = WIDGET_TEXT(jun3base, /EDITABLE, XSIZE=6,$
		VAL=STRTRIM(med_smooth_par.sw,2), UVAL='junk')
	label = WIDGET_LABEL(jun2base, $
		VAL='(sw=1 means NO smoothing)')
			

	jun2base = WIDGET_BASE(junkbase, /ROW)
	ok = WIDGET_BUTTON(jun2base, VALUE=' OK ', UVALUE='OK')
 	cancel = WIDGET_BUTTON(jun2base, VALUE=' Cancel ', UVALUE='CANCEL')

        WIDGET_CONTROL, junkbase, /REALIZE

WAITING:
	event = WIDGET_EVENT(junkbase)
	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	
	IF uvalue EQ 'OK' THEN BEGIN
	   fwwrong=0 & swwrong=0
	   WIDGET_CONTROL, fw_id, GET_VALUE=val
	   fw = FIX(val(0))
	   IF fw LT 16 OR fw GT 300 AND fw NE 1 THEN fwwrong = 1
	   WIDGET_CONTROL, sw_id, GET_VALUE=val
	   sw = FIX(val(0))
	   IF sw LT 1 OR sw GT 15 THEN swwrong = 1
	   
	   IF (fwwrong+swwrong) NE 0 THEN BEGIN
	     IF fwwrong THEN $
	       PRINT, STRING(7B) + 'Not accepted median filtering width' 
	     IF swwrong THEN $
	       PRINT, STRING(7B) + 'Not accepted smoothing window width' 
	   ENDIF ELSE BEGIN
	    IF sw mod 2 EQ 0 THEN BEGIN
	       sw = sw + 1
	       PRINT, STRING(7B) +  'Smoothing window changed to '+$
	       		STRTRIM(sw,2) + '. It must be odd' 
	    ENDIF	    
	    med_smooth_par = {fw:fw,sw:sw}
	    WIDGET_CONTROL, junkbase, /DESTROY
            RETURN
           ENDELSE
           
	ENDIF ELSE IF uvalue EQ 'CANCEL' THEN BEGIN
	   
	   PRINT, 'Default values for filtering and smoothing will be used'
	   WIDGET_CONTROL, junkbase, /DESTROY
           RETURN

        ENDIF ELSE BEGIN
          GOTO, WAITING
        ENDELSE
	
	GOTO, WAITING

END


