;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_FXTFIL
;
; PURPOSE:
;	Menu for PIA External IA Produced Data (FITS) selection and read-in.
;	This is a second level menu in the PIA hirarchy.
;
;	This routine should only be called by the PIA main program
;	and should not be called directly from the command line.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_FXTFIL, GROUP=group
;
; INPUTS:
;	none
;	
; OPTIONAL INPUTS:
;	
; KEYWORD PARAMETERS:
;	GROUP
;		The group leader of the widget hirarchy
;	
; OUTPUTS:
;	none
;	
; METHOD:
;	Widgets
;	
; PROCEDURES USED:
;	PIA Procedure(s):
;		pia_open_fxb
;		pia_read_fits
;		pia_view_txt
;	Astronomical Library:
;		fxbclose
;
; COMMON BLOCKS:
;	pia_fxtfil_cmn	for internal use
;	
; MODIFICATION HISTORY:
;	Written by Carlos GABRIEL (ESA/ESTEC)		February 1995
;	Oct 95 Version 3.5
;-

; ****************************************************************************
;  Event handling routine for PIA Fxtfil menu
; ****************************************************************************

PRO pia_fxtfil_event, event

	COMMON pia_fxtfil_cmn, ftyp, ftyp_filters, dtyp, fxtfil_wid

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.top, GET_UVALUE=stat
	HANDLE_VALUE, stat.id, stat_id
	HANDLE_VALUE, stat.val, stat_val
	WIDGET_CONTROL, event.top, /HOURGLASS

	CASE uvalue OF

; Quit DataReduction

	'QUIT':	BEGIN

		WIDGET_CONTROL, event.top, /DESTROY
	END

;  Select a file with 'pickfile'

	'SELF':	BEGIN
		filt = stat_val.dtyp + stat_val.filter
		file = pickfile( PATH=stat_val.defpath, FILTER=filt, $
			/READ, GROUP=event.top, GET_PATH=newpath )

		IF file NE "" THEN BEGIN
			WIDGET_CONTROL, stat_id.filename, SET_VALUE=file
			stat_val.defpath = newpath
			HANDLE_VALUE, stat.val, stat_val, /SET
		ENDIF
		GOTO, open_fxb
	END

        'OPEN': BEGIN
open_fxb:
                WIDGET_CONTROL, event.top, /HOURGLASS

                WIDGET_CONTROL, stat_id.filename, GET_VALUE=file
                stat_val.filename = STRTRIM(file(0),2)
                IF stat_val.filename EQ "" THEN BEGIN
                        MESSAGE, /INFO, "No file selected."
                        RETURN
                ENDIF

                pia_open_fxb, stat_val.filename, fxbunit, header, dims

                stat_val.fxbunit = fxbunit
                stat_val.dims = dims

                WIDGET_CONTROL, stat_id.ncol, $
                        SET_VALUE=STRING(dims(1),FORMAT='(I9)')
                WIDGET_CONTROL, stat_id.nrow, $
                        SET_VALUE=STRING(dims(2),FORMAT='(I9)')
                WIDGET_CONTROL, stat_id.nax1, $
                        SET_VALUE=STRING(dims(0),FORMAT='(I9)')
                WIDGET_CONTROL, stat_id.vhea, /SENSITIVE

                FXBCLOSE, stat_val.fxbunit

		HANDLE_VALUE, stat.val, stat_val, /SET
		HANDLE_VALUE, stat.header, header, /SET

         END

; Read file 

	'READFITS': BEGIN
read_fxb:
		WIDGET_CONTROL, event.top, /HOURGLASS

		; read new file and go to next level 
		WIDGET_CONTROL, stat_id.filename, GET_VALUE=file
		stat_val.filename = STRTRIM(file(0),2)
		IF stat_val.filename EQ "" THEN BEGIN
			MESSAGE, /INFO, "No file selected in read."
			RETURN
		ENDIF

		pia_read_fits, stat_val.filename, header

		WIDGET_CONTROL, stat_id.vhea, /SENSITIVE
		HANDLE_VALUE, stat.val, stat_val, /SET
		HANDLE_VALUE, stat.header, header, /SET

	END

; View header

	'VHEA':	BEGIN

		HANDLE_VALUE, stat.header, header, /NO_COPY
		IF N_ELEMENTS(header) EQ 0 THEN BEGIN
			MESSAGE, /INFO, 'No header defined.'
		ENDIF ELSE BEGIN
			pia_view_txt, header, TITLE='Header View', $
				NAME=stat_val.filename, GROUP=event.top
			HANDLE_VALUE, stat.header, header, /SET, /NO_COPY
		ENDELSE
	END


; Select file type

	'FTYP':	BEGIN
		stat_val.ftyp = ftyp(event.index)
		stat_val.filter = ftyp_filters(event.index)
		HANDLE_VALUE, stat.val, stat_val, /SET
	END

	'DTYP':	BEGIN
		stat_val.dtyp = dtyp(event.index)
		HANDLE_VALUE, stat.val, stat_val, /SET
	END

;  pressed <RETURN> in 'Filename' widget

	'FNAM':	BEGIN
		GOTO, open_fxb
	END

	'HELP': BEGIN
	   IF !VERSION.OS NE 'vms' THEN $
               spawn, '$w3net $PIA_HTML/um/data_sel_window.html &' ELSE $
               spawn, 'w3net /pia_dsk/pia/html/um/file_sel_window.html',/nowait
      	   END

	ELSE:	MESSAGE, /INFO, 'Function not yet implemented.'
	ENDCASE

	RETURN
END

; ****************************************************************************
;  PIA FileView - menu definition procedure
; ****************************************************************************

PRO pia_fxtfil, GROUP=group


; Definitions common to all instances

	COMMON pia_fxtfil_cmn, ftyp, ftyp_filters, dtyp, fxtfil_wid

; If already registered, pop-up and exit
	IF Xregistered("pia_fxtfil") NE 0 THEN BEGIN
		WIDGET_CONTROL, fxtfil_wid, SHOW=1
		RETURN
	END
		
; Definition of file types:
; file_types    -  Defines what appears in the list widget and can contain
;                  any strings. The largest string determines XSIZE of the
;                  list widget: 12 seems ok.
; ftyp          -  Used in event handling routine to avoid direct coding
;                  of indexes.
; ftyp_filters  -  Used in event handling routine as file filter.
; Take care that the arrays are consistent with each other.

	file_types   =  [	'ERD Files', $
				'SRD Files', $
				'SCP Files', $
				'SPD Files', $
				'AAR Files', $
				'Cal A Files ', $
				'All       ' $
			]
	ftyp         =	[	'ERD', $
				'SRD', $
				'SCP', $
				'SPD', $
				'SPD', $
				'AAR', $
				'CLA', $
				'ALL' $
			]

	 ftyp_filters =	[	'*_ERD.FITS', $
				'*_SRD.FITS', $
				'*_SCP.FITS', $
				'*_SPD.FITS', $
				'*_AAR.FITS', $
				'*_CLA.FITS', $
				'*.FITS' $
			]  

	det_types   =	[	'P1   ', $
				'P2   ', $
				'P3   ', $
				'C100 ', $
				'C200 ', $
				'SS/SL', $
				'All  ' $
                        ]
	dtyp   =	[	'P1', $
				'P2', $
				'P3', $
				'C1', $
				'C2', $
				'S*', $
				'*'  $
			]


; Definitions for individual instances

	stat = { $
		id:	HANDLE_CREATE(), $
		val:	HANDLE_CREATE(), $
		header:	HANDLE_CREATE() $
	}

	stat_id = { $
			clos:		0L, $
			vhea:		0L, $
			vtab:		0L, $
		 	filename:	0L, $
			nax1:		0L, $
			ncol:		0L, $
			nrow:		0L, $
                        col:            0L, $
                        cfr:            0L, $
                        cto:            0L, $
                        row:            0L, $
                        rfr:            0L, $
                        rto:            0L $
	}

	stat_val = { $
			defpath:	'', $
			filename:	'', $
			ftyp:		'', $
			dtyp:		'', $
			filter:		'', $
			fxbunit:	0L, $
			dims:		[ 0L, 0L, 0L ] $
	}


; Set-up widget hierarchy

    fxtfil_wid = WIDGET_BASE( TITLE="PIA Data Selection: IA-External", /COLUMN )

	id_0 = WIDGET_BASE( fxtfil_wid, /ROW )
	id_1 = WIDGET_BUTTON( id_0, VALUE='    File    ', /MENU )
	id_2 = WIDGET_BUTTON( id_1, VALUE='Select File...', UVALUE='SELF' )
	id_2 = WIDGET_BUTTON( id_1, VALUE='Read File...', UVALUE='READFITS' )
	id_2 = WIDGET_BUTTON( id_1, VALUE='Quit', UVALUE='QUIT' )

	id_1 = WIDGET_BUTTON( id_0, VALUE='    View    ', /MENU )
	id_2 = WIDGET_BUTTON( id_1, VALUE='View Header', UVALUE='VHEA' )
	stat_id.vhea = id_2

	id_1 = WIDGET_LABEL( id_0, VALUE='                        ' )
	id_1 = WIDGET_BUTTON( id_0, VALUE='    Help    ', UVALUE='HELP' )

	id_0 = WIDGET_BASE( fxtfil_wid, /ROW )
	id_1 = WIDGET_LABEL( id_0, VALUE='Selected File:' )
	id_1 = WIDGET_LABEL( id_0, VALUE=' ' )
	id_0 = WIDGET_TEXT( fxtfil_wid, /EDITABLE, XSIZE=40, YSIZE=1, $
			VALUE=' ', UVALUE='FNAM')
	stat_id.filename = id_0

	id_0 = WIDGET_BASE( fxtfil_wid, /ROW )

	id_1 = WIDGET_BASE( id_0, /COLUMN )
	id_2 = WIDGET_LABEL( id_1, VALUE='Select Filetype:' )
	id_2 = WIDGET_LIST( id_1, YSIZE=9, VALUE=file_types, UVALUE='FTYP' )

	id_1 = WIDGET_LABEL( id_0, VALUE='                        ' )

	id_1 = WIDGET_BASE( id_0, /COLUMN )
	id_2 = WIDGET_LABEL( id_1, VALUE='Select Detector:' )
	id_2 = WIDGET_LIST( id_1, YSIZE=9, VALUE=det_types, UVALUE='DTYP' )


        id_0 = WIDGET_BASE( fxtfil_wid, /ROW)

        id_1 = WIDGET_BASE( id_0, /COLUMN )
        id_2 = WIDGET_BASE( id_1, /ROW )
        id_3 = WIDGET_LABEL( id_2, VALUE='Dimensions:' )
        id_3 = WIDGET_LABEL( id_2, VALUE=' ' )

        id_3 = WIDGET_LABEL( id_2, VALUE='No. columns:    ' )
        id_3 = WIDGET_LABEL( id_2, VALUE=' ' )
        stat_id.ncol = id_3

        id_2 = WIDGET_BASE( id_1, /ROW )
        id_3 = WIDGET_LABEL( id_2, VALUE=' ' )
        id_3 = WIDGET_LABEL( id_2, VALUE='                    ' )

        id_3 = WIDGET_LABEL( id_2, VALUE='No. rows:        ' )
        id_3 = WIDGET_LABEL( id_2, VALUE=' ' )
        stat_id.nrow = id_3

        id_2 = WIDGET_BASE( id_1, /ROW )
        id_3 = WIDGET_LABEL( id_2, VALUE=' ' )
        id_3 = WIDGET_LABEL( id_2, VALUE='                    ' )

        id_3 = WIDGET_LABEL( id_2, VALUE='No. char/row:     ' )
        id_3 = WIDGET_LABEL( id_2, VALUE=' ' )
        stat_id.nax1 = id_3


; Define initial settings

	stat_val.defpath=!fitdir

	WIDGET_CONTROL, stat_id.vhea, SENSITIVE=0

;  Store values for individual instances with base widget

	HANDLE_VALUE, stat.id, stat_id, /SET, /NO_COPY
	HANDLE_VALUE, stat.val, stat_val, /SET, /NO_COPY
	WIDGET_CONTROL, fxtfil_wid, SET_UVALUE=stat, /NO_COPY


; Realize widget

	WIDGET_CONTROL, fxtfil_wid, /REALIZE, TLB_SET_YOFFSET=300

	xMANAGER,No_BLOCK=1, "pia_fxtfil", fxtfil_wid, GROUP=group

	RETURN
END
