;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_GBLDEF_INIT
;
; PURPOSE:
;	Initialize the common block PIACMN_GBLDEF variable 'gbldef'.
;	Definition of directories from environment variables:
;	PIA_CALG	cal-G files
;	PIA_DATA	ISO data files
;	PIA_WORK	working directory
;
; CATEGORY:
;	PIA - initialization
;
; CALLING SEQUENCE:
;	PIA_GBLDEF_INIT
;
; INPUTS:
;	(none)
;
; KEYWORD PARAMETERS:
;	(none)
;
; OUTPUTS:
;	(none)
;
; COMMON BLOCKS:
;	PIACMN_GBLDEF	The global default definitions
;
; MODIFICATION HISTORY:
;	Written by:	D. Skaley, MPIK/Heidelberg
;	Modified by:	C. Gabriel, ESA/VILSPA
;	Oct 95 Version 3.5
;-

	PRO PIA_GBLDEF_INIT

@piacmn_gbldef

	gbldef = { $
		calgdir: "", $		; cal-G files
		datadir: "", $		; ISO data files
		workdir: "", $		; working directory
		fitsext: ".FITS" $	; FITS file extension
	}

	gbldef.calgdir = GETENV("PIA_CALG")
	gbldef.datadir = GETENV("PIA_DATA")
	gbldef.workdir = GETENV("PIA_WORK")

	RETURN
	END
