;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_GENCHO
;
; PURPOSE:
;	Menu for general choices within an automatic PIA procedure.
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	PIA_gencho
;
; INPUTS:
;	none
;	
; KEYWORD PARAMETERS:
;	GROUP
;		The group leader of the widget hirarchy
;	
; OUTPUTS:
;	none
;	
; SIDE EFFECTS:
;	several variables are defined in two common blocks, which drive
;	the automatic measurements processing	
;	
; PROCEDURES USED:
;	INTERNAL: 
;		pia_gencho_event
;
; COMMON BLOCKS:
;	pia_gencho_cmn	for internal use
;	gencho_cmn	for returning several variables
;	
; MODIFICATION HISTORY:
;	Written by:	C.Gabriel (ESA/ESTEC)		January 1995
;	Modified(last):	CG				September 1995
;	Oct 95 Version 3.5
;	Including ramps deglitching (CG)		December 1995
;	Including drifts recognition (CG)		December 1995
;	Initializing erdsel ... correctly (CG)		May 1996
;	Initializing all corrections to 1 (CG)		July 1996
;	Update including vignetting + reset interval corrections, 
;	 ramps subdivision, background subtraction (CG)	May 1997
;	V6.3
;	Modal defined as prescribed by IDL >= 5.0 (CG)	January 1999
;	V7.3
;	Pattern analysis included for internal version (CG)  March 1999
;	 + also for external version (CG)		     June 1999
;	V7.4
;	Dynamic calibration included for PHT-S chopped meas.(CG) September 1999
;	V8.0.1
;	Save AAP into FITS option added (CG)		May 2000
;	V9.0
;	Follow defaults button added, making possible 
;	several future adds (only P32 subdiv for now) (CG)	May 2002
;	V10.0
;-

; ****************************************************************************
;  Event handling routine for PIA general choices menu
; ****************************************************************************

PRO pia_gencho_event, event


@gen_choices


	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.top, GET_UVALUE=allv_s
	handle_value, allv_s, allv

	CASE uvalue OF

          'ACCEPT': BEGIN
		gen_fits.FITS = allv.fitsel
		gen_fits.delete = allv.fitdel
		gen_respalt = allv.respalt

		gen_select.erdsel = allv.erdsel
		gen_select.srdsel = allv.srdsel
		gen_select.scpsel = allv.scpsel
		
		
		gen_correct.erd_selcor = allv.erd_selcor
		gen_correct.srd_selcor = allv.srd_selcor
		gen_correct.scp_selcor = allv.scp_selcor

		gen_process.drft = allv.drft
		gen_process.splitrp = allv.splitrp
		gen_process.pattern = allv.pattern
		gen_process.dynresp = allv.dynresp
		gen_process.follow_def = allv.follow_def
		gen_process.slchop = allv.slchop
		
		gen_save.savsrd = allv.savsrd
		gen_save.savscp = allv.savscp
		gen_save.savspd = allv.savspd
		gen_save.savaap = allv.savaap
		gen_save.savsrdf = allv.savsrdf
		gen_save.savscpf = allv.savscpf
		gen_save.savspdf = allv.savspdf
		gen_save.savaapf = allv.savaapf
		
                gen_stop = 0

                WIDGET_CONTROL, event.top, /DESTROY
                goto, OUT
          END

          'CANCEL': BEGIN

                gen_stop = 1
                WIDGET_CONTROL, event.top, /DESTROY
                goto, OUT

          END

	  'FITSEL': BEGIN 	
		CASE event.value of
			0: allv.fitsel = 0
			1: allv.fitsel = 1
		ENDCASE
	  END

	  'FITDEL': BEGIN 	
		CASE event.value of
			0: allv.fitdel = 0
			1: allv.fitdel = 1
		ENDCASE
	  END

	  'USERW': BEGIN 	
		CASE event.value of
			0: allv.respalt.single = 0
			1: allv.respalt.single = 1
			2: allv.respalt.single = 2
			3: allv.respalt.single = 3
			4: allv.respalt.single = 4
		ENDCASE
	  END

	  'RESPD': BEGIN 	
		CASE event.value of
			0: allv.respalt.double = 0
			1: allv.respalt.double = 1
			2: allv.respalt.double = 2
		ENDCASE
	  END

	  'SELECS': BEGIN
        	CASE event.value of
		
	        	0: allv.erdsel = event.select
			
                        1: allv.srdsel = event.select
		
                        2: allv.scpsel = event.select
		
		ENDCASE
	  END

	  'SELCOR': BEGIN
        	CASE event.value of
		
	        	0: allv.erd_selcor = event.select
			
                        1: allv.srd_selcor = event.select
		
                        2: allv.scp_selcor = event.select
		
		ENDCASE
	  END


	  'PROCS': BEGIN
        	CASE event.value of
		
	        	0: allv.splitrp = event.select
			
                        1: allv.drft = event.select
		
                        2: allv.slchop = event.select
		
		ENDCASE
	  END

	  'PROCS2': BEGIN
        	CASE event.value of
		
                        0: allv.pattern = event.select

                        1: allv.dynresp = event.select
		
                        2: allv.follow_def = event.select
		
		ENDCASE
	  END


	  'SAVEFIL': BEGIN
        	CASE event.value of
		
	        	0: allv.savsrd = event.select
			
                        1: allv.savscp = event.select
		
	        	2: allv.savspd = event.select
			
                        3: allv.savaap = event.select
		
		ENDCASE
	  END

	  'SAVEFITS': BEGIN
        	CASE event.value of
		
	        	0: allv.savsrdf = event.select
			
                        1: allv.savscpf = event.select
		
	        	2: allv.savspdf = event.select
			
                        3: allv.savaapf = event.select
		
		ENDCASE
	  END
	  
          'DTYP': BEGIN
                
		CASE event.value of
			0: STRPUT, gen_filt, 'P', 1
			1: STRPUT, gen_filt, '1', 1
			2: STRPUT, gen_filt, '2', 1
			3: STRPUT, gen_filt, 'S', 1
			4: IF !VERSION.OS NE 'vms' THEN $
        			gen_filt = 'P?E*.FITS' ELSE $
        			gen_filt = 'P%E*.FITS' 

							
		ENDCASE

	  END

	  ELSE:

       	ENDCASE
       	
       	handle_value, allv_s, allv, /SET
       	
out:
	RETURN
END

; ****************************************************************************
;  PIA GENCHO - menu definition procedure
; ****************************************************************************

PRO pia_gencho, DET=det, GROUP=group

; Definitions common to all instances
@gen_choices


        det_types   =   [       'P1,P2,P3 ', $
                                'C100     ', $
                                'C200     ', $
                                'SS/SL    ', $
                                'All      ' $
                        ]
        dtyp   =        [       'P*', $
                                'C1', $
                                'C2', $
                                'S*', $
                                'AL'  $
                        ]

	IF !VERSION.OS NE 'vms' THEN $
        	gen_filt = 'P?E*.FITS' ELSE $
        	gen_filt = 'P%E*.FITS' 

	IF N_ELEMENTS(gen_respalt) EQ 0 THEN gen_choices_init

	no_fits = 0
	IF gen_fits.FITS GT 1 THEN BEGIN
	 no_fits = 1
	 gen_fits.FITS = 1
	ENDIF
		
	fitsel=gen_fits.FITS 
	fitdel=gen_fits.delete

	respalt = gen_respalt

	erdsel = gen_select.erdsel 
	srdsel = gen_select.srdsel 
	scpsel = gen_select.scpsel

	erd_selcor = gen_correct.erd_selcor
	srd_selcor = gen_correct.srd_selcor
	scp_selcor = gen_correct.scp_selcor
	  
	savsrd=gen_save.savsrd  
	savscp=gen_save.savscp 
	savspd=gen_save.savspd 
	savaap=gen_save.savaap
	savsrdf=gen_save.savsrdf  
	savscpf=gen_save.savscpf 
	savspdf=gen_save.savspdf 
	savaapf=gen_save.savaapf
	
	splitrp = gen_process.splitrp
	drft = gen_process.drft
	pattern = gen_process.pattern
	dynresp = gen_process.dynresp
	follow_def = gen_process.follow_def
	slchop = gen_process.slchop
	
	IF not KEYWORD_SET(group) THEN group = !pia_top_wid

	gchbase = WIDGET_BASE(TITLE = 'PIA processing sequences selection menu', $ 
		 		/COLUMN, /modal, group=group)

	IF N_ELEMENTS(fitsel) EQ 0 THEN fitsel = 0
	stdbut = cw_bgroup(gchbase, LABEL_TOP = 'Input to be used', $
			/EXCLUSIVE, /FRAME, COLUMN=2, $
			SET_VALUE = fitsel, $
			UVALUE = 'FITSEL', $
			["ERD FITS files", $
			 "Measurements in buffer" ])
	IF no_fits THEN WIDGET_CONTROL, stdbut, sensitive=0

	junkbase = WIDGET_BASE(gchbase, /ROW)
	button = CW_BSELECTOR(junkbase, [" Keep ","Delete"], $
			UVALUE = 'FITDEL')
	WIDGET_CONTROL, button, set_VALUE= FITDEL
	junklabel = WIDGET_LABEL(junkbase, $
		VALUE=" ERD buffers after processing")

	stdbut = cw_bgroup(gchbase, LABEL_TOP = 'Data selections desired for:', $
			/NONEXCLUSIVE, /FRAME, COLUMN=3, $
			SET_VALUE = [erdsel,srdsel,scpsel], $
			UVALUE = 'SELECS', $
			["ERD", "SRD", "SCP" ])

	stdbut = cw_bgroup(gchbase, LABEL_TOP = 'Correction selections desired for:', $
			/NONEXCLUSIVE, /FRAME, COLUMN=3, $
			SET_VALUE = [erd_selcor,srd_selcor,scp_selcor], $
			UVALUE = 'SELCOR', $
			["ERD", "SRD", "SCP" ])

	junklabel = WIDGET_LABEL(gchbase, $
		VALUE="Processing")
	gchbase2 = WIDGET_BASE(gchbase, /ROW, /FRAME)
	stdbut = cw_bgroup(gchbase2,   $ 
			/NONEXCLUSIVE,  ROW=3, $
			SET_VALUE = [splitrp, drft, slchop], $
			UVALUE = 'PROCS', $
			["Ramps subdivision    (ERD)", $
			 "Drifts recognition   (SRD)", $
			 "PHT-S chopped calib. (SCP)"])
			 
	stdbut = cw_bgroup(gchbase2,  $ 
			/NONEXCLUSIVE, ROW=3, $
			SET_VALUE = [pattern, dynresp, follow_def], $
			UVALUE = 'PROCS2', $
			["Pattern analysis       (ERD)", $
			 "PHT-S Dynamic Response (SRD)", $
			 "By Default P32 RO-pair (ERD)"])

	junkbase = WIDGET_BASE(gchbase, /ROW)
	junklabel = WIDGET_LABEL(junkbase, $
		VALUE="                            Saving ")
	savbase = WIDGET_BASE(gchbase, /ROW, /FRAME)
	stdbut = cw_bgroup(savbase, $
			LABEL_TOP = '    into PIA internal files', $
			/NONEXCLUSIVE, /FRAME, COLUMN=4, $
			SET_VALUE = [savsrd,savscp,savspd,savaap], $
			UVALUE = 'SAVEFIL', $
			["SRD", "SCP", "SPD", "AAP"])

	stdbut = cw_bgroup(savbase, $
			LABEL_TOP = '    into PIA FITS files', $
			/NONEXCLUSIVE, /FRAME, COLUMN=4, $
			SET_VALUE = [savsrdf,savscpf,savspdf, savaapf], $
			UVALUE = 'SAVEFITS', $
			["SRD", "SCP", "SPD", "AAP"])

	stdbut = cw_bgroup(gchbase, LABEL_TOP = 'Responsivity use', $
			/EXCLUSIVE, /FRAME,  COLUMN=3, $
			SET_VALUE = respalt.single, $
			UVALUE = 'USERW', $
			["Show alternatives ",        $
			 "Default response  ",        $
			 "Always FCS1       ",        $
			 "Always FCS2       ",        $
			 "Always <FCS1,FCS2>" ])
			 
	stdbut = cw_bgroup(gchbase, $
			LABEL_TOP = 'If two calibration measurements', $
			/EXCLUSIVE, /FRAME,  COLUMN=3, $
			SET_VALUE = respalt.double, $
			UVALUE = 'RESPD', $
			["Interpolate    ", $
			 "Use average    ", $
			 "Use second meas"])
			 
	IF KEYWORD_SET(det) THEN BEGIN 
         id_1 = WIDGET_BASE( gchbase, /COLUMN )
         id_2 = WIDGET_LABEL( id_1, VALUE='Selected Detector:' )

	 inddet = WHERE(STRMID(dtyp,0,2) EQ det, n)
	 IF n EQ 0 THEN inddet = WHERE(STRMID(dtyp,0,1) EQ STRMID(det,0,1))

	 chdtyp = dtyp(inddet(0))
         CASE chdtyp OF
                        'P*': STRPUT, gen_filt, 'P', 1 
                        'C1': STRPUT, gen_filt, '1', 1 
                        'C2': STRPUT, gen_filt, '2', 1  
                        'S*': STRPUT, gen_filt, 'S', 1 
	 ENDCASE
         id_2 = WIDGET_LIST( id_1, YSIZE=1, VALUE=det_types(inddet), UVALUE='' )
        ENDIF ELSE BEGIN
;         id_1 = WIDGET_BASE( gchbase, /COLUMN )
;         id_2 = WIDGET_LABEL( id_1, VALUE='Select Detector:' )
;         id_2 = WIDGET_LIST( id_1, YSIZE=6, VALUE=det_types, UVALUE='DTYP' )
	 stdbut = cw_bgroup(gchbase, LABEL_TOP = 'Select Detector:', $
			/EXCLUSIVE, /FRAME, COLUMN=5, $
			SET_VALUE = 4, $
			UVALUE = 'DTYP', $
			[det_types])
        ENDELSE

        control = WIDGET_BASE(gchbase,/ROW)

        junk = WIDGET_LABEL(control, VALUE = '         ')
        accept = WIDGET_BUTTON(control, VALUE = '  OK  ', $
                        /FRAME, UVALUE = 'ACCEPT')
        junk = WIDGET_LABEL(control, VALUE = '                    ')
        cancel = WIDGET_BUTTON(control, VALUE = '  Cancel  ', $
                        /FRAME, UVALUE = 'CANCEL')
        junk = WIDGET_LABEL(control, VALUE = '         ')

        WIDGET_CONTROL, gchbase, /REALIZE, TLB_SET_XOFFSET=450


	allv = {erdsel:erdsel, srdsel:srdsel, scpsel:scpsel, $
	   erd_selcor:erd_selcor, srd_selcor:srd_selcor, scp_selcor:scp_selcor, $
	   savsrd:savsrd, savscp:savscp, savspd:savspd, savaap:savaap, $
	   fitsel:fitsel, respalt:respalt, drft:drft, splitrp:splitrp, $
	   pattern:pattern, dynresp:dynresp, follow_def:follow_def, $
	   fitdel:fitdel, savsrdf:savsrdf, savscpf:savscpf, slchop:slchop, $
		savspdf:savspdf, savaapf:savaapf}

	allv_s = HANDLE_CREATE()
	handle_value, allv_s, allv, /SET
	WIDGET_CONTROL, gchbase, SET_UVALUE=allv_s		
	
        xMANAGER,No_BLOCK=1, "pia_gencho", gchbase, GROUP=group
	
        RETURN
END

