;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_genpro_top
;
; PURPOSE:
;	Ask the interactive user for general decisions for sequence processing 
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_genpro_top, genpro_top
;	
; OUTPUT:
;	genpro_top:
;		The structure chosen by the user: {gbegin: ,gend: ,auto_reco: }
;	
; COMMON BLOCKS:
;	(none)
;
; PROCEDURES USED:
;	none
;	
; MODIFICATION HISTORY:
;	Written by:	C.Gabriel (ESA/VILSPA-SAI)	June 1997
;	V6.4
;-

; ****************************************************************************
;  PIA_genpro_top - menu definition procedure
; ****************************************************************************

PRO pia_genpro_top, genpro_top, abs_phot=abs_phot


	genpro_top = {gbegin:0, gend:2, auto_reco:1, info:0}


        junkbase = WIDGET_BASE(TITLE=$
          'Top decision  ', XSIZE=200, $
            /COLUMN)


        start_id = cw_bgroup(junkbase, LABEL_TOP = 'Start level', $
                        /EXCLUSIVE, /FRAME, $
                        SET_VALUE = genpro_top.gbegin, $
                        UVALUE = 'START', $
                        ['ERD', 'SRD', 'SCP'])

        end_id = cw_bgroup(junkbase, LABEL_TOP = 'End level', $
                        /EXCLUSIVE, /FRAME, $
                        SET_VALUE = genpro_top.gend, $
                        UVALUE = 'END', $
                        ['SRD', 'SCP', 'AAP'])
	IF KEYWORD_SET(abs_phot) THEN WIDGET_CONTROL, end_id, sensitive=0
	
	auto_rec = CW_BSELECTOR(junkbase, $
			LABEL_LEFT="Recognize AOT mode:", $
			[" No  "," Yes "], $
                        UVALUE = 'RECO')
        WIDGET_CONTROL, auto_rec, set_VALUE= genpro_top.auto_reco
	IF KEYWORD_SET(abs_phot) THEN WIDGET_CONTROL, auto_rec, sensitive=0
 
	info = CW_BSELECTOR(junkbase, $
			LABEL_LEFT="Give summary table:", $
			[" No  "," Yes "], $
                        UVALUE = 'INFO')
        WIDGET_CONTROL, info, set_VALUE= genpro_top.info

	jun2base = WIDGET_BASE(junkbase, /ROW)
	ok = WIDGET_BUTTON(jun2base, VALUE=' OK ', UVALUE='OK')
; 	cancel = WIDGET_BUTTON(jun2base, VALUE=' Cancel ', UVALUE='CANCEL')
       WIDGET_CONTROL, junkbase, /REALIZE

WAITING:
	out = 0
	WHILE out EQ 0 DO BEGIN
	 event = WIDGET_EVENT(junkbase)
	 WIDGET_CONTROL, event.id, GET_UVALUE=uvalue


	IF uvalue EQ 'OK' THEN BEGIN
	   WIDGET_CONTROL, start_id, GET_VALUE=value
	   genpro_top.gbegin = value(0)
	   WIDGET_CONTROL, end_id, GET_VALUE=value
	   genpro_top.gend = value(0)
	   WIDGET_CONTROL, auto_rec, GET_VALUE=value
	   genpro_top.auto_reco = value(0)
	   WIDGET_CONTROL, info, GET_VALUE=value
	   genpro_top.info = value(0)
	   out = 1
	ENDIF 
	ENDWHILE

	WIDGET_CONTROL, junkbase, /DESTROY
	RETURN
END

