;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_GET_RPID
;
; PURPOSE:
;	Simple Menu for choosing a RPID from a list
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_get_rpid, rpids, rpid_chosen
;
; INPUT:
;	RPIDS
;		[points per raster line, raster lines]  (INTARR(2))
;
; OUTPUT:
;	RPID_CHOSEN
;		The chosen RPID (BYTARR(2))
;
;	
; METHOD:
;	Widgets
;	
; COMMON BLOCKS:
;	none	
;
; MODIFICATION HISTORY:
;	Written by:	C.Gabriel (ESA/ESTEC)		January 1996
;-

; ****************************************************************************
;  PIA_get_rpid - menu definition procedure
; ****************************************************************************

PRO pia_get_rpid, rpids, rpid_chosen


        base = WIDGET_BASE(TITLE = 'RPID choice', /column, xsize=400)


        label = WIDGET_LABEL(base, VALUE='Choose the RPIDs to be used')
	label = WIDGET_LABEL(base, VALUE='   ')
	pbase = WIDGET_BASE(base, /row)
	label = WIDGET_LABEL(pbase, VALUE='From '+STRTRIM(STRING(rpids(0)),2)+$
					' points per raster ')
	points_id = WIDGET_TEXT(pbase, /editable, VALUE='', UVALUE='JUNK')

	label = WIDGET_LABEL(base, VALUE='   ')

	rbase = WIDGET_BASE(base, /row)
	label = WIDGET_LABEL(rbase, VALUE='and '+STRTRIM(STRING(rpids(1)),2)+$
					' raster lines      ')
	raster_id = WIDGET_TEXT(rbase, /editable, VALUE='', UVALUE='JUNK')
	
	label = WIDGET_LABEL(base, VALUE='   ')
	label = WIDGET_LABEL(base, $
	 VALUE='(Several RPIDs choice: separated by ",", use "*" for all,')
	label = WIDGET_LABEL(base, $
	 VALUE=' all combinations between chosen points and lines will be taken)')
	label = WIDGET_LABEL(base, VALUE='   ')

	ok_id = WIDGET_BUTTON(base, VALUE=' OK ', UVALUE='OK')
	
	WIDGET_CONTROL, base, /REALIZE

	ok = 0
	
	WHILE ok EQ 0 DO BEGIN
	  event = WIDGET_EVENT(BASE)
	  WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	  IF uvalue EQ 'OK' THEN BEGIN
	    WIDGET_CONTROL, points_id, GET_VALUE=point
	    point=point(0)
	    WIDGET_CONTROL, raster_id, GET_VALUE=line
	    line=line(0)
	    ok = 1
	  ENDIF
	ENDWHILE

	
	IF STRTRIM(point(0),2) EQ '*' THEN point=INDGEN(rpids(0))+1 ELSE BEGIN
	ppp = FIX(point)
	out = 0
	newpoint = point
	WHILE out EQ 0 DO BEGIN
	 a=STRPOS(newpoint,',')
	 a = a(0)
	 IF a EQ -1 THEN out=1 $
	 ELSE BEGIN
	   newpoint = STRMID(newpoint, a+1, STRLEN(newpoint)-a)
	   ppp = [ppp,FIX(newpoint)]
	 ENDELSE
	ENDWHILE
	point = ppp
	ENDELSE

	IF STRTRIM(line(0),2) EQ '*' THEN line=INDGEN(rpids(1))+1 ELSE BEGIN
	ppp = FIX(line)
	out = 0
	newline = line
	WHILE out EQ 0 DO BEGIN
	 a=STRPOS(newline,',')
	 a= a(0)
	 IF a EQ -1 THEN out=1 $
	 ELSE BEGIN
	   newline = STRMID(newline, a+1, STRLEN(newline)-a)
	   ppp = [ppp,FIX(newline)]
	 ENDELSE
	ENDWHILE
	line = ppp
	ENDELSE
	
	 

	npoints = N_ELEMENTS(point)
	nlines = N_ELEMENTS(line)
	
	nele = max([npoints, nlines])
	IF npoints LT nlines THEN BEGIN
	   pointnew = line*0
	   pointnew(0:npoints-1) = point
	   pointnew(npoints:*) = point(0)
	   point=pointnew
	ENDIF
	IF npoints GT nlines THEN BEGIN
	   linenew = point*0
	   linenew(0:nlines-1) = line
	   linenew(nlines:*) = line(0)
	   line=linenew
	ENDIF

	rpid_chosen = intarr(2,nele)
	
	rpid_chosen(0,*) = point
	rpid_chosen(1,*) = line
	
	WIDGET_CONTROL, base, /DESTROY

        RETURN
END

