;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_GET_SREGION
;
; PURPOSE:
;	Menu for choosing either a PHT-S pixel or a wavelength region
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_GET_SREGION, phts, sr_STR 
;
; INPUT:
;	phts:	'SS' or 'SL' for PHT-SS or PHT-SL respectively
;
; OUTPUT:
;	SR_STR:	a structure containing chosen parameters 
;
;	
; METHOD:
;	Widgets
;	
; COMMON BLOCKS:
;	none	
;
; MODIFICATION HISTORY:
;	Written by:	C.Gabriel (ESA/VILSPA)		November 1997
;	V6.6
;-


PRO pia_get_sregion, phts, sr_str
@phtslwavlen


        base = WIDGET_BASE(TITLE = 'PHT-S region choice', /column, xsize=300)

	IF phts EQ 'SS' THEN 	wavel = slwavelen(0:63) ELSE $
				wavel = slwavelen(64:127)
	oplot = 0
	model = cw_bgroup(base, LABEL_TOP = 'Region choices', $
                        /EXCLUSIVE, /FRAME, $
                        SET_VALUE = 0, $
                        UVALUE = 'MODEL', $
                        ["Unique Pixel ", "Wavelength region "])
                        
	bbbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(bbbase, VALUE='Pixel nr:    ')
	bbtxt = WIDGET_TEXT(bbbase, /editable, XSIZE=8, VALUE= '',$
		UVALUE='BB')
	bbtxt2= WIDGET_TEXT(bbbase, XSIZE=15, VALUE= ' ?  microns',$
		UVALUE='JUNK')

	plbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(plbase, VALUE='Wavelength region: ')
	pltxt = WIDGET_TEXT(plbase, /editable, XSIZE=8, VALUE= '', $
		UVALUE='JUNK')
	pltxt2 = WIDGET_TEXT(plbase, /editable, XSIZE=8, VALUE= '', $
		UVALUE='JUNK')
	WIDGET_CONTROL, plbase, SENSITIVE=0

                        
        rowbase = WIDGET_BASE(base, /ROW)

	ok_id = WIDGET_BUTTON(rowbase,   VALUE='     OK      ', $
	    UVALUE='OK',XSIZE=100)
	canc_id = WIDGET_BUTTON(rowbase, VALUE='   Cancel    ', $
	    UVALUE='CANCEL', XSIZE=100)
	
	WIDGET_CONTROL, base, /REALIZE

	ok = 0
	
	WHILE ok EQ 0 DO BEGIN
	  event = WIDGET_EVENT(BASE)
	  WIDGET_CONTROL, event.id, GET_UVALUE=Uvalue
	  
	  CASE 1 OF 
	    uvalue EQ 'OK': BEGIN
	  	WIDGET_CONTROL, model, GET_VALUE=value
	   	  corr = 1
		  CASE value(0) OF
	   	  0: BEGIN
	   	     typ = 'pixel'
	   	     WIDGET_CONTROL, bbtxt, GET_VALUE=pixel
	   	
		     IF pixel(0) NE '' THEN BEGIN
	   	       pixel = FIX(pixel(0))-1 
		       IF pixel LE 63 THEN $
		         value = wavel(pixel(0)) ELSE GOTO, OUT_OF
		     ENDIF ELSE GOTO, OUT_OF
	             END
	           1:BEGIN
	   	     typ = 'region'
	   	     value = FLTARR(2)
	   	     WIDGET_CONTROL, pltxt, GET_VALUE=rmin
	   	     value(0) = rmin(0)
	   	     WIDGET_CONTROL, pltxt2, GET_VALUE=rmax
	   	     value(1) = rmax(0)
	             IF STRTRIM(value(0),2) EQ '' OR STRTRIM(value(1),2) EQ '' $
	                THEN BEGIN
	   	        PRINT, STRING(7b) + 'Give Value(s)'
	   	        GOTO, OUT_OF
	   	     ENDIF
	   	     tol = avg(wavel(1:*)-wavel(0:N_ELEMENTS(wavel)-2))/2.
	   	     wavel_min = wavel - tol
	   	     wavel_max = wavel + tol
	   	     pix_min = WHERE(wavel_max GT rmin(0), count)
	   	     IF count EQ 0 THEN BEGIN
	   	        PRINT, STRING(7b) + 'Wrong Value(s)'
	   	        GOTO, OUT_OF
	   	     ENDIF ELSE pix_min=pix_min(0)
	   	     
	   	     pix_max = WHERE(wavel_min LT rmax(0), count)
	   	     IF count EQ 0 THEN BEGIN
	   	        PRINT, STRING(7b) + 'Wrong Value(s)'
	   	        GOTO, OUT_OF
	   	     ENDIF ELSE pix_max=max(pix_max)
	   	     
	   	     IF pix_max LT pix_min THEN BEGIN
	   	        PRINT, STRING(7b) + 'Wrong Value(s)'
	   	        GOTO, OUT_OF
	   	     ENDIF
	   	     
	   	     pixel = indgen(pix_max-pix_min+1) + pix_min
	   	     value = AVG(wavel(pix_min:pix_max)) 
	             END
		    ENDCASE
	        IF STRTRIM(value(0),2) EQ '' THEN $
	          PRINT, STRING(7b) + 'Give Value(s)'$
	        ELSE BEGIN 
 	   	 sr_str={corr:corr, typ:typ, pixel:pixel, cvalue:float(value)}
	    	 ok = 1
	    	 stop=0
	    	ENDELSE
	     END
	     
	    uvalue EQ 'CANCEL': BEGIN 
	     	stop=1
	     	ok = 1
	     	sr_str={corr:0, typ:'', pixel:-1, cvalue:0.}
	     END
	    
	    uvalue EQ 'MODEL': BEGIN 
	  	WIDGET_CONTROL, model, GET_VALUE=value
		IF value(0) NE 1 THEN BEGIN
		  WIDGET_CONTROL,bbbase, /sensitive
		  WIDGET_CONTROL,plbase, sensitive=0
		ENDIF ELSE BEGIN
		  WIDGET_CONTROL,plbase, /sensitive
		  WIDGET_CONTROL,bbbase, sensitive=0
		ENDELSE
	     END
	    uvalue EQ 'BB': BEGIN 
	   	WIDGET_CONTROL, bbtxt, GET_VALUE=pixel
	   	pixel = pixel(0) - 1
	   	IF pixel LT 0 or pixel GT 63 THEN BEGIN
	   	   PRINT, STRING(7b) + 'Wrong pixel number'
	   	   GOTO, OUT_OF
	   	ENDIF
		txt = STRING(wavel(pixel(0)), FORMAT="(F5.2)") + ' microns'
		WIDGET_CONTROL, bbtxt2, SET_VALUE=txt
	    END
	    ELSE: 
	  ENDCASE
OUT_OF:	        
	ENDWHILE
	WIDGET_CONTROL, base, /DESTROY

        RETURN
END

