;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_GET_STRAYL
;
; PURPOSE:
;	Graphical I/F to calculate straylight on the FCS expected from a certain
;	source measurement (including the possibility of changing the sl level)
;
; CATEGORY:
;       PIA - graphics-processing
;
; CALLING SEQUENCE:
;       PIA_GET_STRAYL, ident
;
; INPUT:
;	ident: 	Name (PIA nomenclature) to start with. 
;
; COMMON BLOCKS:
;	pia_get_strayl_res (returning results)
;	pia_get_strayl_cmn (internally used)
;
; PROCEDURES USED:
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel (ESA/VILSPA-SAI)			April 1996
;			
;-

;;;;;;;;;;;;;;;;;;;
;
; The event routine
;
;;;;;;;;;;;;;;;;;;;
PRO pia_get_strayl_event, event

@phtscp
COMMON pia_get_stryl_cmn, meas_wd, strl_wd,ustrl_wd,val_wd,uval_wd,meas_pos		
COMMON pia_get_strayl_res, strayl, strayl_unc

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue of
	
	  'LIST': BEGIN
		ind = meas_pos(event.index)
		decode_admn, phtscp(ind).admn, meas
		WIDGET_CONTROL, meas_wd, SET_VALUE=meas
		handle_value, phtscp(ind).aver, aver
		handle_value, phtscp(ind).avun, avun
		handle_value, phtscp(ind).step, step
		handle_value, phtscp(ind).chop, chop
		npix = N_ELEMENTS(aver(*,0))
		nstep = max(step)
; Discriminate between triangular - sawtooth (straylight from source)
; and rectangular (straylight from somewhere)
		IF nstep LE 2 THEN BEGIN
			weight_mean, aver, avun, avaver, avavun
		ENDIF ELSE BEGIN
			avchop = median(chop)
			ind = WHERE(chop EQ avchop)
			ss = size(aver)
			IF ss(0) EQ 2 THEN $
			  weight_mean, aver(*,ind), avun(*,ind), $
			      avaver, avavun  ELSE $
			  weight_mean, aver(ind), avun(ind), avaver, avavun
		ENDELSE
		WIDGET_CONTROL, strl_wd, GET_VALUE=strl_level
		WIDGET_CONTROL, ustrl_wd, GET_VALUE=strl_unc
		strl_level = FLOAT(strl_level(0))
		strl_unc = FLOAT(strl_unc(0))

		strayl = avaver * strl_level
		strayl_unc = strayl * SQRT( (avavun/avaver)^2 + $
				   (strl_unc/strl_level)^2 )
				   
		WIDGET_CONTROL, val_wd, SET_VALUE=STRTRIM(STRING(strayl),2)
		WIDGET_CONTROL, uval_wd, $
			SET_VALUE=STRTRIM(STRING(strayl_unc),2)
		
	  END
	    
	    'OK': BEGIN
		WIDGET_CONTROL, val_wd, GET_VALUE=strayl
		WIDGET_CONTROL, ustrl_wd, GET_VALUE=strayl_unc
		strayl = FLOAT(strayl(0))
		strayl_unc = FLOAT(strayl_unc(0))
	    	WIDGET_CONTROL, event.top, /destroy

	    END
	    
	    'CANCEL': BEGIN
		strayl = 0.
		strayl_unc = 0.
	    	WIDGET_CONTROL, event.top, /destroy
	    END
	    
	    ELSE:
	   ENDCASE
RETURN
END	

;;;;;;;;;;;;;;;;;;;
;
; The main routine
;
;;;;;;;;;;;;;;;;;;;
				
PRO PIA_get_strayl, ident, group=group

@phtscp
COMMON pia_get_stryl_cmn, meas_wd, strl_wd,ustrl_wd,val_wd,uval_wd,meas_pos		

	ON_ERROR, 2
	
;
; Check the number of parameters
;
	IF N_PARAMS() LT 1 THEN MESSAGE, $
'Syntax: PIA_GET_STRAYL, ident'

	meas_pos = WHERE(STRMID(phtscp.admn,4,8) EQ STRMID(ident,4,8), n)
	decode_admn, phtscp(meas_pos).admn, list	
	decode_admn, ident, dec_ident
	
	strl_base = WIDGET_BASE(TITLE = 'PIA Straylight Calculation Menu', $
                                /COLUMN, /modal, group=group)

	slab = WIDGET_LABEL(strl_base, VALUE='Calculation for '+ dec_ident)
	measbase0 = WIDGET_BASE(strl_base, /COLUMN, /FRAME)
	measbase = WIDGET_BASE(measbase0, /ROW)
	measlab = WIDGET_LABEL(measbase, VALUE='Measurement to be used: ')
	meas_wd = WIDGET_TEXT(measbase0, VALUE='', UVALUE='JUNK', $
			/editable, XSIZE=30, YSIZE=1)
	measbase = WIDGET_BASE(measbase0, /ROW)
	measlab = WIDGET_LABEL(measbase, VALUE='From: ')
	measlist = WIDGET_LIST(measbase, VALUE=list, UVAL='LIST', $
			XSIZE=30, YSIZE=8)

	label = WIDGET_LABEL(strl_base, VALUE='  ')

	label = WIDGET_LABEL(strl_base, VALUE='Straylight level')
	valbase = WIDGET_BASE(strl_base, /ROW, /FRAME)
	strl_wd = WIDGET_TEXT(valbase, /editable, XSIZE=6, $
		VALUE='0.04', UVALUE='JUNK')	
	vallab = WIDGET_LABEL(valbase, VALUE=' +/- ')
	ustrl_wd = WIDGET_TEXT(valbase, /editable, XSIZE=6, $
		VALUE='0.02', UVALUE='JUNK')	
	
	label = WIDGET_LABEL(strl_base, VALUE='  ')
	label = WIDGET_LABEL(strl_base, $
		VALUE='Signal contribution [V/s] from Straylight')
	valbase = WIDGET_BASE(strl_base, /ROW, /FRAME)
	val_wd = WIDGET_TEXT(valbase, /editable, XSIZE=6, $
		VALUE='', UVALUE='JUNK')	
	vallab = WIDGET_LABEL(valbase, VALUE=' +/- ')
	uval_wd = WIDGET_TEXT(valbase, /editable, XSIZE=6, $
		VALUE='', UVALUE='JUNK')	
	

	label = WIDGET_LABEL(strl_base, VALUE='  ')

	contbase = WIDGET_BASE(strl_base, /ROW)
	ok = WIDGET_BUTTON(contbase, VALUE='     OK     ', UVALUE='OK')
	cancel = WIDGET_BUTTON(contbase, VALUE='    Cancel    ',UVALUE='CANCEL')
	
        WIDGET_CONTROL, strl_base, /REALIZE, TLB_SET_XOFFSET=300, $
                        TLB_SET_YOFFSET=50

        xMANAGER,No_BLOCK=1, "pia_get_strayl", strl_base, GROUP=group

RETURN
END
		
	
