;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_GRAPH_EXTRACT
;
; PURPOSE:
;	Widget routine for extraction of points graphically determined on
;	a plot.
;
; CATEGORY:
;	PIA - graphics
;                
; CALLING SEQUENCE: 
;	PRO PIA_GRAPH_EXTRACT, x, y, interp, xch, ych, error=error
;
; INPUT PARAMETERS:
;	x:	The abscissae values
;	y:	The ordinate values
;
; OPTIONAL KEYWORD :
;	ERROR	: 1 for error
;
; OUTPUT:
;	interp:	The interpolated values at the x positions 
;	xch:	The x values for the graphically chosen points
;	ych:	The y values for the graphically chosen points
;
; RESTRICTIONS:
;	At least 4 points must be chosen
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;		colour_indices
;       PIA Procedure(s):
;		pia_write_anything
;		
;
; MODIFICATION HISTORY:
;	Written by: C. Gabriel (ESA/VILSPA-SAI)			July 1997
;	V6.4
;-
PRO PIA_GRAPH_EXTRACT, x, y, interp, xch, ych, error=error, $
   GROUP_LEADER=group_leader
@colour_indices

   error = 0
   xch = 0.
   ych = 0.
   
   base = WIDGET_BASE( TITLE = 'PIA-Extract-PLOT', /COLUMN, /modal, $
   	GROUP_LEADER=group_leader )

   id_plot = WIDGET_BASE( base, /COLUMN, /FRAME )
     id_1 = WIDGET_BASE( id_plot, /ROW, XSIZE = 630 )
       id_draw = WIDGET_DRAW( id_1, XSIZE = 600, $
                 YSIZE = 500, /BUTTON_EVENTS, /MOTION_EVENTS, $
		 UVALUE='DRAW', RETAIN = 2 )
   hbase = WIDGET_BASE(base, /ROW)
   id_smooth = WIDGET_BUTTON(hbase,VAL=' Interpol ', UVAL='COMB')	
   id_refr = WIDGET_BUTTON(hbase,  VAL=' Refresh  ', UVAL='REFR')	
   id_canc = WIDGET_BUTTON(hbase,  VAL='  Cancel  ', UVAL='CANCEL')
   id_quit = WIDGET_BUTTON(hbase,  VAL='    OK    ', UVAL='OK')
   id_range = WIDGET_BUTTON(hbase, VAL=' Change y range', UVAL='CHY')
   
   WIDGET_CONTROL, id_quit, sensitive=0   
   WIDGET_CONTROL, id_smooth, sensitive=0   
   	
   WIDGET_CONTROL, base, TLB_SET_XOFFSET=90, TLB_SET_YOFFSET=30, /REALIZE
   WIDGET_CONTROL, id_draw, GET_VALUE = window
   
   plot, x, y, psym=4, /ynozero

   quit=0
    	
   WHILE quit NE 1 DO BEGIN
     
     event = WIDGET_EVENT(BASE)
     WIDGET_CONTROL, event.id, GET_UVALUE=ACTION
     
     CASE action of
        'DRAW': BEGIN
          
       	  IF event.type EQ 1 THEN BEGIN
       		 
           pos = convert_coord(event.x,event.y,/device,/to_data)
          
           IF (xch(0)+ych(0)) EQ 0. THEN BEGIN
             xch = pos(0) 
             ych = pos(1) 
           ENDIF ELSE BEGIN
             xch = [xch,pos(0)]
             ych = [ych,pos(1)]
           ENDELSE
             
           oplot, [pos(0)], [pos(1)], psym=7, color=orange
           
           IF N_ELEMENTS(xch) EQ 3 THEN BEGIN
             WIDGET_control, id_smooth, sensitive=1
           ENDIF
          ENDIF
         END
         
	 'REFR': BEGIN
	   plot, x, y, psym=4, /ynozero
	   xch = 0. & ych=0.
	   WIDGET_CONTROL, id_quit, sensitive=0
	   WIDGET_CONTROL, id_smooth, sensitive=0
	 END
	 
	 'COMB': BEGIN
	   IF N_ELEMENTS(xch) LT 4 THEN BEGIN
	       error=1
	       PRINT, 'At least 4 points needed, returning'
	   ENDIF ELSE BEGIN
	    WIDGET_CONTROL, id_quit, sensitive=1
	   
	   
	    indsort = bsort(xch, xch)
	    ych = ych(indsort)
	   
	    interp = INTERPOL(ych, xch, x)
	   
	    oplot, x, interp, color=green
	   ENDELSE
	 END
	 'CHY': BEGIN
	   PIA_WRITE_ANYTHING, 'Low Y-value',ymi
	   PIA_WRITE_ANYTHING, 'High Y-value',yma
	   range = [FLOAT(ymi(0)),FLOAT(yma(0))]
	   plot, x, y, psym=4, yrange=range
	 END
	      	   
	 'CANCEL': BEGIN
	   error = 1
	   quit=1
	  END

         'OK': quit=1
         
         ELSE:

     ENDCASE
     
     ENDWHILE
     
     WIDGET_CONTROL, base, /DESTROY
     
     RETURN
     END 
             
       		   
	
