;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

PRO PIA_IN_BUFFER, tmp, REPLACE=replace

;+
; NAME:
;       PIA_IN_BUFFER
;
; PURPOSE:
;	Controls the filling of a temporary structure into one of the 
;	PIA dynamical structures   
;
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;       PIA_IN_BUFFER, tmp, REPLACE=replace
;
; INPUT:
;       tmp 	: A temporary structure  (phterd, phtsrd, ... type)
;
; OPTIONAL INPUT:
;	REPLACE : IF set (> 0) put the structure into this position
;		  within the buffer, if set and negative starts a widget
;		  for getting the desired position
;
;
; RESTRICTIONS:
;       tmp must be a valid (phterd, phtsrd, ...)  temporary structure
;
; PROCEDURES USED: 
;	PIA procedures:
;		FILL_ERD
;		FILL_SRD
;		FILL_SCP
;		FILL_SPD
;		FILL_AAP
;		PICKMEAS_POS
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel  (ESA-SAI)			July 1996
;	Bug for AAP fixed (CG)					December 1996
;	Bug for AAP fixed (after adding CWVL to AAP) (CG)	February 1997
;	V6.1
;	Bug for SPD fixed (CG)					March 1998
;	V7.1
;
;-
;

;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  PIA_IN_BUFFER, tmp, [REPLACE=replace]'

	IF KEYWORD_SET(replace) THEN repl = replace ELSE repl = 0

; identify temporary structure according to tag_names

	tags = TAG_NAMES(tmp)

	CASE tags(9) OF

	  'RAWP': BEGIN
	  	IF KEYWORD_SET(replace) THEN BEGIN
			IF replace LT 0 THEN $
			 posi = pickmeas_pos( FTYPE="ERD", $
				DTYPE=STRMID(tmp.det,0,2) ) $
			 ELSE posi = replace
	 	  	IF posi NE 0 THEN FILL_ERD, tmp, REPLACE=posi
	 	ENDIF ELSE FILL_ERD, tmp
 	  END
	  
	  'SLUN': BEGIN 
	  	IF KEYWORD_SET(replace) THEN BEGIN
			IF replace LT 0 THEN $
			 posi = pickmeas_pos( FTYPE="SRD", $
				DTYPE=STRMID(tmp.det,0,2) ) $
			 ELSE posi = replace
	 	  	IF posi NE 0 THEN FILL_SRD, tmp, REPLACE=posi
	 	ENDIF ELSE FILL_SRD, tmp
	  END
	  
	  'MEDI': BEGIN 
	  	IF KEYWORD_SET(replace) THEN BEGIN
			IF replace LT 0 THEN $
			 posi = pickmeas_pos( FTYPE="SCP", $
				DTYPE=STRMID(tmp.det,0,2) ) $
			 ELSE posi = replace
	 	  	IF posi NE 0 THEN FILL_SCP, tmp, REPLACE=posi
	 	ENDIF ELSE FILL_SCP, tmp
	  END
	  
	  'DWEL': BEGIN 
	  	IF KEYWORD_SET(replace) THEN BEGIN
			IF replace LT 0 THEN $
			 posi = pickmeas_pos( FTYPE="SPD", $
				DTYPE=STRMID(tmp.det,0,2) )$
			 ELSE posi = replace
	 	  	IF posi NE 0 THEN FILL_SPD, tmp, REPLACE=posi
	 	ENDIF ELSE FILL_SPD, tmp
	  END
	  
	  'FILT': BEGIN 
	  	IF KEYWORD_SET(replace) THEN BEGIN
			IF replace LT 0 THEN $
			 posi = pickmeas_pos( FTYPE="SPD", $
				DTYPE=STRMID(tmp.det,0,2) )$
			 ELSE posi = replace
	 	  	IF posi NE 0 THEN FILL_SPD, tmp, REPLACE=posi
	 	ENDIF ELSE FILL_SPD, tmp
	  END
	  
	  'CPOS': BEGIN 
	  	IF KEYWORD_SET(replace) THEN BEGIN
			IF replace LT 0 THEN $
			 posi = pickmeas_pos( FTYPE="AAP", $
				DTYPE=STRMID(tmp.det,0,2)) $
			 ELSE posi = replace
	 	  	IF posi NE 0 THEN FILL_AAP, tmp, REPLACE=posi
	 	ENDIF ELSE FILL_AAP, tmp
	  END
	  
	  'CSTP': BEGIN 
	  	IF KEYWORD_SET(replace) THEN BEGIN
			IF replace LT 0 THEN $
			 posi = pickmeas_pos( FTYPE="AAP", $
				DTYPE=STRMID(tmp.det,0,2))$
			 ELSE posi = replace
	 	  	IF posi NE 0 THEN FILL_AAP, tmp, REPLACE=posi
	 	ENDIF ELSE FILL_AAP, tmp
	  END
	  
	  ELSE: MESSAGE, /info, 'Wrong structure, cannot handle it'
	 
	ENDCASE
	
	RETURN
	END
