;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_LOAD_CALA
;
; PURPOSE:
;	Write a PHT-CALA (Signal measurement from the 
;	dynamical structure CLADAT (PHTCLA type) onto a temporary structure 
;
; CALLING SEQUENCE:
;       PIA_load_CALA, CLADAT, tmpcla
;
; CATEGORY:
;	PIA - processing
;
; INPUT:
;       CLADAT 	: PHTCLA like dynamical structure
;
; KEYWORD PARAMETERS:
;	none
;
; OUTPUT:
;	none
;
; RESTRICTIONS:
;       CLADAT must exist
;
; PROCEDURES USED: 
;	none
;
; MODIFICATION HISTORY:
;       Written by:	C. Gabriel (ESA/ESTEC)		October 1994
;       Modified by:	Wai-Ming Tai (DIAS)		December 1994
;	Modified(last): CG				September 1995
;	Oct 95 Version 3.5
;
;-
PRO PIA_load_cala, cladat, tmpcla 

        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 2 THEN MESSAGE, $
          'Syntax:  PIA_load_CALA, CLADAT, tmpcla'

;  Fill temporary variables from the handles
        HANDLE_VALUE, CLADAT.HDR, HDR 
        HANDLE_VALUE, CLADAT.TIME, TIME 
	HANDLE_VALUE, CLADAT.MNSG, AVER 
        HANDLE_VALUE, CLADAT.MNSU, AVUN
 
	HANDLE_VALUE, CLADAT.MDSG, MEDI 
        HANDLE_VALUE, CLADAT.Q1SG, Q1ME
        HANDLE_VALUE, CLADAT.Q3SG, Q3ME
        HANDLE_VALUE, CLADAT.FLAG, FLAG
        HANDLE_VALUE, CLADAT.CPOS, CHOP
        HANDLE_VALUE, CLADAT.STAT, FCSN
        HANDLE_VALUE, CLADAT.TEMP, TEMP 
        HANDLE_VALUE, CLADAT.FCS1, FCS1   
	HANDLE_VALUE, CLADAT.FCS2, FCS2 
        HANDLE_VALUE, CLADAT.TKEY, TKEY
        HANDLE_VALUE, CLADAT.RPID, RPID

;  Dummy elements in the structure to obtain correspondence to SCP level
	STEP = INTARR(N_ELEMENTS(time)) - 1
;  Fill the cala structure
	NAME = CLADAT.ADMN
	
	tmpcla = {UNIT: CLADAT.UNIT, $     
        DET: CLADAT.DET, $     
	ADMN: NAME, $
        ORDR: CLADAT.ORDR, $ 
        DIMS: CLADAT.DIMS, $
        HDR: [HDR], $ 
        TIME: [TIME], $ 
	AVER: [AVER], $ 
        AVUN: [AVUN], $
	MEDI: [MEDI], $ 
        Q1ME: [Q1ME], $
        Q3ME: [Q3ME], $
        FLAG: [FLAG], $
        STEP: [STEP], $
        CHOP: [CHOP], $
        FCSN: [FCSN], $
        TEMP: [TEMP], $ 
        FCS1: [FCS1], $   
	FCS2: [FCS2], $ 
        TKEY: [TKEY], $
        RPID: [RPID]}

        RETURN
END

