;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_LOAD_DRIFTPAR
;
; PURPOSE:
;	Load drift modelling parameters into structure PIA_DRIFTPAR
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	PIA_LOAD_DRIFTPAR, tmpdata, pixel, FUNCT = funct, NON_INT = non_int 
;
; INPUT:
;	tmpdata:	A phtsrd like temporary structure
;	pixel:		The pixel number of the data to be used
;
; KEYWORD PARAMETERS:
;	FUNCT:		The name of the function to be used
;	NON_INT:	When using it non-interactively less parameters are
;			set variable
;	
; RESTRICTIONS:
;	TMPDATA must be a valid PHTSRD temporary structure
;	
; COMMON BLOCKS:
;	pia_drift_par 
;		
; PROCEDURES USED:
;	PIA LIB:
;		fouks_start_par
;		gauss_start_par
;		gaussinv_start_par
;
; MODIFICATION HISTORY:
;	Written by: C.Gabriel (ESA/VILSPA-SAI)		August 1996
;	Version 5.0 - Aug.96
;			
;-
PRO PIA_LOAD_DRIFTPAR, tmpdata, pixel, FUNCT = funct, NON_INT = non_int, $
	ERROR=error

COMMON PIA_DRIFT_PAR, pia_drift_par 

indok = WHERE(tmpdata.flag(pixel,*) LE 1, ndata)
minp_ext = 7

IF ndata GE minp_ext  THEN slop = tmpdata.slop(pixel,indok) $
	ELSE BEGIN
	   ERROR=1
	   MESSAGE, /INFO, 'not initialized, not enough good signals'
	   RETURN
	ENDELSE

if not keyword_set(FUNCT) then funct = 'FOUKSC_DRIFT'

case funct of 

  'FOUKSC_DRIFT': BEGIN
  		   fouks_start_par, tmpdata.det, slop, pixel, $
  		   	start_par, error= error
  		   if error eq 0 then begin
  		     npar = 4
  		     ffunct = 'FOUKSC_DRIFT'
		     fract_left = 3.
  		     p_label = ['S_infty', 'S_0', 'beta', 'E_j']
		     IF KEYWORD_SET(NON_INT) THEN a_var = [1,1,0,0] ELSE $
  		     	a_var = [1,1,1,1] 
  		   endif ELSE PRINT, 'initialization error'

  		 END

  'FOUKSC_CHOP_DRIFT': BEGIN
		   step = tmpdata.step(indok)
  		   fouks_chop_start_par, tmpdata.det, slop, $
  		   	pixel, start_par, error= error, step=step
  		   if error eq 0 then begin
  		     npar = 6
  		     ffunct = 'FOUKSC_CHOP_DRIFT'
		     fract_left = 3.
  		     p_label = ['S_inf_low', 'S_0_low', 'beta', 'E_j', $
  		     		'S_inf_high', 'S_0_high']
		     IF KEYWORD_SET(NON_INT) THEN a_var = [1,1,0,0,1,1] ELSE $
  		     	a_var = [1,1,1,1,1,1] 
  		   endif ELSE PRINT, 'initialization error'

  		 END

  'GAUSS_DRIFT': BEGIN
  		  gauss_start_par, tmpdata.det, slop, pixel, $
  		  	start_par, error= error
  		  if error eq 0 then begin
  		    npar = 3 
  		    ffunct = 'GAUSS_DRIFT'
  		    fract_left = 10.
  		    p_label = ['S_infty', 'alpha', 'Tau']
		    IF KEYWORD_SET(NON_INT) THEN a_var = [1,1,1] ELSE $
  		    	a_var = [1,1,1] 
  		  endif ELSE PRINT, 'initialization error'
  		 
  		 END

  'GAUSSINV_DRIFT': BEGIN
  		  gaussinv_start_par, tmpdata.det, slop, pixel, $
  		  	start_par, error= error
  		  if error eq 0 then begin
  		    npar = 4 
  		    ffunct = 'GAUSSINV_DRIFT'
  		    fract_left = 10.
  		    p_label = ['A0', 'beta', 'alpha', 'Tau']
		    IF KEYWORD_SET(NON_INT) THEN a_var = [1,1,1,1] ELSE $
  		    	a_var = [1,1,1,1] 
  		  endif ELSE PRINT, 'initialization error'
  		 
  		 END
   
  'NUMDIF_DRIFT': BEGIN
  		numdif_start_par, tmpdata.det, slop, pixel, start_par,$
  			error=error
  			
  		  if error eq 0 then begin
  		    npar = 3 
  		    ffunct = 'NUMDIF_DRIFT'
  		    fract_left = 10.
  		    p_label = ['S_inf', 'S_0', 'C']
		    IF KEYWORD_SET(NON_INT) THEN a_var = [1,1,1] ELSE $
  		    	a_var = [1,1,1] 
  		  endif ELSE PRINT, 'initialization error'
  		 
  		 END
  
 ENDCASE
 		   if error eq 0 then $
 		   PIA_DRIFT_PAR = {p_label:string(p_label,format='(A10)'), $ 
 		        p_field:start_par, s_field:fltarr(npar), $
			a_var:a_var, p_range:fltarr(3,npar), flag:0, $
			ffunct:ffunct, minp_ext:minp_ext, fract_left:fract_left,$
			t_zero:0., chisq:0., chisqt:5.} 
			

end
 		  
