;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_load_IAAP
;
; PURPOSE:
;	Write a PHT-AAP (Astrophysical Applications) measurement from the 
;	dynamical structure AAPDAT (PHTAAP type) onto a temporary structure 
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       PIA_LOAD_IAAP, aapdat, tmpaap
;
; INPUT:
;       aapDAT 	: PHTaap like dynamical structure
;
; KEYWORDS:
;	none
;
; OUTPUTS:
;	TMPaap	: A temporary structure of aap type
;
; RESTRICTIONS:
;       aapDAT must exist
;
; MODIFICATION HISTORY:
;       Written by:	C. Gabriel (ESA/ESTEC)          December 1995
;	Central wavelength added, WMT (DIAS)            Nov 1996
;-

PRO PIA_load_Iaap, aapDAT, tmpaap 

        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 2 THEN MESSAGE, $
          'Syntax:  PIA_load_Iaap, aapDAT, tmpaap'

;  Fill temporary variables from the handles
        HANDLE_VALUE, aapDAT.HDR, HDR 
        HANDLE_VALUE, aapDAT.TIME, TIME 
	HANDLE_VALUE, aapDAT.CSTP, CSTP 
        HANDLE_VALUE, aapDAT.CPOS, CPOS
	HANDLE_VALUE, aapDAT.DWEL, DWEL 
        HANDLE_VALUE, aapDAT.MNFL, MNFL
        HANDLE_VALUE, aapDAT.MNFU, MNFU
        HANDLE_VALUE, aapDAT.MNBR, MNBR
        HANDLE_VALUE, aapDAT.MNBU, MNBU
        HANDLE_VALUE, aapDAT.MDFL, MDFL
        HANDLE_VALUE, aapDAT.Q1FL, Q1FL
        HANDLE_VALUE, aapDAT.Q3FL, Q3FL
        HANDLE_VALUE, aapDAT.MDBR, MDBR 
        HANDLE_VALUE, aapDAT.Q1BR, Q1BR   
	HANDLE_VALUE, aapDAT.Q3BR, Q3BR 
        HANDLE_VALUE, aapDAT.RPID, RPID
        HANDLE_VALUE, aapDAT.DEC , DEC 
        HANDLE_VALUE, aapDAT.RA  , RA  
        HANDLE_VALUE, aapDAT.DECP , DECP 
        HANDLE_VALUE, aapDAT.RAP  , RAP  
        HANDLE_VALUE, aapDAT.ROLL, ROLL
        HANDLE_VALUE, aapDAT.FLAG, FLAG

;  Fill the Iaap structure
	NAME = aapDAT.ADMN
	
	tmpaap = {DET: aapDAT.DET, $     
	ADMN: NAME, $
        DIMS: aapDAT.DIMS, $
        FILT: AAPDAT.FILT, $
        APER: AAPDAT.APER, $
        POLZ: AAPDAT.POLZ, $
	CWVL: AAPDAT.CWVL, $
        HDR: [HDR], $ 
        TIME: [TIME], $ 
        CSTP:[CSTP], $
        CPOS:[CPOS], $
        DWEL:[DWEL], $
        MNFL:[MNFL], $
        MNFU:[MNFU], $
        MNBR:[MNBR], $
        MNBU:[MNBU], $
        MDFL:[MDFL], $
        Q1FL:[Q1FL], $
        Q3FL:[Q3FL], $
        MDBR:[MDBR], $
        Q1BR:[Q1BR], $
        Q3BR:[Q3BR], $
        RPID:[RPID], $
	DEC:[DEC], $
	RA:[RA], $
	DECP:[DECP], $
	RAP:[RAP], $
	ROLL:[ROLL], $
	FLAG:[FLAG]}

        RETURN
END

