;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_load_iCS
;
; PURPOSE:
;	Write a PHT-CS (Compact Status Data) record from the dynamical 
;	structure CSDAT (PHTCS type) onto a temporary structure 
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       PIA_load_ICS, CSDAT, tmpcs
;
; INPUT:
;       CSDAT 	: PHTCS like dynamical structure
;
; KEYWORDS:
;	none
;
; OUTPUTS:
;	tmpcs - A temporary structure of CS type
;
; RESTRICTIONS:
;       CSDAT must exist
;
; MODIFICATION HISTORY:
;       Written by:	C. Gabriel (ESA/VILSPA-SAI)	December 1995
;-
PRO PIA_load_ICS, CSDAT, tmpcs

        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 2 THEN MESSAGE, $
          'Syntax:  PIA_load_ICS, CSDAT, tmpcs'

;  Fill temporary variables from the handles
        HANDLE_VALUE, CSDAT.handle, cst  

;  Fill the ICS structure

	tmpcs = {UNIT: CSDAT.UNIT, $     
        DIMS: CSDAT.DIMS, $     
	HANDLE: CST}

        RETURN
END

