;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_load_IERD
;
; PURPOSE:
;	Write a PHT-ERD (Edited Raw Data) measurement from the dynamical 
;	structure ERDDAT (PHTERD type) onto a temporary structure 
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       PIA_load_IERD, ERDDAT, tmperd
;
; INPUT:
;       ERDDAT 	: PHTERD like dynamical structure
;
; KEYWORDS:
;	none
;
; OUTPUTS:
;	tmperd - A temporary structure of ERD type
;
; RESTRICTIONS:
;       ERDDAT must exist
;
; MODIFICATION HISTORY:
;       Written by:	C. Gabriel (ESA/ESTEC)          August 1994
;	Modified:	CG				September 1994
;	Oct 95 Version 3.5
;	Array FLAG added to temp structure (CG)		November 1997
;	V6.6
;	Position of PIXF changed to be = phterd (CG)	September 1999
;	V8.0
;-
PRO PIA_load_IERD, ERDDAT, tmperd 

        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 2 THEN MESSAGE, $
          'Syntax:  PIA_load_IERD, ERDDAT, tmperd'

;  Fill temporary variables from the handles
        HANDLE_VALUE, ERDDAT.HDR,  HDR 
        HANDLE_VALUE, ERDDAT.RAWP, RAWP 
        HANDLE_VALUE, ERDDAT.CONP, CONP   
        HANDLE_VALUE, ERDDAT.FITV, FITV   
	HANDLE_VALUE, ERDDAT.PIXF, PIXF 
        HANDLE_VALUE, ERDDAT.TIME, TIME
        HANDLE_VALUE, ERDDAT.CHOP, CHOP
        HANDLE_VALUE, ERDDAT.STEP, STEP
        HANDLE_VALUE, ERDDAT.FCSN, FCSN
        HANDLE_VALUE, ERDDAT.TEMP, TEMP 
        HANDLE_VALUE, ERDDAT.FCS1, FCS1   
	HANDLE_VALUE, ERDDAT.FCS2, FCS2 
        HANDLE_VALUE, ERDDAT.TKEY, TKEY
        HANDLE_VALUE, ERDDAT.RPID, RPID
        HANDLE_VALUE, ERDDAT.FLAG, FLAG
;  Fill the IERD structure
	NAME = ERDDAT.ADMN

;  Fill dummy values into FITV if not there
	IF N_ELEMENTS(fitv) NE N_ELEMENTS(conp) THEN fitv = conp * 0 - 99.

	tmperd = {UNIT: ERDDAT.UNIT, $     
        DET: ERDDAT.DET, $     
	ADMN: NAME, $
        ORDR: ERDDAT.ORDR, $ 
        DIMS: ERDDAT.DIMS, $
        TINT: ERDDAT.TINT, $
        NNDR: ERDDAT.NNDR, $
        RCHP: ERDDAT.RCHP, $
        HDR: HDR, $ 
        RAWP: RAWP, $ 
        CONP: CONP, $   
        FITV: FITV, $   
        TIME: TIME, $
	PIXF: PIXF, $ 
        CHOP: CHOP, $
        STEP: STEP, $
        FCSN: FCSN, $
        TEMP: TEMP, $ 
        FCS1: FCS1, $   
	FCS2: FCS2, $ 
        TKEY: TKEY, $
        RPID: RPID, $
        FLAG:FLAG }

        RETURN
END

