;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_load_ISCP
;
; PURPOSE:
;	Write a PHT-SCP (Signal per chopper plateau) measurement from the 
;	dynamical structure SCPDAT (PHTSCP type) onto a temporary structure 
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       PIA_LOAD_ISCP, scpdat, tmpscp
;
; INPUT:
;       SCPDAT 	: PHTSCP like dynamical structure
;
; KEYWORDS:
;	none
;
; OUTPUTS:
;	TMPSCP	: A temporary structure of SCP type
;
; RESTRICTIONS:
;       SCPDAT must exist
;
; MODIFICATION HISTORY:
;       Written by:	C. Gabriel (ESA/ESTEC)          October 1994
;	Oct 95 Version 3.5
;	Extension for ANDR,AVSD and ARSI (CG)		  January 1996
;-

PRO PIA_load_ISCP, SCPDAT, tmpscp 

        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 2 THEN MESSAGE, $
          'Syntax:  PIA_load_ISCP, SCPDAT, tmpscp'

;  Fill temporary variables from the handles
        HANDLE_VALUE, SCPDAT.HDR, HDR 
        HANDLE_VALUE, SCPDAT.TIME, TIME 
	HANDLE_VALUE, SCPDAT.AVER, AVER 
        HANDLE_VALUE, SCPDAT.AVUN, AVUN
	HANDLE_VALUE, SCPDAT.MEDI, MEDI 
        HANDLE_VALUE, SCPDAT.Q1ME, Q1ME
        HANDLE_VALUE, SCPDAT.Q3ME, Q3ME
        HANDLE_VALUE, SCPDAT.FLAG, FLAG
        HANDLE_VALUE, SCPDAT.CHOP, CHOP
        HANDLE_VALUE, SCPDAT.STEP, STEP
        HANDLE_VALUE, SCPDAT.FCSN, FCSN
        HANDLE_VALUE, SCPDAT.TEMP, TEMP 
        HANDLE_VALUE, SCPDAT.FCS1, FCS1   
	HANDLE_VALUE, SCPDAT.FCS2, FCS2 
        HANDLE_VALUE, SCPDAT.TKEY, TKEY
        HANDLE_VALUE, SCPDAT.RPID, RPID
	HANDLE_VALUE, SCPDAT.ARSI, ARSI
        HANDLE_VALUE, SCPDAT.ANDR, ANDR
	HANDLE_VALUE, SCPDAT.AVSD, AVSD 

;  Fill the ISCP structure
	NAME = SCPDAT.ADMN
	
	tmpscp = {UNIT: SCPDAT.UNIT, $     
        DET: SCPDAT.DET, $     
	ADMN: NAME, $
        ORDR: SCPDAT.ORDR, $ 
        DIMS: SCPDAT.DIMS, $
        HDR: [HDR], $ 
        TIME: [TIME], $ 
	AVER: [AVER], $ 
        AVUN: [AVUN], $
	MEDI: [MEDI], $ 
        Q1ME: [Q1ME], $
        Q3ME: [Q3ME], $
        FLAG: [FLAG], $
        CHOP: [CHOP], $
        STEP: [STEP], $
        FCSN: [FCSN], $
        TEMP: [TEMP], $ 
        FCS1: [FCS1], $   
	FCS2: [FCS2], $ 
        TKEY: [TKEY], $
        RPID: [RPID], $
	ARSI: [ARSI], $
        ANDR: [ANDR], $
        AVSD: [AVSD]}

        RETURN
END

