;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_load_ISPD
;
; PURPOSE:
;	Write a PHT-SPD (Standard Processed Data) measurement from the 
;	dynamical structure SPDDAT (PHTSPD type) onto a temporary structure 
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       PIA_LOAD_ISPD, spddat, tmpspd
;
; INPUT:
;       SPDDAT 	: PHTSPD like dynamical structure
;
; KEYWORDS:
;	none
;
; OUTPUTS:
;	TMPSPD	: A temporary structure of SPD type
;
; RESTRICTIONS:
;       SPDDAT must exist
;
; MODIFICATION HISTORY:
;       Written by:	C. Gabriel (ESA/ESTEC)          November 1994
;	Modified:	CG				March 1995
;	Oct 95 Version 3.5
;	Coordinates keywords in double precision - CG	October 1995
;	Order changed (CG)				September 1997
;	V6.5
;-

PRO PIA_load_ISPD, SPDDAT, tmpspd 

        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 2 THEN MESSAGE, $
          'Syntax:  PIA_load_ISPD, SPDDAT, tmpspd'

;  Fill temporary variables from the handles
        HANDLE_VALUE, SPDDAT.hdr, hdr 
        HANDLE_VALUE, SPDDAT.time, time 
	HANDLE_VALUE, SPDDAT.mnpw, mnpw 
        HANDLE_VALUE, SPDDAT.mnpu, mnpu
	HANDLE_VALUE, SPDDAT.mdpw, mdpw 
        HANDLE_VALUE, SPDDAT.q1pw, q1pw
        HANDLE_VALUE, SPDDAT.q3pw, q3pw
        HANDLE_VALUE, SPDDAT.flag, flag
        HANDLE_VALUE, SPDDAT.plen, plen
        HANDLE_VALUE, SPDDAT.cpos, cpos
        HANDLE_VALUE, SPDDAT.tkey, tkey
        HANDLE_VALUE, SPDDAT.rpid, rpid
        HANDLE_VALUE, SPDDAT.kyid, kyid
        HANDLE_VALUE, SPDDAT.filt, filt
        HANDLE_VALUE, SPDDAT.aper, aper
        HANDLE_VALUE, SPDDAT.polz, polz
        HANDLE_VALUE, SPDDAT.ndrs, ndrs
        HANDLE_VALUE, SPDDAT.cstp, cstp
        HANDLE_VALUE, SPDDAT.dwel, dwel
        HANDLE_VALUE, SPDDAT.meas, meas
        HANDLE_VALUE, SPDDAT.dec, dec
        HANDLE_VALUE, SPDDAT.ra, ra
        HANDLE_VALUE, SPDDAT.roll, roll
;  Fill dummy values if not present
	IF N_ELEMENTS(kyid) EQ 0 THEN KYID = INTARR(spddat.dims) - 99
	IF N_ELEMENTS(dec ) EQ 0 THEN DEC  = DBLARR(spddat.dims) - 99.
	IF N_ELEMENTS(ra  ) EQ 0 THEN RA   = DBLARR(spddat.dims) - 99.
	IF N_ELEMENTS(roll) EQ 0 THEN ROLL = DBLARR(spddat.dims) - 99.

;  Fill the ISPD structure
	NAME = SPDDAT.ADMN
	
	tmpspd = {UNIT: SPDDAT.UNIT, $     
        DET: SPDDAT.DET, $     
	ADMN: NAME, $
        ORDR: SPDDAT.ORDR, $ 
        DIMS: SPDDAT.DIMS, $
        HDR:  [HDR], $ 
        TKEY: [TKEY], $
        RPID: [RPID], $
        KYID: [KYID], $
	FILT: [FILT], $ 
	APER: [APER], $ 
 	POLZ: [POLZ], $ 
 	NDRS: [NDRS], $ 
        CSTP: [CSTP], $
        DWEL: [DWEL], $
	MEAS: [MEAS], $ 
        CPOS: [CPOS], $
        TIME: [TIME], $ 
        MNPW: [MNPW], $
        MNPU: [MNPU], $
        MDPW: [MDPW], $
        Q1PW: [Q1PW], $
        Q3PW: [Q3PW], $
	DEC: [DEC],   $
	RA: [RA],     $
	ROLL: [ROLL], $
        PLEN: [PLEN], $
        FLAG: [FLAG]}


        RETURN
END

