;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_load_ISRD
;
; PURPOSE:
;	Write a PHT-SRD (Signal Raw Data) measurement from the dynamical 
;	structure SRDDAT (PHTSRD type) onto a temporary structure 
;
; CALLING SEQUENCE:
;       PIA_load_ISRD, SRDDAT, tmpsrd
;
; CATEGORY:
;	PIA - processing
;
; INPUT:
;       SRDDAT 	: PHTSRD like dynamical structure
;
; KEYWORDS:
;	none
;
; OUTPUTS:
;	TMPSRD	: A temporary structure of SRD type
;
; RESTRICTIONS:
;       SRDDAT must exist
;
; MODIFICATION HISTORY:
;       Written by:	C. Gabriel (ESA/ESTEC)          	September 1994
;	Modified(last):	CG					April 1995
;	Oct 95 Version 3.5
;	Effective reset time and nr of read-outs added (CG)	January 1996
;	Forgotten DIMS keyword added (CG)			June 1996
;-

PRO PIA_load_ISRD, SRDDAT, tmpsrd 

        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 2 THEN MESSAGE, $
          'Syntax:  PIA_load_ISRD, SRDDAT, tmpsrd'

;  Fill temporary variables from the handles
        HANDLE_VALUE, SRDDAT.HDR, HDR 
	HANDLE_VALUE, SRDDAT.SLOP, SLOP 
        HANDLE_VALUE, SRDDAT.SLUN, SLUN
        HANDLE_VALUE, SRDDAT.STIM, STIM
        HANDLE_VALUE, SRDDAT.FLAG, FLAG
        HANDLE_VALUE, SRDDAT.CHOP, CHOP
        HANDLE_VALUE, SRDDAT.STEP, STEP
        HANDLE_VALUE, SRDDAT.FCSN, FCSN
        HANDLE_VALUE, SRDDAT.TEMP, TEMP 
        HANDLE_VALUE, SRDDAT.FCS1, FCS1   
	HANDLE_VALUE, SRDDAT.FCS2, FCS2 
        HANDLE_VALUE, SRDDAT.TKEY, TKEY
        HANDLE_VALUE, SRDDAT.RPID, RPID
	HANDLE_VALUE, SRDDAT.RESI, RESI 
        HANDLE_VALUE, SRDDAT.NROS, NROS

;  Fill the ISRD structure
	NAME = SRDDAT.ADMN
	
	tmpsrd = {UNIT: SRDDAT.UNIT, $     
        DET: SRDDAT.DET, $     
	ADMN: NAME, $
        ORDR: SRDDAT.ORDR, $ 
	DIMS: SRDDAT.DIMS, $
	SLDI: SRDDAT.SLDI, $
	RCHP: SRDDAT.RCHP, $
        HDR: [HDR], $ 
	SLOP: [SLOP], $ 
        SLUN: [SLUN], $
        FLAG: [FLAG], $
        STIM: [STIM], $
        CHOP: [CHOP], $
        STEP: [STEP], $
        FCSN: [FCSN], $
        TEMP: [TEMP], $ 
        FCS1: [FCS1], $   
	FCS2: [FCS2], $ 
        TKEY: [TKEY], $
        RPID: [RPID], $
	RESI: [RESI], $ 
        NROS: [NROS]}

        RETURN
END

