;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_MAN_MEA
;
; PURPOSE:
;       This is the "ISOPHOT Interactive Analysis" Control Panel
;       program. It is used for the management of
;       measurement.
;
; CATEGORY:
;       PIA - graphics
;
; CALLING SEQUENCE:
;       PIA
;
; COMMON BLOCKS:
;       phtcs
;       phterd
;       phtsrd
;       phtspd
;       phtscp
;       phtsmc
;       phtcla
;
; PROCEDURES USED:
;       PIA LIB:
;         pia_disp_hdr
;         pia_load_ierd
;         pia_pickfile1
;         pia_load_isrd
;         pia_sm_load_ismc
;         pia_load_iscp
;         pia_load_ispd
;         pia_read_ifile
;         pia_dispdata
;         pia_disp_cs
;         pia_showdata
;         pcont_valid_dir
;         pcont_getfiles
;         pcont_getdirs
;         decode_cs2mea
;         decode_filetype
;         decode_hdr2mea
;         decode_tdt2mea
;       Astronomical Library:
;         sxpar
; MODIFICATION HISTORY:
;       Written by: Wai-Ming Tai (DIAS)                    Apr 1996
;	Modified (last) by CG-SB - Oct 96
;	V5.x
;	Leaving last chosen combination as default +
;	 print contents added + display also measurement
;	 name given by the user (if any) + 
;	 use explicitly chosen measurement		   May 1997
;	V6.3
;	Change the renaming of measurements + saving (JA)  December 1997
;	Change call to pcont_vmeahdr (JA)		   January 1998
;	V7.0
;	phtaar added (CG)				   April 1998
;	V7.1
;	Save FITS allowed for AAP from here (CG)	   February 1999
;	V7.4
;
;-
;------------------------------------------------------------------------
pro pia_man_mea_event, event
@phterd
@phtsrd
@phtscp
@phtspd
@phtaap
@phtaar
@phtsmc
@phtcla
common pia_man_mea_cmn, id, mea_par, mea_sel_par, mealist


	case event.id of

        id.hmeatype: begin
                tmp = mea_par.data_type(event.index)
		mea_sel_par.decodeflag = mea_par.decodeflag(event.index)
                if tmp EQ 'Cal A' then begin
                  mea_sel_par.thedtype = 'CLA' 
                  butval = ' Clear ' + tmp +' Buffer '
		endif else begin  
                  mea_sel_par.thedtype = tmp
                  butval = ' Clear ' + tmp +' Buffer   '
		endelse
		WIDGET_CONTROL, id.hmeavcs, /SENSITIVE
		case mea_sel_par.thedtype of
		  'SPD': begin
			 det_list = mea_par.spd_det_list
			 sys_det_list = mea_par.spd_det_list
			 end
		  'AAP': begin
			 det_list = mea_par.aap_det_list
			 sys_det_list = mea_par.aap_det_list
			 end
		  'AAR': begin
			 det_list = mea_par.aar_det_list
			 sys_det_list = mea_par.sys_aar_det_list
			WIDGET_CONTROL, id.hmeavcs, SENSITIVE=0
			 end
		  'CLA': begin
			 det_list = mea_par.cla_det_list
			 sys_det_list = mea_par.cla_det_list
			 end
		   ELSE: begin
			 det_list = mea_par.def_det_list
			 sys_det_list = mea_par.def_det_list
			 end
		endcase
		ind = where(det_list EQ mea_sel_par.thedet, matches)
		widget_control, id.hmeadet, set_uvalue = sys_det_list
		widget_control, id.hmeadet, set_value = det_list
		if matches gt 0 then $
		  widget_control, id.hmeadet, set_list_select = ind(0)$
		else begin
		  mea_sel_par.thedet = det_list(0)
		  widget_control, id.hmeadet, set_list_select = 0
		endelse
		case mea_sel_par.thedtype of
		  'SRD': widget_control, id.hsavefits, sensitive = 1
		  'SMC': widget_control, id.hsavefits, sensitive = 1
		  'SCP': widget_control, id.hsavefits, sensitive = 1
		  'SPD': widget_control, id.hsavefits, sensitive = 1
		  'AAP': widget_control, id.hsavefits, sensitive = 1
		  else: widget_control, id.hsavefits, sensitive = 0
		endcase
		pcont_updatemea, mea_sel_par.thedtype, $
			mea_sel_par.thedet, mea_sel_par.decodeflag,$
			id, mea_sel_par, mealist
		widget_control, id.hclrbuf, set_value = butval
		widget_control, id.hmsgline, $
		  set_value = mea_par.type_desc(event.index)
		end

        id.hmeadet: begin
		widget_control, id.hmeadet, get_uvalue = tmpdet
		tmp = tmpdet(event.index)
		mea_sel_par.thedet = tmp
		pcont_updatemea, mea_sel_par.thedtype, $
			mea_sel_par.thedet, mea_sel_par.decodeflag,$
			id, mea_sel_par, mealist
		end

        id.hmeaprint: begin
		text = ['Measurements buffer list for ' + $
			   mea_sel_par.thedtype + ' level ', ' ', $
			   mea_sel_par.thedet + ' detector ', ' ']
		text = [text,mealist.decodename]
		PIA_DISP_PRINT_FILE, '', TITLE='Measurements buffer list',$
			text=text
		end

	id.hmealist: begin
		mea_sel_par.themea = mealist(event.index).filename
		mea_sel_par.mlist_index = event.index
		pcont_msgline, 'Measurement: ' + $
		  mealist(event.index).decodename + ' selected.', id.hmsgline
		end
	id.hmeaplot: begin
		if mea_sel_par.themea EQ '' then $
		  pcont_msgline, 'Warning: No measurement selected!',$
		    id.hmsgline $
		else begin
		  widget_control, event.top, /hourglass
		  pia_dispdata, mea_sel_par.themea, mea_sel_par.thedtype, $
		    tmppos=mealist(mea_sel_par.mlist_index).index, $
		    group = event.top
		endelse
		end
	id.hmeavhdr: begin
		if mea_sel_par.themea NE '' then $
		   pcont_vmeahdr,mealist(mea_sel_par.mlist_index).index,    $
		     mea_sel_par.thedtype, group = group                    $  
		else pcont_msgline, 'Warning: No measurement selected!',$
		       id.hmsgline
		end

	id.hmeaname: begin
		IF mea_sel_par.themea NE '' then BEGIN
		   cur_name = mealist(mea_sel_par.mlist_index).uname
		   PIA_WRITE_ANYTHING, 'the name for this measurement',$
		       PROPOSAL=cur_name, baptism
		   baptism = baptism(0)
		   IF baptism EQ '' THEN RETURN
		   pcont_vmeahdr,mealist(mea_sel_par.mlist_index).index,  $
		      mea_sel_par.thedtype, group = group, naming=baptism  
		   ;pcont_vmeahdr, mea_sel_par.themea, mea_sel_par.thedtype, $
		   ;  group = group, naming=baptism 
		   pcont_updatemea, mea_sel_par.thedtype, $
			mea_sel_par.thedet, mea_sel_par.decodeflag,$
			id, mea_sel_par, mealist
		
		ENDIF else pcont_msgline, 'Warning: No measurement selected!',$
		       id.hmsgline
		end

	id.hmeavcs: begin
		if mea_sel_par.themea NE '' then $
		  pia_disp_cs, mea_sel_par.themea, group = event.top $
		else pcont_msgline, 'Warning: No measurement selected!',$
		       id.hmsgline
		end

	id.hmeashowf: begin
		if mea_sel_par.themea NE '' then $
		  pia_showdata, mea_sel_par.themea, mea_sel_par.thedtype, $
		    group = event.top, $
                    tmppos=mealist(mea_sel_par.mlist_index).index    $
		else pcont_msgline, 'Warning: No measurement selected!',$
		       id.hmsgline
		end

; clear the buffer
	id.hclrbuf: pcont_clrbuf, id, mea_sel_par, mealist

; save the internal file

	id.hsaveint: if mea_sel_par.themea NE '' then pcont_saveint, $
			id, mea_sel_par.thedtype, mea_sel_par.mlist_index, $
			mealist else $
			pcont_msgline, 'Warning: No measurement selected!',$
			  id.hmsgline

; save fits file
	id.hsavefits: begin
	        if mea_sel_par.themea NE '' then $
		 pcont_savefits, id, mea_sel_par.thedtype,$
		   mea_sel_par.mlist_index, mealist $
		 else pcont_msgline, 'Warning: No measurement selected!', $
		      id.hmsgline
			 end
	id.hquit: BEGIN
	  !PIA_BUFINFO.level = mea_sel_par.thedtype
	  !PIA_BUFINFO.det = mea_sel_par.thedet
	  widget_control, event.top, /destroy
	END
		  
	id.hhelp: BEGIN
	   IF !VERSION.OS NE 'vms' THEN $
               spawn, '$w3net $PIA_HTML/um/m_b_control_window.html &' ELSE $
               spawn, 'w3net /pia_dsk/pia/html/um/m_b_control_window.html',/nowait
      	   END
		
	else:
	endcase
return
	
print_error:
  pcont_msgline, "!!! Unable to Open File !!!", id.hmsgline
  return
end


;------------------------------------------------------------------------
pro pia_man_mea, group = group

; we only want to show pia_man_mea once, xregistered function would bring
; the pia_man_mea to the front of all the other windows by default

  if xregistered("pia_man_mea") NE 0 then return

@phterd
@phtsrd
@phtscp
@phtspd
@phtsmc
@phtaap
@phtcla
common pia_man_mea_cmn, id, mea_par, mea_sel_par, mealist
; where:
;	id : is the structure for the widget handlers
;	mea_par : is the measurement parameter
;	mea_sel_par : is the measurement selection instance
;	mealist: is the list of measurement

; default is the erd data type
  setmea = 0
  defsysv,'!PIA_bufinfo', exists=i
  IF i NE 0 THEN BEGIN
    case !PIA_bufinfo.level of
      'ERD': BEGIN
        buflevel = phterd
        buflev = 0
      END
      'SRD': BEGIN
        buflevel = phtsrd
        buflev = 1
      END
      'SMC': BEGIN
        buflevel = phtsmc
        buflev = 2
      END
      'SCP': BEGIN
        buflevel = phtscp
        buflev = 3
      END
      'SPD': BEGIN
        buflevel = phtspd
        buflev = 4
      END
      'AAP': BEGIN
        buflevel = phtaap
        buflev = 5
      END
      ELSE: BEGIN
        buflevel = phterd
        buflev = 0
        !PIA_BUFINFO.level = 'ERD'
        !PIA_BUFINFO.det = 'P1'
      END
     ENDCASE
           
     det_chosen = !PIA_bufinfo.det
     
     
   ENDIF ELSE BEGIN
     buflevel = phterd
     buflev = 0
     det_chosen = 'P1'
     bufinfo = {level:buflevel, det:det_chosen}
     defsysv, '!PIA_BUFINFO', bufinfo
   ENDELSE

; the widget handle structure
  id = { $
	 hmeatype: 0L, $ ; the data type
	 hmeadet: 0L, $  ; the detectors
	 hmeainfo: 0L, $ ; the measurement info above the list
	 hmealist: 0L, $ ; the list of measurement
	 hmeaplot: 0L, $ ; the plot menu item
	 hmeaprint: 0L,$ ; the print item
	 hmeaname: 0L,$  ; the measurement naming item
	 hmeavhdr: 0L, $ ; the show fits header menu item
	 hmeavcs: 0L, $  ; the show compact status menu item
	 hmeashowf: 0L,$ ; the show data value menu item
	 hclrbuf: 0L, $  ; the clear ... Buffer menu item
	 hsaveint: 0L,$  ; the save internal file menu item
	 hsavefits: 0L,$ ; the save fits file menu item
	 hquit: 0L, $	 ; the quit button
	 hhelp: 0L, $    ; the help button
	 hmsgline: 0L$   ; the message line
	 }

  base = widget_base(title='PIA Measurement Buffer Control Panel', /COLUMN)

; define the font to use, esp important for vms and ultrix machine
; again this only apply to x-window system
  widget_control, base, default_font = $
    "fixed"

  bar_base = widget_base(base, /ROW)
  id.hquit = widget_button(bar_base, val=' Quit ',/FR)

; the save measurement menu
  id_0 = widget_button(bar_base,        val='Save...', /menu)
  id.hsavefits =widget_button(id_0, val='FITS File')
  id.hsaveint = widget_button(id_0, val='Internal Save File')

; the show various menu
  id_0 = widget_button(bar_base,        val='Show...', /menu)
  id.hmeavhdr = widget_button(id_0, val='FITS Header')
  id.hmeavcs  = widget_button(id_0, val='Compact Status')
  id.hmeashowf =widget_button(id_0, val='Data Values')

; plot & reduce data button
  id.hmeaplot = widget_button(bar_base, val=' Plot & Reduce Data ')
; clear ... buffer button
  clval = ' Clear ' + !PIA_BUFINFO.level + ' Buffer   '
  id.hclrbuf  = widget_button(bar_base, val=clval)
; print list of meas. ... buffer button
  id.hmeaprint  = widget_button(bar_base, val=' Buffer List ')
; naming element . ... buffer button
  id.hmeaname  = widget_button(bar_base, val=' Baptize Meas. ')
; the help button
;  dummy = widget_label(bar_base, val=' ')
  id.hhelp = widget_button(bar_base, val=' Help ', /FR)

; Measurement parameter and selection instance parameter
  data_type = ['ERD', 'SRD', 'SMC', 'SCP', 'SPD', 'AAP', 'AAR', 'Cal A']
  type_desc = [ $
	       'Edited Raw Data type', $
	       'Signal per Ramp Data type', $
	       'Serendipity mode Data type', $
	       'Signal per Chopper Plateaux Data type', $
	       'Standard Processing Data type', $
	       'Astro Physical Data type', $
	       'PipeLine: Auto Analysis Result Data type', $
	       'Calibration A Data type']
  det_list = ['P1', 'P2', 'P3', 'C100', 'C200', 'SL/SS', 'ALL']
  spd_det_list = ['P1', 'P2', 'P3', 'C100', 'C200', 'SL', 'SS', 'ALL']
  aap_det_list = ['P1', 'P2', 'P3', 'C100', 'C200', 'SL', 'SS', 'ALL']
  aar_det_list = ['P', 'C100', 'C200', 'SS', 'SL', 'MAP', 'ALL']
; the sys_aar_det_list is for system only
  sys_aar_det_list = [ $
		  'PP', 'PC', 'PC', 'PS', 'PL', 'PG', 'ALL']
  cla_det_list = ['P1', 'P2', 'P3', 'C100', 'C200', 'ALL']

; decode flag is to indicate if it is possible to decode the compact
; information for the measurement shown in the measurement panel
; 1 indicate it is okay to use, 0 otherwise
; it corresponds to the p_file_type
  decodeflag = [1, 1, 1, 1, 1, 1, 0, 0]

; the measurement parameter information
  mea_par = { $
	data_type: data_type, $; the data_type
	type_desc: type_desc, $; the data type description
	def_det_list: det_list, $ ; the default detectors list
	spd_det_list: spd_det_list, $ ; the SPD detectors list
	aap_det_list: aap_det_list,$ ; the AAP detector list
	aar_det_list: aar_det_list,$ ; the AAR detector list
	sys_aar_det_list: sys_aar_det_list,$ ; the system AAR detector list
	cla_det_list: cla_det_list,$ ; the Cal A detector list
	decodeflag: decodeflag $     ; flag for decoding the measurement
	}

; the mea_sel_par is the instance of the various selection
; note also that the instance of the detector list is stored
; in the uvalue of the detector widget handle
  IF buflev LE 3 THEN BEGIN
    detlev = WHERE(STRMID(det_list,0,2) EQ STRMID(!PIA_BUFINFO.det,0,2),nlev) 
    IF nlev EQ 0 THEN detlev = 0
    la_lista = det_list
  ENDIF ELSE IF buflev EQ 4 THEN BEGIN
    detlev = WHERE(STRMID(spd_det_list,0,2) EQ STRMID(!PIA_BUFINFO.det,0,2),nlev)
    IF nlev EQ 0 THEN detlev = 0
    la_lista = spd_det_list 
  ENDIF ELSE BEGIN
    detlev = WHERE(STRMID(aap_det_list,0,2) EQ STRMID(!PIA_BUFINFO.det,0,2),nlev)
    IF nlev EQ 0 THEN detlev = 0
    la_lista = aap_det_list
  ENDELSE 

  mea_sel_par = { $
	thedtype: data_type(buflev), $  ; the selected data type
	decodeflag: decodeflag(buflev), $	; flag to indicate how to decode mea
	thedet: la_lista(detlev), $	; the selected detector
	themea: '',$		; the selected measurement
	mlist_index: 0, $	; the index of the selected measurement
	mmlist_index: -1 $	; the index in the multiple panel
	}
	
  
  if n_elements(buflevel) gt 1 then begin
    tmp = buflevel.admn
    hdr = buflevel.hdr
    ind = where(strmid(tmp, 0, 2) EQ STRMID(det_chosen,0,2), matches)
    IF !PIA_BUFINFO.det EQ 'ALL' THEN BEGIN
      matches = N_ELEMENTS(tmp)-1	
      ind= INDGEN(matches)+1
    ENDIF


      if matches GT 0 then begin
	setmea = 1
	mealist = replicate({mea, index: 0, filename: '', decodename: '', $
		  uname: ''}, matches)

	for i = 0, matches-1 do begin
	  mealist(i).index = ind(i)
	  mealist(i).filename = tmp(ind(i))
          decode_tdt2mea, mealist(i).filename, strl
          decode_cs2mea, mealist(i).filename, strl1
          handle_value, hdr(ind(i)), tmphdr
          decode_hdr2mea, tmphdr, strl2, mname
          mealist(i).uname = mname
      
          mealist(i).decodename = strl +': ' + strl1 + ', ' + strl2 +', '+mname
	endfor

      endif
      nbuf = n_elements(buflevel) - 1
      msg = 'Measurements: (' + strtrim(string(nbuf),2) + $
	  ' measurements in the ' + mea_sel_par.thedtype+ ' buffer)'
  endif else msg = 'Measurements:                                     '

  mmlist = {mea, index: 0, filename: '', decodename: '', uname:''}

  mea_base = widget_base(base, /ROW, /FR)
  
  id_0 = widget_base(mea_base, /COLUMN)
  id_1 = widget_label(id_0, value = 'Data Type:')
  id.hmeatype = widget_list(id_0, value = data_type, $
    YS = 9)
  
  id_0 = widget_base(mea_base, /COLUMN)
  id_1 = widget_label(id_0, value = 'Detectors:')
  id.hmeadet = widget_list(id_0, value = la_lista, $
    YS = 9)
  
  id_0 = widget_base(mea_base, /COLUMN, XS=580)
  id.hmeainfo = widget_label(id_0, value = $
	strtrim(string(n_elements(mealist)), 2) + $
	' measurements' )
  if setmea EQ 1 then $
  id.hmealist = widget_list(id_0, XS = 55,  YS = 9, $
		val = mealist.decodename, $
		uval = mealist.filename) $
  else id.hmealist = widget_list(id_0, XS = 55,  YS = 9)

  id_0 = widget_base(base, /FR, /ROW)
  id.hmsgline = widget_TEXT(id_0, XS=120, YS=1, $
  	val='                                               ')

; store the detector list 
  widget_control, id.hmeadet, set_uvalue = la_lista
  
  ; initialize widget states
  widget_control, id.hmeatype, set_list_select = buflev(0)
  widget_control, id.hmeadet, set_list_select = detlev(0)
  widget_control, id.hsavefits, sensitive = 0
  widget_control, base, /realize, TLB_SET_YOFFSET=575
  
  xmanager, No_BLOCK=1, 'pia_man_mea', base, group=group
END
