;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_MANN
;
; PURPOSE:
;	Menu for mann stability parameters handling.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_MANN, tmpdata, pixel, GROUP=group 
;
; INPUT:
;	tmpdata: SRD level temporary structure
;	pixel:	 chosen pixel for testing
;
; KEYWORD PARAMETERS:
;	GROUP:	The group leader of the widget hirarchy
;	
; RESTRICTIONS:
;	TMPDATA must be a valid PHTSRD temporary structure
;	
; COMMON BLOCKS:
;	colour_indices
;		
; PROCEDURES USED:
;	PIA LIB:
;		decode_admn
;		mann
;       INTERNAL:
;		pia_mann_event
;
; MODIFICATION HISTORY:
;	Written by: C.Gabriel (ESA/VILSPA-SAI)		January 1996
;	Interval division logic changed  (CG)		February 1996
;	Interval division (special case) bug fixed (CG)	February 1996
;	Confidence level renamed to (1-confidence) (CG) May 1996
;	Use of bitflag system (CG)			April 2000
;	V8.2
;			
;-
; *********************************************************************
; *  Event routine for PIA_MANN
; *********************************************************************
PRO PIA_MANN_EVENT, event

COMMON pht_mann_st, conflvl, intdiv, minp, tmann_min
COMMON pia_mann_cmn, conflvl_id, intdiv_id, minp_id, tmpdata, pix_nr
COMMON pia_mann_cmn2, mint_id

@colour_indices
                                                                 
	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue OF

	'TEST': BEGIN
; Read the values from the widgets
		WIDGET_CONTROL, event.top, /HOURGLASS
		WIDGET_CONTROL, conflvl_id, GET_VALUE=s_conflvl
		WIDGET_CONTROL, intdiv_id, GET_VALUE=s_intdiv
		WIDGET_CONTROL, minp_id, GET_VALUE=s_minp
		WIDGET_CONTROL, mint_id, GET_VALUE=s_mint
		
		conflvl = FLOAT(1.-s_conflvl(0))
		intdiv = FIX(s_intdiv(0))
		minp = FIX(s_minp(0))
		tmann_min = FLOAT(s_mint(0))
		time = tmpdata.stim
		
		reti=0
		IF(conflvl GT 0.5 OR conflvl LT 0.01) THEN BEGIN
			WIDGET_CONTROL, conflvl_id, SET_VALUE='0.95'
			PRINT, '0.5 </= Confidence level </= 0.99, returning'
			RETI = 1
		ENDIF
		IF(intdiv GT 3 OR intdiv LT 1) THEN BEGIN
			WIDGET_CONTROL, intdiv_id, SET_VALUE='1'
			PRINT, '1 </= Interval Division </= 3, returning'
			RETI = 1
		ENDIF
		IF minp LT 4 THEN BEGIN
			WIDGET_CONTROL, minp_id, SET_VALUE='7'
			PRINT, 'Minimum of points >/= 4, returning'
			RETI = 1
		ENDIF


		IF reti THEN RETURN
		
		ipix = pix_nr
		get_rastersteps, tmpdata.rpid, raststeps
		get_rpchopstep, raststeps, tmpdata.step, rpchopstep

		get_sigdisc, tmpdata, /ENCODE_FLAG
		get_validflag, tmpdata.flag, 'SRD', sigflag, $
			  det=tmpdata.det, /allpix
		
		dum_aver = $
		  fltarr(N_ELEMENTS(tmpdata.slop(*,0)),max(rpchopstep))
		dum_avun = dum_aver
		dum_avsd = dum_aver		
		meas_mann, tmpdata, rpchopstep, sigflag, notexist, $
		   dum_aver, dum_avun, dum_avsd, pixel=pix_nr, mann_str 

                text = 'Stability analysis (mann method) Results: ' 

		stability = ['Completely stable ', $
			     'Partially stable  ', $
			     'Not stable  ', $
			     'No valid points  ',$
			     'Valid points < required']
		FOR i=1,max(rpchopstep) DO BEGIN

		  text = [text, $
		  	'Raster/Chopper point combination '+ STRTRIM(i,2), $
		  	'~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~',' ', $
			'Using trend confidence level= ' +s_conflvl(0), $
			'interval division = '+s_intdiv(0), $
			'minimum number of points = '+s_minp(0), $
			'minimum time = '+s_mint(0), '', $
			'Characterisation: ' + $
			 stability(mann_str.stabflag(ipix,i-1)), '', $
			'Number of points taken: ' +  $
			 STRTRIM(mann_str.tpoints(ipix,i-1),2), $
			'Average result: '+$
			 STRTRIM(mann_str.aver(ipix,i-1),2) + ' +/- ' + $
			 STRTRIM(mann_str.avun(ipix,i-1),2), $
			'Slope variation/minute:  ' + $
			 STRTRIM(mann_str.slopvar(ipix,i-1),2)+ $
			  	' [V/s/min]', ' ',' ']
			  	
		ENDFOR

		pia_disp_print_file, '', TITLE='Stability Analysis (mann)',$
			GROUP=event.top, TEXT=text
		
		decode_admn, tmpdata.admn, dec

		elpixel = STRTRIM(STRING(ipix+1),2)
		pia_xplot, time, tmpdata.slop(ipix,*), $
			tmpdata.slun(ipix,*), psym=4, $
			title='Stability Analysis: '+ dec, $
			xtitle='Time  [s]', ytitle='Signal   [V/s]', $
			legend='Pixel '+elpixel 

		 indnot = WHERE(sigflag(ipix,*) EQ 1, nnot)
		 IF nnot GT 0 THEN $ 
		  pia_xplot, time(indnot), tmpdata.slop(ipix,indnot), psym=7, $
			legend='Discarded points', color=red, /overplot

		
		 FOR i=1,max(rpchopstep) DO BEGIN
		  ind = WHERE(rpchopstep EQ i, nn) 
		  firstp = ind(0)
		  match, ind, indnot, suba, subb, count=match
		  IF match GT 0 THEN BEGIN 	
		   indnok=WHERE(suba GE (nn-mann_str.tpoints(ipix,i-1)),nk)
		   IF nk GT 0 THEN $
		    lastp = max(ind) - mann_str.tpoints(ipix,i-1) - nk ELSE $
		    lastp = max(ind) - mann_str.tpoints(ipix,i-1)
		  ENDIF ELSE lastp = max(ind) - mann_str.tpoints(ipix,i-1)
		  
		    
		  IF firstp LT lastp AND mann_str.stabflag(ipix,i-1) NE 0 THEN $		
		    pia_xplot, time(firstp:lastp), $
		    	tmpdata.slop(ipix,firstp:lastp), $
		  	psym=7, color=yellow, /overplot, $
		  	legend='Non-stability region points' 
		 ENDFOR

	END
	
	'DEF': BEGIN

		WIDGET_CONTROL, conflvl_id, set_VALUE=STRTRIM(0.95,2)
		WIDGET_CONTROL, intdiv_id, set_VALUE=STRTRIM(1,2)
		WIDGET_CONTROL, minp_id, set_VALUE=STRTRIM(7,2)
		WIDGET_CONTROL, mint_id, set_VALUE=STRTRIM(8.,2)
	
	END
	
	
	'DEFQUIT': BEGIN

		conflvl=0.05
		intdiv=1
		minp=7
		tmann_min = 8.

		WIDGET_CONTROL, event.top, /DESTROY
			
	END
	'QUIT': BEGIN
		WIDGET_CONTROL, conflvl_id, GET_VALUE=s_conflvl
		s_conflvl = 1. - s_conflvl(0)
		WIDGET_CONTROL, intdiv_id, GET_VALUE=s_intdiv
		WIDGET_CONTROL, minp_id, GET_VALUE=s_minp
		WIDGET_CONTROL, mint_id, GET_VALUE=s_mint
		
		conflvl = FLOAT(s_conflvl(0))
		intdiv = FIX(s_intdiv(0))
		minp = FIX(s_minp(0))
		tmann_min = FLOAT(s_mint(0))

 		IF(conflvl GT 0.5 OR conflvl LT 0.01) THEN BEGIN
			conflvl = 0.05
		  PRINT, '0.5 </= Confidence level </= 0.99, back to default'
 		ENDIF
		IF(intdiv GT 3 OR intdiv LT 1) THEN BEGIN
			intdiv = 1
			PRINT, '1 </= Interval Division </= 3, back to default'
 		ENDIF
		IF minp LT 4 THEN BEGIN
			minp = 7
			PRINT, 'Minimum of points >/= 4, back to default '
 		ENDIF
		WIDGET_CONTROL, event.top, /DESTROY
	END
	ELSE:
	
	ENDCASE
	
RETURN
END
; *********************************************************************
; *  Menu for PIA_MANN
; *********************************************************************
PRO PIA_MANN, tmp, pixel, GROUP=group 

COMMON pht_mann_st, conflvl, intdiv, minp, tmann_min
COMMON pia_mann_cmn, conflvl_id, intdiv_id, minp_id, tmpdata, pix_nr
COMMON pia_mann_cmn2, mint_id

	tmpdata = tmp
	pix_nr = pixel

	IF N_ELEMENTS(conflvl) EQ 0 THEN BEGIN
		conflvl=0.05
		intdiv = 1
		minp=7
		tmann_min = 8.
	ENDIF

	base = WIDGET_BASE(TITLE="PIA Stability Analisis ('mann')", /COLUMN)
	
	parbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(parbase, VALUE='Confidence level for a trend:')
	label = WIDGET_LABEL(parbase, VALUE='            ')
	conflvl_id = WIDGET_TEXT(parbase, /EDITABLE, VALUE=STRTRIM(1.-conflvl,2), $
		UVALUE='JUNK', XSIZE=8)
		
	parbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(parbase, $
		VALUE='Intervals divisions (1=1/2, 2=1/4, 3=1/8):')
	intdiv_id = WIDGET_TEXT(parbase, /EDITABLE, VALUE=STRTRIM(intdiv,2), $
		UVALUE='JUNK', XSIZE=8)
		
	
	parbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(parbase, VALUE='Minimum of points for algorithm:')
	label = WIDGET_LABEL(parbase, VALUE='         ')
	minp_id = WIDGET_TEXT(parbase, /EDITABLE, VALUE=STRTRIM(minp,2), $
		UVALUE='JUNK', XSIZE=8)
	
	parbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(parbase, VALUE='Minimum time for algorithm:')
	label = WIDGET_LABEL(parbase, VALUE='              ')
	mint_id = WIDGET_TEXT(parbase, /EDITABLE, VALUE=STRTRIM(tmann_min,2), $
		UVALUE='JUNK', XSIZE=8)
	cont_base = WIDGET_BASE(base, /ROW)
	
	test_id = WIDGET_BUTTON(cont_base, VALUE='OK, test them', UVALUE='TEST')
	
	def_id = WIDGET_BUTTON(cont_base, VALUE='Default Par', UVALUE='DEF')
	
	quit_id = WIDGET_BUTTON(cont_base, VALUE= 'Accept & Quit ', $
		UVALUE= 'QUIT')
	
	quit_id = WIDGET_BUTTON(cont_base, VALUE= 'Default & Quit', $
		UVALUE= 'DEFQUIT')

        WIDGET_CONTROL, base, /REALIZE, TLB_SET_XOFFSET=150, $
                        TLB_SET_YOFFSET=150

        xMANAGER,No_BLOCK=1, "pia_mann", base, GROUP=group
	
        RETURN
END
	
