;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_MAP_ROTATE
;
; PURPOSE:
;	Rotates a PHT PIA map by a given angle
;
; CATEGORY:
;	PIA - graphics/processing
;
; CALLING SEQUENCE:
;	PIA_MAP_ROTATE, imap, imappar, imaphdr
;
; INPUTS:
;	IMAP		The two dimensional map of the input image
;
;	IMAPPAR		The map parameter structure  as used in PIA
;
;	IMAPHDR		The header of the measurement
;
; KEYWORD PARAMETERS:
;	GROUP		The widget group leader
;
; OUTPUTS:
;	(none)
;
; PROCEDURES USED:
;	PIA Procedure(s):
;		pia_mapdraw
;		pia_mktrans
;	Internal:
;		pia_map_rotate_event
;
; COMMON BLOCKS:
;	PIA_map_rotate_cmn		internal
;
; MODIFICATION HISTORY:
;	Written by:		C. Gabriel, ESA/VILSPA		July 1996
;	Modified by CG						November 1996
;	V5.x
;	Different interpolation alternatives built in,
;	no pivot.   (CG)					April 1997
;	V6.2 
;	Bug for rotated saved maps fixed (CG)			February 1999
;	V7.4
;-
PRO PIA_MAP_ROTATE_EVENT, event


	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue of

	   'INTERPOL': BEGIN
		interpol = event.value 
	   	WIDGET_CONTROL, event.top, GET_UVALUE=hsave
		HANDLE_VALUE, hsave, save
		save.interpol = interpol
		HANDLE_VALUE, hsave, save, /SET, /NO_COPY
	   	WIDGET_CONTROL, event.top, SET_UVALUE=hsave
	   END
	   	 
	   
	   'OK': BEGIN

		WIDGET_CONTROL, event.top, /hourglass
	   	WIDGET_CONTROL, event.top, GET_UVALUE=hsave
		HANDLE_VALUE, hsave, save
		WIDGET_CONTROL, save.angle_id, GET_VALUE=rot_str
		rot_ang = FLOAT(rot_str(0))

		imappar = save.imappar
		imap = save.imap
		
		WIDGET_CONTROL, save.add_id, GET_VALUE=pixadd
		pixadd = FIX(pixadd(0))

;new
		sz = size(imap)
		nx = sz(1)
		ny = sz(2)
		newmap = fltarr(nx+2*pixadd,ny+2*pixadd)
		newmap(pixadd:nx+pixadd-1,pixadd:ny+pixadd-1) = imap
		imap = newmap
		imappar.trans.crpix = imappar.trans.crpix + [pixadd,pixadd]
;new
		trans = PIA_MKTRANS([imappar.trans_ra, imappar.trans_dec], $
			imappar.trans.crpix,  imappar.pixsize, rot_ang)
		

		CASE save.interpol of
                2: newmap = rot(imap, -imappar.rota + rot_ang, 1., $
                	trans.crpix(0),trans.crpix(1),/pivot, /cubic)
                ELSE: newmap = rot(imap, -imappar.rota + rot_ang, 1., $
                	trans.crpix(0),trans.crpix(1),/pivot, $
                	interp=save.interpol)
                ENDCASE
              		
		imappar.rota = rot_ang

 		posi = strpos(imappar.admn_decoded, 'micron')
		

 		 totlen = STRLEN(imappar.admn_decoded)
 		 headline = $
 		  STRMID(imappar.admn_decoded, 0, posi(0)+7) + $
 		  ' Rotated with ' + rot_str(0) + ' to RA-DEC'
 		 headline = headline(0)
 		 imappar.admn_decoded = headline
		 imappar.trans = trans
 		 pia_mapdraw, newmap, trans, imappar, $
 			save.imaphdr, 0, headline=headline, /NO_ROT

		 WIDGET_CONTROL, event.top, /DESTROY		 
 		 
 	  END
 	  
 	  'QUIT': WIDGET_CONTROL, event.top, /DESTROY
 	  
 	  ELSE:
 	  
 	ENDCASE
 	  
 	RETURN
 	END	
		
;;;;;;;;;;;;;;;               The menu routine      ;;;;;;;;;;;;;;;;;;;;;;	
	     

PRO PIA_MAP_ROTATE, imap, imappar, imaphdr


	interpol = 2
	
	base = WIDGET_BASE(TITLE="PIA map rotation menu", /COLUMN)
	
	parbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(parbase, $
		VALUE='Original (anti-clock) rotation angle to RA-DEC: ')
	rota = WIDGET_TEXT(parbase, VALUE=STRTRIM(STRING(imappar.rota),2), $
		UVALUE='JUNK', XSIZE=12)
		
	parbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(parbase, $
		VALUE='Desired Angle (degrees & clockwise)  to RA-DEC: ')
	angle_id = WIDGET_TEXT(parbase, /EDITABLE, VALUE = ' 0. ', XSIZE=12, $
		UVALUE='JUNK')
	
	parbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(parbase, $
		VALUE='Add zero rows (each side) previous to rotation: ')
	add_id = WIDGET_TEXT(parbase, /EDITABLE, VALUE = ' 4 ', XSIZE=12, $
		UVALUE='JUNK')
	
	stdbut = cw_bgroup(base, LABEL_TOP = 'Interpolation', $
			/EXCLUSIVE, /FRAME, COLUMN=3, $
			SET_VALUE = 2, $
			UVALUE = 'INTERPOL', $
			["None  ", $
			 "Simple ", "Cubic " ])
	
	
	cont_base = WIDGET_BASE(base, /ROW)
	
	test_id = WIDGET_BUTTON(cont_base, VALUE='   OK  ', UVALUE='OK')
	
	quit_id = WIDGET_BUTTON(cont_base, VALUE= '   Quit  ', $
		UVALUE= 'QUIT')


;new
;	sz = size(imap)
;	nx = sz(1)
;	ny = sz(2)
;	newmap = fltarr(nx+8,ny+8)
;	newmap(4:nx+3,4:ny+3) = imap
;	imap = newmap
;	print, imappar.trans.crpix
;	imappar.trans.crpix = imappar.trans.crpix + [4,4]
;new
	save = {imap:imap, imappar:imappar, imaphdr:imaphdr, $
		angle_id:angle_id, add_id:add_id, interpol:interpol}
	
	hsave = HANDLE_CREATE()
	HANDLE_VALUE, hsave, save, /SET, /NO_COPY

        WIDGET_CONTROL, base, /REALIZE, TLB_SET_XOFFSET=150, $
                        TLB_SET_YOFFSET=150, SET_UVALUE=hsave

        xMANAGER,No_BLOCK=1, "pia_map_rotate", base, GROUP=group
	
        RETURN
END
	
