;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_MAPDEF
;
; PURPOSE:
;	Define a default grid size of a map
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	PIA_MAPDEF, detector, pixsize
;
; INPUTS:
;	PAR		The map obs. structure containing at least:
;	 par.DETECTOR	  'P1', 'P2', 'P3', 'C1', 'C2', 'SS', 'SL'
;	 par.APER	  Aperture position (meaningful only for PHT-P)
;	 par.DPTS	  The raster step size in Y raster direction
;	 par.DLNS	  The raster step size in Z raster direction
;	 par.AOTN	  AOT name
;
;
; KEYWORD PARAMETERS:
;	(none)
;
; OUTPUTS:
;	PIXSIZE		The pixel size of the resulting map grid in arcsec
;			(0) = in spacecraft y-direction
;			(1) = in spacecraft z-direction
;
; MODIFICATION HISTORY:
;	Written by:	D. Skaley, MPIK/Heidelberg	March 1995
;	Modified by:	C. Gabriel (ESA/VILSPA)		October 1995
;	Oct 95 Version 3.5
;	Maps default pixsizes changed (CG)		April 1996
;	V6.2 
;	Change in input (using structure par) + 
;	 full refinement of default map size (CG)	September 1998
;	V7.3
;	Preventing from pixsize=0. for scan case (CG)	February 1999
;	V7.4
;-

	PRO PIA_MAPDEF, par, pixsize
; common block for aperture constants
@piacmn_pow2fb

; load the aperture constants into common block (if not yet done)

	IF N_ELEMENTS( aper_r ) EQ 0 THEN PIA_DEFAPER
	
	aper = aper_r(0:1,par.aper) * !RADEG * 3600.
	IF aper(1) EQ 0. THEN aper(1)=aper(0)
	

	CASE STRMID(par.detector,0,1) OF
	'P':	BEGIN
		  sidex = MIN([aper(0),par.dpts])
		  sidey = MIN([aper(1),par.dlns])
		  IF sidex EQ 0. THEN sidex = aper(0)
		  IF sidey EQ 0. THEN sidey = aper(1)
		  pixsize = [ sidex, sidey ]
		  
	END
	'C':	BEGIN
		IF par.detector EQ 'C1' THEN BEGIN
			IF par.aotn EQ 'P32' THEN sidex=15. ELSE BEGIN
			   sidex = MIN([46.,par.dpts])
			   IF par.dpts EQ 69. THEN sidex=23.
			ENDELSE
			sidey = MIN([46.,par.dlns])
			IF par.dlns EQ 69. THEN sidey=23.
		        IF sidex EQ 0. THEN sidex = 46.
			IF sidey EQ 0. THEN sidey = 46.
		ENDIF ELSE BEGIN
			IF par.aotn EQ 'P32' THEN sidex=30. ELSE $
			   sidex = MIN([92.,par.dpts])
		        sidey = MIN([92.,par.dlns])
		        IF sidex EQ 0. THEN sidex = 92.
			IF sidey EQ 0. THEN sidey = 92.
		ENDELSE

		pixsize = [sidex,sidey]
	END
	'S':		pixsize = [ 24.0, 24.0]	
	ELSE:	MESSAGE, "Wrong detector"
	ENDCASE

	RETURN
	END
