;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;     PIA_MULT_RP_CHOICE
;
; PURPOSE:
;       Graphical I/F for choosing raster point, chopper position
;		and mode for using the combination
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_MULT_RP_CHOP, RP_MAX, STEP_MAX, CHOP_MAX, rpc_CHOICE
;
; INPUTS:
;	RP_MAX:	   A maximal value ISO raster point [byte or intarr(2)] 
;			(informative)
;	STEP_MAX:  Maximal value for chopperstep (informative)
;	CHOP_MAX:  Maximal value for chopper plateau (informative)
;
;
; OUTPUTS:
;	rpc_CHOICE:	The choice in a structure, see EXAMPLE
;
; EXAMPLE:
;	Measurement with a 3x4 raster, chopped rectangular with 
;	a total of 32 chopper plateaux
; 
;	The corresponding call should be:
;		PIA_MULT_RP_CHOP, [3,4], 2, 32, rp
;	The widget ask for raster position and chopper step or absolute 
;	chopper plateau. If raster [2,3] and absolute ch-plateau 20 chosen:
;	    
;			   rp.rpid_chosen: [2B,3B]
;			   rp.chop_chosen: [0,20]
;
;	In case of chopper step 2 the last would be
;			   rp.chop_chosen: [1,2]
;			
;
;
;
; MODIFICATION HISTORY:
;       Written by:	Carlos GABRIEL (ESA/VILSPA-SAI)		February 1997
;	V6.1
;-
PRO PIA_MULT_RP_CHOP, RP_MAX, STEP_MAX, CHOP_MAX, rpc_CHOICE

	rpids = FIX(rp_max)
	base0 = WIDGET_BASE(TITLE = 'PIA Raster Point / Chopper Choice Menu', $ 
		 		/COLUMN)
		 	

	baserp = WIDGET_BASE(base0, /COLUMN, /FRAME)
        label = WIDGET_LABEL(baserp, VALUE='Choose the RPID to be plotted')
	label = WIDGET_LABEL(baserp, VALUE='   ')
	pbase = WIDGET_BASE(baserp, /row)
	label = WIDGET_LABEL(pbase, VALUE='From '+STRTRIM(STRING(rpids(0)),2)+$
					' points per raster ')
	points_id = WIDGET_TEXT(pbase, /editable, VALUE='1', UVALUE='JUNK')

	label = WIDGET_LABEL(baserp, VALUE='   ')

	rbase = WIDGET_BASE(baserp, /row)
	label = WIDGET_LABEL(rbase, VALUE='and '+STRTRIM(STRING(rpids(1)),2)+$
					' raster lines       ')
	raster_id = WIDGET_TEXT(rbase, /editable, VALUE='1', UVALUE='JUNK')

	base = WIDGET_BASE(base0, /COLUMN, /FRAME)
	ch_choice_wid = cw_bgroup(base, LABEL_TOP = 'Chopper Choices', $
			/EXCLUSIVE, /FRAME, $
			SET_VALUE = 0, $
			UVALUE = 'CHOICE', $
			["Average of Chopper Step",$
			 "Single Chopper Plateau "])

	stbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(stbase, $
		VALUE='From '+STRTRIM(step_max,2)+ ' steps:           ')
	chop_avg_id = WIDGET_TEXT(stbase, /editable, VALUE='1', UVALUE='Junk')
	
	totbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(totbase, $
		VALUE='From '+STRTRIM(chop_max,2)+ ' chopper plateux: ')
	chop_tot_id = WIDGET_TEXT(totbase, /editable, VALUE='1', UVALUE='Junk')
	
	WIDGET_CONTROL, totbase, sensitive=0

	ok_id = WIDGET_BUTTON(base0, VALUE=' OK ', UVALUE='OK')
	
	WIDGET_CONTROL, base0, /REALIZE


	ok = 0
	ch_avg=1 & ch_tot=0
	
	WHILE ok EQ 0 DO BEGIN
	  event = WIDGET_EVENT(BASE0)
	  WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	  CASE UVALUE OF
	  
	  'CHOICE': BEGIN
	     WIDGET_CONTROL, event.id, GET_VALUE=value
	     IF value(0) EQ 0 THEN BEGIN
		WIDGET_CONTROL, totbase, sensitive=0
		WIDGET_CONTROL, stbase, sensitive=1
		WIDGET_CONTROL, baserp, sensitive=1
		ch_avg=1 & ch_tot=0
	      ENDIF ELSE BEGIN
		WIDGET_CONTROL, totbase, sensitive=1
		WIDGET_CONTROL, stbase, sensitive=0
		WIDGET_CONTROL, baserp, sensitive=0
		ch_avg=0 & ch_tot=1
	      ENDELSE
	  END

	  'OK': BEGIN
	     WIDGET_CONTROL, points_id, GET_VALUE=point
	     point = BYTE(FIX(point(0)))
	     WIDGET_CONTROL, raster_id, GET_VALUE=line
	     line = BYTE(FIX(line(0)))
	     WIDGET_CONTROL, chop_tot_id, GET_VALUE=chop_tot
	     chop_tot = FIX(chop_tot(0))
	     WIDGET_CONTROL, chop_avg_id, GET_VALUE=chop_avg
	     chop_avg = FIX(chop_avg(0))
  	     ok = 1
	  END		      
	       
	  ELSE:
	  ENDCASE
	ENDWHILE
	
		
	rpid_chosen = [point,line]
	chop_chosen = [chop_avg*ch_avg, chop_tot*ch_tot]

	rpc_choice = {rpid_chosen:rpid_chosen, chop_chosen:chop_chosen}	
	WIDGET_CONTROL, base0, /DESTROY

        RETURN
END
	
