;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_MULTCHOICE
;
; PURPOSE:
;	Simple Menu for getting one element from a list
;
; CATEGORY:
;
; CALLING SEQUENCE:
;	PIA_multchoice, list, ELEMNAMES = elemnames 
;
; INPUTS:
;	LIST:
;		An array of elements to choose from	
;	
; KEYWORD PARAMETERS:
;	ELEMNAMES
;		A string array containing the elements names
;	
; OUTPUT:
;	LIST:
;		The index of the chosen element within the input LIST
;	
; MODIFICATION HISTORY:
;	Written by C.Gabriel (ESA/ESTEC-SAI)		March 1995
;	Oct 95 Version 3.5
;       Include xsize as optional keyword (Jacosta)     April 1996
;	Modal and group keywords added (CG)		January 1998
;	V7.3	
;-

; ****************************************************************************
;  PIA_multchoice - menu definition procedure
; ****************************************************************************

PRO pia_multchoice, list, ELEMNAMES = elemnames, XSIZE=xsize, modal=modal, $
	group=group


	IF KEYWORD_SET(ELEMNAMES) THEN elements = ELEMNAMES else $
			elements = STRING(INDGEN(N_ELEMENTS(list))+1)

	IF NOT KEYWORD_SET(xsize) then xsize = 600

        junkbase = WIDGET_BASE(TITLE=$
          'Several elements to choose from', /COLUMN,XSIZE=xsize, $
	  group=group, modal=modal)

	declist = elements

	IF N_ELEMENTS(declist) LT 25 THEN YSIZE = MAX([N_ELEMENTS(declist),5])$
	    ELSE ysize = 25

        lis = WIDGET_LIST(junkbase, VALUE=declist, $
                                UVALUE='LIST', YSIZE=ysize)
        WIDGET_CONTROL, junkbase, /REALIZE


	event = WIDGET_EVENT(junkbase)

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	list = event.index

	WIDGET_CONTROL, junkbase, /DESTROY

        RETURN
END

