;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_MULTI_AAP
;
; PURPOSE:
;	Extract several measurements variables from phtaap accomodating them 
;	in a new structure for further processing
;
; CATEGORY:
;	PIA I/O + processing
;
; CALLING SEQUENCE:
;	PIA_MULTI_AAP
;
; INPUTS:
;	index:	the indices within phtaap from which the variables have to 
;		be extracted
;
; OUTPUTS:
;	mult_aap_str: structure containing (reduced) variables
;
; COMMON BLOCKS:
;	phtaap
;	phtfilter
;	phtapertures
;
; SIDE EFFECTS:
;	The variables in the phtapertures & phtfilter common blocks are 
;	initialised
;
; PROCEDURES USED:
;	PIA LIB:
;		phtfilter_init
;		aperture_size_init
;		pia_load_iaap
;		weight_mean
;
; MODIFICATION HISTORY:
;	Written by:	Carlos GABRIEL (ESA/VILSPA-SAI)		January 1996
;	Modified (last) by CG 					December 1996
;	V5.4
;	Full PSF used for C100/C200 arrays			January 1997
;	V6.0	
;	Using phtapert now (CG)					February 1998
;	V7.0
;	Hardcoding of nominal apertures (CG)			February 1998
;	Bug in calculation for not chosen pixels fixed (CG)	February 1998
;	V7.1
;	Use of coded bitflag system (CG)			May 1999
;	V7.4 
;	Bugs fixed for brightness calculations - using
;	individual brightnesses instead of fluxes !! (CG)	November 1999
;	V8.2		
;	Signal added to mult_aap_str (CG)			May 2002
;	V10.0
;-
PRO PIA_MULTI_AAP, index, mult_aap_str, C1_pixel=C1_pixel, C2_pixel=C2_pixel

@phtaap
@phtpolar
@phtfilter
@phtapert
@phtppsf
aper_corfac = [ $
[1.00,1.00,1.00,1.00,0.00,1.00,0.00,1.00,1.00,1.00,1.00,1.00,0.00,1.00],$
[1.00,1.00,1.00,1.00,0.00,1.00,0.00,1.00,1.00,1.00,1.00,1.00,0.00,1.00],$
[1.00,1.00,1.00,1.00,0.00,1.00,0.00,1.00,1.00,1.00,1.00,1.00,0.00,1.00],$
[0.50,0.50,0.65,0.80,0.00,1.00,0.00,0.50,0.50,0.50,0.50,0.50,0.00,0.50],$ 
[1.00,1.00,1.00,1.00,0.00,1.00,0.00,1.00,1.00,1.00,1.00,1.00,0.00,1.00],$
[0.40,0.40,0.50,0.65,0.00,1.00,0.00,0.40,0.40,0.40,0.40,0.40,0.00,0.40],$
[1.00,1.00,1.00,1.00,0.00,1.00,0.00,1.00,1.00,1.00,1.00,1.00,0.00,1.00],$
[1.00,1.00,1.00,1.00,0.00,1.00,0.00,1.00,1.00,1.00,1.00,1.00,0.00,1.00],$
[0.35,0.57,0.63,0.72,0.00,1.00,0.00,0.35,0.35,0.35,0.35,0.35,0.00,0.35],$
[0.62,0.68,0.70,0.78,0.00,1.00,0.00,0.90,0.90,0.90,0.75,0.75,0.00,0.80],$
[1.00,1.08,1.01,1.00,0.00,1.00,0.00,0.40,0.40,0.40,0.40,0.40,0.00,0.65],$
[0.48,0.82,0.91,0.97,0.00,1.00,0.00,0.45,0.45,0.45,0.45,0.45,0.00,0.45],$
[2.30,1.75,1.17,1.08,0.00,1.00,0.00,0.30,0.30,0.30,0.30,0.40,0.00,0.40],$
[1.00,1.00,1.00,1.00,0.00,1.00,0.00,1.00,1.00,1.00,1.00,1.00,0.00,1.00] ] 

	
	IF N_ELEMENTS(c1filters) EQ 0 THEN phtfilter_init
	IF N_ELEMENTS(p_area) EQ 0 THEN read_omega
	IF N_ELEMENTS(phtppsf) EQ 0 THEN read_ppsf
	
        AP_AS = [ '52', '79', '99', '120', '127', '180', '180',   $
                     '5', '7.6', '10.0', '13.8', '18', '20', '23' ] + ' "'
                 
	mult_aap_str = {admn:'', filt_id:'', apert_id:'', polar_id:'', $
			area:0., lambda:0., poldeg:-1, $
			mnfl:0., mnfu:0., mnbr:0., mnbu:0., mdfl:0., q1fl:0.,$
			q3fl:0., mdbr:0., q1br:0., q3br:0., ra:0., dec:0.,$
			roll:0., flag:0., sign:0., usig:0., ppsf:0., corfac:0.}
	mult_aap_str = replicate(mult_aap_str, n_elements(index))


	FOR I=0,N_ELEMENTS(index) - 1 DO BEGIN
		pia_load_iaap, phtaap(index(i)), tmpaap
		signal = FXPAR(tmpaap.hdr, 'PRC_SIGN', count=count)
		usignal = FXPAR(tmpaap.hdr, 'PRC_USIG', count=ucount)
		IF count EQ 0 THEN signal=-1.
		IF ucount EQ 0 THEN usignal=-1.
		CASE STRMID(tmpaap.admn,0,2) OF
		   'P1': BEGIN
			filt_id = p1filters(tmpaap.filt - 1)			
			lambda = tmpaap.cwvl
			aper = tmpaap.aper - 1
			apert_id = ap_as(aper)
			area = p_area(aper,0)
			polar_id = phtpolar(tmpaap.polz - 1)
			poldeg = phtpoldeg(tmpaap.polz - 1) 
			pixels = 1
			ppsf = phtppsf(aper, tmpaap.filt-1)
			corfac = aper_corfac(aper, tmpaap.filt-1)
		         END
		   'P2': BEGIN
			filt_id = p2filters(tmpaap.filt - 11)			
			lambda = tmpaap.cwvl
			aper = tmpaap.aper - 1
			apert_id = ap_as(aper)
			area = p_area(aper,0)
			polar_id = phtpolar(tmpaap.polz - 1)
			poldeg = phtpoldeg(tmpaap.polz - 1) 
			pixels = 1
			ppsf = phtppsf(aper, tmpaap.filt-1)
			corfac = aper_corfac(aper, tmpaap.filt-1)
		         END
		   'P3': BEGIN
			filt_id = p3filters(tmpaap.filt - 13)			
			lambda = tmpaap.cwvl
			aper = tmpaap.aper - 1
			apert_id = ap_as(aper)
			area = p_area(aper,0)
			polar_id = phtpolar(tmpaap.polz - 1)
			poldeg = phtpoldeg(tmpaap.polz - 1) 
			pixels = 1
			ppsf = phtppsf(aper, tmpaap.filt-1)
			corfac = aper_corfac(aper, tmpaap.filt-1)
		         END
		   'C1': BEGIN
			filt_id = c1filters(tmpaap.filt - 2)			
			lambda = tmpaap.cwvl
			apert_id = 'unique'
			area = 36.
			polar_id = phtpolar(tmpaap.polz - 11)
			poldeg = phtpoldeg(tmpaap.polz - 11)
			pixels = 9 
			IF KEYWORD_SET(C1_pixel) THEN pixch = C1_pixel ELSE $
			pixch=[0,1,2,3,4,5,6,7,8]
			ppsf = phtppsf(14,tmpaap.filt-1)
			IF N_ELEMENTS(pixch) EQ 1 THEN $
				ppsf = phtppsf(15,tmpaap.filt-1)
			corfac=-1.
		   END
		   'C2': BEGIN
			filt_id = c2filters(tmpaap.filt - 9)			
			lambda = tmpaap.cwvl
			apert_id = 'unique'
			area = 64.
			polar_id = phtpolar(tmpaap.polz - 11)
			poldeg = phtpoldeg(tmpaap.polz - 11) 
			pixels = 4
			ppsf = phtppsf(14,tmpaap.filt-1)
			IF KEYWORD_SET(C2_pixel) THEN pixch = C2_pixel ELSE $
			pixch=[0,1,2,3]
			corfac=-1.
		         END
		   ELSE: GOTO, jump_over
		ENDCASE		

		smnfl = 0.
		smnfu = 0.
		smnfl_corner = 0.
		smnfu_corner = 0.
		smnfl_rand = 0.
		smnfu_rand = 0.
		n_corner = 0
		n_rand = 0
		smnbr = 0.
		smnbu = 0.
		smdfl = 0.
		sq1fl = 0.
		sq3fl = 0.
		smdbr = 0.
		sq1br = 0.
		sq3br = 0.

		IF pixels GT 1 THEN BEGIN

		 n_taken = 0
		 FOR ipix=0,pixels-1 DO BEGIN

		  ind = WHERE(pixch EQ ipix, nacc)
		  
		  IF nacc GT 0 THEN BEGIN
		   get_validflag, tmpaap.flag, 'AAP', redflag, det=tmpaap.det
		   
		   siz = size(tmpaap.flag)
		   IF siz(0) EQ 1 THEN BEGIN 
		     mnfl = tmpaap.mnfl(ipix)
		     mnfu = tmpaap.mnfu(ipix)
		     mnbr = tmpaap.mnbr(ipix)
		     mnbu = tmpaap.mnbu(ipix)
		     flag = redflag(ipix) * 2 
		     mdfl = tmpaap.mdfl(ipix)
		     q1fl = tmpaap.q1fl(ipix)
		     q3fl = tmpaap.q3fl(ipix)
	             mdbr = tmpaap.mdbr(ipix)
		     q1br = tmpaap.q1br(ipix)
		     q3br = tmpaap.q3br(ipix)
		   ENDIF ELSE BEGIN
		    
		    indok = WHERE(redflag(ipix,*) EQ 0., n)
		    IF n EQ 0 THEN BEGIN
			indok = WHERE(redflag(ipix,*) LT 1000.)
			flag = 2
		    ENDIF ELSE flag=0
			  
		  
		    weight_mean, tmpaap.mnfl(ipix,indok), $
			tmpaap.mnfu(ipix,indok), mnfl, mnfu		
		    weight_mean, tmpaap.mnbr(ipix,indok), $
			tmpaap.mnbu(ipix,indok), mnbr, mnbu		

		    IF N_ELEMENTS(tmpaap.mdfl(ipix,indok)) GT 1 THEN BEGIN
			mdfl = median(tmpaap.mdfl(ipix,indok))
			q1fl = median(tmpaap.q1fl(ipix,indok))
			q3fl = median(tmpaap.q3fl(ipix,indok))
			mdbr = median(tmpaap.mdbr(ipix,indok))
			q1br = median(tmpaap.q1br(ipix,indok))
			q3br = median(tmpaap.q3br(ipix,indok))
		    ENDIF ELSE BEGIN
			mdfl = tmpaap.mdfl(ipix,indok)
			q1fl = tmpaap.q1fl(ipix,indok)
			q3fl = tmpaap.q3fl(ipix,indok)
			mdbr = tmpaap.mdbr(ipix,indok)
			q1br = tmpaap.q1br(ipix,indok)
			q3br = tmpaap.q3br(ipix,indok)
		    ENDELSE
		   ENDELSE
; integrate over the pixels - Use full PSF now (V6.0) and 
; take into account the full solid angle afterwards

		   smnfl = smnfl + mnfl
		   smnfu = SQRT(smnfu^2 + mnfu^2)
		   smnbr = smnbr + mnbr 
		   smnbu = SQRT(smnbu^2 + mnbu^2)
		   smdfl = smdfl + mdfl
		   sq1fl = sq1fl + q1fl
		   sq3fl = sq3fl + q3fl
		   smdbr = smdbr + mdbr
		   sq1br = sq1br + q1br
		   sq3br = sq3br + q3br
		   n_taken = n_taken + 1

; used for normalizing deselected pixels
		   IF tmpaap.det EQ 'C1' THEN BEGIN
		     IF (ipix mod 2) EQ 0 AND ipix NE 4 THEN BEGIN
		         smnfl_corner = smnfl_corner + mnfl 
		   	 smnfu_corner = SQRT(smnfu_corner^2 + mnfu^2)
		   	 n_corner = n_corner+1
		     ENDIF
		         
		     IF (ipix mod 2) EQ 1 THEN BEGIN 
		         smnfl_rand = smnfl_rand + mnfl 
		   	 smnfu_rand = SQRT(smnfu_rand^2 + mnfu^2)
		   	 n_rand = n_rand+1
		     ENDIF
		   ENDIF

		  ENDIF
		 ENDFOR
; PSF correction for full array 
		 IF n_taken LT pixels THEN BEGIN 		 
		  IF n_taken NE 1 THEN BEGIN
		   PRINT, 'Array not complete: trying to normalize to full array'
		   allpix = indgen(pixels)
		   pix_missed = -1
		   FOR ip=0,pixels-1 DO BEGIN
		     mis = WHERE(pixch EQ allpix(ip), count)
		     IF count EQ 0 THEN pix_missed=[pix_missed,ip]
		   ENDFOR
		   IF tmpaap.det EQ 'C1' THEN BEGIN
		     corner_pix = [0,2,6,8]
		     rand_pix = [1,3,5,7]
		     mid_pix = 4
		     FOR Imis=1,N_ELEMENTS(pix_missed)-1 DO BEGIN
		       ind = WHERE(corner_pix EQ pix_missed(imis), count)
		       IF count EQ 1 THEN BEGIN
		         smnfl = smnfl + smnfl_corner / n_corner
		         smnfu = SQRT(smnfu^2 + (smnfu_corner/n_corner)^2)
		       ENDIF
		       ind = WHERE(rand_pix EQ pix_missed(imis), count)
		       IF count EQ 1 THEN BEGIN
		         smnfl = smnfl + smnfl_rand / n_rand
		         smnfu = SQRT(smnfu^2 + (smnfu_rand/n_rand)^2)
		       ENDIF
		     ENDFOR
		   ENDIF ELSE BEGIN
		     smnfl = smnfl + smnfl/n_taken * (4-n_taken)
		     smnfu = SQRT(smnfu^2 + ((smnfu/n_taken)^2)*(4-n_taken)) 
		   ENDELSE
		 ENDIF ELSE PRINT, 'Using only central pixel & corresponding PSF'   
		ENDIF
		   
		 smnfl = smnfl / ppsf
		 smnfu = smnfu / ppsf
		 
; Normalize the solid angle
		 smnbr = smnbr / n_taken
		 smdbr = smdbr / n_taken
		 sq1br = sq1br / n_taken
		 sq3br = sq3br / n_taken
		 smnbu = smnbu / n_taken
		 
;		 get_validflag, tmpaap.flag, 'AAP', redflag, det=tmpaap.det
;		    
;		 indok = WHERE(redflag(ipix,*) EQ 0., n)
;		 IF n EQ 0 THEN BEGIN
;			indok = WHERE(redflag(ipix,*) LT 1000.)
;			flag = 2
;			MESSAGE, /INFO, $
;		  'Warning, no valid points present, continuing using bad data'
;		 ENDIF ELSE flag=0
			  
		 ra = tmpaap.ra(0)
		 dec = tmpaap.dec(0)
		 roll = tmpaap.roll(0)

		ENDIF ELSE BEGIN

		 get_validflag, tmpaap.flag, 'AAP', redflag, det=tmpaap.det

		 siz = size(tmpaap.flag)
		 ipix = 0
		 IF siz(0) EQ 1 THEN BEGIN 
		     smnfl = tmpaap.mnfl(ipix)
		     smnfu = tmpaap.mnfu(ipix)
		     smnbr = tmpaap.mnbr(ipix)
		     smnbu = tmpaap.mnbu(ipix)
		     flag = redflag(ipix) * 2 
		     smdfl = tmpaap.mdfl(ipix)
		     sq1fl = tmpaap.q1fl(ipix)
		     sq3fl = tmpaap.q3fl(ipix)
	             smdbr = tmpaap.mdbr(ipix)
		     sq1br = tmpaap.q1br(ipix)
		     sq3br = tmpaap.q3br(ipix)
		     ra = tmpaap.ra(ipix)
		     dec = tmpaap.dec(ipix)
		     roll = tmpaap.roll(ipix)
		 ENDIF ELSE BEGIN
		    
		  indok = WHERE(redflag(ipix,*) EQ 0., n)
		  IF n EQ 0 THEN BEGIN
			indok = WHERE(redflag(ipix,*) LT 1000.)
			flag = 2
			MESSAGE, /INFO, $
		  'Warning, no valid points present, continuing using bad data'
		  ENDIF ELSE flag=0

		 weight_mean, tmpaap.mnfl(indok), tmpaap.mnfu(indok), $
		 		smnfl, smnfu		
		 weight_mean, tmpaap.mnbr(indok), tmpaap.mnbu(indok), $
		 		smnbr, smnbu		
		 IF N_ELEMENTS(tmpaap.mdfl(indok)) GT 1 THEN BEGIN
			smdfl = median(tmpaap.mdfl(indok))
			sq1fl = median(tmpaap.q1fl(indok))
			sq3fl = median(tmpaap.q3fl(indok))
			smdbr = median(tmpaap.mdbr(indok))
			sq1br = median(tmpaap.q1br(indok))
			sq3br = median(tmpaap.q3br(indok))
			ra = median(tmpaap.ra(indok))
			dec = median(tmpaap.dec(indok))
			roll = median(tmpaap.roll(indok))
		  ENDIF ELSE BEGIN
			smdfl = tmpaap.mdfl(indok)
			sq1fl = tmpaap.q1fl(indok)
			sq3fl = tmpaap.q3fl(indok)
			smdbr = tmpaap.mdbr(indok)
			sq1br = tmpaap.q1br(indok)
			sq3br = tmpaap.q3br(indok)
			ra = tmpaap.ra(indok)
			dec = tmpaap.dec(indok)
			roll = tmpaap.roll(indok)
		  ENDELSE
		 ENDELSE
		ENDELSE
		mult_aap_str(I).admn = tmpaap.admn
		mult_aap_str(I).filt_id = filt_id
		mult_aap_str(I).lambda = lambda
		mult_aap_str(I).apert_id = apert_id
		mult_aap_str(I).area = area
		mult_aap_str(I).polar_id = polar_id
		mult_aap_str(I).poldeg = poldeg
		mult_aap_str(I).mnfl = smnfl
		mult_aap_str(I).mnfu = smnfu
		mult_aap_str(I).mnbr = smnbr
		mult_aap_str(I).mnbu = smnbu
		mult_aap_str(I).mdfl = smdfl
		mult_aap_str(I).q1fl = sq1fl
		mult_aap_str(I).q3fl = sq3fl
		mult_aap_str(I).mdbr = smdbr
		mult_aap_str(I).q1br = sq1br
		mult_aap_str(I).q3br = sq3br
		mult_aap_str(I).ra = ra
		mult_aap_str(I).dec = dec 
		mult_aap_str(I).roll = roll
		mult_aap_str(I).flag = flag
		mult_aap_str(I).sign = signal
		mult_aap_str(I).usig = usignal
		mult_aap_str(I).ppsf = ppsf
		mult_aap_str(I).corfac = corfac
		
jump_over:
	ENDFOR

RETURN
END
