;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_MULTMEAS
;
; PURPOSE:
;	Simple Menu for getting one measurement from a list of measurements
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_multmeas, measlist
;
; INPUTS:
;	measlist:
;		The list of measurements to choose from	
;
; KEYWORD PARAMETERS:
;	none
;	
; OUTPUT:
;	measlist:
;		The index of the chosen measurement
;	
; METHOD:
;	Widgets
;
; PROCEDURES USED:
;	PIA Procedure(s):
;		decode_admn
;
; COMMON BLOCKS:
;	none
;	
; MODIFICATION HISTORY:
;	Written by:	C.Gabriel (ESA/ESTEC)		October 1994
;	Modified by:	CG				December 1994
;	Oct 95 Version 3.5
;-

; ****************************************************************************
;  PIA_multmeas - menu definition procedure
; ****************************************************************************

PRO pia_multmeas, measlist


        junkbase = WIDGET_BASE(TITLE=$
          'Several measurements with same name - Choose', /COLUMN,XSIZE=600)

	declist = measlist

	FOR I=0,N_ELEMENTS(measlist)-1 DO BEGIN 
		decode_admn, measlist(i), deco
	        declist(i) = deco
	ENDFOR

        list = WIDGET_LIST(junkbase, VALUE=declist, $
                                UVALUE='LIST', YSIZE=5)
        WIDGET_CONTROL, junkbase, /REALIZE


	event = WIDGET_EVENT(junkbase)

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	measlist = event.index

	WIDGET_CONTROL, junkbase, /DESTROY

        RETURN
END

