;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_MULTMEAS_CHOICE
;
; PURPOSE:
;	Menu for choosing several measurements from the dynamical structures
;	phterd, phtsrd, phtscp, phtspd and phtaap
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_MULTMEAS_CHOICE, level, indices
;
; INPUTS:
;	LEVEL:	the pht type level, from which to choose
;
; OUTPUTS:
;	INDICES: The indices of the chosen measurements within the level
; OPT. OUTPUT:
;	status: character flag, '0' for fail and '1' for sucess
;	
; KEYWORD PARAMETERS:
;	(none)
;		
; PROCEDURES USED:
;	PIA LIB:
;		pickmeas
;		pia_multmeas
;
; COMMON BLOCKS:
;	phterd
;	phtsrd
;	phtscp
;	phtspd
;	phtaap
;	
; MODIFICATION HISTORY:
;	Written by C.Gabriel (ESA/VILSPA-SAI)		January 1996
;	Returning indices=0 & message if cancelled (CG)	January 1996
;	status flag added (WMT)			        March 1996
;	Using new pickmeas and pickmeas_results-CB (CG)	May 1997
;	V6.3
;			
;-
PRO PIA_MULTMEAS_CHOICE, level, indices, status = status

	on_error, 2

@phterd
@phtsrd
@phtscp
@phtscp
@phtspd
@phtaap
COMMON pickmeas_results, pickmeas_res

	CASE level of 
		'ERD': phtdst = phterd
		'SRD': phtdst = phtsrd
		'SCP': phtdst = phtscp
		'SPD': phtdst = phtspd
		'AAP': phtdst = phtaap
	ENDCASE
		

	measnames = pickmeas(FTYPE=level, /multi, posi=posi)
	meas = WHERE(phtdst.admn EQ measnames(0),n)

	IF measnames(0) EQ '' THEN BEGIN
		meas=0
		if keyword_set(status) then status = '0'
		indices = 0
		MESSAGE, /INFO, 'No measurement chosen, returning'
		RETURN
	ENDIF				

	if keyword_set(status) then status = '1'

	IF n GT 1 THEN meas = meas(posi(0))
	
			
	IF N_ELEMENTS(measnames) GT 1 THEN BEGIN

        FOR I=1,N_ELEMENTS(measnames) - 1 DO BEGIN
	  	measadd = WHERE(phtdst.admn EQ measnames(I),n)
		IF n GT 1 THEN measadd = measadd(posi(i))
		meas = [meas,measadd(0)]
	ENDFOR
	ENDIF
	
	indices = meas
	
RETURN
END
	 
