;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_OPEN_FXB
;
; PURPOSE:
;	Opens a binary FITS file,
;	returns the FITS header and the dimensions of the binary table.
;
; CATEGORY:
;	PIA - I/O
;	
; CALLING SEQUENCE:
;	PIA_OPEN_FXB, filename, unit, header, dims
;	
; INPUTS:
;	filename :	The file name of the FITS file to be openend.
;	
; KEYWORD PARAMETERS:
;	none
;
; OUTPUTS:
;	unit :		The unit number under which the file is opened.
;
;	header :	The FITS header as a string array.
;
;	dims :		The dimensions of the binary table in the FITS file
;			read from the common block FXBINTABLE.
;			It is an array of three elements with the meaning:
;			Element# 0: NAXIS1 = Number of bytes per table row
;			Element# 1: TFIELDS = Number of table columns
;			Element# 2: NAXIS2 = Number of table rows
;	
;	FXBOPEN		from ASTRON library, used to open the FITS binary file.
;	
; COMMON BLOCKS:
;	FXBINTABLE	defined in ASTRON library, file FXBINTABLE.PRO
;	
; SIDE EFFECTS:
;	The FITS file must be closed by the routine FXBCLOSE, since
;	the FXB package defines its own administration to trace FITS files
;	which have been opened by the routine FXBOPEN.
;
; PROCEDURES USED:
;	Astronomical Library:
;		fxbintable
;		fxbopen
;	
; MODIFICATION HISTORY:
;	Written by:	D. Skaley, MPIK/Heidelberg	July 1994
;	Oct 95 Version 3.5	
;-

PRO PIA_OPEN_FXB, filename, unit, header, dims

; include the FXBINTABLE common block

@fxbintable

;  FITS extension is always = 1

	FXBOPEN, unit, filename, 1, header

; Find the dimensions of the table, 'lun' is defined in common FXBINTABLE.

	i = (WHERE( lun EQ unit))(0)
	ncol = tfields(i)
	nax1 = naxis1(i)
	nrow = naxis2(i)
	dims = [ nax1, ncol, nrow ]

	RETURN
END
