;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_OPEN_IAAP
;
; PURPOSE:
;	Interface to the PHTAAP common block.
;	Let the user select an AAP measurement.
;	PHTAAP structure of selected measurement is returned.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_OPEN_IAAP, aap
;
; INPUTS:
;	(none)
;
; KEYWORD PARAMETERS:
;	GROUP		The widgets group leader
;
;	DTYPE		The detector type
;
;	ERROR		Returns an error status:
;			0 = no error
;			1 = error: AAP does not contain valid AAP data
;
; OUTPUTS:
;	AAP		A copy of the selected PHTAAP structure
;			(structure of handles).
;
; PROCEDURES USED:
;	PIA Procedure(s):
;		pickmeas
;
; COMMON BLOCKS:
;	PHTAAP
;	pickmeas_results
;
; MODIFICATION HISTORY:
;	Written by:	D. Skaley, MPIK/Heidelberg	March 1995
;	Modified by:	C. Gabriel, ESA/VILSPA		July 1995
;	Oct 95 Version 3.5
;	Several same AAP measurements case handled (CG)	October 1995
;	Detector keyword added (CG)			April 1996
;	Using new pickmeas and pickmeas_results-CB (CG)	May 1997
;	V6.3
;	Creating a new pseudo measurement for making 
;	 possible PHT-S mapping (CG)			November 1997
;	V6.6
;-

PRO PIA_OPEN_IAAP, aap, map=map, DTYPE=dtype, GROUP=group, $
		SR_STR=SR_STR, ERROR=error

@phtaap
@phtslwavlen
COMMON pickmeas_results, pickmeas_res

	error = 1
	sr_str = -1

	IF KEYWORD_SET(DTYPE) THEN dt = DTYPE ELSE dt=''
	admn = PICKMEAS( FTYPE="AAP", DTYPE=dt, GROUP=group )
	IF admn EQ "" THEN RETURN

	index = WHERE( phtaap.admn EQ admn, count )

	IF count EQ 0 THEN RETURN

	IF count GT 1 THEN index = index(pickmeas_res.position)


	aap = phtaap(index(0))
	
	IF STRMID(aap.det,0,1) EQ 'S' AND KEYWORD_SET(map) THEN BEGIN
	  pia_load_iaap, aap, tmpaap
	  pia_get_sregion, STRMID(aap.admn,0,2), sr_str
	  IF sr_str.corr EQ 1 THEN BEGIN
	   pixel = FIX(sr_str.pixel) 
	   cwavl = sr_str.cvalue
	  ENDIF ELSE BEGIN
	   pixel = 0
	   cwavl = 0.
	  ENDELSE

          PHTAAPT = {PHTAAP_TYPE}
          PHTAAPT.HDR = HANDLE_CREATE()
          PHTAAPT.TIME = HANDLE_CREATE()
          PHTAAPT.CSTP = HANDLE_CREATE()
          PHTAAPT.CPOS = HANDLE_CREATE()
          PHTAAPT.DWEL = HANDLE_CREATE()
          PHTAAPT.MNFL = HANDLE_CREATE()
          PHTAAPT.MNFU = HANDLE_CREATE()
          PHTAAPT.MNBR = HANDLE_CREATE()
          PHTAAPT.MNBU = HANDLE_CREATE()
          PHTAAPT.MDFL = HANDLE_CREATE()
          PHTAAPT.Q1FL = HANDLE_CREATE()
          PHTAAPT.Q3FL = HANDLE_CREATE()
          PHTAAPT.MDBR = HANDLE_CREATE()
          PHTAAPT.Q1BR = HANDLE_CREATE()
          PHTAAPT.Q3BR = HANDLE_CREATE()
          PHTAAPT.RPID = HANDLE_CREATE()
          PHTAAPT.FLAG = HANDLE_CREATE()
          PHTAAPT.DEC = HANDLE_CREATE()
          PHTAAPT.RA = HANDLE_CREATE()
          PHTAAPT.ROLL = HANDLE_CREATE()

          HANDLE_VALUE, PHTAAPT.HDR, tmpaap.hdr, /SET
;         
          PHTAAPT.DET  = tmpaap.DET
          PHTAAPT.ADMN = tmpaap.ADMN
          PHTAAPT.FILT = tmpaap.filt
          PHTAAPT.APER = tmpaap.aper
          PHTAAPT.POLZ = tmpaap.polz
          PHTAAPT.DIMS = tmpaap.dims
          PHTAAPT.CWVL = cwavl

          HANDLE_VALUE, PHTAAPT.RPID, tmpaap.RPID, /SET
          HANDLE_VALUE, PHTAAPT.TIME, tmpaap.TIME, /SET
          HANDLE_VALUE, PHTAAPT.CPOS, tmpaap.cpos, /SET
          HANDLE_VALUE, PHTAAPT.CSTP, tmpaap.cstp, /SET
          HANDLE_VALUE, PHTAAPT.DWEL, tmpaap.dwel, /SET
          HANDLE_VALUE, PHTAAPT.DEC, tmpaap.dec, /SET
          HANDLE_VALUE, PHTAAPT.RA, tmpaap.ra, /SET
          HANDLE_VALUE, PHTAAPT.ROLL, tmpaap.roll, /SET

	  nele = N_ELEMENTS(tmpaap.mnfl(0,*))
	  mnfl = FLTARR(NELE)
	  mnfu = mnfl
	  mnbr = mnfl
	  mnbu = mnfl
	  mdbr = mnfl
	  q1br = mnfl
	  q3br = mnfl
	  mdfl = mnfl
	  q1fl = mnfl
	  q3fl = mnfl
	  flag = INTARR(NELE)
	  
	  FOR iele=0,nele-1 DO BEGIN
	     weight_mean, tmpaap.mnfl(pixel,iele), tmpaap.mnfu(pixel,iele),$
	         mnf, mnu
	     mnfl(iele) = mnf
	     mnfu(iele) = mnu
	     weight_mean, tmpaap.mnbr(pixel,iele), tmpaap.mnbu(pixel,iele),$
	         mnf, mnu
	     mnbr(iele) = mnf
	     mnbu(iele) = mnu
	     mdbr(iele) = MEDIAN([tmpaap.mdbr(pixel,iele)])
	     q1br(iele) = MEDIAN([tmpaap.q1br(pixel,iele)])
	     q3br(iele) = MEDIAN([tmpaap.q3br(pixel,iele)])
	     mdfl(iele) = MEDIAN([tmpaap.mdfl(pixel,iele)])
	     q1fl(iele) = MEDIAN([tmpaap.q1fl(pixel,iele)])
	     q3fl(iele) = MEDIAN([tmpaap.q3fl(pixel,iele)])
	  ENDFOR
	     
	  
	  handle_value, phtaapt.mnfl, mnfl, /set
	  handle_value, phtaapt.mnfu, mnfu, /set
	  handle_value, phtaapt.mnbr, mnbr, /set
	  handle_value, phtaapt.mnbu, mnbu, /set
	  handle_value, phtaapt.mdbr, mdbr, /set
	  handle_value, phtaapt.q1br, q1br, /set
	  handle_value, phtaapt.q3br, q3br, /set
	  handle_value, phtaapt.mdfl, mdfl, /set
	  handle_value, phtaapt.q1fl, q1fl, /set
	  handle_value, phtaapt.q3fl, q3fl, /set
	  handle_value, phtaapt.flag, flag, /set
	  aap = phtaapt
 	ENDIF

	error = 0
	RETURN
	END
