;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_OPLOT
;
; PURPOSE:
;	PIA OPLOT routine. It allows overplotting one point, not possible with
;	the normal OPLOT routine
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_OPLOT, X, Y
;
; INPUTS:
;	X: Abscisse data to be plotted. It can be a scalar
;	Y: Ordinate data to be plotted. It can be a scalar
;	
; KEYWORD PARAMETERS:
;	XERR: X uncertainties
;	YERR: Y uncertainties
;	+ some original plot keywords: 
;		psym, title, xtitle, ytitle, subtitle, charsize, 
;		color, symsize, xrange, yrange, xmargin, thick
;	
; OUTPUTS:
;	none
;	
; COMMON BLOCKS:
;	none
;
; PROCEDURES USED:
; 	Astronomical Library:
;		oploterr
;	
; MODIFICATION HISTORY:
;	Written by:	C.Gabriel (ESA/ESTEC)		October 1994
;	thick keyword added (CG)			August 1997
;	Doing nothing if !NO_ERRBARS set (CG)		September 1997
;	V6.5
;-
PRO PIA_OPLOT, X, Y,xerr=xerr,yerr=yerr,psym=psym,color=color,symsize=symsize,$
			linestyle=linestyle, thick=thick 

; IF system variable !NO_ERRBARS set do nothing
	defsysv, '!NO_ERRBARS', exist=exi
	IF exi THEN $
	 IF !NO_ERRBARS THEN RETURN
	
	xerrset = keyword_set(xerr)
	yerrset = keyword_set(yerr)
	IF KEYWORD_SET(psym) THEN psym=psym ELSE psym=0 
	IF KEYWORD_SET(symsize) THEN symsize=symsize ELSE symsize=1
	IF KEYWORD_SET(thick) THEN thick=thick ELSE thick=1
	IF KEYWORD_SET(color) THEN color=color ELSE color=1
	IF KEYWORD_SET(linestyle) THEN linestyle=linestyle ELSE linestyle=0

;Duplicate the values for the case if there is just one point per axis
        IF N_ELEMENTS(x) EQ 1 THEN BEGIN
                x = [x,x]
        ENDIF
        IF N_ELEMENTS(y) EQ 1 THEN BEGIN
                y = [y,y]
		IF yerrset THEN yerr=[yerr,yerr]
        ENDIF

	 
        OPLOT, X, Y, psym=psym, color=color, symsize=symsize, $
			linestyle=linestyle, thick=thick 

	IF yerrset THEN OPLOTERR, X, Y, yerr, psym		 

        RETURN
END

