;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_PAIRDEGL
;
; PURPOSE:
;	Menu for RO-deglitching parameters handling (Readout pair method).
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_PAIRDEGL, tmpdata, pixel, GROUP=group 
;
; INPUT:
;	tmpdata: ERD level temporary structure
;	pixel:	 chosen pixel for testing
;
; KEYWORD PARAMETERS:
;	GROUP:	The group leader of the widget hirarchy
;	NO_DATA: 
;	
; RESTRICTIONS:
;	TMPDATA must be a valid PHTERD temporary structure
;	
; COMMON BLOCKS:
;	colour_indices
;		
; PROCEDURES USED:
;	PIA LIB:
;		pairr_deglitch
;		pia_xplot
;       INTERNAL:
;		pia_pairdegl_event
;
; MODIFICATION HISTORY:
;	Written by: C.Gabriel (ESA/VILSPA-SAI)		November 1997
;	V6.6
;	Extension for setting params without data testing (CG) 	January 1998
;	V7.0
;	-> In this case modal keyword can be active (CG) 	January 1999
;	V7.3 
;	Default initialisation through pdegl_str_init (CG)	July 1999
;	and ramps reconstruction included			August 1999
;	V8.0
;			
;-
; *********************************************************************
; *  Event routine for PIA_RODEGL
; *********************************************************************
PRO PIA_pairDEGL_EVENT, event
COMMON pdegl_str, pdegl_str
COMMON degl_string, degltext


@colour_indices
                                                                 
	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.top, get_UVALUE=hsave
	handle_value, hsave, save
	id = save.id
	
	val = {medw:pdegl_str.medw,thr1:pdegl_str.thr1, $
	       thr2:pdegl_str.thr2,nite:pdegl_str.nite, reco:save.val.reco}
	

	CASE uvalue OF

	'TEST': BEGIN
; Read the values from the widgets
		WIDGET_CONTROL, event.top, /HOURGLASS
		WIDGET_CONTROL, id.medw, GET_VALUE=medw
		WIDGET_CONTROL, id.nite, GET_VALUE=nite
		WIDGET_CONTROL, id.thr1, GET_VALUE=thr1
		WIDGET_CONTROL, id.thr2, GET_VALUE=thr2
		

		pix = save.pixel
		pix_disc = save.erd_disc(pix,*)

		degltext = STRARR(1)
		
		pair_deglitch, save.tmpdata, medw(0), thr1(0), thr2(0), $
			nite(0), pix_disc, pix, pdegl_flag
			
		IF save.val.reco THEN BEGIN
		  tmpdata = save.tmpdata
		  degl_acc = tmpdata.flag * 0
		  ind = WHERE(pdegl_flag NE 0, nind)
		  IF nind GT 0 THEN degl_acc(pix,*) = pdegl_flag
          	  encode_piaflag, 'ERD', 'GLITCH', tmpdata.flag, newflag, $
		  degl_acc, DET = tmpdata.det, /ALLPIX
          	  tmpdata.flag = newflag 
		  REBUILD_TMPERD, tmpdata, newconp, newflag
		  tmpdata.conp = newconp
		  legend = "After deglitching"
		ENDIF ELSE BEGIN
		  tmpdata = save.tmpdata  
		  legend = "Before deglitching"
		ENDELSE
			
		PIA_XPLOT, tmpdata.time, tmpdata.conp(pix,*), $
			psym=4, $
			title="Testing of pair deglitching parameters", $
			xtitle = "Time    [s]", ytitle="RO Voltage   [V]", $
			legend=""

		ind = WHERE(pdegl_flag EQ 5, count)
		
		IF count GT 0 THEN $ 
			PIA_XPLOT, tmpdata.time(ind), $
			tmpdata.conp(pix,ind), psym=2, color=blue, $
			   legend="Flagged points", /overplot
		
		ind_disc = WHERE(pix_disc GT 0, fdisc)
		IF fdisc GT 0 THEN $
			PIA_XPLOT, tmpdata.time(ind_disc), $
			tmpdata.conp(pix,ind_disc), psym=7, color=red, $
			   legend="Discarded points", /overplot
		
		XDISPLAYFILE, '', TEXT=STRTRIM(count,2) + ' points flagged',$
			width=30, height=3

		decode_admn, save.tmpdata.admn, meastxt
		deglsum=meastxt+ ' - Test of Ramp (two Thresholds) Deglitching'
		deglsum=[deglsum,$
         '==================================================================']
		deglsum=[deglsum,' ']
		deglsum=[deglsum,'Pixel '+STRTRIM(STRING(pix+1),2)]
		deglsum=[deglsum,' ']
		deglsum=[deglsum,'Parameters:']
		deglsum=[deglsum,'-----------']
		deglsum=[deglsum,'1st Sigma threshold: '+string(thr1(0))]
		deglsum=[deglsum,'2nd Sigma threshold: '+string(thr2(0))]
		deglsum=[deglsum,'Number of iterations: '+string(nite(0))]
		deglsum=[deglsum,'Median filtering window: '+string(medw(0))]
		deglsum=[deglsum,' ']
		deglsum=[deglsum, $
'          Time            Strength        Mean Delta	  Strength/Mean    Flagged']
		deglsum=[deglsum, degltext]
		PIA_DISP_PRINT_FILE, 'degl_test', TITLE='Deglitching Statistics',$
	  		TEXT=deglsum 		

	END
	
	'DEF': BEGIN

		pdegl_str_init
				
		WIDGET_CONTROL, id.medw, set_VALUE=STRING(pdegl_str.medw)
		WIDGET_CONTROL, id.nite, set_VALUE=STRING(pdegl_str.nite)
		WIDGET_CONTROL, id.thr1, set_VALUE=STRING(pdegl_str.thr1)
		WIDGET_CONTROL, id.thr2, set_VALUE=STRING(pdegl_str.thr2)
	
	END
	
	
	'RECO': BEGIN
		WIDGET_CONTROL, event.id, GET_VALUE=value
		save.val.reco = value(0)
		handle_value, hsave, save, /SET
		WIDGET_CONTROL, event.top, set_UVALUE=hsave		
		END

	'DEFQUIT': BEGIN
		pdegl_str_init
		WIDGET_CONTROL, event.top, /DESTROY
		
			
	END
	'QUIT': BEGIN
	
		WIDGET_CONTROL, id.medw, GET_VALUE=medw
		WIDGET_CONTROL, id.nite, GET_VALUE=nite
		WIDGET_CONTROL, id.thr1, GET_VALUE=thr1
		WIDGET_CONTROL, id.thr2, GET_VALUE=thr2

		pdegl_str = {medw:FIX(medw(0)),thr1:FLOAT(thr1(0)), $
			thr2:FLOAT(thr2(0)), nite:FIX(nite(0))}
		WIDGET_CONTROL, event.top, /DESTROY
		
	END

	ELSE:
	
	ENDCASE
	
RETURN
END
; *********************************************************************
; *  Menu for PIA_PAIRDEGL
; *********************************************************************
PRO PIA_pairDEGL, tmp, pixel, erd_disc, GROUP=group, NO_data=no_data, $
	modal=modal 

COMMON pdegl_str, pdegl_str


	IF KEYWORD_SET(no_Data) THEN BEGIN 
	  tmp={null:-1}
	  pixel=0
	  erd_disc = 0
	  IF not KEYWORD_SET(modal) THEN modal = 0
	ENDIF ELSE modal=0
	
	IF N_ELEMENTS(pdegl_str) EQ 0 THEN PDEGL_STR_INIT

	id = {medw:0L, thr1:0L,thr2:0L,nite:0L}
	val = {medw:pdegl_str.medw,thr1:pdegl_str.thr1, $
	       thr2:pdegl_str.thr2,nite:pdegl_str.nite, reco:0}
	
	base = WIDGET_BASE(TITLE="PIA read-out 2 threshold deglitching Parameters", $
	   /COLUMN, modal=modal, group=group)

	parbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(parbase, VALUE='Median filtering width:          ')
	id.medw = WIDGET_TEXT(parbase, /EDITABLE, VALUE=STRING(pdegl_str.medw), $
		UVALUE='JUNK',Xsize=20)
	
	parbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(parbase, VALUE='Sigma threshold for flagging:    ')
	id.thr1 = WIDGET_TEXT(parbase, /EDITABLE, VALUE=STRING(pdegl_str.thr1), $
		UVALUE='JUNK',Xsize=20)
		
	parbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(parbase, VALUE='Sigma threshold for reacceptance:')
	id.thr2 = WIDGET_TEXT(parbase, /EDITABLE, VALUE=STRING(pdegl_str.thr2), $
		UVALUE='JUNK',Xsize=20)
		
	parbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(parbase, $
		                      VALUE='Number of iterations:            ')
	id.nite = WIDGET_TEXT(parbase, /EDITABLE, VALUE=STRING(pdegl_str.nite), $
		UVALUE='JUNK',Xsize=20)
		
	reco_id= cw_bgroup(base, /NONexclusive,$
		SET_VALUE=[val.RECO], FONT=font, UVAL='RECO', $
		['Show reconstructed ramps']) 
	
	cont_base = WIDGET_BASE(base, /ROW)
	
	IF not KEYWORD_SET(NO_data) THEN $
	 test_id = WIDGET_BUTTON(cont_base, VALUE='OK, test them', UVALUE='TEST')
	
	def_id = WIDGET_BUTTON(cont_base, VALUE='Default Par', UVALUE='DEF')
	
	quit_id = WIDGET_BUTTON(cont_base, VALUE= 'Accept & Quit ', $
		UVALUE= 'QUIT')
	
	quit_id = WIDGET_BUTTON(cont_base, VALUE= 'Default & Quit', $
		UVALUE= 'DEFQUIT')

	save = {tmpdata:tmp, pixel:pixel, id:id, val:val, erd_disc:erd_disc}
	hsave = handle_create()
	handle_value, hsave, save, /set, /NO_COPY
	
	WIDGET_CONTROL, base, SET_UVALUE=hsave
	
        WIDGET_CONTROL, base, /REALIZE, TLB_SET_XOFFSET=150, $
                        TLB_SET_YOFFSET=150

        xMANAGER,No_BLOCK=1, "pia_pairdegl", base, GROUP=group
	
        RETURN
END
	
