;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_PIXCHOICE
;
; PURPOSE:
;	Menu for PIA drawing pixels choice.
;	This is a display dependant level menu in the PIA hierarchy.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_pixchoice
;
; INPUTS:
;	none
;	
; KEYWORD PARAMETERS:
;	GROUP
;		The group leader of the widget hirarchy
;
; OUTPUTS:
;	none
;	
; SIDE EFFECTS:
;	Modifies the variables in common block pia_pixch_cmn, used for
;	defining the pixels to be used (e.g. for display)
; 	
; PROCEDURES USED:
;	Internal:
;		pia_pixchoice_event
;
; COMMON BLOCKS:
;	pia_pixch_cmn
;	
; MODIFICATION HISTORY:
;	Written by:	C.Gabriel (ESA/ESTEC)		August 1994
;	Oct 95 Version 3.5
;	/modal acc IDL>=5.0 (CG)			January 1999
;	V7.3
;	Fixing widget numbers as LONG (CG)		February 1999
;	V7.4
;-

; ****************************************************************************
;  Event handling routine for PIA pixels selection 
; ****************************************************************************

PRO pia_pixchoice_event, event

COMMON pia_pixch_cmn, new_pixcho, new_pix 

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue OF

          'ACCEPT': BEGIN
		
	    ind = WHERE(new_pix NE 0, nvi)
	    FOR i=0,nvi-1 DO BEGIN
		WIDGET_CONTROL, new_pix(i), GET_VALUE=value
                new_pixcho(i) = FLOAT(value(0)) 
            ENDFOR               
		WIDGET_CONTROL, event.top, /DESTROY

          END

          'CANCEL': BEGIN

                WIDGET_CONTROL, event.top, /DESTROY

          END
             
          ELSE:          
       	ENDCASE
	RETURN
END

; ****************************************************************************
;  PIA PIXCHOICE - menu definition procedure
; ****************************************************************************

FUNCTION pia_pixchoice, GROUP=group, PIXC=pixc, nv=nv


COMMON pia_pixch_cmn, new_pixcho, new_pix

	IF KEYWORD_SET(nv) THEN nviews = nv ELSE nviews = 4
	new_pixcho = pixc+1
	new_pix = LONARR(4)

	str_pixch = strtrim(string(pixc+1),2)

	pixbase = WIDGET_BASE(TITLE = 'PIA Pixel Display Choice cmenu', $ 
		 		/COLUMN, /modal, group=group)


	junkbase = WIDGET_BASE(pixbase, /ROW)
        junktit = WIDGET_LABEL(junkbase, $
			VALUE='Choose the pixels to be displayed:')

	levbase = WIDGET_BASE(pixbase, /ROW)

	FOR I=0,nviews - 1 DO BEGIN
	 valtxt = 'Display '+STRTRIM(STRING(I+1),2)
	 uvaltxt = 'PIX'+STRTRIM(STRING(I+1),2)

         label = WIDGET_LABEL(levbase, VALUE=valtxt)
         new_pix(i) = WIDGET_TEXT(levbase, /EDITABLE, XSIZE=4, YSIZE=1, $
                   VALUE=str_pixch(i), UVALUE=uvaltxt) 

	 junklabel = WIDGET_LABEL(levbase, VALUE='       ')
	ENDFOR
  

        control = WIDGET_BASE(pixbase,/ROW)

        junk = WIDGET_LABEL(control, VALUE = '                          ')
        accept = WIDGET_BUTTON(control, VALUE = '  OK  ', $
                        /FRAME, UVALUE = 'ACCEPT')
        junk = WIDGET_LABEL(control, VALUE = '                          ')
        cancel = WIDGET_BUTTON(control, VALUE = '  Cancel  ', $
                        /FRAME, UVALUE = 'CANCEL')

        WIDGET_CONTROL, pixbase, /REALIZE, TLB_SET_XOFFSET=150, $
                        TLB_SET_YOFFSET=150

        xMANAGER,No_BLOCK=1, "pia_pixchoice", pixbase, GROUP=group
	
new_pixcho = new_pixcho - 1

RETURN, new_pixcho
END

