;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_PLOT_OVER
;
; PURPOSE:
;	Menu for getting decision to overplot or not.
;	This is a display dependant level menu in the PIA hierarchy.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_plot_over
;
; INPUTS:
;	none
;	
; KEYWORD PARAMETERS:
;	none
;	
; OUTPUTS:
;	none
;	
; COMMON BLOCKS:
;	pia_plot_over_cmn
;
; PROCEDURES USED:
;	Internal:
;		pia_plot_over_event	
;	
; MODIFICATION HISTORY:
;	Written by:	C.Gabriel (ESA/ESTEC)			December 1994
;	Oct 95 Version 3.5
;	Modified to include status as output, COMMON
;	block is meant to be of internal use (Jacosta)		August 1998
;	Modal keyword according to IDL5.0 prescription (CG)	January 1999
;	V7.3
;-

; ****************************************************************************
;  Event handling routine for PIA plot_over
; ****************************************************************************

PRO pia_plot_over_event, event

COMMON pia_plot_over_cmn, plmenu_ids, state 

	button_id = WHERE(plmenu_ids EQ event.id, count)

	IF count GT 0 THEN BEGIN

	   WIDGET_CONTROL, event.id, GET_UVALUE = state

	ENDIF ELSE BEGIN

	   WIDGET_CONTROL, event.id, GET_UVALUE = uvalue

	   CASE uvalue OF
		'DONE': WIDGET_CONTROL, event.top, /DESTROY
	   ENDCASE
	ENDELSE

	END


; ****************************************************************************
;  PIA plot_over
; ****************************************************************************

PRO pia_plot_over, status, group=group

	COMMON pia_plot_over_cmn, plmenu_ids, state 

	IF not KEYWORD_set(group) THEN group=!pia_top_wid

	plbase = WIDGET_BASE(Title = 'Plot or overplot', /COLUMN, $
			/modal, group=group)
	button_labels=['Plot new', 'Overplot synchronized', $
                'Overplot non-synchronized']
		
	state = 0 	

	XMENU, button_labels, plbase, BUTTONS = plmenu_ids, $
        	/EXCLUSIVE, UVALUE=st, /NO_RELEASE

	done = WIDGET_BUTTON(plbase, UVALUE='DONE', VALUE='DONE')

	WIDGET_CONTROL, plbase, /REALIZE

	WIDGET_CONTROL, plmenu_ids(0), /SET_BUTTON

        XMANAGER,No_BLOCK=1, "pia_plot_over", plbase, GROUP_LEADER=GROUP 
	
	status = state
	
        RETURN
END

