;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_POW2FB
;
; !!!WARNING!!! This routine is obsolete and uses as input an AAP
;		structure which is DIFFERENT to the phtaap structure.
;
; PURPOSE:
;	Convert in-band power values of AAP data
;	into flux density and brightness.
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	PIA_POW2FB, aap, ERROR=error
;
; INPUTS:
;	AAP : 		An AAP data structure (one measurement).
;			Handles contain in-band power arrays.
;
; KEYWORD PARAMETERS:
;	ERROR :		Returns an error condition:
;			0 = no error
;			1 = data could not be converted
;
; OUTPUTS:
;	none
;
; PROCEDURES USED:
;	PIA Procedure(s):
;		pia_defaper
;		pia_defratio
;		pia_defwavel
;		pia_read_ppsf
;		read_ppsf
;
; COMMON BLOCKS:
;	PIACMN_POW2FB	Transformation parameters power -> flux/brightness
;
; SIDE EFFECTS
;	The AAP structure in common block is filled with flux density
;	and brightness values.
;
; MODIFICATION HISTORY:
;	Written by: 	D. Skaley (MPIK/Heidelberg)		March 1995
;	Modified(last): Carlos Gabriel (ESA/ESTEC)		July 1995
;	Oct 95 Version 3.5
;-

PRO PIA_POW2FB, aap, ERROR=error

; common blocks:
; transformation parameters

@piacmn_pow2fb

; initialize error status

	error = 1

; load the transformation parameters into common block the first time

	IF N_ELEMENTS( ppsf ) EQ 0 THEN BEGIN
		PIA_READ_PPSF, ERROR=err
		IF err THEN RETURN
	ENDIF
	IF N_ELEMENTS( aper_m ) EQ 0 OR N_ELEMENTS( aper_r ) EQ 0 THEN BEGIN
		PIA_DEFAPER
	ENDIF
	IF N_ELEMENTS( p_wavel ) EQ 0 OR N_ELEMENTS( c_wavel ) EQ 0 THEN BEGIN
		PIA_DEFWAVEL
	ENDIF
	IF N_ELEMENTS( p_ratio ) EQ 0 OR N_ELEMENTS( c_ratio ) EQ 0 THEN BEGIN
		PIA_DEFRATIO
	ENDIF

; check if 'data' is present

	IF N_ELEMENTS( data ) NE 1 THEN GOTO, not_aap

; determine the detector: C1, C2, P1, P2, P3, SL, SS
; and the detector type: C, P, S

	detector = aap.det
	dettype  = STRMID(detector,0,1)

; PHT-S is still unclear to me:

	IF dettype EQ "S" THEN GOTO, dont_know_what_to_do

; for PHT-C or PHT-P: get the filter ID (1..14)

	IF dettype EQ "C" OR dettype EQ "P" THEN BEGIN
		filter = aap.filt
	ENDIF

; for PHT-P: get the aperture ID (1..14)

	IF dettype EQ "P" THEN BEGIN
		aperture = aap.aper
	ENDIF

; get the ISO main aperture [m^2]

	isoarea = DOUBLE(aper_m(2,0))

; get the central wavelength for the filter [m]
; and the 1/delta_lambda value [1/m]
; and the PSF value [1]
; and the detector area [sterad]

	IF dettype EQ "P" THEN BEGIN
		wavel = DOUBLE(p_wavel(filter))
		ratio = DOUBLE(p_ratio(filter))
		psf = DOUBLE(ppsf(aperture,filter))
		detarea = aper_r(2,aperture)
	ENDIF
	IF dettype EQ "C" THEN BEGIN
		wavel = DOUBLE(c_wavel(filter))
		ratio = DOUBLE(c_ratio(filter))
		psf = DOUBLE(ppsf(15,filter))
		IF detector EQ "C1" THEN $
			detarea = aper_r(2,15) $
		ELSE $ ; must be C2
			detarea = aper_r(2,16)
	ENDIF

; the speed of light [m/s]

	light_speed = 299792500.D0

; the secondary mirror correction factor

	epsilpon_factor = 1.D0 - (0.3D0)^2

; transformation factors W -> Jy and W -> MJy/sr

	tmp = ratio/isoarea * wavel^2/light_speed * 1.E26
	trans_flux       = FLOAT(tmp/psf)
	trans_brightness = FLOAT(tmp/detarea/epsilon_factor * 1.D-6)

; create new flux arrays from power arrays

	HANDLE_VALUE, aap.mnpw, mnfl
	HANDLE_VALUE, aap.mnpu, mnfu
	HANDLE_VALUE, aap.mdpw, mdfl
	HANDLE_VALUE, aap.q1pw, q1fl
	HANDLE_VALUE, aap.q3pw, q3fl

; transformation W -> Jy, move arrays to handles

	mnfl = TEMPORARY(mnfl) * trans_flux
	mnfu = TEMPORARY(mnfu) * trans_flux
	mdfl = TEMPORARY(mdfl) * trans_flux
	q1fl = TEMPORARY(q1fl) * trans_flux
	q3fl = TEMPORARY(q3fl) * trans_flux

	HANDLE_VALUE, aap.mnfl, mnfl, /SET, /NO_COPY
	HANDLE_VALUE, aap.mnfu, mnfu, /SET, /NO_COPY
	HANDLE_VALUE, aap.mdfl, mdfl, /SET, /NO_COPY
	HANDLE_VALUE, aap.q1fl, q1fl, /SET, /NO_COPY
	HANDLE_VALUE, aap.q3fl, q3fl, /SET, /NO_COPY

; create new brightness arrays from power arrays

	HANDLE_VALUE, aap.mnpw, mnbr
	HANDLE_VALUE, aap.mnpu, mnbu
	HANDLE_VALUE, aap.mdpw, mdbr
	HANDLE_VALUE, aap.q1pw, q1br
	HANDLE_VALUE, aap.q3pw, q3br

; transformation W -> MJy/sr, move arrays to handles

	mnfl = TEMPORARY(mnbr) * trans_brightness
	mnfu = TEMPORARY(mnbu) * trans_brightness
	mdfl = TEMPORARY(mdbr) * trans_brightness
	q1fl = TEMPORARY(q1br) * trans_brightness
	q3fl = TEMPORARY(q3br) * trans_brightness

	HANDLE_VALUE, aap.mnbr, mnbr, /SET, /NO_COPY
	HANDLE_VALUE, aap.mnbu, mnbu, /SET, /NO_COPY
	HANDLE_VALUE, aap.mdbr, mdbr, /SET, /NO_COPY
	HANDLE_VALUE, aap.q1br, q1br, /SET, /NO_COPY
	HANDLE_VALUE, aap.q3br, q3br, /SET, /NO_COPY

; normal return

	error = 0
	RETURN

; error conditions

not_aap:
	MESSAGE, /INFO, "Input AAP data not provided"
	RETURN

dont_know_what_to_do:
	MESSAGE, /INFO, "Don't know how to process these data"
	RETURN

	END
