;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_PRINT_AAPVAL
;
; PURPOSE:
;	Print out the values corresponding to the AAP arrays
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;       PIA_Print_aapval, tmpdata
;
; INPUT PARAMETERS:
;       tmpdata:
;		A PHT-AAP temporary structure
;
; OUTPUT PARAMETERS:
;	none
;
;
; PROCEDURES USED:
;	PIA Procedure(s):
;		decode_admn
;
; MODIFICATION HISTORY:
;       Written by Carlos GABRIEL (ESA/VILSPA)              September 1995
;	Oct 95 Version 3.5
;	Free_lun instead of close (CG)			    May 1996
;	Simplified through use of PIA_DISP_PRINT_FILE (CG)	Feb.1997
;	V6.1
;-

PRO PIA_PRINT_AAPVAL, TMPDATA

	measname = tmpdata.admn
        IF strmid(tmpdata.det,0,1) EQ 'C' THEN det = tmpdata.det+'00' ELSE $
                                                det = tmpdata.det

        decode_admn, tmpdata.admn, title

	str = 'AAP Results - '+title
        str = [str,'=================================================']
        bytstr = [str,' ']
	
	
        FOR I=0,tmpdata.dims - 1 DO BEGIN

        	str =  [str,'Pos. '+STRTRIM(string(I+1),2)+$
               		': Chopper Position  '+$
			STRTRIM(string(tmpdata.cpos(I)),2)+' arcsec'] 

        str = [str,$
	 '..................................................................']

        	npix = N_ELEMENTS(tmpdata.mnfl(*,0))

		FOR ipix=0,npix-1 DO BEGIN
                   str = [str,'Pixel '+strtrim(string(ipix+1),2)+$
		       '  Mean Flux Density:  '+$
			STRTRIM(STRING(tmpdata.mnfl(ipix,I)),2)+$
                        '  +/-  '+STRTRIM(STRING(tmpdata.mnfu(ipix,I)),2)]
                   
                   str = [str,'         Median            :  '+$
			STRTRIM(STRING(tmpdata.mdfl(ipix,I)),2)+$
			'  1st Q: '+STRTRIM(STRING(tmpdata.q1fl(ipix,I)),2)+$
			'  3rd Q: '+STRTRIM(STRING(tmpdata.q3fl(ipix,I)),2)]
                   str = [str,' ']
                ENDFOR
		   str = [str,' -------------------------------------- ']
		   str = [str,'']
		FOR ipix=0,npix-1 DO BEGIN
                   str = [str,'Pixel '+strtrim(string(ipix+1),2)+$
		       '  Mean Surface Brightness:  '+$
			STRTRIM(STRING(tmpdata.mnbr(ipix,I)),2)+$
                        '  +/-  '+STRTRIM(STRING(tmpdata.mnbu(ipix,I)),2)]
                   
                   str = [str,'         Median            :  '+$
			STRTRIM(STRING(tmpdata.mdbr(ipix,I)),2)+$
			'  1st Q: '+STRTRIM(STRING(tmpdata.q1br(ipix,I)),2)+$
			'  3rd Q: '+STRTRIM(STRING(tmpdata.q3br(ipix,I)),2)]
                   str = [str,' ']
                ENDFOR
	ENDFOR

	text = str
	lines = N_ELEMENTS(text)
		
	filename = measname + "_AAP"
	pia_disp_print_file, filename, TITLE='PIA AAP values', HEIGHT=40, $
		TEXT=str 



	RETURN
	END
