;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_PRINT_SCPVAL
;
; PURPOSE:
;	Print out the values corresponding to the SCP arrays
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;       PIA_Print_scpval, tmpdata
;
; INPUT PARAMETERS:
;       tmpdata:
;		A PHT-SCP temporary structure
;
; OUTPUT PARAMETERS:
;	none
;
; COMMON BLOCKS:
;	pia_printscp_cmn
;
; PROCEDURES USED:
;	PIA Procedure(s):
;		decode_admn
;		pia_disp_print_file
;
; MODIFICATION HISTORY:
;       Written by:	Carlos GABRIEL (ESA/VILSPA)	October 1994
;	Modified (last) by:	CG			November 1996
;	V5.x
;	Simplified through use of PIA_DISP_PRINT_FILE (CG)	Feb.1997
;	V6.1
;-

PRO PIA_PRINT_SCPVAL, TMPDATA


	indfcs = WHERE(tmpdata.fcsn gt 0, n)

	IF strmid(tmpdata.det,0,1) EQ 'C' THEN det = tmpdata.det+'00' ELSE $
						det = tmpdata.det 

	measname = tmpdata.admn
	decode_admn, tmpdata.admn, title
	str = 'SCP Results - '+title

        str = [str,'=================================================']
	str = [str,'  ']
	
        FOR I=0,tmpdata.dims - 1 DO BEGIN

        str = [str, 'Pos. '+STRTRIM(string(I+1),2)+$
               ': Chopper Step '+STRTRIM(string(tmpdata.step(I)),2)+$
               ':  FCS  '+STRTRIM(string(tmpdata.fcsn(I)),2)+$
               ': Chopper Position  '+$
		STRTRIM(string(tmpdata.chop(I)),2)+' arcsec'] 

	str = [str,$
	'..................................................................']


        npix = N_ELEMENTS(tmpdata.aver(*,0))
	indp = WHERE([6,11] EQ npix, ncount) 
	IF ncount NE 0 THEN npix = npix - 2
	IF npix EQ 132 THEN npix=128
	
                 FOR ipix=0,npix-1 DO BEGIN
                   str = [str, 'Pixel '+strtrim(string(ipix+1),2)+$
                        ' - Average Signal:  '+$
                        STRTRIM(STRING(tmpdata.aver(ipix,I)),2)+$
                        '  +/-  '+STRTRIM(STRING(tmpdata.avun(ipix,I)),2)]
                   str = [str,'          Median        :  '+$
                        STRTRIM(STRING(tmpdata.medi(ipix,I)),2)+$
                        '  1st Q: '+STRTRIM(STRING(tmpdata.q1me(ipix,I)),2)+$
                        '  3rd Q: '+STRTRIM(STRING(tmpdata.q3me(ipix,I)),2)]
                   str = [str,' ']
                 ENDFOR
                ENDFOR

	filename = measname + "_SCP"
	pia_disp_print_file, filename, TITLE='PIA SCP values', HEIGHT=40, $
		TEXT=str 


	
	RETURN
	END
