;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_PRINT_SRCBCK
;
; PURPOSE:
;	Print out the values corresponding to a SRC - BCK subtraction structure
;
; CALLING SEQUENCE:
;       PIA_Print_srcbck, value, unc
;
; INPUT PARAMETERS:
;       value: 	Array (Pixel#) of SRC-BCK values
;	unc:	Uncertainties array
;
; KEYWORD PARAMETERS:
;	GROUP:	The group leader of this widget hierarchy
;
; OUTPUT PARAMETERS:
;	none
;
; COMMON BLOCKS:
;	pia_print_srcbck_cmn
;
; PROCEDURES USED:
;	PIA Procedure(s):
;		decode_admn
;	Internal:
;		pia_print_srcbck_event
;
; MODIFICATION HISTORY:
;       Written by Carlos GABRIEL (ESA/ESTEC-SAI)	February 1995
;	Oct 95 Version 3.5
;	Free_lun instead of close (CG)			May 1996
;-
PRO pia_print_srcbck_event, event

COMMON pia_print_srcbck_cmn, lines, measname, text 

        WIDGET_CONTROL, event.id, GET_UVALUE=uvalue


	CASE UVALUE of

        'QUIT': WIDGET_CONTROL, event.top, /DESTROY

	ELSE: BEGIN

          filename=measname+'_srcbck.txt'

          if uvalue eq 'PRINT' then filename='_'+filename

          openw,1,filename
          printf,1

          for i=0,lines-1 do begin
            printf,1,text(i)
          endfor

          printf,1,string(12B)

          free_LUN,1

          if uvalue eq 'PRINT' then begin
            if !VERSION.OS ne 'vms' then begin
              spawn,'lpr -P$pslaser '+filename
              spawn,'rm '+filename
            endif else begin
              spawn,'print/queue=pslaser/notify/delete '+filename
            endelse
          endif
        END

	ENDCASE
END

PRO PIA_PRINT_SRCBCK, name, aver, avun, comment, GROUP=group

        COMMON pia_print_srcbck_cmn, lines, measname, text 

	measname = name
	decode_admn, name, title

	str = comment+ ' ' + title

        str = [str,'=================================================']
	str = [str,'  ']
	
        npix = N_ELEMENTS(aver)

        FOR ipix=0,npix-1 DO BEGIN
            str = [str, 'Pixel '+strtrim(string(ipix+1),2)+$
                        ' - Average:  '+$
                   STRTRIM(STRING(aver(ipix)),2)+$
                    '  +/-  ' + STRTRIM(STRING(avun(ipix)),2) ]
                   str = [str,' ']
                 ENDFOR

	text = str
        lines = N_ELEMENTS(text)
		
; menu definition
        base = WIDGET_BASE(TITLE =title+' SRC - BCK values',/COLUMN)
	label = WIDGET_LABEL(base, VALUE=title)

        ctrlbase = WIDGET_BASE(base,/ROW)

        quit = WIDGET_BUTTON(ctrlbase, VALUE = ' QUIT ', $
                        /FRAME, UVALUE = 'QUIT')
        junk = WIDGET_LABEL(ctrlbase, VALUE = '                              ')
        print = WIDGET_BUTTON(ctrlbase, VALUE = ' PRINT ', $
                        /FRAME, UVALUE = 'PRINT')
        junk = WIDGET_LABEL(ctrlbase, VALUE = '  ')
        file = WIDGET_BUTTON(ctrlbase, VALUE = ' FILE ', $
                        /FRAME, UVALUE = 'FILE')

        textwid = WIDGET_TEXT(base, /SCROLL, XSIZE=75, YSIZE=38, $
                        VALUE=text, UVALUE='', $
                        font='-*-courier-bold-*-*-*-14-*')

        WIDGET_CONTROL, base, /REALIZE, TLB_SET_XOFFSET=150, $
                        TLB_SET_YOFFSET=150

        xMANAGER,No_BLOCK=1, "pia_print_srcbck", base, GROUP=group


	RETURN
	END
