;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_PRTDEF
;	
; PURPOSE:
;	Define parameters for sending an IDL plot to the printer
;	(printer device, print command, device keywords, etc.).
;	The parameters are stored in a common block to make them
;	available to each routine that needs to print out something.
;	Although the routine is part of the 'Interactive Analysis
;	software for ISOPHOT' (PIA) it makes no use of special
;	definitions of that software and thus can be used generally.
;	
; CATEGORY:
;	PIA - initialization
;	
; CALLING SEQUENCE:
;	PIA_PRTDEF 
;	
; INPUTS:
;	None.
;	
; KEYWORD PARAMETERS:
;	GROUP:
;		The widget group leader. Destroying the group leader
;		will also destroy the PIA_PRTDEF widget.
;	
; OUTPUTS:
;	None.
;	
; SIDE EFFECTS:
;	None.
;	
; RESTRICTIONS:
;	None.
;	
; COMMON BLOCKS:
;	PIA_PRINT
;	
; PROCEDURES USED:
;	Internal:
;		pia_prtinit
;		pia_devkey_event
;		pia_devkey
;		pia_prtdef_event
;
; MODIFICATION HISTORY:
;	Written by:	Detlef Skaley, MPIK Heidelberg	October 1994
;	Modified (last) by CG				November 1996
;	Initialized as no color (CG)			March 1998
;	V7.1
;	Initialized as 8 bits per pixel (CG)		June 1998
;	V7.2
;	Modal keyword according to IDL>=5.0 (CG)	January 1999
;	V7.3
;
;-


PRO pia_prtinit

   COMMON pia_print, prt
   
     filena = !PIA_PRINTDIR + 'idl.ps'
     if !version.os EQ 'vms' then $
       pcmd = 'print' $
     else $
       pcmd = 'lpr'

   prt = { device:	'PS',			$
           copy:	1,			$
           interpolate:	0,			$
           print:	1,			$
           command:	pcmd, 			$
           filename:	filena,			$
           portrait:	0,			$
           landscape:	1,			$
           xsize:	'',			$
           xoffset:	'',			$
           ysize:	'',			$
           yoffset:	'',			$
           color:	0,			$
           encapsulated:0,			$
           bitsperpixel:8,			$
           scalefactor:	'',			$
           optimize:	'0',			$
           resolution:	0,			$
           keys:	'',			$
           addkeys:	''			$
         }

   RETURN
   END


PRO pia_devkey_event, event

   WIDGET_CONTROL, event.id, GET_UVALUE=action
   IF N_ELEMENTS(action) EQ 0 THEN RETURN
   WIDGET_CONTROL, event.top, GET_UVALUE=id
   WIDGET_CONTROL, id.tmp, GET_UVALUE=tmp, /NO_COPY
   hash = STRMID(action,0,1)
   rest = STRMID(action,1,100)

   CASE hash OF
   'E': BEGIN
           CASE rest OF
           'OK':   BEGIN
                   WIDGET_CONTROL, id.xsize, GET_VALUE=val
                   tmp.xsize = STRTRIM(val(0),2)
                   WIDGET_CONTROL, id.xoffset, GET_VALUE=val
                   tmp.xoffset = STRTRIM(val(0),2)
                   WIDGET_CONTROL, id.ysize, GET_VALUE=val
                   tmp.ysize = STRTRIM(val(0),2)
                   WIDGET_CONTROL, id.yoffset, GET_VALUE=val
                   tmp.yoffset = STRTRIM(val(0),2)
                   WIDGET_CONTROL, id.addkeys, GET_VALUE=val
                   tmp.addkeys = STRTRIM(val(0),2)
                   tmp.keys = ''
                   IF tmp.portrait THEN tmp.keys = tmp.keys + ',/PORTRAIT'
                   IF tmp.landscape THEN tmp.keys = tmp.keys + ',/LANDSCAPE'
                   IF tmp.xsize THEN tmp.keys = tmp.keys + ',XSIZE='+tmp.xsize
                   IF tmp.xoffset THEN tmp.keys = tmp.keys + ',XOFFSET='+tmp.xoffset
                   IF tmp.ysize THEN tmp.keys = tmp.keys + ',YSIZE='+tmp.ysize
                   IF tmp.yoffset THEN tmp.keys = tmp.keys + ',YOFFSET='+tmp.yoffset
                   CASE tmp.device OF
                   'PS':   BEGIN 
                           WIDGET_CONTROL, id.scalefactor, GET_VALUE=val
                           tmp.scalefactor = STRTRIM(val(0),2)
                           IF tmp.scalefactor THEN $
                               tmp.keys = tmp.keys + ',SCALE_FACTOR='+tmp.scalefactor
                           IF tmp.bitsperpixel NE 0 THEN $
                               tmp.keys = tmp.keys + ',BITS_PER_PIXEL='+STRTRIM(tmp.bitsperpixel,2)
                           IF tmp.color THEN tmp.keys = tmp.keys + ',/COLOR'
                           IF tmp.encapsulated THEN tmp.keys = tmp.keys + ',/ENCAPSULATED'
                           END
                   'PCL':  BEGIN
                           IF tmp.optimize NE '' AND tmp.optimize NE '0' THEN $
                               tmp.keys = tmp.keys + ',OPTIMIZE='+tmp.optimize
                           IF tmp.resolution NE 0 THEN $
                               tmp.keys = tmp.keys + ',RESOLUTION='+STRTRIM(tmp.resolution,2)
                           END 
                   ELSE:
                   ENDCASE
                   IF tmp.addkeys NE "" THEN tmp.keys = tmp.keys + ',' + tmp.addkeys
                   WIDGET_CONTROL, id.tmp, SET_UVALUE=tmp, /NO_COPY
                   END
           ELSE:   ; quit leaves uvalue of id.tmp undefined
           ENDCASE
           WIDGET_CONTROL, event.top, /DESTROY
           RETURN
        END
                   
   'G': CASE rest OF
        'POR': BEGIN
		tmp.portrait = event.select
		IF event.select THEN BEGIN
			xsize	= '18.0'
			ysize	= '26.5'
			xoffset	= '2.0'
			yoffset	= '1.5'
		ENDIF ELSE BEGIN
			xsize	= ''
			ysize	= ''
			xoffset	= ''
			yoffset	= ''
		ENDELSE
		WIDGET_CONTROL, id.xsize, SET_VALUE=xsize
		WIDGET_CONTROL, id.ysize, SET_VALUE=ysize
		WIDGET_CONTROL, id.xoffset, SET_VALUE=xoffset
		WIDGET_CONTROL, id.yoffset, SET_VALUE=yoffset
		END
        'LAN': BEGIN
		tmp.landscape = event.select
		IF event.select THEN BEGIN
			xsize	= '26.5'
			ysize	= '18.0'
			xoffset	= '1.3'
			yoffset	= '28.0'
		ENDIF ELSE BEGIN
			xsize	= ''
			ysize	= ''
			xoffset	= ''
			yoffset	= ''
		ENDELSE
		WIDGET_CONTROL, id.xsize, SET_VALUE=xsize
		WIDGET_CONTROL, id.ysize, SET_VALUE=ysize
		WIDGET_CONTROL, id.xoffset, SET_VALUE=xoffset
		WIDGET_CONTROL, id.yoffset, SET_VALUE=yoffset
		END
        'COL': tmp.color = event.select
        'ENC': tmp.encapsulated = event.select
        ELSE:
        ENDCASE

   'B': BEGIN
        rest = FIX(rest)
        IF event.select OR tmp.bitsperpixel EQ rest THEN $
           tmp.bitsperpixel = rest * event.select
        END

   'O': tmp.optimize = rest

   'R': BEGIN
        rest = FIX(rest)
        IF event.select OR tmp.resolution EQ rest THEN $
           tmp.resolution = rest * event.select
        END

   ELSE:
   ENDCASE

   WIDGET_CONTROL, id.tmp, SET_UVALUE=tmp, /NO_COPY
   RETURN
   END


PRO pia_devkey, tmp, GROUP=group

   id = { tmp:0L, xsize:0L, xoffset:0L, ysize:0L, yoffset:0L, addkeys:0L, scalefactor:0L }

   id.tmp = WIDGET_BASE( UVALUE=tmp )
   IF not KEYWORD_SET(group) THEN group=!PIA_TOP_WID
   id_base = WIDGET_BASE( TITLE="Device Keywords", /COLUMN, /modal, GROUP=group )

   id_2 = WIDGET_BASE( id_base, /ROW )
       id_0 = WIDGET_BUTTON( id_2, VALUE='      OK      ', UVALUE='EOK' )
       id_0 = WIDGET_BUTTON( id_2, VALUE='     Quit     ', UVALUE='EQU' )

   id_4 = WIDGET_BASE( id_base, /ROW )

     id_3 = WIDGET_BASE( id_4, /COLUMN )
       XMENU, ['Portrait    ','Landscape    '], id_3, UVALUE=['GPOR','GLAN'], $
           /ROW, /EXCLUSIVE, BUTTONS=ids
       WIDGET_CONTROL, ids(0), SET_BUTTON=tmp.portrait
       WIDGET_CONTROL, ids(1), SET_BUTTON=tmp.landscape
       id_2 = WIDGET_BASE( id_3, /ROW )
           id_0 = WIDGET_LABEL( id_2, VALUE='Xsize: ' )
           id.xsize = WIDGET_TEXT( id_2, /EDITABLE, XSIZE=8, VALUE=tmp.xsize )
           id_0 = WIDGET_LABEL( id_2, VALUE='cm    ' )
           id_0 = WIDGET_LABEL( id_2, VALUE='Xoffset: ' )
           id.xoffset = WIDGET_TEXT( id_2, /EDITABLE,XSIZE=8,VALUE=tmp.xoffset)
           id_0 = WIDGET_LABEL( id_2, VALUE='cm' )
       id_2 = WIDGET_BASE( id_3, /ROW )
           id_0 = WIDGET_LABEL( id_2, VALUE='Ysize: ' )
           id.ysize = WIDGET_TEXT( id_2, /EDITABLE, XSIZE=8, VALUE=tmp.ysize )
           id_0 = WIDGET_LABEL( id_2, VALUE='cm    ' )
           id_0 = WIDGET_LABEL( id_2, VALUE='Yoffset: ' )
           id.yoffset = WIDGET_TEXT( id_2, /EDITABLE,XSIZE=8,VALUE=tmp.yoffset)
           id_0 = WIDGET_LABEL( id_2, VALUE='cm' )

     id_3 = WIDGET_BASE( id_base, /COLUMN )
     CASE tmp.device OF
     'PS': BEGIN
           XMENU, ['Color','Encapsulated'], id_3, UVALUE=['GCOL','GENC'], $
               /COLUMN, /NONEXCLUSIVE, BUTTONS=ids
           WIDGET_CONTROL, ids(0), SET_BUTTON=tmp.color
           WIDGET_CONTROL, ids(1), SET_BUTTON=tmp.encapsulated
           XMENU, ['1','2','4','8'], id_3, TITLE='Bits/Pixel:', $
               UVALUE=['B1','B2','B4','B8'], /ROW, /EXCLUSIVE, BUTTONS=ids
           IF tmp.bitsperpixel EQ 1 THEN WIDGET_CONTROL, ids(0), /SET_BUTTON
           IF tmp.bitsperpixel EQ 2 THEN WIDGET_CONTROL, ids(1), /SET_BUTTON
           IF tmp.bitsperpixel EQ 4 THEN WIDGET_CONTROL, ids(2), /SET_BUTTON
           IF tmp.bitsperpixel EQ 8 THEN WIDGET_CONTROL, ids(3), /SET_BUTTON
           id_2 = WIDGET_BASE( id_3, /ROW )
               id_0 = WIDGET_LABEL ( id_2, VALUE='Scalefactor: ' )
               id.scalefactor = WIDGET_TEXT( id_2, /EDITABLE, XSIZE=8, $
                                              VALUE=tmp.scalefactor )
           END
     'PCL': BEGIN
               XMENU, ['0  ','1  ','2  '], id_3, TITLE='Optimization:', $
                   UVALUE=['O0','O1','O2'], /ROW, /EXCLUSIVE, /NO_RELEASE, BUTTONS=ids
               IF tmp.optimize EQ '0' THEN WIDGET_CONTROL, ids(0), /SET_BUTTON
               IF tmp.optimize EQ '1' THEN WIDGET_CONTROL, ids(1), /SET_BUTTON
               IF tmp.optimize EQ '2' THEN WIDGET_CONTROL, ids(2), /SET_BUTTON
               XMENU, ['75  ','100  ','150  ','300  '], id_3, TITLE='Resolution:', $
                   UVALUE=['R75','R100','R150','R300'], /ROW, /EXCLUSIVE, BUTTONS=ids
               IF tmp.resolution EQ  75 THEN WIDGET_CONTROL, ids(0), /SET_BUTTON
               IF tmp.resolution EQ 100 THEN WIDGET_CONTROL, ids(1), /SET_BUTTON
               IF tmp.resolution EQ 150 THEN WIDGET_CONTROL, ids(2), /SET_BUTTON
               IF tmp.resolution EQ 300 THEN WIDGET_CONTROL, ids(3), /SET_BUTTON
           END
     ELSE:
     ENDCASE

   id_0 = WIDGET_LABEL( id_base, VALUE='' )
   id_0 = WIDGET_LABEL( id_base, VALUE='Additional device keywords:' )
   id.addkeys = WIDGET_TEXT( id_base, /EDITABLE, VALUE=tmp.addkeys, XSIZE=44 )

   WIDGET_CONTROL, group, TLB_GET_OFFSET=off
   WIDGET_CONTROL, id_base, /REALIZE, SET_UVALUE=id, $
                   TLB_SET_XOFFSET=off(0)+40, TLB_SET_YOFFSET=off(1)+30

   xMANAGER,No_BLOCK=1, "pia_devkey", id_base, GROUP=group
   
   WIDGET_CONTROL, id.tmp, GET_UVALUE=tmptmp, /NO_COPY
   IF N_ELEMENTS(tmptmp) NE 0 THEN tmp = tmptmp
   WIDGET_CONTROL, id.tmp, /DESTROY

   RETURN
   END


PRO pia_prtdef_event, event

   COMMON pia_print, prt

   WIDGET_CONTROL, event.id, GET_UVALUE=action
   IF N_ELEMENTS(action) EQ 0 THEN RETURN
   WIDGET_CONTROL, event.top, GET_UVALUE=id
   WIDGET_CONTROL, id.tmp, GET_UVALUE=tmp, /NO_COPY
   hash = STRMID(action,0,1)
   rest = STRMID(action,1,100)

   CASE hash OF
   'E': BEGIN
           CASE rest OF
           'OK':   BEGIN
                   WIDGET_CONTROL, id.filename, GET_VALUE=val
                   tmp.filename = STRTRIM(val(0),2)
                   WIDGET_CONTROL, id.command, GET_VALUE=val
                   tmp.command = STRTRIM(val(0),2)
                   prt = tmp
                   END
           ELSE:
           ENDCASE
           WIDGET_CONTROL, event.top, /DESTROY
           RETURN
        END

   'H': BEGIN
	   IF !VERSION.OS NE 'vms' THEN $
		spawn, '$w3net $PIA_HTML/um/printer.html &' ELSE $
		spawn, 'w3net /pia_dsk/pia/html/um/printer.html', /nowait
	END
	
   'D': BEGIN
	value = STRING(" ", FORMAT='(A24)')
	STRPUT, value, rest, 10
        WIDGET_CONTROL, id.device, SET_VALUE=value
        tmp.device = rest
        END

   'B': CASE rest OF
        'COP': tmp.copy = event.select
        'INT': tmp.interpolate = event.select
        'PRT': BEGIN
               tmp.print = event.select
               WIDGET_CONTROL, id.cmdlbl, SENSITIVE=tmp.print
               WIDGET_CONTROL, id.command, SENSITIVE=tmp.print
               END
        ELSE:
        ENDCASE

   'K': BEGIN
        pia_devkey, tmp, GROUP=event.top
        END

   ELSE:
   ENDCASE

   WIDGET_CONTROL, id.tmp, SET_UVALUE=tmp, /NO_COPY
   RETURN
   END


PRO pia_prtdef, GROUP=group

   COMMON pia_print, prt

   IF XREGISTERED("pia_prtdef") THEN BEGIN
       MESSAGE, /INFO, "already registered!"
       RETURN
   ENDIF

   IF not KEYWORD_SET(group) THEN group = !pia_top_wid
   
   IF N_ELEMENTS(prt) EQ 0 THEN pia_prtinit

   id = { device:0L, tmp:0L, filename:0L, command:0L, cmdlbl:0L }
   font=''

   id_base = WIDGET_BASE( TITLE="Printer Definition", /COLUMN, $
   		/MODAL, GROUP=group )

   id_1 = WIDGET_BASE( id_base, /ROW )
       id_0 = WIDGET_BUTTON( id_1, VALUE="      OK      ", UVALUE="EOK" )
       id_0 = WIDGET_BUTTON( id_1, VALUE="     Quit     ", UVALUE="EQU" )
       id_0 = WIDGET_LABEL( id_1, VALUE='        ')
       id_0 = WIDGET_BUTTON( id_1, VALUE="     Help     ", UVALUE="HELP" )

   id.tmp = WIDGET_BASE( id_base, /ROW, UVALUE=prt )
   id_1 = WIDGET_LABEL( id_base, VALUE='' )

   id_3 = WIDGET_BASE( id_base, /ROW )

       id_2 = WIDGET_BASE( id_3, /COLUMN )
           id_1 = WIDGET_LABEL( id_2, VALUE='Printer device:        ' )
           value = STRING(" ", FORMAT='(A24)')
           STRPUT, value, prt.device, 10
           id_1 = WIDGET_BUTTON( id_2, /MENU, VALUE=value )
           id.device = id_1
               id_0 = WIDGET_BUTTON( id_1, $
                               VALUE='CGM     - Computer Graphics Metafile)', $
                               UVALUE='DCGM', FONT=font )
               id_0 = WIDGET_BUTTON( id_1, $
                               VALUE='HP        - Hewlett-Packard Graphics Language HP-GL', $
                               UVALUE='DHP', FONT=font )
               id_0 = WIDGET_BUTTON( id_1, $
                               VALUE='LJ         - Digital Equipment LJ250', $
                               UVALUE='DLJ', FONT=font )
               id_0 = WIDGET_BUTTON( id_1, $
                               VALUE='NULL    - No graphics output', $
                               UVALUE='DNULL', FONT=font )
               id_0 = WIDGET_BUTTON( id_1, $
                               VALUE='PCL      - Hewlett-Packard Printer Control Language', $
                               UVALUE='DPCL', FONT=font )
               id_0 = WIDGET_BUTTON( id_1, $
                               VALUE='PS        - PostScript', $
                               UVALUE='DPS', FONT=font )
               id_0 = WIDGET_BUTTON( id_1, $
                               VALUE='REGIS  - Regis graphics protocol', $
                               UVALUE='DREGIS', FONT=font )
               id_0 = WIDGET_BUTTON( id_1, $
                               VALUE='SUN     - SunView Windowing system', $
                               UVALUE='DSUN', FONT=font )
               id_0 = WIDGET_BUTTON( id_1, $
                               VALUE='TEK      - Tektronics compatible terminal', $
                               UVALUE='DTEK', FONT=font )
               id_0 = WIDGET_BUTTON( id_1, $
                               VALUE='X          - X window system', $
                               UVALUE='DX', FONT=font )
               id_0 = WIDGET_BUTTON( id_1, $
                               VALUE='Z          - Z-buffer pseudo device', $
                               UVALUE='DZ', FONT=font )

           id_1 = WIDGET_BUTTON( id_2, VALUE='    Keywords...    ', UVALUE='KEYW' )

       id_2 = WIDGET_LABEL( id_3, VALUE='   ' )

       XMENU, ['Copy','Interpolate'], id_3, UVALUE=['BCOP','BINT'], $
              /NONEXCLUSIVE, /COLUMN, BUTTONS=ids, TITLE='Color table:        '
       WIDGET_CONTROL, ids(0), SET_BUTTON=prt.copy
       WIDGET_CONTROL, ids(1), SET_BUTTON=prt.interpolate

   id_3 = WIDGET_BASE( id_base, /COLUMN )
       id_0 = WIDGET_LABEL( id_3, VALUE='' )
       id_1 = WIDGET_BASE( id_3, /NONEXCLUSIVE )
           id_0 = WIDGET_BUTTON( id_1, VALUE='Send file to printer', UVALUE='BPRT' )
           WIDGET_CONTROL, id_0, SET_BUTTON=prt.print
       id.cmdlbl = WIDGET_LABEL( id_3, VALUE='Print command of operating system:' )
       id.command = WIDGET_TEXT( id_3, /EDITABLE, VALUE=prt.command )
       id_0 = WIDGET_LABEL( id_3, VALUE='Name of print file (leave blank for IDL default):' )
       id.filename = WIDGET_TEXT( id_3, /EDITABLE, VALUE=prt.filename )


   WIDGET_CONTROL, id_base, /REALIZE
   WIDGET_CONTROL, id.cmdlbl, SENSITIVE=prt.print
   WIDGET_CONTROL, id.command, SENSITIVE=prt.print

   WIDGET_CONTROL, id_base, SET_UVALUE=id, /NO_COPY

   xMANAGER,No_BLOCK=1, "pia_prtdef", id_base, GROUP=group

   RETURN
   END
