;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_pseudo_rd
;
; PURPOSE:
;	Ask the interactive user for a value, and pass it back to the PIA 
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_pseudo_rd, anythin, anythout
;
; INPUTS:
;	anythin:
;		A value indicating a maximum value to be chosen
;	
; OUTPUT:
;	anythout:
;		The structure chosen by the user: {model:0 or 1,value:value}
;	
; COMMON BLOCKS:
;	@splitramp_par
;
; PROCEDURES USED:
;	none
;	
; MODIFICATION HISTORY:
;	Written by:	C.Gabriel (ESA/VILSPA-SAI)	November 1996
;	Version 5.x
;	Returning a structure for defining model 	May 1997
;	V6.3
;	Checking that number of read-outs per ramp or
;	number of sub-ramps is not outside (CG)	        November 1999
;	V8.2
;	Check for maximum RO-number allowed fixed (CG)	July 2000
;	V9.1 
;-

; ****************************************************************************
;  PIA_pseudo_RD - menu definition procedure
; ****************************************************************************

PRO pia_pseudo_rd, anythin, anythout

@splitramp_par


	IF N_ELEMENTS(splitramp_par) EQ 0 THEN splitramp_par_init

        junkbase = WIDGET_BASE(TITLE=$
          'Ramp Subdivision menu ', $
            /COLUMN)


	anythout = splitramp_par       
	
        model = cw_bgroup(junkbase, LABEL_TOP = 'Division choices', $
                        /EXCLUSIVE, /FRAME, $
                        SET_VALUE = anythout.model, $
                        UVALUE = 'MODEL', $
                        ['Number of read-outs (< '+STRTRIM(anythin/2+1,2)+ ')', $
                         'Number of sub-ramps / ramp (< '+STRTRIM(anythin,2)+')'])

	jun2base = WIDGET_BASE(junkbase, /ROW)
	junk = WIDGET_LABEL(jun2base, $
		VAL='Give value:    ', UVAL='JUNK')
	text_id = WIDGET_TEXT(jun2base, VAL=STRTRIM(splitramp_par.value,2), $
		/EDITABLE, UVAL='JUNK')

	jun2base = WIDGET_BASE(junkbase, /ROW)
	ok = WIDGET_BUTTON(jun2base, VALUE=' OK ', UVALUE='OK')
 	cancel = WIDGET_BUTTON(jun2base, VALUE=' Cancel ', UVALUE='CANCEL')
       WIDGET_CONTROL, junkbase, /REALIZE

WAITING:
	out = 0
	WHILE out EQ 0 DO BEGIN
	 event = WIDGET_EVENT(junkbase)
	 WIDGET_CONTROL, event.id, GET_UVALUE=uvalue


	IF uvalue EQ 'OK' THEN BEGIN
	   WIDGET_CONTROL, text_id, GET_VALUE=value
           IF STRTRIM(value(0),2) EQ '' THEN $
                  PRINT, STRING(7b) + 'Give Value, please' $
           ELSE BEGIN 
	    anythout.value = FIX(value(0))
	    WIDGET_CONTROL, model, GET_VALUE=value
	    anythout.model = value(0)
	    
; Check that is not outside the range

	    IF anythout.model EQ 0 AND $
	    	anythout.value GT (anythin/2) THEN BEGIN
	          PRINT, STRING(7b) + 'Value too high, set to maximum'
		  anythout.value = anythin/2
	    ENDIF ELSE IF anythout.model AND anythout.value GE anythin $
	    	THEN BEGIN
	          PRINT, STRING(7b) + 'Value too high, set to maximum'
		  anythout.value = anythin-1	
	    ENDIF
		  
	    splitramp_par = anythout
            out = 1
           ENDELSE
	ENDIF ELSE IF uvalue EQ 'MODEL' THEN BEGIN
           WIDGET_CONTROL, model, GET_VALUE=value
 	   anythout.model = value(0)
	ENDIF ELSE IF uvalue EQ 'CANCEL' THEN BEGIN
	   anythout.model = -1
	   anythout.value = 0
           out = 1
        ENDIF 
	ENDWHILE

	WIDGET_CONTROL, junkbase, /DESTROY
	RETURN
END

