;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_READ_EXT
;
; PURPOSE:
;       This is the "ISOPHOT Interactive Analysis" Control Panel
;	program. It is used for reading input files. 
;
; CATEGORY:
;       PIA - graphics
;
; CALLING SEQUENCE:
;       PIA
;
; COMMON BLOCKS:
;       phtcs
;       phterd
;	phtsrd
;	phtspd
;	phtscp
;	phtsmc
;	phtcla
;
; PROCEDURES USED:
;       PIA LIB:
;	  pia_read_fits
;	  pia_view_txt
;	  pia_load_ierd
;	  pia_pickfile1
;	  pia_load_isrd
;	  pia_sm_load_ismc
;	  pia_load_iscp
;	  pia_load_ispd
;	  pia_read_ifile
;	  pia_prtdef
;	  pia_dispdata
;	  pia_disp_cs
;	  pia_showdata
;	  pcont_valid_dir
;	  pcont_getfiles
;	  pcont_getdirs
;	  decode_cs2mea
;	  decode_filetype
;	  decode_hdr2mea
;	  decode_tdt2mea
;	Astronomical Library:
;	  sxpar
; MODIFICATION HISTORY:
;	Written by: Wai-Ming Tai (DIAS)			Apr 1996
;	Changed (last) by SB+CG				Oct 1996
;	V5.x
;	Preventing a crash by choosing 1 measurement 
;	  in multi-mode (CG)				Jun 1997
;	V6.4
;	Passing real string to filelist to avoid Linux
;	 strange appearance (CG)			Aug 1999
;	V8.0
;	Taking out question on adding several meas.(CG) Dec 1999
;	V8.2
;
;-
;------------------------------------------------------------------------
pro pia_read_ext_event, event
@phterd
@phtsrd
@phtscp
@phtspd
@phtsmc
@phtcla
common pia_rext_cmn, sel_par, id, par, mfilelist

	case event.id of

; the select file from chose
	id.hpipeline : pcont_refresh, id, sel_par, par, selection = '0'
	id.hpiafits : pcont_refresh, id, sel_par, par, selection = '1' 
	id.hintsave : pcont_refresh, id, sel_par, par, selection = '2'

; the detector type
	id.hdet : begin
	        par.det_index = event.index
		widget_control, id.hdet, get_uvalue = tmp
		par.thedet = tmp(event.index)
		pcont_refresh, id, sel_par, par, /update
		end

; the file type
	id.hftype : begin
	        par.ftype_index = event.index
		widget_control, id.hftype, get_uvalue = tmp
		par.theftype = tmp(event.index)
		pcont_refresh, id, sel_par, par, /update
		end

; The subdirectories box
	id.hsubdir: pcont_subdir, id, par, event

; The file selection box
	id.hfiles : begin
		widget_control, id.hfiles, get_uvalue=filelist
		par.thefile = filelist(event.index)
                decode_filetype, par.thefile, strl
		if par.showfinfo eq 1 then begin
		  if par.sel_index lt 2 then begin
; only valid when we select fits file, ie. sel_index = 2 means internal
; save files is selected.
		  read_fits_header, par.thefile, hdr
		  keyword = strmid(hdr, 0, 8)
		  if n_elements(keyword) gt 0 then begin
		    nrow = string(sxpar(hdr, 'NAXIS1'))
		    ncol = string(sxpar(hdr, 'NAXIS2'))
		    if nrow gt 0 then begin
		      widget_control, id.hfilerow, set_value = nrow
		      widget_control, id.hfilecol, set_value = ncol
		    endif
		  endif
		  endif
		endif

		msg = strl + ': ' + par.thefile + ' selected.'
		pcont_msgline, msg, id.hmsgline
		end

; the file filter box
	id.hfilt : begin
		widget_control, id.hfilt, get_value=newfilter
		pcont_filter, id, newfilter
		end

; the below three are the pathtext, where
;     0 is the pipeline fits
;     1 is the pia fits
;     2 is the internal file
	id.hpathtxt(0) : pcont_change_path, id, par, 0
	id.hpathtxt(1) : pcont_change_path, id, par, 1
	id.hpathtxt(2) : pcont_change_path, id, par, 2

; change the state of the show file panel
	id.hshowinfo: begin
		if par.showfinfo eq 0 then $
		  par.showfinfo = 1 $
		else par.showfinfo = 0
		widget_control, id.hfileinfopanel, sensitive = par.showfinfo
		end

; view the fits header
	id.hviewhdr: if par.thefile NE '' then $
		       pcont_viewhdr, par.sel_index, id, par.theftype, $
			par.thefile, group = event.top $
		     else pcont_msgline, 'Warning: No file Selected!',$
		       id.hmsgline

; reading the selected file
	id.hread: begin
		if par.thefile EQ '' then $
		  pcont_msgline, 'Warning: No file selected!', id.hmsgline $
		else begin
		if par.mread EQ 0 then begin
  		  widget_control, event.top, /hourglass
		; read file now!
		  pcont_readfile, id, par.sel_index, par.thefile, $
		    par.pathtxt(par.sel_index) 
		endif else begin

; or begin adding file

; make sure selected file is not in the filelist
		ind = where(mfilelist.filename EQ par.thefile, matches)

		if matches EQ 0 then begin
		  tmpfile = {filelist, stype: par.sel_index, $
		    filename: par.thefile, $
                    pathname: par.pathtxt(par.sel_index) }
		  mfilelist = [ mfilelist, tmpfile ]
		  n = n_elements(mfilelist) - 1

		  if n GT 1 then $
		    tmpfile = mfilelist(1:n).filename $
		  else tmpfile = [ mfilelist(1).filename ]
		    widget_control, id.hmread_list, set_value=tmpfile

		endif else pcont_msgline, 'File: ' + par.thefile + ' already added', id.hmsgline
			
		endelse
		endelse
		end
		
; the read multiple file selection box, it changes the readfile button
; to Add file if selected.

	id.hmreadfile: begin
	  	par.mread = event.select
		if par.mread EQ 1 then begin
		  widget_control, id.hread, set_value = $
		    'Add File =>' 
		  widget_control, id.hmreadpan, sensitive = 1
		  widget_control, id.haddall, sensitive = 1
		endif else begin
		  widget_control, id.hread, set_value = $
                    'Read File  '
		  widget_control, id.hmreadpan, sensitive = 0
		  widget_control, id.haddall, sensitive = 0
		endelse
		end
	id.haddall: begin
		widget_control, id.hfiles, get_uvalue=filelist
		n_ele = n_elements(filelist)
; no point doing it if there is no files
		if n_ele gt 0 then begin
		msg = 'Are you sure to add all the files?'
; take out question
;		res = yes_no(msg)
		res = 1
		if res eq 1 then begin
		  tmpfile = replicate(mfilelist(0), n_ele)
; make sure there is no duplicated files in the mfilelist
		  tmpfile(*).stype = par.sel_index
		  tmpfile(*).pathname = par.pathtxt(par.sel_index)
		  IF n_ele EQ 1 THEN filelist = filelist(0)
		  tmpfile(*).filename = filelist
		  ind = where(mfilelist(*).filename ne tmpfile(*).filename, count)
		  if count gt 0 then $
		    tmpfile = tmpfile(ind)
		  mfilelist = [mfilelist, tmpfile]

		  n = n_elements(mfilelist)
; note that mfilelist is 
		  if n gt 1 then $
		    tmpfile = mfilelist(1:n-1).filename
		  widget_control, id.hmread_list, set_value=tmpfile
		endif
		endif
		end

; selecting a file from the multiple file list
	id.hmread_list: par.mfileindex = event.index 
	
; reading the files from the multiple file list box
	id.hmread: begin
		  n = n_elements(mfilelist)
		  if n GT 1 then begin
                  widget_control, event.top, /hourglass
                  for i = 1, n-1 do $
                    pcont_readfile, id, mfilelist(i).stype, $
			mfilelist(i).filename, mfilelist(i).pathname
		  pcont_clearmfile, id, par, mfilelist
		endif else pcont_msgline, 'Warning: No file to read!', id.hmsgline
 		end

; remove a file from the multiple file list
	id.hmremove: if par.mfileindex NE -1 then $
		  pcont_mremove, id, par, mfilelist $
		else pcont_msgline, 'Warning: No file selected to remove!', id.hmsgline

; help
	id.hhelp: begin
		widget_control, event.top, /hourglass
		if !VERSION.OS NE 'vms' THEN $
                 spawn, '$w3net $PIA_HTML/um/f_b_control_window.html &' ELSE $
                 spawn, 'w3net /pia_dsk/pia/html/um/f_b_control_window.html',/nowait
                END
; well quit
        id.hquit: widget_control, event.top, /destroy

	else:
	endcase
return
	
print_error:
  widget_control, id.hmsgline, set_value="!!! Unable to Open File !!!"
  return
end


;------------------------------------------------------------------------
pro pia_read_ext, group = group

; we only want to show pia_read_ext once, xregistered function would bring
; the pia_control to the front of all the other windows by default

  if xregistered("pia_read_ext") NE 0 then return

@phterd
@phtsrd
@phtscp
@phtspd
@phtsmc
@phtcla
common pia_rext_cmn, sel_par, id, par, mfilelist

; the array are :
; index 0: pipeline fits selection
; index 1: PIA fits selection
; index 2: internal save selection

  sel_par = lonarr(3)

  p_file_type = ['ERD', 'SRD', 'SMC', 'SCP', 'SPD', 'AAP', 'Cal A', 'ALL']
  pdet_list = ['P1', 'P2', 'P3', 'C100', 'C200', 'SS/SL', 'ALL']
  p_filters = ['P1*_ERD.FITS', 'P2*_ERD.FITS', 'P3*_ERD.FITS', $
	     'C1*_ERD.FITS', 'C2*_ERD.FITS', 'S**_ERD.FITS', '*_ERD.FITS', $
             'P1*_SRD.FITS', 'P2*_SRD.FITS', 'P3*_SRD.FITS', $
	     'C1*_SRD.FITS', 'C2*_SRD.FITS', 'S**_SRD.FITS', '*_SRD.FITS', $
             'PPSM*.FITS', 'PPSM*.FITS', 'PPSM*.FITS', $
	     'P1SM*.FITS', 'P2SM*.FITS', 'PSSM*.FITS', 'P*SM.FITS', $
             'P1*_SCP.FITS', 'P2*_SCP.FITS', 'P3*_SCP.FITS', $
	     'C1*_SCP.FITS', 'C2*_SCP.FITS', 'S**_SCP.FITS', '*_SCP.FITS', $
             'P1*_SPD.FITS', 'P2*_SPD.FITS', 'P3*_SPD.FITS', $
	     'C1*_SPD.FITS', 'C2*_SPD.FITS', 'S**_SPD.FITS', '*_SPD.FITS', $
             'P1*_AAP.FITS', 'P2*_AAP.FITS', 'P3*_AAP.FITS', $
	     'C1*_AAP.FITS', 'C2*_AAP.FITS', 'S**_AAP.FITS', '*_AAP.FITS', $
             'P1*_CLA.FITS', 'P2*_CLA.FITS', 'P3*_CLA.FITS', $
	     'C1*_CLA.FITS', 'C2*_CLA.FITS', 'S**_CLA.FITS', '*_CLA.FITS', $
	     '*.FITS', '*.FITS', '*.FITS', '*.FITS', '*.FITS', $
	     '*.FITS', '*.FITS']
  nftype = n_elements(pdet_list)
  pstruc = { nftype: nftype, detectors: pdet_list, $
	filetype: p_file_type, filters: p_filters }

  sel_par(1) = handle_create()
  handle_value, sel_par(1), pstruc, /set

  p_file_type = ['ERD', 'SRD', 'SMC', 'SCP', 'SPD', 'AAP', 'Cal A', 'ALL']
  pdet_list = ['P1', 'P2', 'P3', 'C100', 'C200', 'SS/SL', 'ALL']
  p_filters = ['P1*.IERD', 'P2*.IERD', 'P3*.IERD', $
	     'C1*.IERD', 'C2*.IERD', 'S**.IERD', '*.IERD', $
             'P1*.ISRD', 'P2*.ISRD', 'P3*.ISRD', $
	     'C1*.ISRD', 'C2*.ISRD', 'S**.ISRD', '*.ISRD', $
             'P1*.ISMC', 'P2*.ISMC', 'P3*.ISMC', $
	     'C1*.ISMC', 'C2*.ISMC', 'S**.ISMC', '*.ISMC', $
             'P1*.ISCP', 'P2*.ISCP', 'P3*.ISCP', $
	     'C1*.ISCP', 'C2*.ISCP', 'S**.ISCP', '*.ISCP', $
             'P1*.ISPD', 'P2*.ISPD', 'P3*.ISPD', $
	     'C1*.ISPD', 'C2*.ISPD', 'S**.ISPD', '*.ISPD', $
             'P1*.IAAP', 'P2*.IAAP', 'P3*.IAAP', $
	     'C1*.IAAP', 'C2*.IAAP', 'S**.IAAP', '*.IAAP', $
             'P1*.ICLA', 'P2*.ICLA', 'P3*.ICLA', $
	     'C1*.ICLA', 'C2*.ICLA', 'S**.ICLA', '*.ICLA', $
	     '*.I*', '*.I*', '*.I*', '*.I*', '*.I*', $
	     '*.I*', '*.I*']
  nftype = n_elements(pdet_list)
  pstruc = { nftype: nftype, detectors: pdet_list, $
	filetype: p_file_type, filters: p_filters }
  sel_par(2) = handle_create()
  handle_value, sel_par(2), pstruc, /set

  p_file_type = ['ERD', 'SPD', 'AAR', 'Cal A', 'ALL']
  pdet_list = ['P1, P2, P3', 'C100', 'C200', 'SS/SL', 'ALL']
  if !version.os EQ "vms" then $
; note that vms use % for one wildcard character and unix use ?
    p_filters = ['PPER*.FITS', 'P1ER*.FITS', 'P2E*.FITS', $
             'PSER*.FITS', 'P%ER*.FITS', $
	     'PP*S*.FITS', 'PC1S*.FITS', 'PC2S*.FITS', $
	     'PS*S*.FITS', 'P%%S*.FITS', $
	     'P%A*.FITS', 'P%A*.FITS', 'P%A*.FITS', 'P%A*.FITS', 'P%A*.FITS', $
	     'PP*A*.FITS', 'PC1A*.FITS', 'PC2A*.FITS', $
	     'PS*A*.FITS', 'P%%A*.FITS', $
	     '*.FITS', '*.FITS', '*.FITS', '*.FITS', '*.FITS'] $
  else $

; The order of the following table is ERD, SPD, AAR, CLA, ALL
    p_filters = [ $
	'PPER*.FITS',$		; ERD, P1, P2, P3
	'P1ER*.FITS',$		; ERD C100
	'P2E*.FITS',$		; ERD C200 & Serendipity
	'PSER*.FITS',$		; ERD SS/SL
	'P?ER*.FITS',$ 		; ERD ALL    
	'PP[123]S*.FITS',$	; SPD P1, P2, P3
	'PC1S*.FITS',$		; SPD C100
	'PC2S*.FITS',$		; SPD C200
	'PS[LS]S*.FITS',$	; SPD SS/SL
	'P??S*.FITS',$		; SPD ALL
	'PPA[PES]*.FITS',$	; AAR P1, P2, P3
	'PCA[PES]*.FITS',$	; AAR C100
	'PCA[PES]*.FITS',$	; AAR C200
	'P[LS]A[PES]*.FITS',$	; AAR SS/SL
	'P?A*.FITS',$		; AAR ALL
	'PP[123]A*.FITS',$	; Cal A P1, P2, P3
	'PC1A*.FITS',$		; Cal A C100
	'PC2A*.FITS',$		; Cal A C200
	'PS*A*.FITS',$		; Cal A SS/SL
	'P??A*.FITS',$		; Cal A ALL
	'*.FITS', '*.FITS', '*.FITS', '*.FITS', '*.FITS']
  nftype = n_elements(pdet_list)
  pstruc = { nftype: nftype, detectors: pdet_list, $
	filetype: p_file_type, filters: p_filters }

  sel_par(0) = handle_create()
  handle_value, sel_par(0), pstruc, /set

  par = { sel_index: 0, det_index: 0, ftype_index: 0, thefile : '',$
	  thedet: '', theftype: '', separator: '',$
	  showfinfo: 0, $
	  pathtxt: strarr(3), mread: 0, mfileindex: -1}

  CASE !VERSION.OS OF
  'vms':          par.separator       = ''
  ; WINDOWS does NOT want a \ at the end of the directory
  'windows':      par.separator       = ''
  'MacOS': par.separator = ""
  ELSE:           par.separator       = '/'
  ENDCASE

  id = { $
	 hftype: 0L, hdet: 0L, $
	 hpipeline: 0L, hpiafits: 0L, hintsave: 0L , hfilt: 0L, $
	 hpathtxt: lonarr(3), $
	 hfiles: 0L, hsubdir: 0L, $
	 hmreadfile: 0L, hread: 0L, hviewhdr: 0L, $
	 haddall: 0L, $
	 hmreadpan: 0L, hmread_list: 0L, hmread: 0L, hmremove: 0L, $
	 hshowinfo: 0L, hfileinfopanel: 0L, hfilerow: 0L, hfilecol: 0L, $
	 habout: 0L, hquit: 0L, hhelp: 0L, $
	 hmsgline: 0L}

  par.pathtxt(0) = !FITDIR
  par.pathtxt(1) = !PFITDIR
  par.pathtxt(2) = !xdrdir
; we would like to use the mfilelist as flexible as possible and
; therefore use the following:
; stype: the file type, 0 for pipeline, 1 for pia fits and 2 for internal
; filename: is the filename
; pathname: is the pathname associate with the filename
  tmpfile = { filelist, stype: 0, filename: '', pathname: ''}
  mfilelist = [ tmpfile ]

  par.thedet = pdet_list(0)
  par.theftype = p_file_type(0)
  par.mread = 0
  cd, par.pathtxt(0)
  directories = pcont_getdirs()

  filelist = pcont_getfiles(p_filters(0))
    
  base = widget_base(title='PIA Files Control Window', /COLUMN)

  widget_control, base, default_font = $
    "fixed"

  bar_base = widget_base(base, /ROW)
  id.hquit = widget_button(bar_base, val=' Quit ',/FR)
;  id_1 = widget_label( bar_base, $
;    val='                                                                ')
  id.hhelp = widget_button(bar_base, val=' Help ', /FR)

  bar_base = widget_base(base, /column, /FR)

  id_0 = widget_base(bar_base, /ROW, SPACE = 10)
  
  id_1 = widget_base(id_0, /COLUMN)
  id_2 = widget_label(id_1, value = 'File Type:  ')
  id.hftype = widget_list(id_1, value = p_file_type, $
    uvalue = p_file_type, YS = 8)
  
  id_1 = widget_base(id_0, /COLUMN)
  id_2 = widget_label(id_1, value = 'Detectors:  ')
  id.hdet = widget_list(id_1, value = pdet_list, $
    uvalue = pdet_list, YS = 8)
  
  id_1 = widget_base(id_0, /COLUMN)
  id_2 = widget_label(id_1, value = 'Select Files From:    ')
  id_2 = widget_base(id_1, /EXCLUSIVE )
  id.hpipeline = widget_button(id_2, val="Pipeline FITS:", $
    UVA="PLINE", /NO_RELEASE)
  id.hpiafits  = widget_button(id_2, val="PIA FITS:", $
    UVA="PIAF", /NO_RELEASE)
  id.hintsave  = widget_button(id_2, val="Internal Save file:", $
    UVA="ISAVE", /NO_RELEASE)
; The Filter
  id_2 = widget_base(id_1, /ROW)
  id_3 = widget_label(id_2, value='Filters:')
  id.hfilt = widget_text(id_2, value=p_filters(0), uval=p_filters(0), $
		/edit, xs = 12)

  id_1 = widget_base(id_0, /COLUMN)
  id_2 = widget_label(id_1, value = '                            ')
  id.hpathtxt(0) = widget_text(id_1, val=par.pathtxt(0), $
    uva=par.pathtxt(0), /edit, xs = 52)
  id.hpathtxt(1) = widget_text(id_1, val=par.pathtxt(1), $
    uva=par.pathtxt(1), /edit, xs = 52)
  id.hpathtxt(2) = widget_text(id_1, val=par.pathtxt(2), $
    uva=par.pathtxt(2), /edit, xs = 52)

; Subdirectories box  
  id_0 = widget_base(bar_base, /ROW, space = 10)
  
  id_1 = widget_base(id_0, /COLUMN, XS=130, /fr)
  id_2 = widget_label(id_1, value = 'Subdirectories:    ')
  id.hsubdir = widget_list(id_1, value = directories, $
    uv = directories, ys = 11, xsize = 11)

; File selection box  
  id_1 = widget_base(id_0, /COLUMN, XS = 190, /FR)
  if filelist(0) EQ '' THEN ffflist = '       ' ELSE ffflist = filelist
  id_2 = widget_label(id_1, value = 'Files:                       ')
  id.hfiles = widget_list(id_1, value = ffflist, $
    uv = filelist, ys = 11, xsize = 14)

; Multiple file box  
  id_1 = widget_base(id_0, /COLUMN)
;  id_2 = widget_label(id_1, val='  ')
  id_2 = widget_base(id_1, /NONEXCLUSIVE, /FR)
  id.hmreadfile = widget_button(id_2,   val='Read Multiple File')
  id.hshowinfo = widget_button(id_2,   val='Show File Info')

  id.hviewhdr = widget_button(id_1, val='Show Header')
  id.hread = widget_button(id_1,    val='Read File  ')
  id.haddall = widget_button(id_1, val=' Add all Files => ')
;  id_2 = widget_base(id_1, /NONEXCLUSIVE, /FR)
  id.hfileinfopanel = widget_base(id_1, /column, /fr)
  id_3 = widget_base(id.hfileinfopanel, /row)
  id_4 = widget_label(id_3, value='Rows: ')
  id.hfilerow = widget_label(id_3, value='        ', xs=90)
  id_3 = widget_base(id.hfileinfopanel, /row)
  id_4 = widget_label(id_3, value='Cols: ')
  id.hfilecol = widget_label(id_3, value='        ', xs=90)

  id.hmreadpan = widget_base(id_0, XS = 180, /COLUMN, /FR)
  id_1 = widget_label(id.hmreadpan, val='Selected Files for Reading:')
  id.hmread_list = widget_list(id.hmreadpan, YS=9)
  id_2 = widget_base(id.hmreadpan, /ROW)
  id_3 = widget_label(id_2, val='  ')
  id.hmread = widget_button(id_2, val=' Read All ')
  id.hmremove = widget_button(id_2, val=' Remove ')

; message line
  id_0 = widget_base(base, /FR, /ROW)
  id.hmsgline = widget_label(id_0, val='                                 ', $
  		XS = 640)

  ; initialize widget states
  widget_control, id.hdet, set_list_select = 0
  widget_control, id.hftype, set_list_select = 0
  widget_control, id.hpathtxt(0), sensitive = 1
  widget_control, id.hpathtxt(1), sensitive = 0
  widget_control, id.hpathtxt(2), sensitive = 0
  widget_control, id.hfileinfopanel, sensitive = 0
  widget_control, id.haddall, sensitive = 0
  widget_control, id.hmreadpan, sensitive = 0
  widget_control, id.hpipeline, set_button = 1
  widget_control, id.hpiafits, set_button = 0
  widget_control, id.hintsave, set_button = 0
  widget_control, base, /realize, TLB_SET_YOFFSET=75
  
  xmanager, No_BLOCK=1, 'pia_read_ext', base, group=group
end
