;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_READ_IFILE
;
; PURPOSE:
;	Recognize one of the PIA internal files (IDL save format) and call
;	the corresponding read procedure 
;
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;	pia_read_ifile, filename, path = path
;
; INPUTS:
;	Filename
; OPTIONAL INPUT:
;	PATH : path for the filename
;	
; KEYWORD PARAMETERS:
;	none
;	
; OUTPUTS:
;	none
;	
; RESTRICTIONS:
;	suffix of filename must correspond to the PIA internal files
;	nomenclature 	
;	
; COMMON BLOCKS:
;	none
;
; PROCEDURES USED:
;	PIA Procedure(s):
;		read_icla
;		read_ierd
;		read_iscp
;		read_ispd
;		read_isrd
;
; MODIFICATION HISTORY:
;	Written by:	C. Gabriel, ESA/ESTEC		August 1994
;	Oct 95 Version 3.5
;	Modified (last) by CG - October 1996
;	V5.x
;	Accepting any filename (CG)			May 1997
;	V6.3
;-
;
PRO pia_read_ifile, filename, path = path

        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  PIA_READ_IFILE, FILENAME, [PATH = PATH]'

;	filename = STRUPCASE(STRTRIM(filename,2))
 	filename = STRTRIM(filename,2)

;  Look for semicolon position (VMS version, inexistent under UNIX)

	if !version.os EQ "vms" then $
	  possemic = STRPOS(filename,';') ELSE $
          possemic = STRLEN(filename)

	ityp = STRMID(filename,possemic - 4,4) 
	
	CASE ityp of

		'IERD': BEGIN
			if keyword_set(path) then begin
			  read_ierd, filename, path = path, admn = admn
			  csname = 'CS'+STRMID(admn,4,8)+'.ICS'
			  read_ics, csname, path = path
			endif else begin
			  read_ierd, filename, admn = admn
			  csname = 'CS'+STRMID(admn,4,8)+'.ICS'
			  read_ics, csname
			endelse
		END
		'ISRD': BEGIN
			if keyword_set(path) then begin
			  read_isrd, filename, path = path, admn = admn
			  csname = 'CS'+STRMID(admn,4,8)+'.ICS'
			  read_ics, csname, path = path
			endif else begin
			  read_isrd, filename, admn=admn
			  csname = 'CS'+STRMID(admn,4,8)+'.ICS'
			  read_ics, csname
			endelse
		END

                'ISMC': BEGIN
                        if keyword_set(path) then begin
                          read_ismc, filename, path = path, admn = admn
			  csname = 'CS'+STRMID(admn,4,8)+'.ICS'
                          read_ics, csname, path = path
                        endif else begin
                          read_ismc, filename, admn = admn
			  csname = 'CS'+STRMID(admn,4,8)+'.ICS'
                          read_ics, csname
                        endelse
                END
 
		'ISCP': BEGIN
			if keyword_set(path) then begin
			  read_iscp, filename, path = path, admn = admn
			  csname = 'CS'+STRMID(admn,4,8)+'.ICS'
			  read_ics, csname, path = path
			endif else begin
			  read_iscp, filename, admn = admn
			  csname = 'CS'+STRMID(admn,4,8)+'.ICS'
			  read_ics, csname
			endelse
		END

		'ISPD': BEGIN
			if keyword_set(path) then begin
			  read_ispd, filename, path = path, admn = admn
			  csname = 'CS'+STRMID(admn,4,8)+'.ICS'
			  read_ics, csname, path = path
			endif else begin
			  read_ispd, filename, admn = admn
			  csname = 'CS'+STRMID(admn,4,8)+'.ICS'
			  read_ics, csname
			endelse
		END
		
		'IAAP': BEGIN
			if keyword_set(path) then begin
			  read_iaap, filename, path = path, admn = admn
			  csname = 'CS'+STRMID(admn,4,8)+'.ICS'
			  read_ics, csname, path = path
			endif else begin
			  read_iaap, filename, admn = admn
			  csname = 'CS'+STRMID(admn,4,8)+'.ICS'
			  read_ics, csname
			endelse
		END
		
		'ICLA': BEGIN
			if keyword_set(path) then begin
			  read_icla, filename, path = path, admn = admn
			  csname = 'CS'+STRMID(admn,4,8)+'.ICS'
			  read_ics, csname, path = path
			endif else begin
			  read_icla, filename, admn = admn
			  csname = 'CS'+STRMID(admn,4,8)+'.ICS'
			  read_ics, csname
			endelse
		END
		
		'IAAR': MESSAGE, /INFO, 'IAAR read not yet implemented   '
		
		ELSE: MESSAGE, /INFO, 'No file match   '

	ENDCASE

	RETURN
END
