;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_RESPS_STRUCT_VAL_CHOICE
;
; PURPOSE:
;	Menu for extracting values from the PHT Responses Structures 
;
; CATEGORY:
;       PIA - graphics
;
; CALLING SEQUENCE:
;       PIA_RESPS_STRUCT_VAL_CHOICE
;
; INPUTS:
;	STRRESPONS
;		The structure to be chosen from
;
; KEYWORD PARAMETERS:
;	GROUP=group: Group leader
;
; OUTPUTS:
;	ACC_INDICES
;		The structure indices corresponding to the selection
; COMMON BLOCKS:
;	pia_varselected_cmn	I/F to pia_select_var
;	
; PROCEDURES USED:
;	PIA Lib: 
;		pia_select_var
;	Astro Lib:
;		match
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel (ESA/VILSPA) 		November 1995
;	Bug with String lengths fixed (CG)		January 1996
;	Bug for several absolute choices fixed (CG)	February 1996
;
;-
; *****************************************************************
; ***************  choice menu for structure elements
; *****************************************************************
PRO PIA_RESPS_STRUCT_VAL_CHOICE, strresp, acc_indices

COMMON pia_varselected_cmn, vars


; set first the acc_indices to bad
	acc_indices = -1

; data specifications
	data_names = ['Flag', 'Date', 'Source', 'Filter_id', $
	         'In-band power', '# Photons', 'Orb pos']
        data_exa = [STRING(strresp(0).flag), strresp(0).date, $
	  strresp(0).source, strresp(0).filter_id, $
	  STRING(strresp(0).f_star), $
	  STRING(strresp(0).qb_star),STRING(strresp(0).orbpos)]  
	data_pos = [0,1,2,5,6,8,4]
	  
; get variables limits
	vartyp=[0,0,1,1,0,0,0]
	pia_select_var, data_exa, VARNAMES=data_names, $
		VARTYP=vartyp, GROUP=group
	
	nelem = N_ELEMENTS(strresp)
	indall = indgen(nelem)


; look first for absolute choices

	indch = WHERE(vars(0,*) NE '' AND vartyp EQ 1, count)

	IF count GT 0 THEN BEGIN
	  FOR I=0,count-1 DO BEGIN
	  	filt = [vars(0,indch(i))]
		posi = data_pos(indch(i))
		posi = posi(0)
		indfilt = WHERE(STRTRIM(strresp.(posi),2) EQ $
			STRTRIM(filt(0),2), nfilt)

	     	IF nfilt EQ 0 THEN BEGIN

			text = 'No ' + data_names(indch) + $
				' corresponding to selection'
                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = text
                        RETURN
	     	ENDIF
			  	 	  
		match, indall, indfilt, suba, subb, count=count
		IF count EQ 0 THEN GOTO, nocomb
		indall = indall(suba)
	   ENDFOR
	  ENDIF


; and then for chosen ranges

	indch = WHERE(vars(0,*) NE '' AND vartyp EQ 0, count)

	IF count GT 0 THEN BEGIN
	  FOR I=0,count-1 DO BEGIN
		IF vars(1,indch(i)) EQ '' THEN BEGIN
                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [" Incomplete Spec found, returning  "]
			RETURN
		ENDIF			

	  	filt = [vars(0,indch(i)),vars(1,indch(i))]
		posi = data_pos(indch(i))
		posi = posi(0)
		indfilt = WHERE(strresp.(posi) GE filt(0) AND $
				strresp.(posi) LE filt(1), nfilt)

	     	IF nfilt EQ 0 THEN BEGIN

			text = 'No ' + data_names(indch(i)) + $
				' corresponding to selection'
                        XDISPLAYFILE, "", $
                                TITLE = "Input not accepted", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = text
                        RETURN
	     	ENDIF
			  	 	  
		match, indall, indfilt, suba, subb, count=count
		IF count EQ 0 THEN GOTO, nocomb
		indall = indall(suba)
	  ENDFOR
	ENDIF

	acc_indices = indall
	nacc = N_ELEMENTS(indall)
	Text =  ["A total of "+ STRTRIM(STRING(nacc),2) + " observations", $
		 "correspond to the combination selected"]
        XDISPLAYFILE, "", $
                TITLE = "New Respons Table Calculation", $
                                WIDTH = 50, $
                                HEIGHT = 4, $
                          TEXT = [text]      

	RETURN
NOCOMB: 
        XDISPLAYFILE, "", $
            TITLE = "Input not accepted", $
            WIDTH = 50, $
            HEIGHT = 4, $
            TEXT = [" Combined selection discards all elements "]
        RETURN


END 

