;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_RODEGL
;
; PURPOSE:
;	Menu for RO-deglitching parameters handling.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_RODEGL, tmpdata, pixel, GROUP=group 
;
; INPUT:
;	tmpdata: ERD level temporary structure 
;	pixel:	 chosen pixel for testing
;
; KEYWORD PARAMETERS:
;	GROUP:	The group leader of the widget hierarchy
;	NO_data: For no data testing
;	
; RESTRICTIONS:
;	TMPDATA must be a valid PHTERD temporary structure in case the
;	NO_DATA Keyword is not set
;	
; COMMON BLOCKS:
;	colour_indices
;		
; PROCEDURES USED:
;	PIA LIB:
;		decode_pixf
;		acc_flag
;		acc_volt
;		degl_ramps
;		pia_xplot
;       INTERNAL:
;		pia_rodegl_event
;
; MODIFICATION HISTORY:
;	Written by: C.Gabriel (ESA/VILSPA-SAI)			December 1995
;	Modified by CG
;	Version 5.0 						August 1996
;	Statistical info extended (CG)				January 1998
;	V6.6
;	Extension for setting params without data testing (CG) 	January 1998
;	V7.0
;	-> In this case modal keyword can be active (CG) 	January 1999
;	V7.3 
;	Ramps reconstruction added as option (CG)		August 1999
;	V8.0
;			
;-
; *********************************************************************
; *  Event routine for PIA_RODEGL
; *********************************************************************
PRO PIA_RODEGL_EVENT, event

COMMON degl_ramps_cmn, fsig, niter, minp
COMMON pia_rodgl_cmn, fsig_id, niter_id, minp_id, tmpdata, pix_nr, pixstat, $
            rampend1, reco
@phtacc
@colour_indices
                                                                 
	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue OF

	'TEST': BEGIN
; Read the values from the widgets
		WIDGET_CONTROL, event.top, /HOURGLASS
		WIDGET_CONTROL, fsig_id, GET_VALUE=s_fsig
		WIDGET_CONTROL, niter_id, GET_VALUE=s_niter
		WIDGET_CONTROL, minp_id, GET_VALUE=s_minp
		
		fsig = FLOAT(s_fsig(0))
		niter = FIX(s_niter(0))
		minp = FIX(s_minp(0))
; If number of read-outs selected lower than minp do return
	
	junk = WHERE(ndrnacc NE 0, numero)

	IF ndr1nac THEN BEGIN
	  junk = WHERE(ndrnacc EQ 1, nnn) 
	  numero = numero + 1 - nnn
	ENDIF

	nrreads = tmpdata.nndr - numero
	
	IF nrreads LT minp THEN BEGIN
		XDISPLAYFILE, "", $
                         TITLE = "Number of read-outs too low", $
                         WIDTH = 50, $
                         HEIGHT = 5, $
                TEXT = ["Number of read-outs lower than minimum required.", $
                     " ", "Change corresponding parameter for deglitching", $
                     "if correction should be done."]
               RETURN
        ENDIF



		x = tmpdata.time
		y = tmpdata.conp(pix_nr,*)
	  	DEGL_RAMPS, X, Y, pixstat, rampend1, deglflag, degltext

		IF not reco THEN $
		PIA_XPLOT, x, y, psym=4, $
			title="Testing of deglitching parameters", $
			xtitle = "Time    [s]", ytitle="RO Voltage   [V]", $
			legend="Before deglitching"

		inda = WHERE(pixstat NE 0,counta)
		
		IF counta GT 0 AND not reco THEN $ 
			PIA_XPLOT, x(inda), y(inda), psym=7, color=red, $
			   legend="De-selected points", /overplot
			   
		ind = WHERE(deglflag NE 0, count)	   
		
		IF count GT 0 AND not reco THEN $
		       PIA_XPLOT, x(ind), y(ind), psym=5, color=yellow, $
			   legend="Detected glitches", /overplot
			   
		IF reco THEN BEGIN
			iramp0 = 0
			FOR iramp=0, N_ELEMENTS(rampend1)-1 DO BEGIN
   				npt_ramp = rampend1(iramp)-iramp0+1
   				ind_ramp = INDGEN(npt_ramp) + iramp0
   				xxt = x(ind_ramp)
				yyt = y(ind_ramp)
				fyt = pixstat(ind_ramp)
				indok = WHERE(fyt EQ 0, nok)
				indgl = WHERE(deglflag(ind_ramp) NE 0, nmask)
				IF nok GT 1 AND nmask GT 0 THEN BEGIN
				  yyt = rebuild_ramps(xxt, yyt, indok, indgl)
				  y(ind_ramp) = yyt
				ENDIF
			ENDFOR

			PIA_XPLOT, x, y, psym=4, $
			 title="Testing of deglitching parameters", $
			 xtitle = "Time    [s]", ytitle="RO Voltage   [V]", $
			 legend="After deglitching"

			IF counta GT 0 THEN $ 
			 PIA_XPLOT, x(inda), y(inda), psym=7, color=red, $
			   legend="De-selected points", /overplot
			   
			IF count GT 0 THEN $
		         PIA_XPLOT, x(ind), y(ind), psym=5, color=yellow, $
			 legend="Detected glitches", /overplot
		ENDIF
			
			
		decode_admn, tmpdata.admn, meastxt
		deglsum=meastxt+ ' - Test of Ramp Deglitching'
       	deglsum=[deglsum,'===================================================']
		deglsum=[deglsum,' ']
		deglsum=[deglsum,'Pixel '+STRTRIM(STRING(pix_nr+1),2)]
		deglsum=[deglsum,' ']
		deglsum=[deglsum,'Parameters:']
		deglsum=[deglsum,'-----------']
		deglsum=[deglsum,'Sigma threshold: '+string(fsig)]
		deglsum=[deglsum,'Number of iterations: '+string(niter)]
		deglsum=[deglsum,'Minimum mumber of points per ramp: '+string(minp)]
		deglsum=[deglsum,' ']
		deglsum=[deglsum, $
'          Time            Strength        Mean Delta	  Strength/Mean      Position/Ramp']
		deglsum=[deglsum, degltext]
		PIA_DISP_PRINT_FILE, 'degl_test', TITLE='Deglitching Statistics',$
	  		TEXT=deglsum 

	END
	
	'DEF': BEGIN

		degl_ramps_init
		WIDGET_CONTROL, fsig_id, set_VALUE=STRING(fsig)
		WIDGET_CONTROL, niter_id, set_VALUE=STRING(niter)
		WIDGET_CONTROL, minp_id, set_VALUE=STRING(minp)
	
	END
	
	
	'DEFQUIT': BEGIN

		degl_ramps_init
		WIDGET_CONTROL, event.top, /DESTROY
			
	END
	
	'RECO': BEGIN
		WIDGET_CONTROL, event.id, GET_VALUE=val
		reco = val(0)
		END
		
	'QUIT': BEGIN
	
		WIDGET_CONTROL, fsig_id, GET_VALUE=s_fsig
		WIDGET_CONTROL, niter_id, GET_VALUE=s_niter
		WIDGET_CONTROL, minp_id, GET_VALUE=s_minp

		fsig = FLOAT(s_fsig(0))
		niter = FIX(s_niter(0))
		minp = FIX(s_minp(0))

		WIDGET_CONTROL, event.top, /DESTROY
		
	END

	ELSE:
	
	ENDCASE
	
RETURN
END
; *********************************************************************
; *  Menu for PIA_RODEGL
; *********************************************************************
PRO PIA_RODEGL, tmp, pixel, erd_disc_pix, rampend, GROUP=group,  $ 
    NO_data=no_data, MODAL=modal

COMMON degl_ramps_cmn, fsig, niter, minp
COMMON pia_rodgl_cmn, fsig_id, niter_id, minp_id, tmpdata, pix_nr, pixstat, $
            rampend1, reco

	IF KEYWORD_SET(no_data) THEN BEGIN
		tmpdata={null:-1} 
		pixel = 0
		IF not KEYWORD_SET(modal) THEN modal = 0
	ENDIF ELSE BEGIN
	 tmpdata = tmp
	 pix_nr = pixel
	 rampend1 = rampend
	 pixstat = erd_disc_pix
	 modal = 0
	ENDELSE

	IF N_ELEMENTS(fsig) EQ 0 THEN degl_ramps_init
	
	IF N_ELEMENTS(reco) EQ 0 THEN reco=0
	

	base = WIDGET_BASE(TITLE="PIA Ramps Deglitching Parameters", /COLUMN, $
			modal=modal, GROUP=group)
	
	parbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(parbase, $
	VALUE='Sigma threshold for acceptance:      ')
	fsig_id = WIDGET_TEXT(parbase, /EDITABLE, VALUE=STRING(fsig), $
		UVALUE='JUNK')
		
	parbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(parbase, $
	VALUE='Number of iterations to be performed:')
	niter_id = WIDGET_TEXT(parbase, /EDITABLE, VALUE=STRING(niter), $
		UVALUE='JUNK')
		
	
	parbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(parbase, $
	VALUE='Minimum of points for algorithm:     ')
	minp_id = WIDGET_TEXT(parbase, /EDITABLE, VALUE=STRING(minp), $
		UVALUE='JUNK')
	
	reco_id= cw_bgroup(base, /NONexclusive,$
		SET_VALUE=[RECO], FONT=font, UVAL='RECO', $
		['Show reconstructed ramps']) 

	cont_base = WIDGET_BASE(base, /ROW)
	
	IF not KEYWORD_SET(NO_DATA) THEN $
	test_id = WIDGET_BUTTON(cont_base, VALUE='OK, test them', UVALUE='TEST')
	
	def_id = WIDGET_BUTTON(cont_base, VALUE='Default Par', UVALUE='DEF')
	
	quit_id = WIDGET_BUTTON(cont_base, VALUE= 'Accept & Quit ', $
		UVALUE= 'QUIT')
	
	quit_id = WIDGET_BUTTON(cont_base, VALUE= 'Default & Quit', $
		UVALUE= 'DEFQUIT')

        WIDGET_CONTROL, base, /REALIZE, TLB_SET_XOFFSET=150, $
                        TLB_SET_YOFFSET=150

        xMANAGER,No_BLOCK=1, "pia_rodegl", base, GROUP=group
	
        RETURN
END
	
