;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_RODISC
;
; PURPOSE:
;	Menu for PIA Read-out selection.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_RODISC
;
; INPUTS:
;	none
;	
; KEYWORD PARAMETERS:
;	GROUP
;		The group leader of the widget hirarchy
;	NNDR
;		Number of non destructive read-outs per ramp
;	
; OUTPUTS:
;	none
;	
; SIDE EFFECTS:
;	values of some variables in common phtacc are changed, which drive
;	the different data selections
; 	
; COMMON BLOCKS:
;	pia_rodisc_cmn		for internal use
;	phtacc			selection variables
;	phtselndr		default selection criteria 
;	pia_rodis_out		for passing back error status
;	
; PROCEDURES USED:
;	Internal:
;		pia_rodisc_event
;
; MODIFICATION HISTORY:
;	Written by:	C.Gabriel (ESA/ESTEC)		August 1994
;	V3.5
;	Modification history:
;	  pia_rodis_out added  (CG)			December 1996
;	  V5.5
;	Modal use according to IDL >= 5.0 (CG)		January 1999
;	V7.3
;-

; ****************************************************************************
;  Event handling routine for PIA read-outs selection menu
; ****************************************************************************

PRO pia_rodisc_event, event

@phtacc
@phtselndr

	COMMON pia_rodis_cmn, new_drnacc, new_ndrnacc, minramp, maxramp,$
		      new_ndr1nac, new_anyr, ndrfrom_id, ndrok_id, ndrto_id, $
		      lislist,$
		      ndrfrom, ndrto, read_cont, ramp_cont, nrndr, new_nselndr 
                                                                 
	COMMON pia_rodis_out, pia_rodis_err

	
	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	pia_rodis_err = 0 

	CASE uvalue OF

          'ACCEPT': BEGIN
		drnacc = new_drnacc
		ndr1nac = new_ndr1nac
		ndrnacc = new_ndrnacc
		nselndr = new_nselndr
		minr = minramp 
                maxr = maxramp
                anyr = new_anyr
		
                WIDGET_CONTROL, event.top, /DESTROY
          END

          'CANCEL': BEGIN

		pia_rodis_err = 1
                WIDGET_CONTROL, event.top, /DESTROY

          END

	  'STANDARD': BEGIN

        	CASE event.value of
		
                        0: BEGIN
			     new_nselndr = event.select
			     IF new_nselndr THEN BEGIN
				
				 WIDGET_CONTROL, ndrfrom_id, $
					SET_VALUE=''
				 WIDGET_CONTROL, ndrfrom_id, SENSITIVE=0
				 WIDGET_CONTROL, ndrto_id, $
					SET_VALUE=''
				read_str = 'Not active'
        		        WIDGET_CONTROL, read_cont, SET_VALUE = read_str

                              ENDIF ELSE BEGIN
					   
				 str_ndrfrom = strtrim(string(ndrfrom),2)
				 str_ndrto = strtrim(string(ndrto),2)
				 WIDGET_CONTROL, ndrfrom_id, $
					SET_VALUE=str_ndrfrom
				 WIDGET_CONTROL, ndrfrom_id, /SENSITIVE
				 WIDGET_CONTROL, ndrto_id, $
					SET_VALUE=str_ndrto
				read_str = 'Active'
        		        WIDGET_CONTROL, read_cont, SET_VALUE = read_str

		              ENDELSE
			END

	        	1: new_drnacc = event.select
			
                        2: new_ndr1nac = event.select
		
		ENDCASE
	  END

	  'NDRFROM': BEGIN
			WIDGET_CONTROL, event.id, GET_VALUE=value
                        ndrfrom = fix(value)
			ndrfrom = ndrfrom(0)
 			WIDGET_CONTROL, ndrto_id, /SENSITIVE
 			WIDGET_CONTROL, ndrto_id, /INPUT_FOCUS
 	  END
                    
	  'NDRTO':  BEGIN
			WIDGET_CONTROL, event.id, GET_VALUE=value
                        ndrto = fix(value)
			ndrto = ndrto(0)
 			WIDGET_CONTROL, ndrok_id, /SENSITIVE
 			WIDGET_CONTROL, ndrok_id, /INPUT_FOCUS
	  END

	  'NDROK':  BEGIN
			IF ndrfrom EQ 0 and ndrto EQ 0 THEN BEGIN 
				new_ndrnacc = 0

			  IF nrndr NE -1 THEN $
			   str_nndr = strtrim(string(nrndr),2) ELSE $
			   str_nndr = '?'

			  read_str = 'No ND-Read-Outs will be discarded from '+$
					str_nndr+' per Ramp '
        		  WIDGET_CONTROL, read_cont, SET_VALUE = read_str

			  RETURN
			ENDIF
                        IF ndrfrom EQ 0 or ndrto EQ 0 or ndrfrom gt ndrto $
			  THEN  BEGIN
					XDISPLAYFILE, "", $
                			GROUP = event.top, $
                			TITLE = "Warning to YOU", $
                			WIDTH = 30, $
                			HEIGHT = 4, $
                			TEXT = ["Non-acceptable Values"]   
			ENDIF ELSE BEGIN

			  new_ndrnacc = ndrfrom			  

			  FOR i=ndrfrom+1,ndrto DO $
				new_ndrnacc = [new_ndrnacc,i] 	

			  str_ndrfrom = strtrim(string(ndrfrom),2)
			  str_ndrto = strtrim(string(ndrto),2)

			  IF nrndr NE -1 THEN $
			   str_nndr = strtrim(string(nrndr),2) ELSE $
			   str_nndr = '?'

			  read_str = 'All ND-Read-Outs between '+str_ndrfrom+$
					' and '+str_ndrto+$ 
					' from '+str_nndr+$ 
					' per Ramp will be discarded'
        		  WIDGET_CONTROL, read_cont, SET_VALUE = read_str

 			  WIDGET_CONTROL, ndrto_id, SENSITIVE=0
 			  WIDGET_CONTROL, ndrok_id, SENSITIVE=0
			ENDELSE
          END

	  'AROUPTO': BEGIN
			WIDGET_CONTROL, event.id, GET_VALUE=value
                        minramp = fix(value)
	        	firrmp = minramp(0) + 1
			IF firrmp GT 1 THEN $
 				str_firrmp = STRTRIM(STRING(firrmp),2) ELSE $   
 				str_firrmp = 'First'   

		        lasrmp = maxramp(0) - 1
			IF lasrmp GT 0 THEN $
		 		str_lasrmp = STRTRIM(STRING(lasrmp),2) ELSE $   
		 		str_lasrmp = 'Last'   

			ramp_str = 'All Ramps between '+str_firrmp+$
					' and '+str_lasrmp+$
					' are taken'
        		WIDGET_CONTROL, ramp_cont, SET_VALUE=ramp_str
		

	  END

	  'AROFROM': BEGIN
			WIDGET_CONTROL, event.id, GET_VALUE=value
                        maxramp = fix(value)
	        	firrmp = minramp(0) + 1
			IF firrmp GT 1 THEN $
 				str_firrmp = STRTRIM(STRING(firrmp),2) ELSE $   
 				str_firrmp = 'First'   

		        lasrmp = maxramp(0) - 1
			IF lasrmp GT 0 THEN $
		 	  str_lasrmp = STRTRIM(STRING(lasrmp),2) ELSE $   
		 	  str_lasrmp = 'Last'   

			ramp_str = 'All Ramps between '+str_firrmp+$
					' and '+str_lasrmp+$
					' are taken'
        		WIDGET_CONTROL, ramp_cont, SET_VALUE=ramp_str
	  END

	  'INDDES': BEGIN
			WIDGET_CONTROL, event.id, GET_VALUE=value
                        new_anyr = [new_anyr,fix(value)]
                        indno = WHERE(new_anyr ne 0)
			new_anyr = new_anyr(indno)
			str_anyr = STRING(new_anyr)
			WIDGET_CONTROL, lislist, SET_VALUE = str_anyr

	  END

	  'INDRES': BEGIN
			WIDGET_CONTROL, event.id, GET_VALUE=value
			res = fix(value)
			indno = WHERE(new_anyr eq res(0), count)
			IF count NE 0 THEN BEGIN
				new_anyr(indno) = 0 
                        	indno = WHERE(new_anyr ne 0, count)
				IF count ne 0 THEN BEGIN  
					new_anyr = new_anyr(indno)
					str_anyr = STRING(new_anyr)
				ENDIF ELSE str_anyr = ''
				WIDGET_CONTROL, lislist, SET_VALUE = str_anyr
			ENDIF
	  END
			
       	ENDCASE
	RETURN
END

; ****************************************************************************
;  PIA RODISC - menu definition procedure
; ****************************************************************************

PRO pia_rodisc, GROUP=group, NNDR=nndr

@phtacc

; Definitions common to all instances

	COMMON pia_rodis_cmn, new_drnacc, new_ndrnacc, minramp, maxramp,$
		      new_ndr1nac, new_anyr, ndrfrom_id, ndrok_id, ndrto_id, $
		      lislist,$
		      ndrfrom, ndrto, read_cont, ramp_cont, nrndr, new_nselndr 
                                                                  

	IF not KEYWORD_SET(group) THEN group = !pia_top_wid	

	ndrfrom = fix(min(ndrnacc))
	ndrto = fix(max(ndrnacc))

	num = ndrto - ndrfrom
	num = findgen(num+1)
	IF ndrto GT 0 THEN new_ndrnacc = num + ndrfrom ELSE new_ndrnacc = 0 

	new_nselndr = nselndr
	new_drnacc = drnacc
	new_ndr1nac = ndr1nac
	new_anyr = 0

	str_drnacc = strtrim(string(drnacc),2)
	str_ndrfrom = strtrim(string(ndrfrom),2)
	str_ndrto = strtrim(string(ndrto),2)
	str_anyr = strtrim(string(0),2)

	
	IF (KEYWORD_SET(NNDR))	THEN nrndr = NNDR 	ELSE $
		BEGIN 
			MESSAGE, /INFO, ': Please provide ndr number'
			RETURN
		END

	minramp = minr 
	str_minr = strtrim(string(minramp(0)),2)  

	maxramp = maxr 
	IF maxramp(0) eq 1 THEN maxramp = 0
	str_maxr = strtrim(string(maxramp(0)),2)  

	rodbase = WIDGET_BASE(TITLE = 'PIA Read-Out selection menu', $ 
		 		/COLUMN, /MODAL, GROUP=group)

	stdbut = cw_bgroup(rodbase, LABEL_TOP = 'Standard Choices', $
			/NONEXCLUSIVE, /FRAME, $
			SET_VALUE = [nselndr,drnacc,ndr1nac], $
			UVALUE = 'STANDARD', $
			["Use general criteria for discarding Read-outs",$
			 "Discard all Destructive Read-outs", $
			 "Discard first Readout of every Ramp"])

        label = WIDGET_LABEL(rodbase, VALUE='Special Choices')

	junkbase = WIDGET_BASE(rodbase, /ROW)
        junktit = WIDGET_LABEL(junkbase, $
			VALUE='Discard Non-Destructive Read-outs per Ramp:')

	ndrbase = WIDGET_BASE(rodbase, /ROW)
        label = WIDGET_LABEL(ndrbase, VALUE='  From:' )
        ndrfrom_id = WIDGET_TEXT(ndrbase, /EDITABLE, XSIZE=3, YSIZE=1, $
                        VALUE=str_ndrfrom, UVALUE='NDRFROM')
        label = WIDGET_LABEL(ndrbase, VALUE='  To:' )
        ndrto_id = WIDGET_TEXT(ndrbase, /EDITABLE, XSIZE=3, YSIZE=1, $
                        VALUE=str_ndrto, UVALUE='NDRTO')
	dummy = WIDGET_LABEL(ndrbase, VALUE='       ')
	ndrok_id = WIDGET_BUTTON(ndrbase, VALUE='OK', UVALUE='NDROK')	
	
	IF nrndr NE -1 THEN $
		str_nndr = strtrim(string(nrndr),2) ELSE $
		str_nndr = '?'

	read_str = 'All ND-Read-Outs between '+str_ndrfrom+$
					' and '+str_ndrto+$ 
					' from '+str_nndr+$ 
					' per Ramp will be discarded'
        read_cont = WIDGET_TEXT(rodbase, XSIZE=60, VALUE = read_str)

; non sensitive if general criteria to be applied
	IF nselndr THEN BEGIN
		WIDGET_CONTROL, ndrfrom_id, SENSITIVE=0
				 WIDGET_CONTROL, ndrfrom_id, $
					SET_VALUE=''
				 WIDGET_CONTROL, ndrfrom_id, SENSITIVE=0
				 WIDGET_CONTROL, ndrto_id, $
					SET_VALUE=''
				read_str = 'Not active'
        		        WIDGET_CONTROL, read_cont, SET_VALUE = read_str
        ENDIF
; always non sensitive in the beginning
	WIDGET_CONTROL, ndrto_id, SENSITIVE=0
	WIDGET_CONTROL, ndrok_id, SENSITIVE=0
	
	junklabel = WIDGET_LABEL(rodbase, VALUE='       ')

	junkbase = WIDGET_BASE(rodbase, /ROW)
        junktit = WIDGET_LABEL(junkbase, $
			VALUE='Discard Ramps per Measurement:')

	arobase = WIDGET_BASE(rodbase, /ROW)
        label = WIDGET_LABEL(arobase, VALUE='From beginning up to:' )
        aroupto = WIDGET_TEXT(arobase, /EDITABLE, XSIZE=5, YSIZE=1, $
                   VALUE=str_minr, UVALUE='AROUPTO') 
        label = WIDGET_LABEL(arobase, VALUE='To the end from  :' )
        arofrom = WIDGET_TEXT(arobase, /EDITABLE, XSIZE=5, YSIZE=1, $
                        VALUE=str_maxr, UVALUE='AROFROM')
  
        firrmp = minramp(0) + 1
	IF firrmp GT 1 THEN $
 		str_firrmp = STRTRIM(STRING(firrmp),2) ELSE $   
 		str_firrmp = 'First'   

        lasrmp = maxramp(0) - 1
	IF lasrmp GT 0 THEN $
 		str_lasrmp = STRTRIM(STRING(lasrmp),2) ELSE $   
 		str_lasrmp = 'Last'   

	ramp_str = 'All Ramps between '+str_firrmp+' and '+str_lasrmp+$
			' are taken'
        ramp_cont = WIDGET_TEXT(rodbase, VALUE = ramp_str)


	junklabel = WIDGET_LABEL(rodbase, VALUE='       ')

	junkbase = WIDGET_BASE(rodbase, /ROW)
        junktit = WIDGET_LABEL(junkbase, $
			VALUE='Discard Individual Read-Outs per Measurement:')

	indbase = WIDGET_BASE(rodbase, /ROW)
        label = WIDGET_LABEL(indbase, VALUE='Discard:' )
        inddes = WIDGET_TEXT(indbase, /EDITABLE, XSIZE=5, YSIZE=1, $
                        VALUE='', UVALUE='INDDES')  
        label = WIDGET_LABEL(indbase, VALUE='Reselect:' )
        indres = WIDGET_TEXT(indbase, /EDITABLE, XSIZE=5, YSIZE=1, $
                        VALUE='', UVALUE='INDRES')  

	lisbase = WIDGET_BASE(rodbase, /ROW)  
	lislist = WIDGET_TEXT(lisbase, VALUE='', XSIZE=50)

	junklabel = WIDGET_LABEL(rodbase, VALUE='       ')

        control = WIDGET_BASE(rodbase,/ROW)

        junk = WIDGET_LABEL(control, VALUE = '                          ')
        accept = WIDGET_BUTTON(control, VALUE = '  OK  ', $
                        /FRAME, UVALUE = 'ACCEPT')
        junk = WIDGET_LABEL(control, VALUE = '                          ')
        cancel = WIDGET_BUTTON(control, VALUE = '  Cancel  ', $
                        /FRAME, UVALUE = 'CANCEL')

        WIDGET_CONTROL, rodbase, /REALIZE, TLB_SET_XOFFSET=150, $
                        TLB_SET_YOFFSET=150

        xMANAGER,No_BLOCK=1, "pia_rodisc", rodbase, GROUP=group
	
        RETURN
END

