;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_SATLEV
;
; PURPOSE:
;	Menu for PIA valid voltage levels setting.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_SATLEV
;
; INPUTS:
;	none
;	
; KEYWORD PARAMETERS:
;	GROUP
;		The group leader of the widget hirarchy
;	
; OUTPUTS:
;	none
;	
; SIDE EFFECTS:
;	changes the contents of the common block phtacc for data selection
;	
; COMMON BLOCKS:
;	phtacc		data selection parameters
;	pia_satlv_cmn	for internal use
;
; PROCEDURES USED:
;	Internal:
;		pia_satlev_event
;	
; MODIFICATION HISTORY:
;	Written by:	C.Gabriel (ESA/ESTEC)		August 1994
;	Oct 95 Version 3.5
;	Made much more simple (CG)			April 1996
;	Widget bug fixed (CG)				May 1996
;	Argument ierr added to pia_satlev to facilitate
;	 the interaction from pia_disperd  (JAcosta)	July 2000
;-

; ****************************************************************************
;  Event handling routine for PIA read-outs selection menu
; ****************************************************************************

PRO pia_satlev_event, event

@phtacc

	COMMON pia_satlv_cmn, new_minvolt, new_maxvolt, minc_id, maxc_id, $
	     retsat

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	retsat =0

	CASE uvalue OF

          'ACCEPT': BEGIN
		WIDGET_CONTROL, minc_id, GET_VALUE=value
 		minvolt = float(value(0))
		WIDGET_CONTROL, maxc_id, GET_VALUE=value
		maxvolt = float(value(0))
		
                WIDGET_CONTROL, event.top, /DESTROY
          END

          'CANCEL': BEGIN
	        retsat = 1 
                WIDGET_CONTROL, event.top, /DESTROY

          END

	  ELSE:
	                      
       	ENDCASE
	
	
	RETURN
END

; ****************************************************************************
;  PIA SATLEV - menu definition procedure
; ****************************************************************************

PRO pia_satlev, ierr, GROUP=group

@phtacc

	COMMON pia_satlv_cmn, new_minvolt, new_maxvolt, minc_id, maxc_id, $
	     retsat

        IF not KEYWORD_SET(group) THEN group = !pia_top_wid


	new_minvolt = minvolt
	new_maxvolt = maxvolt

	str_minvolt = strtrim(string(minvolt),2)
	str_maxvolt = strtrim(string(maxvolt),2)

	satbase = WIDGET_BASE(TITLE = 'PIA Voltages Level setting menu', $ 
		 		/COLUMN, /MODAL, GROUP=group)


	junkbase = WIDGET_BASE(satbase, /ROW)
        junktit = WIDGET_LABEL(junkbase, $
			VALUE='Choose minimum and maximum allowed voltages:')

	levbase = WIDGET_BASE(satbase, /ROW)
        label = WIDGET_LABEL(levbase, VALUE='Minimum Voltage:  ' )
        minc_id = WIDGET_TEXT(levbase, /EDITABLE, XSIZE=8, YSIZE=1, $
                   VALUE=str_minvolt, UVALUE='MINVOL') 

	junklabel = WIDGET_LABEL(levbase, VALUE='       ')

        label = WIDGET_LABEL(levbase, VALUE='Maximum Voltage:  ' )
        maxc_id = WIDGET_TEXT(levbase, /EDITABLE, XSIZE=8, YSIZE=1, $
                        VALUE=str_maxvolt, UVALUE='MAXVOL')
  

	junklabel = WIDGET_LABEL(levbase, VALUE='       ')

        control = WIDGET_BASE(satbase,/ROW)

        junk = WIDGET_LABEL(control, VALUE = '                          ')
        accept = WIDGET_BUTTON(control, VALUE = '  OK  ', $
                        /FRAME, UVALUE = 'ACCEPT')
        junk = WIDGET_LABEL(control, VALUE = '                          ')
        cancel = WIDGET_BUTTON(control, VALUE = '  Cancel  ', $
                        /FRAME, UVALUE = 'CANCEL')

        WIDGET_CONTROL, satbase, /REALIZE, TLB_SET_XOFFSET=150, $
                        TLB_SET_YOFFSET=150

        xMANAGER,No_BLOCK=1, "pia_satlev", satbase, GROUP=group
	
	ierr = retsat
	
        RETURN
END

