;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_SCPDISC
;
; PURPOSE:
;	Menu for PIA Chopper Plateau selection.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_SCPDISC
;
; INPUTS:
;	none
;	
; KEYWORD PARAMETERS:
;	GROUP
;		The group leader of the widget hirarchy
;	NCHP
;		Ramps per chopper plateau
;	
; OUTPUTS:
;	none
;	
; SIDE EFFECTS:
;	Affects variables in common phtacc for selection criteria
;	
; COMMON BLOCKS:
;	phtacc			data selection parameters 
;	pia_scpdsc_cmn		for internal use
;	
; PROCEDURES USED:
;	Internal:
;		pia_scpdisc_event
;
; MODIFICATION HISTORY:
;	Written by:	C.Gabriel (ESA/ESTEC)		October 1994
;	Modified by:	CG				February 1995
;	Oct 95 Version 3.5
;	XSIZE deleted from button (IDL V4 problem) (CG)	January 1996 
;	Modal use according to IDL >= 5.0 (CG)		January 1999
;	V7.3
;-

; ****************************************************************************
;  Event handling routine for PIA Chopper Plateau selection menu
; ****************************************************************************

PRO pia_scpdisc_event, event

@phtacc

	COMMON pia_scpdsc_cmn, new_scpnacc, new_mincp, new_maxcp, new_anycp, $
		      scpok_id, scpto_id, lislist,$
		      scpfrom, scpto, read_cont, scp_cont, scpch 

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue OF

          'ACCEPT': BEGIN
		scpnacc = new_scpnacc
		mincp = new_mincp 
                maxcp = new_maxcp  
		anycp = new_anycp  
                WIDGET_CONTROL, event.top, /DESTROY
          END

          'CANCEL': BEGIN

                WIDGET_CONTROL, event.top, /DESTROY

          END

	  'SCPFROM': BEGIN
			WIDGET_CONTROL, event.id, GET_VALUE=value
                        scpfrom = fix(value)
			scpfrom = scpfrom(0)
 			WIDGET_CONTROL, scpto_id, /SENSITIVE
 			WIDGET_CONTROL, scpto_id, /INPUT_FOCUS
 	  END
                    
	  'SCPTO':  BEGIN
			WIDGET_CONTROL, event.id, GET_VALUE=value
                        scpto = fix(value)
			scpto = scpto(0)
 			WIDGET_CONTROL, scpok_id, /SENSITIVE
 			WIDGET_CONTROL, scpok_id, /INPUT_FOCUS
	  END

	  'SCPOK':  BEGIN
			IF scpfrom EQ 0 and scpto EQ 0 THEN BEGIN 
				new_scpnacc = 0

			  str_scpch = strtrim(string(scpch),2)
			  read_str = 'No Chopper Plateaux from '+$
					str_scpch+' will be discarded '
        		  WIDGET_CONTROL, read_cont, SET_VALUE = read_str

			  RETURN
			ENDIF
                        IF scpfrom EQ 0 or scpto EQ 0 or scpfrom gt scpto $
			  THEN  BEGIN
					XDISPLAYFILE, "", $
                			GROUP = event.top, $
                			TITLE = "Warning to YOU", $
                			WIDTH = 30, $
                			HEIGHT = 4, $
                			TEXT = ["Non-acceptable Values"]   
			ENDIF ELSE BEGIN

			  new_scpnacc = scpfrom			  

			  FOR i=scpfrom+1,scpto DO $
				new_scpnacc = [new_scpnacc,i] 	

			  str_scpfrom = strtrim(string(scpfrom),2)
			  str_scpto = strtrim(string(scpto),2)
			  str_scpch = strtrim(string(scpch),2)
			  read_str = 'All Chopper Plateaux between '+$
					str_scpfrom+$
					' and '+str_scpto+$ 
					' from '+str_scpch+$ 
					' will be discarded'
        		  WIDGET_CONTROL, read_cont, SET_VALUE = read_str

 			  WIDGET_CONTROL, scpto_id, SENSITIVE=0
 			  WIDGET_CONTROL, scpok_id, SENSITIVE=0
			ENDELSE
          END

	  'ASGUPTO': BEGIN
			WIDGET_CONTROL, event.id, GET_VALUE=value
                        new_mincp = fix(value)
	        	firscp = new_mincp(0) + 1
			IF firscp GT 1 THEN $
 				str_firscp = STRTRIM(STRING(firscp),2) ELSE $   
 				str_firscp = 'First'   

		        lasscp = new_maxcp(0) - 1
			IF lasscp GT 0 THEN $
		 		str_lasscp = STRTRIM(STRING(lasscp),2) ELSE $   
		 		str_lasscp = 'Last'   

			scp_str = 'All Signals between '+str_firscp+$
					' and '+str_lasscp+$
					' are taken'
        		WIDGET_CONTROL, scp_cont, SET_VALUE=scp_str
		

	  END

	  'ASGFROM': BEGIN
			WIDGET_CONTROL, event.id, GET_VALUE=value
                        new_maxcp = fix(value)
	        	firscp = new_mincp(0) + 1
			IF firscp GT 1 THEN $
 				str_firscp = STRTRIM(STRING(firscp),2) ELSE $   
 				str_firscp = 'First'   

		        lasscp = new_maxcp(0) - 1
			IF lasscp GT 0 THEN $
		 	  str_lasscp = STRTRIM(STRING(lasscp),2) ELSE $   
		 	  str_lasscp = 'Last'   

			scp_str = 'All Signals between '+str_firscp+$
					' and '+str_lasscp+$
					' are taken'
        		WIDGET_CONTROL, scp_cont, SET_VALUE=scp_str
	  END

	  'INDDES': BEGIN
			WIDGET_CONTROL, event.id, GET_VALUE=value
                        new_anycp = [new_anycp,fix(value)]
                        indno = WHERE(new_anycp ne 0)
			new_anycp = new_anycp(indno)
			str_anyscp = STRING(new_anycp)
			WIDGET_CONTROL, lislist, SET_VALUE = str_anyscp

	  END

	  'INDRES': BEGIN
			WIDGET_CONTROL, event.id, GET_VALUE=value
			res = fix(value)
			indno = WHERE(new_anycp eq res(0), count)
			IF count NE 0 THEN BEGIN
				new_anycp(indno) = 0 
                        	indno = WHERE(new_anycp ne 0, count)
				IF count ne 0 THEN BEGIN  
					new_anycp = new_anycp(indno)
					str_anyscp = STRING(new_anycp)
				ENDIF ELSE str_anyscp = ''
				WIDGET_CONTROL, lislist, SET_VALUE = str_anyscp
			ENDIF
	  END
			
       	ENDCASE
	RETURN
END

; ****************************************************************************
;  PIA SCPDISC - menu definition procedure
; ****************************************************************************

PRO pia_scpdisc, GROUP=group, nchp = nchp

@phtacc

; Definitions common to all instances

	COMMON pia_scpdsc_cmn, new_scpnacc, new_mincp, new_maxcp, new_anycp, $
		      scpok_id, scpto_id, lislist,$
		      scpfrom, scpto, read_cont, scp_cont, scpch 


	IF not KEYWORD_SET(group) THEN group = !pia_top_wid

	IF KEYWORD_SET(nchp) THEN scpch = nchp ELSE scpch = 0

	scpfrom = fix(min(scpnacc))
	scpto = fix(max(scpnacc))

	num = scpto - scpfrom
	num = findgen(num+1)

	IF scpto GT 0 THEN new_scpnacc = num + scpfrom ELSE new_scpnacc = 0 

	new_scpnacc = scpnacc
	new_anycp = 0

	str_scpfrom = strtrim(string(scpfrom),2)
	str_scpto = strtrim(string(scpto),2)
	str_scpch = strtrim(string(scpch),2)
	str_anyscp = '0'

	new_mincp = mincp
	str_minr = strtrim(string(new_mincp(0)),2)  

	new_maxcp = maxcp
	str_maxr = strtrim(string(new_maxcp(0)),2)  

	rodbase = WIDGET_BASE(TITLE = 'PIA Chopper Plateau selection menu', $ 
		 		/COLUMN, /MODAL, group=group)

	junkbase = WIDGET_BASE(rodbase, /ROW)
        junktit = WIDGET_LABEL(junkbase, $
			VALUE='Discard Chopper Plateau Signals:')

	scpbase = WIDGET_BASE(rodbase, /ROW)
        label = WIDGET_LABEL(scpbase, VALUE='  From:' )
        scpall = WIDGET_TEXT(scpbase, /EDITABLE, XSIZE=3, YSIZE=1, $
                        VALUE=str_scpfrom, UVALUE='SCPFROM')
        label = WIDGET_LABEL(scpbase, VALUE='  To:' )
        scpto_id = WIDGET_TEXT(scpbase, /EDITABLE, XSIZE=3, YSIZE=1, $
                        VALUE=str_scpto, UVALUE='SCPTO')
	dummy = WIDGET_LABEL(scpbase, VALUE='       ')
	scpok_id = WIDGET_BUTTON(scpbase, VALUE='OK', UVALUE='SCPOK')	
	
	WIDGET_CONTROL, scpto_id, SENSITIVE=0
	WIDGET_CONTROL, scpok_id, SENSITIVE=0
	
	read_str = 'All Chopper Plateau Signals between '+str_scpfrom+$
				' and '+str_scpto+$ 
				' from '+str_scpch+$ 
				' will be discarded'

        read_cont = WIDGET_TEXT(rodbase, VALUE = read_str)

	junklabel = WIDGET_LABEL(rodbase, VALUE='       ')

	junkbase = WIDGET_BASE(rodbase, /ROW)
        junktit = WIDGET_LABEL(junkbase, $
			VALUE='Discard Chopper Plateaux Region:')

	arobase = WIDGET_BASE(rodbase, /ROW)
        label = WIDGET_LABEL(arobase, VALUE='From beginning up to:' )
        aroupto = WIDGET_TEXT(arobase, /EDITABLE, XSIZE=5, YSIZE=1, $
                   VALUE=str_minr, UVALUE='ASGUPTO') 
        label = WIDGET_LABEL(arobase, VALUE='To the end from  :' )
        arofrom = WIDGET_TEXT(arobase, /EDITABLE, XSIZE=5, YSIZE=1, $
                        VALUE=str_maxr, UVALUE='ASGFROM')
  
        firscp = new_mincp(0) + 1
	IF firscp GT 1 THEN $
 		str_firscp = STRTRIM(STRING(firscp),2) ELSE $   
 		str_firscp = 'First'   

        lasscp = new_maxcp(0) - 1
	IF lasscp GT 0 THEN $
 		str_lasscp = STRTRIM(STRING(lasscp),2) ELSE $   
 		str_lasscp = 'Last'   

	scp_str = 'All Chopper Plateaux between '+str_firscp+' and '+$
		str_lasscp+' are taken'
        scp_cont = WIDGET_TEXT(rodbase, VALUE = scp_str)


	junklabel = WIDGET_LABEL(rodbase, VALUE='       ')

	junkbase = WIDGET_BASE(rodbase, /ROW)
        junktit = WIDGET_LABEL(junkbase, $
			VALUE='Discard Individual Chopper Plateaux:')

	indbase = WIDGET_BASE(rodbase, /ROW)
        label = WIDGET_LABEL(indbase, VALUE='Discard:' )
        inddes = WIDGET_TEXT(indbase, /EDITABLE, XSIZE=5, YSIZE=1, $
                        VALUE='', UVALUE='INDDES')  
        label = WIDGET_LABEL(indbase, VALUE='Reselect:' )
        indres = WIDGET_TEXT(indbase, /EDITABLE, XSIZE=5, YSIZE=1, $
                        VALUE='', UVALUE='INDRES')  

	lisbase = WIDGET_BASE(rodbase, /ROW)  
	lislist = WIDGET_TEXT(lisbase, VALUE='', XSIZE=60)

	junklabel = WIDGET_LABEL(rodbase, VALUE='       ')

        control = WIDGET_BASE(rodbase,/ROW)

        junk = WIDGET_LABEL(control, VALUE = '                          ')
        accept = WIDGET_BUTTON(control, VALUE = '  OK  ', $
                        /FRAME, UVALUE = 'ACCEPT')
        junk = WIDGET_LABEL(control, VALUE = '                          ')
        cancel = WIDGET_BUTTON(control, VALUE = '  Cancel  ', $
                        /FRAME, UVALUE = 'CANCEL')

        WIDGET_CONTROL, rodbase, /REALIZE, TLB_SET_XOFFSET=150, $
                        TLB_SET_YOFFSET=150

        xMANAGER,No_BLOCK=1, "pia_scpdisc", rodbase, GROUP=group
	
        RETURN
END

