;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_SELECT_VAR
;
; PURPOSE:
;	Menu for PIA general selection of variables.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_SELECT_VAR, var, VARNAMES=varnames, GROUP=group
;
; INPUTS:
;	VAR
;		 variable example (one for each variable)
;		
; KEYWORD PARAMETERS:
;	GROUP
;		The group leader of the widget hierarchy
;	VARNAMES
;		String for variable identification
;	VARTYP
;		Type of selection: 0 for range, 1 for exact matching
;
; OUTPUTS:
;	none
;	
; SIDE EFFECTS:
;	
; COMMON BLOCKS:
;	pia_select_var_cmn	for internal use
;	pia_varselected_cmn	variable ranges per index
;	
; PROCEDURES USED:
;	Internal:
;		pia_select_var_event
;
; MODIFICATION HISTORY:
;	Written by:	C.Gabriel (ESA/ESTEC)		April 1995
;	Modified by:	CG				May 1995
;	Oct 95 Version 3.5
;	'xxxxx' indicating non selectable fields (CG)	November 1995
;	Modal keyword according to IDL>=5.0 (CG)	January 1999
;	V7.3
;-

; ****************************************************************************
;  Event handling routine for PIA variables selection menu
; ****************************************************************************

PRO pia_select_var_event, event

COMMON pia_select_var_cmn, ids, variables, names, vars, stop_proc
;;COMMON pia_varselected_cmn, vars


	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue OF

          'ACCEPT': BEGIN
	        stop_proc = 0
		vars = strarr(2,N_ELEMENTS(variables)) 
		FOR I=0,N_ELEMENTS(variables)-1 DO BEGIN
			WIDGET_CONTROL, ids(0,i), GET_VALUE=varfrom
			vars(0,I) = varfrom(0)			
			WIDGET_CONTROL, ids(1,i), GET_VALUE=varto
			vars(1,I) = varto(0)			
                ENDFOR
                WIDGET_CONTROL, event.top, /DESTROY
          END

          'CANCEL': BEGIN

		vars = strarr(2,N_ELEMENTS(variables))
		stop_proc = 1 
                WIDGET_CONTROL, event.top, /DESTROY

          END

	  ELSE: 		

       	ENDCASE
	RETURN
END

; ****************************************************************************
;  PIA select_var - menu definition procedure
; ****************************************************************************

PRO pia_select_var, var, lim_vars, VARNAMES=varnames, VARTYP=vartyp, $
         STOP =stop, GROUP=group 

COMMON pia_select_var_cmn, ids, variables, names, vars, stop_proc

	IF KEYWORD_SET(varnames) THEN names = varnames ELSE $
			names = STRTRIM(STRING(indgen(N_elements(var))+1),2)

	IF KEYWORD_SET(vartyp) THEN typ = vartyp ELSE $
			typ = intarr(N_elements(var))

	variables = var

	IF not KEYWORD_SET(group) THEN group = !pia_top_wid
   
 	varbase = WIDGET_BASE(TITLE = 'PIA variables selection menu', $ 
		 		/COLUMN, /MODAL, GROUP=group)

	ids = lonarr(2,N_ELEMENTS(var))

	FOR I=0,N_ELEMENTS(var)-1 DO BEGIN

	  junklabel = WIDGET_LABEL(varbase, VALUE='     ')

 	  junkbase = WIDGET_BASE(varbase, /ROW)
          junktit = WIDGET_LABEL(junkbase, $
			VALUE='Select variable '+names(i)+$
			'  Format= '+var(i))

	  id_1 = WIDGET_BASE(varbase, /ROW)
          id_2 = WIDGET_LABEL(id_1, VALUE='  From:' )
          id_2 = WIDGET_TEXT(id_1, /EDITABLE, XSIZE=25, YSIZE=1, $
                        VALUE='', UVALUE='JUNK')
	  ids(0,i) = id_2

          id_2 = WIDGET_LABEL(id_1, VALUE='  To:' )
          id_2 = WIDGET_TEXT(id_1, /EDITABLE, XSIZE=25, YSIZE=1, $
                        VALUE='', UVALUE='JUNK')
	  ids(1,i) = id_2
	  IF typ(i) EQ 1 THEN WIDGET_CONTROL, id_2, $
	  	SET_VALUE='XXXXXXXXXXXXXXXXXX'
	  IF typ(i) EQ 1 THEN WIDGET_CONTROL, id_2, SENSITIVE=0

	ENDFOR

        control = WIDGET_BASE(varbase,/ROW)

        junk = WIDGET_LABEL(control, VALUE = '                          ')
        accept = WIDGET_BUTTON(control, VALUE = '  OK  ', $
                        /FRAME, UVALUE = 'ACCEPT')

        junk = WIDGET_LABEL(control, VALUE = '                          ')
        cancel = WIDGET_BUTTON(control, VALUE = '  Cancel  ', $
                        /FRAME, UVALUE = 'CANCEL')

        WIDGET_CONTROL, varbase, /REALIZE, TLB_SET_XOFFSET=150, $
                        TLB_SET_YOFFSET=150

        xMANAGER,No_BLOCK=1, "pia_select_var", varbase, GROUP=group
	
	lim_vars = vars
	stop = stop_proc
	
	
        RETURN
END

