;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_SELLIST
; PURPOSE:
;       Creates a GUI which displays list of selections and an editable name and
;	then returns the changes made by the user
; CATEGORY:
;       Graphics - I/F
; CALLING SEQUENCE:
;       PIA_SELLIST, LIST, MASK[, TYPE=TYPE, NAME=NAME]
; INPUT:
;       list: list of selections to be displayed in the GUI
;	mask: acceptance vector for each selection 
;	      (1 means accepted and 0 means masked)	
; OPTIONAL KEYWORD:
;	type: title of the selections
;	name: some editable name (When defined, it changes it to something like 
;	      'May121327_AAP.FITS' - this is to use it with write_aap_multi.pro)
; OUTPUT:
;	mask: updated mask variable reflecting the user's changes
;	name: user edited or unedited name if it was defined at the beginning 
; RESTRICTIONS:
;
; PROCEDURES USED: 
;	
; MODIFICATION HISTORY:
;       Written by:     J. Acosta (ISO-SOC, Vilspa)      	August 1998
;       Version 7.x
;	Program header added by: Min Y. Hur (IPAC/Caltech)	May 2000
;	v9.0
;-
PRO pia_sellist, list, mask, type=type, name=name

ncal_lot = N_ELEMENTS(list)
IF NOT KEYWORD_SET(type) THEN type="   Name   "

junkbase = WIDGET_BASE(title='Selection of elements', $
         /COLUMN, xsize=500)
	  
IF KEYWORD_SET(name) THEN BEGIN
  tbase = WIDGET_BASE(junkbase, /ROW)
  junk = WIDGET_LABEL(tbase, /ALIGN_LEFT, $
   VAL='File name: ')
  now=systime(0)
  month=strmid(now,4,3)
  day='00'
  if strmid(now,8,1) eq ' ' then day='0'+strmid(now,9,1) $
	   else day=strmid(now,8,2)
  fitsfile=month+day+strmid(now,11,2)+strmid(now,14,2)+'_AAP.FITS'
  fitsfile = !INTDIR + fitsfile
   
  twid = WIDGET_TEXT(tbase, VAL=fitsfile, /EDITABLE)
ENDIF
  

junk = WIDGET_LABEL(junkbase, /ALIGN_LEFT, $
   VAL=type)

wid_val = STRARR(ncal_lot)
mask = INTARR(N_ELEMENTS(list)) + 1

FOR i=0,ncal_lot-1 DO wid_val(i) = list(i)
wid_selmeas = CW_BGROUP(junkbase,wid_val,/NONEXCLUSIVE,UVALUE='SELI',$
          SET_VALUE=mask, XOFFSET=20)
   
junkbase1 = WIDGET_BASE(junkbase,/COLUMN)
junkbase2 = WIDGET_BASE(junkbase1, /ROW)
junk = WIDGET_BUTTON(junkbase2, VAL='Select all', UVALUE='SELA')
junk = WIDGET_BUTTON(junkbase2, VAL='Deselect all', UVALUE='SELN')

junkbase2 = WIDGET_BASE(junkbase1, /ROW)
junk = WIDGET_BUTTON(junkbase2, VAL='   Accept & Quit   ', UVALUE='EXIT')
junk = WIDGET_BUTTON(junkbase2, VAL='   Cancel   ',UVALUE='CANCEL') 	 


WIDGET_CONTROL, junkbase, /REALIZE

;start loop until exit is selected
exit_wid = 0 
exit_sav = 0
REPEAT  BEGIN
    event = WIDGET_EVENT(junkbase)
    WIDGET_CONTROL, event.id, GET_UVALUE= uvalue
    CASE uvalue OF 
     'SELA': WIDGET_CONTROL, wid_selmeas, SET_VALUE=mask*0+1
     'SELN': WIDGET_CONTROL, wid_selmeas, SET_VALUE=mask*0
     'CANCEL': exit_wid =1 
     'EXIT': BEGIN
     		exit_wid = 1
		exit_sav = 1
	     END	
    ELSE: 
    ENDCASE

ENDREP UNTIL exit_wid

WIDGET_CONTROL, wid_selmeas, GET_VALUE = measmask
IF KEYWORD_SET(name) THEN BEGIN
  WIDGET_CONTROL, twid, GET_VALUE=name
  name = name(0)
ENDIF

WIDGET_CONTROL, junkbase,/DESTROY

IF exit_sav THEN mask=measmask

RETURN
END
