;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_sep_AAP_chop
;
; PURPOSE:
;	Separate a chopper step from an AAP structure writing this part
;	as a new measurement in the dynamical structure
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       PIA_SEP_AAP_chop, aapdat, nchop
;
; INPUT:
;       aapDAT 	: PHTaap like dynamical structure
;	nchop:	  Chopper step to be taken
;
; KEYWORDS:
;	(none)
;
; OUTPUTS:
;	(none)
;
; RESTRICTIONS:
;       aapDAT must exist
;
; MODIFICATION HISTORY:
;       Written by:	C. Gabriel (ESA/ESTEC-SAI)          January 1996
;	central wavelength added (WMT)                      Nov 1996
;-

PRO PIA_sep_aap_chop, aapDAT, chop 
@phtaap
        ON_ERROR, 2
;
;  Check the number of parameters.
;
    IF N_PARAMS() LT 2 THEN MESSAGE, $
          'Syntax:  PIA_sep_aap_chop, aapDAT, chopstep'

    PIA_LOAD_IAAP, aapdat, tmpaap

    ind = WHERE(tmpaap.cstp EQ chop(0), n)
    IF N_ELEMENTS(chop) EQ 2 THEN BEGIN
    	ind2=WHERE(tmpaap.cstp EQ chop(1), n2)
    	ind = [ind,ind2]
    	n = n+n2
    ENDIF
    

    hdr = tmpaap.hdr
    FXADDPAR, hdr, 'ChopStep', chop(0)
    IF N_ELEMENTS(chop) EQ 2 THEN FXADDPAR, hdr, 'ChopStep', chop(1)

    IF n GT 0 THEN BEGIN
;  Fill the Iaap structure
	NAME = aapDAT.ADMN + '_CSTEP' + STRTRIM(STRING(chop(0)),2)
	IF N_ELEMENTS(chop) EQ 2 THEN NAME=NAME+'-'+STRTRIM(STRING(chop(1)),2)
	
	tmppart = {DET: aapDAT.DET, $     
	ADMN: NAME, $
        DIMS: n, $
        FILT: AAPDAT.FILT, $
        APER: AAPDAT.APER, $
        POLZ: AAPDAT.POLZ, $
	CWVL: AAPDAT.cwvl, $
        HDR: HDR, $ 
        TIME: tmpaap.TIME(ind), $ 
        CSTP:tmpaap.CSTP(ind), $
        CPOS:tmpaap.CPOS(ind), $
        DWEL:tmpaap.DWEL(ind), $
        MNFL:tmpaap.MNFL(*,ind), $
        MNFU:tmpaap.MNFU(*,ind), $
        MNBR:tmpaap.MNBR(*,ind), $
        MNBU:tmpaap.MNBU(*,ind), $
        MDFL:tmpaap.MDFL(*,ind), $
        Q1FL:tmpaap.Q1FL(*,ind), $
        Q3FL:tmpaap.Q3FL(*,ind), $
        MDBR:tmpaap.MDBR(*,ind), $
        Q1BR:tmpaap.Q1BR(*,ind), $
        Q3BR:tmpaap.Q3BR(*,ind), $
        RPID:tmpaap.RPID(*,ind), $
	DEC:tmpaap.DEC(ind), $
	RA:tmpaap.RA(ind), $
	ROLL:tmpaap.ROLL(ind), $
	FLAG:tmpaap.FLAG(*,ind)}

	tmpaap = tmppart
		
;  Accomodate data into the spd structure and the spd handles after
;  creating the temporary ones                  
FILLSTR:
	PHTAAPT = {PHTAAP_TYPE}
        PHTAAPT.HDR = HANDLE_CREATE()
	PHTAAPT.TIME = HANDLE_CREATE()
	PHTAAPT.CSTP = HANDLE_CREATE()
	PHTAAPT.CPOS = HANDLE_CREATE()
	PHTAAPT.DWEL = HANDLE_CREATE()
	PHTAAPT.MNFL = HANDLE_CREATE()
	PHTAAPT.MNFU = HANDLE_CREATE()
	PHTAAPT.MNBR = HANDLE_CREATE()
	PHTAAPT.MNBU = HANDLE_CREATE()
	PHTAAPT.MDFL = HANDLE_CREATE()
	PHTAAPT.Q1FL = HANDLE_CREATE()
	PHTAAPT.Q3FL = HANDLE_CREATE()
	PHTAAPT.MDBR = HANDLE_CREATE()
	PHTAAPT.Q1BR = HANDLE_CREATE()
	PHTAAPT.Q3BR = HANDLE_CREATE()
	PHTAAPT.RPID = HANDLE_CREATE()
	PHTAAPT.FLAG = HANDLE_CREATE()
	PHTAAPT.DEC = HANDLE_CREATE()
	PHTAAPT.RA = HANDLE_CREATE()
	PHTAAPT.ROLL = HANDLE_CREATE()

	HANDLE_VALUE, PHTAAPT.HDR, tmpaap.hdr, /SET
; 	  
	PHTAAPT.DET  = tmpaap.DET
	PHTAAPT.ADMN = tmpaap.ADMN
	PHTAAPT.FILT = tmpaap.filt
	PHTAAPT.APER = tmpaap.aper
	PHTAAPT.POLZ = tmpaap.polz
	PHTAAPT.DIMS = tmpaap.dims
	PHTAAPT.CWVL = tmpaap.cwvl

	HANDLE_VALUE, PHTAAPT.RPID, tmpaap.RPID, /SET
	HANDLE_VALUE, PHTAAPT.TIME, tmpaap.TIME, /SET
	HANDLE_VALUE, PHTAAPT.CPOS, tmpaap.cpos, /SET
	HANDLE_VALUE, PHTAAPT.CSTP, tmpaap.cstp, /SET
	HANDLE_VALUE, PHTAAPT.DWEL, tmpaap.dwel, /SET
        HANDLE_VALUE, PHTAAPT.MNFL, tmpaap.mnfl, /SET 
	HANDLE_VALUE, PHTAAPT.MNFU, tmpaap.mnfu, /SET 
	HANDLE_VALUE, PHTAAPT.MNBR, tmpaap.mnbr, /SET 
	HANDLE_VALUE, PHTAAPT.MNBU, tmpaap.mnbu, /SET
	HANDLE_VALUE, PHTAAPT.MDFL, tmpaap.mdfl, /SET 
	HANDLE_VALUE, PHTAAPT.Q1FL, tmpaap.q1fl, /SET 
	HANDLE_VALUE, PHTAAPT.Q3FL, tmpaap.q3fl, /SET 
	HANDLE_VALUE, PHTAAPT.MDBR, tmpaap.mdbr, /SET 
	HANDLE_VALUE, PHTAAPT.Q1BR, tmpaap.q1br, /SET 
	HANDLE_VALUE, PHTAAPT.Q3BR, tmpaap.q3br, /SET 
	HANDLE_VALUE, PHTAAPT.DEC, tmpaap.dec, /SET
	HANDLE_VALUE, PHTAAPT.RA, tmpaap.ra, /SET
	HANDLE_VALUE, PHTAAPT.ROLL, tmpaap.roll, /SET
	HANDLE_VALUE, PHTAAPT.FLAG, tmpaap.flag, /SET

; Update the PHTAAP structure using the temporary structure
	PHTAAP = [PHTAAP, PHTAAPT]
   ENDIF ELSE MESSAGE, /info, 'Chopper step does not exist'
		
        RETURN
END

