;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_SET_PATHS
;
; PURPOSE:
;	Menu for setting different path variables.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_SET_PATHS
;
; INPUT KEYWORD:
;	MODAL		set widget in modal 
;		
; PROCEDURES USED:
;
; MODIFICATION HISTORY:
;	Written by: C.Gabriel (ESA/VILSPA-SAI)		July 1996
;	Keyword MODAL added (CG)			June 1999
;	V7.4				
;	IRAF_LOGIN and IRAF_DATA system keywords added	August 1999
;	V8.0
;-
; *********************************************************************
; *  Event routine for PIA_RODEGL
; *********************************************************************
PRO PIA_SET_PATHS_EVENT, event

COMMON PIA_SET_PATHS_CMN, ids
                                                                 
	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	WIDGET_CONTROL, event.top, GET_UVALUE=id
	HANDLE_VALUE, id, ids

	CASE uvalue OF

	'OK': BEGIN
; Read the values from the widgets
		WIDGET_CONTROL, ids.fitdir, GET_VALUE=fitdir
		!FITDIR = fitdir
		WIDGET_CONTROL, ids.xdrdir, GET_VALUE=xdrdir
		!XDRDIR = xdrdir
		WIDGET_CONTROL, ids.calg, GET_VALUE=calg
		!CALG = calg
		WIDGET_CONTROL, ids.calu, GET_VALUE=calu
		!CALU = calu
		WIDGET_CONTROL, ids.calsave, GET_VALUE=calsave
		!CALSAVE = calsave
		WIDGET_CONTROL, ids.intdir, GET_VALUE=intdir
		!INTDIR = intdir
		WIDGET_CONTROL, ids.print, GET_VALUE=print
		!PIA_PRINTDIR = print
		!PRINT = print
		WIDGET_CONTROL, ids.calc, GET_VALUE=calc
		!CALC = calc
		WIDGET_CONTROL, ids.html, GET_VALUE=html
		!PIA_HTML = html
		WIDGET_CONTROL, ids.help, GET_VALUE=help
		!PIA_HELP = help
		WIDGET_CONTROL, ids.irafdir, GET_VALUE=iraf_login
		!IRAF_LOGIN = iraf_login
		WIDGET_CONTROL, ids.irafdata, GET_VALUE=iraf_data
		!IRAF_DATA = iraf_data
		WIDGET_CONTROL, ids.fallperigee, GET_VALUE=f_allperigee
		!F_ALLPERIGEE = f_allperigee
	WIDGET_CONTROL, event.top, /destroy

	END

	ELSE:
	ENDCASE
	
RETURN
END
; *********************************************************************
; *  Menu for PIA_PATH_SET
; *********************************************************************
PRO PIA_SET_PATHS, GROUP=group, MODAL=modal 
                                               
	ids = {fitdir:0L, xdrdir:0L, calg:0l, calu:0L, calsave:0l, $
		intdir:0L, print:0L, calc:0l, html:0L, help:0L, fallperigee:0L,$
		irafdir:0L, irafdata:0L }
	IF not KEYWORD_SET(modal) THEN modal=0
	IF not KEYWORD_SET(group) THEN group=!PIA_TOP_WID

	abase = WIDGET_BASE(TITLE="PIA path definitions", /COLUMn, $
		MODAL=modal, GROUP=group)
	
	base = WIDGET_BASE(abase, /COLUMN, /FRAME)

	label = WIDGET_LABEL(base, VALUE='General PIA path definitions')

	parbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(parbase, $
		VALUE='FITS files directory:             ',XSIZE=241)
	ids.fitdir = WIDGET_TEXT(parbase, /EDITABLE, VALUE=!FITDIR, $
		UVALUE='JUNK', XSIZE=60)
		
	parbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(parbase, XSIZE=241, $
		VALUE='Internal files (read) directory:  ')
	ids.xdrdir = WIDGET_TEXT(parbase, /EDITABLE, VALUE=!XDRDIR, $
		UVALUE='JUNK', XSIZE=60)
		
	parbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(parbase, XSIZE=241, $
		VALUE='Internal save (write) directory:  ')
	ids.intdir = WIDGET_TEXT(parbase, /EDITABLE, VALUE=!INTDIR, $
		UVALUE='JUNK', XSIZE=60)
		
	parbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(parbase, XSIZE=241, $
		VALUE='Cal G files directory:            ')
	ids.calg = WIDGET_TEXT(parbase, /EDITABLE, VALUE=!CALG, $
		UVALUE='JUNK', XSIZE=60)
		
	parbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(parbase, XSIZE=241, $
		VALUE='Calibration savefiles directory:  ')
	ids.calsave = WIDGET_TEXT(parbase, /EDITABLE, VALUE=!CALSAVE, $
		UVALUE='JUNK', XSIZE=60)
		
	parbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(parbase, XSIZE=241, $
		VALUE='Print directory:                  ')
	ids.print = WIDGET_TEXT(parbase, /EDITABLE, VALUE=!PRINT, $
		UVALUE='JUNK', XSIZE=60)

	parbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(parbase, XSIZE=241, $
		VALUE='Hypertext documentation:          ')
	ids.html = WIDGET_TEXT(parbase, /EDITABLE, VALUE=!PIA_HTML, $
		UVALUE='JUNK', XSIZE=60)
		
	parbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(parbase, XSIZE=241, $
		VALUE='PIA routines help:                ')
	ids.help = WIDGET_TEXT(parbase, /EDITABLE, VALUE=!PIA_HELP, $
		UVALUE='JUNK', XSIZE=60)

	parbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(parbase, XSIZE=241, $
		VALUE='IRAF login directory:             ')
	ids.irafdir = WIDGET_TEXT(parbase, /EDITABLE, VALUE=!iraf_login, $
		UVALUE='JUNK', XSIZE=60)
		
	parbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(parbase, XSIZE=241, $
		VALUE='IRAF data directory:              ')
	ids.irafdata = WIDGET_TEXT(parbase, /EDITABLE, VALUE=!iraf_data, $
		UVALUE='JUNK', XSIZE=60)
		
		
		
	
	base = WIDGET_BASE(abase, /COLUMN)
	label = WIDGET_LABEL(base, VALUE='  ')


	base = WIDGET_BASE(abase, /COLUMN, /FRAME)

	label = WIDGET_LABEL(base, VALUE='Calibration PIA path variables')

	parbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(parbase, XSIZE=241, $
		VALUE='Cal U directory:                  ')
	ids.calu = WIDGET_TEXT(parbase, /EDITABLE, VALUE=!CALU, $
		UVALUE='JUNK', XSIZE=60)
		
	parbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(parbase, XSIZE=241, $
		VALUE='Calibration sources directory:    ')
	ids.calc = WIDGET_TEXT(parbase, /EDITABLE, VALUE=!CALC, $
		UVALUE='JUNK', XSIZE=60)
		
	parbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(parbase, XSIZE=241, $
		VALUE='Perigee time file:                ')
	ids.fallperigee = WIDGET_TEXT(parbase, /EDITABLE, VALUE=!F_ALLPERIGEE, $
		UVALUE='JUNK', XSIZE=60)
		
;	cont_base = WIDGET_BASE(abase, /column, /frame)
	
	quit_id = WIDGET_BUTTON(abase, $
		VALUE= ' Done ', $
		UVALUE= 'OK')

	id = HANDLE_CREATE()
	HANDLE_VALUE, id, ids, /SET
        
        WIDGET_CONTROL, abase, /REALIZE, TLB_SET_XOFFSET=150, $
                        TLB_SET_YOFFSET=150, SET_UVALUE=id

        xMANAGER,No_BLOCK=1, "pia_set_paths", abase, GROUP=group
	
        RETURN
END
	
