;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_SET_SYSVAR
;
; PURPOSE:
;	Menu for changing PIA system variables.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_set_sysvar, sysvar
;
; INPUTS:
;	sysvar: a string identifier for the system variable to be 
;		displayed and changed. 
;		Valid identifiers are:
;			'FITDIR': for the external FITS directory 
;			'XDRDIR': for the general internal save directory 
;                  	'CALG': for the Cal G files directory
;                   	'CALU': for the Cal U files directory 	
;                   	'CALSAVE': for the directory to accomodate SAVE files 
;				from cal menues (requires write permission)
;                   	'INTDIR': for the directory to accomodate general 
;				save files (requires write permission)       	
;	
; KEYWORD PARAMETERS:
;	GROUP : The group leader of the widget hierarchy
;	
; OUTPUTS:
;	(none)
;	
; SIDE EFFECTS:
;	System variables used in PIA are changed
;	
; COMMON BLOCKS:
;	(none)
;
; PROCEDURES USED:
;	Internal:
;		pia_set_sysvar_event
;
; MODIFICATION HISTORY:
;	Written by:	Jose ACOSTA (IAC)		August 1995
;	Modified by:	Carlos GABRIEL (ESA/VILSPA)	August 1995
;	Oct 95 Version 3.5
;	XDRDIR added (CG)				December 1995
;	Appearance changed (CG)				October 1997
;	V6.5
;	Modal keyword according to IDL>=5.0 (CG)	January 1999
;	V7.3
;-

PRO pia_set_sysvar_event, event

   WIDGET_CONTROL, event.id, GET_UVALUE=action
   IF N_ELEMENTS(action) EQ 0 THEN RETURN
   WIDGET_CONTROL, event.top, GET_UVALUE=id
   WIDGET_CONTROL, id.fitsdir, GET_VALUE=tmp
   hash = STRMID(action,0,1)
   rest = STRMID(action,1,100)

   CASE hash OF
   'E': BEGIN
           CASE rest OF
           'OK':   BEGIN
                   WIDGET_CONTROL, id.fitsdir, GET_VALUE=val
                   tmp = STRTRIM(val(0),2)
		   CASE id.type OF
                   	'NVIEWS': !PIA_NVIEWS = FIX(tmp)                     	
                   	'FITDIR': !FITDIR = tmp                   	
                   	'XDRDIR': !XDRDIR = tmp                   	
                   	'CALG': !CALG = tmp
                   	'CALU': !CALU = tmp                   	
                   	'CALSAVE': !CALSAVE = tmp
                   	'INTDIR': !INTDIR = tmp                   	
			ELSE:
                   ENDCASE
		END
		ELSE:
           ENDCASE
           WIDGET_CONTROL, event.top, /DESTROY
           RETURN
        END

   ELSE:
   ENDCASE

   WIDGET_CONTROL, id.tmp, SET_UVALUE=tmp, /NO_COPY
   RETURN
   END

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

pro pia_set_sysvar, var, GROUP=group

   CASE var of
   	'NVIEWS': BEGIN
     		fits_dir = '4'         
		valtext = 'Number of plots in main display windows:'
   	END

   	'FITDIR': BEGIN
     		fits_dir = !FITDIR         
		valtext = 'External FITS Files directory:'
   	END

   	'XDRDIR': BEGIN
     		fits_dir = !XDRDIR         
		valtext = 'General Save Files directory:'
   	END

   	'CALG': BEGIN
     		fits_dir = !CALG         
		valtext = 'Calibration G Files directory:'
   	END

   	'CALU': BEGIN
     		fits_dir = !CALU         
		valtext = 'Calibration U Files directory:'
   	END   	

   	'CALSAVE': BEGIN
     		fits_dir = !CALSAVE        
		valtext = 'Calibration Save Files directory:'
   	END   	

   	'INTDIR': BEGIN
     		fits_dir = !INTDIR        
		valtext = 'Own Save Files directory:'
   	END
   ENDCASE


  id = { fitsdir:0L, tmp:0L, type:var }
   font=''
  IF not KEYWORD_SET(group) THEN group = !pia_top_wid
  id_base = WIDGET_BASE( TITLE="PIA System Variables Re-Definition", $
  		/MODAL, group=group, /COLUMN )


   id_3 = WIDGET_BASE( id_base, /ROW )
       id_0 = WIDGET_LABEL( id_3, VALUE='' )
      id_0 = WIDGET_LABEL( id_3, VALUE=valtext )

    id.fitsdir = WIDGET_TEXT( id_3, /EDITABLE, VALUE=fits_dir)
    
   id_1 = WIDGET_BASE( id_base, /ROW )
       id_0 = WIDGET_BUTTON( id_1, VALUE="      OK      ", UVALUE="EOK" )
       id_0 = WIDGET_BUTTON( id_1, VALUE="     Quit     ", UVALUE="EQU" )
       
    
      WIDGET_CONTROL, id_base, /REALIZE
      
   WIDGET_CONTROL, id_base, SET_UVALUE=id, /NO_COPY

   xMANAGER,No_BLOCK=1, "pia_set_sysvar", id_base, GROUP= group

   RETURN
   END
