;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_SELECT_VAR
;
; PURPOSE:
;	Menu for PIA general selection of variables.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_SELECT_VAR, var, VARNAMES=varnames, GROUP=group
;
; INPUTS:
;	VAR
;		 variable example (one for each variable)
;		
; KEYWORD PARAMETERS:
;	GROUP
;		The group leader of the widget hierarchy
;	VARNAMES
;		String for variable identification
;	VARTYP
;		Type of selection: 0 for range, 1 for exact matching
;
; OUTPUTS:
;	none
;	
; SIDE EFFECTS:
;	
; COMMON BLOCKS:
;	pia_select_var_cmn	for internal use
;	pia_varselected_cmn	variable ranges per index
;	
; PROCEDURES USED:
;	Internal:
;		pia_select_var_event
;
; MODIFICATION HISTORY:
;	Written by:	C.Gabriel (ESA/ESTEC)		April 1995
;	Modified by:	CG				May 1995
;	Oct 95 Version 3.5
;	'xxxxx' indicating non selectable fields (CG)	November 1995
;	Modal keyword according to IDL>=5.0 (CG)	January 1999
;	V7.3
;-

; ****************************************************************************
;  Event handling routine for PIA variables selection menu
; ****************************************************************************

PRO pia_set_var_event, event


	WIDGET_CONTROL, event.top, GET_UVALUE=pid
	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
	
	ids = (*pid).ids
	names = (*pid).names
	vars = (*pid).vars
	

	CASE uvalue OF

          'ACCEPT': BEGIN
		FOR I=0,N_ELEMENTS(ids)-1 DO BEGIN
			WIDGET_CONTROL, ids(i), GET_VALUE=varfrom
			vars(I) = varfrom(0)			
                ENDFOR
		(*pid).vars = vars
                WIDGET_CONTROL, event.top, /DESTROY
          END

          'CANCEL': BEGIN

		(*pid).vars = (*pid).variables
                WIDGET_CONTROL, event.top, /DESTROY

          END


          'SAVE': BEGIN
		WIDGET_CONTROL, event.top, /hourglass
		FOR I=0,N_ELEMENTS(ids)-1 DO BEGIN
			WIDGET_CONTROL, ids(i), GET_VALUE=varfrom
			vars(I) = varfrom(0)			
                ENDFOR
		WIDGET_CONTROL, (*pid).idsname, GET_VALUE=filename
		filename=filename(0)
		
		(*pid).vars = vars

		SAVE, vars, filename=filename
          END

	  'READ': BEGIN
	        
		WIDGET_CONTROL, event.top, /hourglass
		WIDGET_CONTROL, (*pid).idsname, GET_VALUE=filename
		filename=filename(0)
		pos = STRPOS(filename, '.')
		len = STRLEN(filename)
		IF pos NE -1 THEN $
		    filter = '*' + STRMID(filename,pos,len-1) $
		    ELSE filter = '*'
		name = PIA_pickfile(filter=filter)
	        prev_vars = vars
		IF name NE '' THEN BEGIN
		   RESTORE, name

		 IF N_ELEMENTS(vars) NE N_ELEMENTS(prev_vars) THEN BEGIN
		  MESSAGE, /INFO, 'Wrong file chosen'
		  RETURN
		 ENDIF
		
		
		 (*pid).vars = vars
		 FOR I=0,N_ELEMENTS(vars)-1 DO BEGIN
			WIDGET_CONTROL, ids(i), SET_VALUE=vars(i)
                 ENDFOR
		ENDIF ELSE MESSAGE, /INFO, 'Nothing chosen, returning'
	  END
	  		
	  ELSE: 		

       	ENDCASE
	RETURN
END

; ****************************************************************************
;  PIA set_var - menu definition procedure
; ****************************************************************************

PRO pia_set_var, var, varout, VARNAMES=varnames, $
         STOP =stop, GROUP=group, filename=FILENAME 

	IF KEYWORD_SET(varnames) THEN names = varnames ELSE $
			names = STRTRIM(STRING(indgen(N_elements(var))+1),2)

	IF not KEYWORD_SET(filename) THEN filename = ''
	variables = var

	IF not KEYWORD_SET(group) THEN group = !pia_top_wid
   
 	base = WIDGET_BASE(TITLE = 'PIA variables setting menu', $ 
		 		/COLUMN, GROUP=group, /MODAL)

 	varbase = WIDGET_BASE(base, $ 
		 		/COLUMN, /FRAME, SCR_YSIZE=700, $
				SCR_XSIZE=500, /SCROLL)
	ids = lonarr(N_ELEMENTS(var))

        control = WIDGET_BASE(varbase,/ROW)

        accept = WIDGET_BUTTON(control, VALUE = '  OK  ', $
                        /FRAME, UVALUE = 'ACCEPT')

        junk = WIDGET_LABEL(control, VALUE = '    ')
        cancel = WIDGET_BUTTON(control, VALUE = '  Cancel  ', $
                        /FRAME, UVALUE = 'CANCEL')

        control = WIDGET_BASE(varbase,/ROW)

         junk = WIDGET_LABEL(control, VALUE = '    ')
        cancel = WIDGET_BUTTON(control, VALUE = ' Save under: ', $
                        /FRAME, UVALUE = 'SAVE')

	idsname = WIDGET_TEXT(control, VALUE = filename, UVALUE='JUNK', $
				xsize=25, /EDITABLE)
				
        junk = WIDGET_LABEL(control, VALUE = '    ')
        cancel = WIDGET_BUTTON(control, VALUE = '  Read from file  ', $
                        /FRAME, UVALUE = 'READ')

	FOR I=0,N_ELEMENTS(var)-1 DO BEGIN

	  junklabel = WIDGET_LABEL(varbase, VALUE='     ')

 	  junkbase = WIDGET_BASE(varbase, /ROW)
          junktit = WIDGET_LABEL(junkbase, XSIZE=240, $
			VALUE='Set variable '+names(i), /ALIGN_LEFT)
          id_2 = WIDGET_LABEL(junkbase, VALUE='   ' )
          id_2 = WIDGET_TEXT(junkbase, /EDITABLE, XSIZE=12, YSIZE=1, $
                        VALUE=var(i), UVALUE='JUNK')
	  ids(i) = id_2
	ENDFOR

        all_eles = {ids:ids, variables:variables, names:names, vars:variables,$
	             idsname:idsname}
	pid = ptr_new(all_eles)
	 
        WIDGET_CONTROL, base, /REALIZE, TLB_SET_XOFFSET=150, $
                        TLB_SET_YOFFSET=150, set_UVALUE=pid

        xMANAGER,No_BLOCK=1, "pia_set_var", base, GROUP=group
	
	varout = (*pid).vars 	
	
        RETURN
END

