;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_SHOWDATA
;
; PURPOSE:
;	PIA Data Structure Show menu selector.
;	Calls the show structure menu. 
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_showdata, filename, ftype
;
; INPUTS:
;	filename: internal name (*.admn) of the chosen measurement
;	ftype: data level type  
;	
; KEYWORDS USED:
;	TMPPOS	Position within the corresponding buffer
;	GROUP	The group leader of the widget hierarchy
;
; OUTPUTS:
;	none
;	
; COMMON BLOCKS:
;	phtaap	AAP (Astrophysical Applications level) dynamical structure
;	phtcla	CLA (Cal A) dynamical structure
;	phterd	ERD (Edited Raw Data) dynamical structure
;	phtscp	SCP (Signal per Chopper Plateau data) dynamical structure
;	phtsmc	SMC (Serendipity Mode data) dynamical structure
;	phtspd	SPD (Standard Processed Data) dynamical structure
;	phtsrd	SRD (Signal per Ramp data) dynamical structure
;	
; MODIFICATION HISTORY:
;	Written by:	Carlos GABRIEL (ESA/ESTEC-SAI)	February 1995
;	Modified(last): SB, WMT             	        October 1996
;	change aar/aap for including central wavelength Nov 1996
;	V5.x
;	Wavelengths now from buffers (CG)		January 1997
;	V6.0
;	Keyword tmppos added (CG)			June 1997
;	V6.3
;-

PRO pia_showdata, filename, ftype, GROUP=group, tmppos=tmppos

@phterd
@phtsrd
@phtsmc
@phtscp
@phtspd
@phtaap
@phtaar
@phtcla
@phtfilter_prop

;        ON_ERROR, 2

;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 2 THEN MESSAGE, $
          'Syntax:  PIA_SHOWDATA, NAME, TYP'

	ftype = STRTRIM(ftype(0),2)
	filename = STRTRIM(filename(0),2)

	CASE ftype of

 	 'ERD': BEGIN

		count = 1
		IF NOT KEYWORD_SET(tmppos) THEN BEGIN
		 datind = WHERE(phterd.admn eq filename, count)
		 IF count EQ 0 THEN $
			MESSAGE, /INFO, 'Measurement not found!'

		 IF count GT 1 THEN BEGIN
			measlist = phterd(datind).admn
                        pia_multmeas, measlist
		 ENDIF else measlist = 0
		 pos = datind(measlist)
		ENDIF ELSE pos = tmppos

                IF count NE 0 THEN BEGIN  
			PIA_LOAD_IERD, phterd(tmppos), tmpstr
			PIA_SHOWSTR, tmpstr, GROUP=group, $
			  VALNAMES=phterd_desc
		ENDIF
	 END

 	 'SRD': BEGIN

		count = 1
		IF NOT KEYWORD_SET(tmppos) THEN BEGIN
		 datind = WHERE(phtsrd.admn eq filename, count)
		 IF count EQ 0 THEN $
			MESSAGE, /INFO, 'Measurement not found!'

		 IF count GT 1 THEN BEGIN
			measlist = phtaar(datind).admn
                        pia_multmeas, measlist
		 ENDIF else measlist = 0
		 pos = datind(measlist)
		ENDIF ELSE pos = tmppos

                IF count NE 0 THEN BEGIN  
			PIA_LOAD_ISRD, phtsrd(pos), tmpstr
			PIA_SHOWSTR, tmpstr, GROUP=group, $
			  VALNAMES=phtsrd_desc
		ENDIF
	 END

         'SMC': BEGIN
                
		count = 1
		IF NOT KEYWORD_SET(tmppos) THEN BEGIN
                 datind = WHERE(phtsmc.admn eq filename, count)
                 IF count EQ 0 THEN $
                        MESSAGE, /INFO, 'Measurement not found!'   

		 IF count GT 1 THEN BEGIN
			measlist = phtsmc(datind).admn
                        pia_multmeas, measlist
		 ENDIF else measlist = 0
		 pos = datind(measlist)
		ENDIF ELSE pos = tmppos

                IF count NE 0 THEN BEGIN
                        PIA_SM_LOAD_ISMC, phtsmc(pos), tmpstr
                        PIA_SHOWSTR, tmpstr, GROUP=group, $
			  VALNAMES=phtsmc_desc
                ENDIF
         END
 
 	 'SCP': BEGIN

		count = 1
		IF NOT KEYWORD_SET(tmppos) THEN BEGIN
		 datind = WHERE(phtscp.admn eq filename, count)
		 IF count EQ 0 THEN $
			MESSAGE, /INFO, 'Measurement not found!'


		 IF count GT 1 THEN BEGIN
			measlist = phtscp(datind).admn
                        pia_multmeas, measlist
		 ENDIF else measlist = 0
		 pos = datind(measlist)
		ENDIF ELSE pos = tmppos
		 
                IF count NE 0 THEN BEGIN  
			PIA_LOAD_ISCP, phtscp(pos), tmpstr
			PIA_SHOWSTR, tmpstr, GROUP=group, $
			  VALNAMES=phtscp_desc
		ENDIF

	 END

 	 'SPD': BEGIN

		count = 1
		IF NOT KEYWORD_SET(tmppos) THEN BEGIN
		 datind = WHERE(phtspd.admn eq filename, count)
		 IF count EQ 0 THEN $
			MESSAGE, /INFO, 'Measurement not found!'

		 IF count GT 1 THEN BEGIN
			measlist = phtspd(datind).admn
                        pia_multmeas, measlist
		 ENDIF else measlist = 0
		 pos = datind(measlist)
		ENDIF ELSE pos = tmppos
		 
                IF count NE 0 THEN BEGIN  
			PIA_LOAD_ISPD, phtspd(pos), tmpstr
			PIA_SHOWSTR, tmpstr, GROUP=group, $
			  VALNAMES=phtspd_desc
		ENDIF

	 END
 	 'AAP': BEGIN

		count = 1
		IF NOT KEYWORD_SET(tmppos) THEN BEGIN
		 datind = WHERE(phtaap.admn eq filename, count)
		 IF count EQ 0 THEN $
			MESSAGE, /INFO, 'Measurement not found!'

		 IF count GT 1 THEN BEGIN
			measlist = phtaap(datind).admn
                        pia_multmeas, measlist
		 ENDIF else measlist = 0
		 pos = datind(measlist)
		ENDIF ELSE pos = tmppos

		if count ne 0 then begin
			pia_load_iaap, phtaap(pos), tmpstr
			pia_showstr, tmpstr, $
			  group=group, valnames = phtaap_desc
		endif

	 END

 	 'AAR': BEGIN

		count = 1
		IF NOT KEYWORD_SET(tmppos) THEN BEGIN
		 datind = WHERE(phtaar.admn eq filename, count)
		 IF count EQ 0 THEN $
			MESSAGE, /INFO, 'Measurement not found!'

		 IF count GT 1 THEN BEGIN
			measlist = phtaar(datind).admn
                        pia_multmeas, measlist
		 ENDIF else measlist = 0
		 pos = datind(measlist)
		ENDIF ELSE pos = tmppos
		
                IF count NE 0 THEN begin
			dtype = phtaar(pos).type
			case dtype of
			'PPAP': data_names = ppap_desc
			'PPAE': data_names = ppae_desc
			'PPAS': data_names = ppas_desc
			'PLAP': data_names = plap_desc
			'PLAE': data_names = plae_desc
			'PLAS': data_names = plas_desc
			'PSAP': data_names = psap_desc
			'PSAE': data_names = psae_desc
			'PSAS': data_names = psas_desc
			'PCAP': data_names = pcap_desc
			'PCAE': data_names = pcae_desc
			'PCAS': data_names = pcas_desc
			else:
			endcase
			handle_value, phtaar(pos).data, tmpstr
;			case strmid(dtype, 0, 2) of
;			'PP': begin
;				cwave = [filtprop.p1cwl, filtprop.p2cwl, filtprop.p3cwl]
;				n = n_elements(tmpstr.filt)
;				for i = 0, n-1 do $
; note that the tmpstr in here is array of structure
;				  tmpstr(i).cwvl = cwave(tmpstr(i).filt - 1)
;			      end
;			'PC': begin
;				cwave = [filtprop.c1cwl, filtprop.c2cwl]
;				n = n_elements(tmpstr.filt)
;				for i = 0, n-1 do $
;				  tmpstr(i).cwvl = cwave(tmpstr(i).filt - 2)
;			      end
;			else: 
;			endcase
				
			pia_showstr, tmpstr, $
			  group=group, valnames = data_names
		endif

	 END

         ELSE: MESSAGE, /INFO, 'Function not yet implemented!'

	ENDCASE

	RETURN
END
