;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium.                                                                 ! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_showstr
;
; PURPOSE:
;	Menu for display of structures variables
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_SHOWSTR, tmpstr, GROUP=group, VALNAMES=valnames, TITLE=title
;
; INPUTS:
;	(none)
;	
; KEYWORD PARAMETERS:
;	GROUP : 	The group leader of the widget hirarchy
;	VALNAMES:	String for variables identification
;	
; OUTPUTS:
;	(none)
;	
; COMMON BLOCKS:
;	pia_dspchz_cmn	keywords for plotting/overplotting 
;	colour_indices	PIA plot color definitions
;
; PROCEDURES USED:
;	PIA Procedure(s):
;		pia_xplot
;	Internal:
;		pia_showstr_cleanup
;		pia_showstr_event
;
; MODIFICATION HISTORY:
;	Written by:	C. Gabriel, ESTEC/ESA		February 1995  
;	Modified(last):	CG				July 1995
;	Oct 95 Version 3.5
;	PIA_XPLOT call without GROUP (CG)		November 1995
;	lindgen for indgen to allow for large str. (CG) March 1998
;	V7.1
;	Saving the structure capability added (CG)	May 1999
;	V7.4
;-


PRO PIA_SHOWSTR_CLEANUP, event_id

	WIDGET_CONTROL, event_id, GET_UVALUE=save, /NO_COPY
	HANDLE_VALUE, save.id, waste, /NO_COPY
	HANDLE_VALUE, save.status, waste, /NO_COPY
	HANDLE_VALUE, save.subindex, waste, /NO_COPY
	HANDLE_VALUE, save.columns, waste, /NO_COPY
	HANDLE_VALUE, save.values, waste, /NO_COPY
	RETURN
	END

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

PRO PIA_showstr_EVENT, event

COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
COMMON pia_struc_exch, ch_struc, ch_type

@colour_indices
	WIDGET_CONTROL, event.id, GET_UVALUE=action
	WIDGET_CONTROL, event.top, GET_UVALUE=save
	HANDLE_VALUE, save.id, id
	HANDLE_VALUE, save.status, status, /NO_COPY
	HANDLE_VALUE, save.subindex, subindex, /NO_COPY
	HANDLE_VALUE, save.values, values, /NO_COPY
	HANDLE_VALUE, save.columns, columns, /NO_COPY
	HANDLE_VALUE, save.struct, tmpstr, /NO_COPY

	CASE action OF

	'SHOWALL': BEGIN
		text =        'Full Table Display '
		text = [text, '================== ', '', '']
		
		FOR I=0,N_ELEMENTS(tmpstr)-1 DO BEGIN
			TEXT = [TEXT, 'Record '+STRTRIM(STRING(I+1),2)+':', $
			'----------']
			FOR IELE=0,N_ELEMENTS(values)-1 DO BEGIN
			   tmp = tmpstr(I).(IELE)
			   n2dim = N_ELEMENTS(tmp(0,*))
			   IF n2dim EQ 1 THEN $ 
				text = [text, values(iele), $
				STRTRIM(STRING(tmp),2), ''] $
			   ELSE BEGIN
			      n1dim = N_ELEMENTS(tmp(*,0))
			      FOR I1DIM = 0, n1dim-1 DO $				
				text = [text, values(iele), $
				'Pix '+STRTRIM(STRING(I1DIM+1),2),  $
				  REFORM(STRTRIM(STRING(tmp(I1DIM,*)),2)), ''] 
			   ENDELSE   	 	
				 
			ENDFOR
		ENDFOR 	
				
        	PIA_DISP_PRINT_FILE, "", $
                  GROUP = event.top, $
                  TITLE = "Full Table", $
                  WIDTH = 40, $
                  HEIGHT = 50, $
;		  FONT='-*-*-*-*-*-*-10-*', $ 
                  TEXT = [text]
	END
	'QUIT':	BEGIN
		WIDGET_CONTROL, event.top, /DESTROY
		RETURN
		END

	'SAVSTR': BEGIN
		WIDGET_CONTROL, id.savstr, GET_VALUE=filename
		SAVE, tmpstr, filename=filename(0)
		text = ["The structure has been saved under the filename ",$
			filename, $
			" ", $
		 'The IDL restore command brings it back as "tmpstr" in memory']
		PIA_DISP_PRINT_FILE, "", $
                  GROUP = event.top, $
                  TITLE = "Full Table", $
                  WIDTH = 20, $
                  HEIGHT = 10, $
;		  FONT='-*-*-*-*-*-*-10-*', $ 
                  TEXT = [text]
	END	
	'NAME':	BEGIN
		status.selname = values(event.index)
		status.selcolumn = columns(event.index)
		array_size = SIZE(tmpstr.(status.selcolumn))
; only 1 or 2 dimensional arrays allowed
		type = array_size(N_ELEMENTS(array_size)-2)
		IF array_size(0) LE 1 OR type EQ 7 THEN  $
			indices = ['*'] ELSE BEGIN
				subsize = array_size(1)
				indices = ['*',STRING(lindgen(subsize)+1)]
		ENDELSE
		WIDGET_CONTROL, id.suba, SET_VALUE=indices
		status.subindex = 0
		HANDLE_VALUE, save.subindex, 0, /SET
		END

	'SUBA': BEGIN
		status.subindex = event.index
		HANDLE_VALUE, save.subindex, status.subindex, /set
		END

	'CLRX':	BEGIN
		status.xname = 'Index'
		status.xcolumn = 0
		status.xsubindex = 0
		WIDGET_CONTROL, id.xname, SET_VALUE=status.xname
		END

	'CVAR':	BEGIN
		status.cname = status.selname
		status.ccolumn = status.selcolumn
		status.csubindex = status.subindex
		IF status.csubindex EQ 0 THEN ss = '*' ELSE $
					ss = STRCOMPRESS(status.csubindex)
		sn = status.cname + "(" + ss + ")" 
		WIDGET_CONTROL, id.cname, SET_VALUE=sn
		END

	'RVAR':	BEGIN
		
		WIDGET_CONTROL, id.rn0, GET_VALUE=record
		recnr=FIX(record(0))-1
		IF N_ELEMENTS(recnr) EQ 0 OR recnr LT 0 OR $
			recnr GE N_ELEMENTS(tmpstr) THEN BEGIN
			MESSAGE, /INFO, 'Non existing record'
			GOTO, skip_plot
		ENDIF

		text =        'Table Display for Record '+$
			STRTRIM(STRING(recnr+1),0)
		text = [text, '============================ ', '', '']
		
		I=recnr
			TEXT = [TEXT, 'Record '+STRTRIM(STRING(I+1),2)+':', $
			'----------']
			FOR IELE=0,N_ELEMENTS(values)-1 DO BEGIN
			   tmp = tmpstr(I).(IELE)
			   n2dim = N_ELEMENTS(tmp(0,*))
			   IF n2dim EQ 1 THEN $ 
				text = [text, values(iele), $
				STRTRIM(STRING(tmp),2), ''] $
			   ELSE BEGIN
			      n1dim = N_ELEMENTS(tmp(*,0))
			      FOR I1DIM = 0, n1dim-1 DO $				
				text = [text, values(iele), $
				'Pix '+STRTRIM(STRING(I1DIM+1),2),  $
				  REFORM(STRTRIM(STRING(tmp(I1DIM,*)),2)), ''] 
			   ENDELSE   	 	
				 
			ENDFOR
				
        	PIA_DISP_PRINT_FILE, "", $
                  GROUP = event.top, $
                  TITLE = "Full Table", $
                  WIDTH = 40, $
                  HEIGHT = 50, $
;		  FONT='-*-*-*-*-*-*-10-*', $ 
                  TEXT = [text]
		

		END
	'SHOWVAR': BEGIN

		arr = tmpstr.(status.ccolumn)

		IF status.csubindex NE 0 THEN BEGIN
			arr = arr(status.csubindex-1,*)
			ss = STRCOMPRESS(status.csubindex)
		ENDIF ELSE ss = '*'
		sn = status.cname + "(" + ss + ")" 

		nelem = N_ELEMENTS(arr)
		dims = size(arr)
		IF dims(0) EQ 2 THEN BEGIN
		  nelem = dims(2)
		  ndim = dims(1)
		  STRar = STRARR(nelem)
		  FOR I=0,nelem-1 DO $
		    FOR II=0,ndim-1 DO STRAR(I) = STRAR(I) + STRING(ARR(II,I))
		ENDIF ELSE STRAR = STRING(ARR)
		
		TEXT = 'Record '+STRTRIM(STRING(lindgen(nelem)+1),2)+'   '+STRAR

		PIA_DISP_PRINT_FILE,"", $
                  GROUP = event.top, $
                  TITLE = "Record Table", $
                  WIDTH = 40, $
                  HEIGHT = 50, $
;		  FONT='-*-*-*-*-*-*-10-*', $ 
                  TEXT = [text]
		
 	END

	'CHNG': BEGIN

		ch_struc = tmpstr
		
		WIDGET_CONTROL, id.rnum, GET_VALUE=record
		recnr=FIX(record(0))-1
		IF N_ELEMENTS(recnr) EQ 0 OR recnr LT 0 OR $
			recnr GE N_ELEMENTS(tmpstr) THEN BEGIN
			MESSAGE, /INFO, 'Non existing record'
			RETURN
		ENDIF
			 
		arr = tmpstr(recnr).(status.ccolumn)
		IF status.csubindex NE 0 THEN BEGIN
			arr = arr(status.csubindex-1,*)
			ss = STRCOMPRESS(status.csubindex)
		ENDIF ELSE ss = '*'
		sn = status.cname + "(" + ss + ")" 

		nelem = N_ELEMENTS(arr)
		
		base=WIDGET_BASE(TITLE='Change Structures Variables', /COLUMN )
		label = 'Variable '+sn+ ' /  Record '+record(0) 
	  	id_2 = WIDGET_LABEL( base, VALUE=label )
	  	id_text = WIDGET_TEXT( base, VALUE=STRING(arr), UVALUE='junk', $
				/editable, /scroll, YSIZE=5)
		id_1 = WIDGET_BASE(base, /ROW)
		id_2 = cw_bgroup(id_1, /EXCLUSIVE, SET_VALUE=0, $
			UVALUE='OK', ["Waiting for input", $
					"OK for Numbers", $
					"OK for Strings", $
					"Cancel" ] )

		WIDGET_CONTROL, base, /REALIZE
		
		OK = 0		

		WHILE OK EQ 0 DO BEGIN
			event = WIDGET_EVENT(base)
			WIDGET_CONTROL, event.id, GET_UVALUE=uval
			IF uval EQ 'OK' THEN BEGIN
			  WIDGET_CONTROL, event.id, GET_VALUE=val
			  IF val(0) NE 0 THEN OK = 1
			ENDIF			
		ENDWHILE
		
		IF val(0) EQ 1 or val(0) EQ 2 THEN BEGIN
			WIDGET_CONTROL, id_text, GET_VALUE=arr
			nelem_new = N_ELEMENTS(arr)
			IF nelem_new NE nelem THEN BEGIN
				XDISPLAYFILE, "", $
                         		GROUP = event.top, $
                         		TITLE = "Wrong input", $
                         		WIDTH = 30, $
                         		HEIGHT = 5, $
                         	   TEXT = ["Wrong input has be given...", $
                                 	"Try it again, Sam. Returning for now."]
                                WIDGET_CONTROL, base, /destroy
                        ENDIF
                        
			IF val(0) EQ 1 THEN $
                          arr = FLOAT(arr(lindgen(nelem_new))) ELSE $
                          arr = arr(lindgen(nelem_new))
			IF nelem_new EQ 1 THEN arr=arr(0)
                        tmpstr(recnr).(status.ccolumn) = arr
                        WIDGET_CONTROL, base, /destroy
                ENDIF ELSE WIDGET_CONTROL, base, /destroy

		ch_struc = tmpstr
		END	

	'NEWX':	BEGIN
		status.xname = status.selname
		status.xsubindex = status.subindex
		IF status.xsubindex EQ 0 THEN ss = '*' ELSE $
					ss = STRCOMPRESS(status.xsubindex)
		sn = status.xname + "(" + ss + ")" 
		status.xcolumn = status.selcolumn
		WIDGET_CONTROL, id.xname, SET_VALUE=sn
		END

	'NEWY':	BEGIN
		status.yname = status.selname
		status.ycolumn = status.selcolumn
		status.ysubindex = status.subindex
		IF status.ysubindex EQ 0 THEN ss = '*' ELSE $
					ss = STRCOMPRESS(status.ysubindex)
		sn = status.yname + "(" + ss + ")" 
		WIDGET_CONTROL, id.yname, SET_VALUE=sn
		END

	'NEWY_ERR':	BEGIN
		status.yerror = status.selname
		status.yerrcolumn = status.selcolumn

		IF status.ysubindex EQ 0 THEN ss = '*' ELSE $
					ss = STRCOMPRESS(status.ysubindex)
		sn = status.yerror + "(" + ss + ")" 
		WIDGET_CONTROL, id.yerror, SET_VALUE=sn
		END

	'CLRY_ERR':	BEGIN
		status.yerror = ''
		WIDGET_CONTROL, id.yerror, SET_VALUE=status.yerror
		END

	'PLOT': IF status.yname NE '' THEN BEGIN
		overplot = 0
		GOTO, do_plot
		END

	'OPL1': IF status.yname NE ''  THEN BEGIN
		overplot = -1
		GOTO, do_plot
		END

	'OPL2': IF status.yname NE '' THEN BEGIN
		WIDGET_CONTROL, id.oplotval, GET_VALUE=val
		overplot = FIX(val(0))
		GOTO, do_plot
		END

	'MEANS': IF status.yname NE '' THEN BEGIN
		meanflag = 1
		overplot = 0
		GOTO, do_plot
		END
	ELSE:
	ENDCASE

	GOTO, skip_plot

do_plot:
	yarray = tmpstr.(status.ycolumn)
	
; look first if string array

	dims = size(yarray)
	IF dims(N_ELEMENTS(dims)-2) EQ 7 THEN BEGIN
        	XDISPLAYFILE, "", $
                  GROUP = event.top, $
                  TITLE = "String in structure", $
                  WIDTH = 80, $
                  HEIGHT = 10, $
		  FONT='-*-courier-bold-*-*-*-14-*', $ 
                  TEXT = [yarray]

                goto, skip_plot
	ENDIF

	xarray = lindgen(N_ELEMENTS(yarray))
	yname = status.yname
	IF status.yerror NE '' THEN yerror = tmpstr.(status.yerrcolumn) ELSE $
			yerror = yarray * 0.
	IF status.ysubindex NE 0 THEN BEGIN
		yarray = yarray(status.ysubindex-1,*)
		xarray = lindgen(N_ELEMENTS(yarray))
		yerror = yerror(status.ysubindex-1,*)
		yname = yname+"(" + STRCOMPRESS(status.ysubindex)+")"
	ENDIF
	
        IF overplot NE 0 THEN BEGIN
                IF zoom_color EQ -1 THEN zoom_color = green ELSE $
                        zoom_color = zoom_color + 1
                        IF zoom_color EQ 9 then zoom_color = 1
                zoom_psymch = zoom_psymch + 1
                IF zoom_psymch eq 8 THEN zoom_psymch = 1
                title = ''
        ENDIF ELSE BEGIN
                zoom_color = -1
                zoom_psymch = 4
        ENDELSE

	IF status.xcolumn NE 0 THEN BEGIN
		xarray = tmpstr.(status.xcolumn)
		xname = status.xname
		IF status.xsubindex NE 0 THEN BEGIN
		 xarray = xarray(status.xsubindex-1,*)
		 xname = xname + "(" + STRCOMPRESS(status.xsubindex) + ")"
		ENDIF

		IF N_ELEMENTS(meanflag) EQ 1 THEN BEGIN
			IF yerror(0) EQ 0. THEN ye = yerror + 1. ELSE ye=yerror
			weight_mean, yarray, ye, mean, meanstd
			med = median(yarray)
			text = [yname, '===========', $
				'Average: ' + $
				STRTRIM(STRING(mean),2) + ' +/- ' + $
				STRTRIM(STRING(meanstd),2), $
				'Median: ' + STRTRIM(STRING(med),2)]
			pia_disp_print_file, '', title=yname, text=text
		ENDIF ELSE BEGIN
		  IF N_ELEMENTS(xarray) EQ N_ELEMENTS(yarray) AND $
		     N_ELEMENTS(xarray) EQ N_ELEMENTS(yerror) THEN $
		  PIA_XPLOT, xarray, yarray, yerror, $
			xtitle=xname, ytitle=yname, $
			OVERPLOT=overplot, LEGEND=yname, $
			PSYM=zoom_psymch, COLOR=zoom_color ELSE $
		  PRINT, 'Dimensions do not match '
		ENDELSE    
	ENDIF ELSE BEGIN
		IF N_ELEMENTS(meanflag) EQ 1 THEN BEGIN
			IF yerror(0) EQ 0. THEN ye = yerror + 1. ELSE ye=yerror
			weight_mean, yarray, ye, mean, meanstd
			med = median(yarray)
			text = [yname, '===========', $
				'Average: ' + $
				STRTRIM(STRING(mean),2) + ' +/- ' + $
				STRTRIM(STRING(meanstd),2), $
				'Median: ' + STRTRIM(STRING(med),2)]
			pia_disp_print_file, '', title=yname, text=text
		ENDIF ELSE BEGIN
		  IF N_ELEMENTS(xarray) EQ N_ELEMENTS(yarray) AND $
		     N_ELEMENTS(xarray) EQ N_ELEMENTS(yerror) THEN $
		  PIA_XPLOT, xarray, yarray, yerror, $
			xtitle=status.xname, ytitle=yname, $
			OVERPLOT=overplot, LEGEND=yname, $
			PSYM=zoom_psymch, COLOR=zoom_color ELSE $
		  PRINT, 'Dimensions do not match '
		ENDELSE   
	ENDELSE

skip_plot:
	HANDLE_VALUE, save.status, status, /SET, /NO_COPY
	HANDLE_VALUE, save.subindex, subindex, /SET, /NO_COPY
	HANDLE_VALUE, save.values, values, /SET, /NO_COPY
	HANDLE_VALUE, save.columns, columns, /SET, /NO_COPY
	HANDLE_VALUE, save.struct, tmpstr, /SET, /NO_COPY

	RETURN

	END


PRO PIA_SHOWSTR, tmpdata, GROUP=group, VALNAMES=valnames, TITLE = title

	tmpstr = tmpdata
	IF KEYWORD_SET(valnames) THEN values = valnames ELSE $
	  values = tag_names(tmpstr)
	n_found = n_tags(tmpstr)
	columns = lindgen(n_found)

	id 	= { cname:0L, rnum:0L, rn0:0L, xname:0L, yname:0L,$
			yerror:0L, suba:0L, oplotval:0L, savstr:0L }
	status 	= {	selname:'', 	$
			selcolumn:0, 	$
			subindex:0, 	$
			cname:'',	$
			ccolumn:0,	$
			csubindex:0,	$
			rn0:0,	$
			rnum:0,		$
			xname:'Index', 	$
			xcolumn:0, 	$
			xsubindex:0,	$
			yname:'', 	$
			ysubindex:0,	$
			ycolumn:0, 	$
			yerror:'', 	$
			yerrcolumn:0 	$
		}

	IF NOT KEYWORD_SET(title) THEN title = 'Show Structures - Plot Curves'
	id_base = WIDGET_BASE( TITLE=title, /COLUMN )

	id_0 = WIDGET_BASE( id_base, /ROW )
	 id_1 = WIDGET_BASE( id_0, /COLUMN )
	  id_2 = WIDGET_LABEL( id_1, VALUE='Select data to be plotted: ' )
	  id_2 = WIDGET_LIST( id_1, VALUE=values, UVALUE='NAME', $
				XSIZE=16, YSIZE=14 )
	  id_2 = WIDGET_BUTTON( id_1, VALUE='Show full structure', $
	  	 UVALUE='SHOWALL' )
	  id_2 = WIDGET_BASE( id_1, /ROW )
	    id_3 = WIDGET_BUTTON( id_2, VALUE='>>Show rec>>', $
	  	 UVALUE='RVAR' )
	    id.rn0 = WIDGET_TEXT( id_2, VALUE=STRING(status.rn0), XSIZE=8,$
	  			/EDITABLE, UVALUE='junk' )
	  id_2 = WIDGET_BUTTON( id_1, VALUE='Averages & medians', $
	  	 UVALUE='MEANS' )

	 idlab = WIDGET_LABEL( id_1, value='   ')
	 idlab = WIDGET_LABEL( id_1, value='Show & Change Variables: ')
	 id_1 = WIDGET_BASE( id_1, /COLUMN, /FRAME )
	  id_2 = WIDGET_BASE( id_1, /ROW )
	  id_3 = WIDGET_BUTTON( id_2, VALUE='>>Variable>>', $
	  	 UVALUE='CVAR' )
	  id.cname = WIDGET_TEXT( id_2, VALUE=status.cname, XSIZE=12 )
	  id_2 = WIDGET_BUTTON( id_1, VALUE='Show Variable', UVALUE='SHOWVAR') 	   
	  id_2 = WIDGET_BASE( id_1, /ROW )
	  id_3 = WIDGET_BUTTON( id_2, VALUE='>>Record nr>>', $
	  	 UVALUE='RNUM' )
	  id.rnum = WIDGET_TEXT( id_2, VALUE=STRING(status.rnum), XSIZE=12,$
	  			/EDITABLE, UVALUE='junk' )
	  id_2 = WIDGET_BUTTON( id_1, VALUE='>>Change record>>', $
	  	 UVALUE='CHNG' )

	 id_1 = WIDGET_BASE( id_0, /COLUMN )
	  id_2 = WIDGET_LABEL( id_1, VALUE='Sub-array: ' )
	  id.suba = WIDGET_LIST( id_1, VALUE='*', UVALUE='SUBA', $
			 XSIZE=16, YSIZE=14 )
	 id_1 = WIDGET_BASE( id_0, /COLUMN )
	  id_2 = WIDGET_LABEL( id_1, VALUE=' ' )
	  id_2 = WIDGET_BASE( id_1, /ROW )
	   id_3 = WIDGET_BUTTON( id_2, VALUE='>> X-axis >>', UVALUE='NEWX' )
	   id.xname = WIDGET_TEXT( id_2, VALUE=status.xname, XSIZE=16 )
	  id_2 = WIDGET_BASE( id_1, /ROW )
	   id_3 = WIDGET_BUTTON( id_2, VALUE='Clear X-axis', UVALUE='CLRX' )
	  id_2 = WIDGET_BASE( id_1, /ROW )
	   id_3 = WIDGET_BUTTON( id_2, VALUE='>> Y-axis >>', UVALUE='NEWY' )
	   id.yname = WIDGET_TEXT( id_2, VALUE=' ', XSIZE=16 )
	  id_2 = WIDGET_BASE( id_1, /ROW )
	   id_3 = WIDGET_BUTTON( id_2, VALUE='>> Y-error bar >>', $
	   	UVALUE='NEWY_ERR' )
	   id.yerror = WIDGET_TEXT( id_2, VALUE=' ', XSIZE=16 )
	  id_2 = WIDGET_BASE( id_1, /ROW )
	   id_3 = WIDGET_BUTTON( id_2, VALUE='Clear Y-error bar', $
	   		UVALUE='CLRY_ERR' )
	  id_2 = WIDGET_BUTTON( id_1, VALUE='Plot (new window)', UVALUE='PLOT' )	
	  id_2 = WIDGET_BUTTON( id_1, $
		VALUE='Overplot (same window, new axis)', UVALUE='OPL1' )
	  id_2 = WIDGET_BUTTON( id_1, $
		VALUE='Overplot (same window, existing axis)', UVALUE='OPL2' )
	  id_2 = WIDGET_BASE( id_1, /ROW )
	   id_3 = WIDGET_LABEL( id_2, VALUE="Overplot axis #: " )
	   id.oplotval = WIDGET_TEXT( id_2, VALUE='99', XSIZE=16, /EDIT )
	  id_2 = WIDGET_LABEL(id_1, VAL='      ')
	  id_2 = WIDGET_BUTTON(id_1, VALUE=' Save structure under: ', $
	  		UVAL='SAVSTR')
	  id.savstr = WIDGET_TEXT(id_1, /EDITABLE, VALUE=!XDRDIR+'struct.SAV', $
	  		UVAL='junk')
	  id_2 = WIDGET_LABEL(id_1, VAL='      ')
	  id_2 = WIDGET_BUTTON( id_1, VALUE='    Quit    ', UVALUE='QUIT' )
			

	save =	{ id:			HANDLE_CREATE(), $
		  status:		HANDLE_CREATE(), $
		  struct:		HANDLE_CREATE(), $
		  subindex:		HANDLE_CREATE(), $
		  columns:		HANDLE_CREATE(), $
		  values:		HANDLE_CREATE() $
		}

	HANDLE_VALUE, save.id, id, /SET, /NO_COPY
	HANDLE_VALUE, save.status, status, /SET, /NO_COPY
	HANDLE_VALUE, save.subindex, subindex, /SET, /NO_COPY
	HANDLE_VALUE, save.struct, tmpstr, /SET, /NO_COPY
	HANDLE_VALUE, save.columns, columns, /SET, /NO_COPY
	HANDLE_VALUE, save.values, values, /SET, /NO_COPY
	WIDGET_CONTROL, id_base, /REALIZE, SET_UVALUE=save, /NO_COPY
	xMANAGER,No_BLOCK=1, "PIA_showstr", id_base, GROUP=group, $
		CLEANUP="PIA_showstr_CLEANUP"

	RETURN
	END


