;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_SIGDISC
;
; PURPOSE:
;	Menu for PIA Signal selection.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_SIGDISC
;
; INPUTS:
;	none
;	
; KEYWORD PARAMETERS:
;	GROUP
;		The group leader of the widget hirarchy
;	NSIG
;		Number of ramps per chopper plateau
;	
; OUTPUTS:
;	none
;	
; SIDE EFFECTS:
;	Modifies the variables in phtacc for selection criteria
;	
; COMMON BLOCKS:
;	pia_sigdsc_cmn	for internal use
;	phtacc		selection parameters
;	
; PROCEDURES USED:
;	Internal:
;		pia_sigdisc_event
;
; MODIFICATION HISTORY:
;	Written by:	C.Gabriel (ESA/ESTEC)		September 1994
;	Modified by:	CG				February 1995
;	Oct 95 Version 3.5
;	Not reseting anysig when starting (CG)		December 1995
;	XSIZE deleted from button (IDL V4 problem) (CG)	January 1996 
;	Modal keyword according to IDL>=5.0 (CG)	January 1999
;	V7.3
;-

; ****************************************************************************
;  Event handling routine for PIA signal selection menu
; ****************************************************************************

PRO pia_sigdisc_event, event

@phtacc
COMMON rp_limits, rp_limits

	COMMON pia_sigdisc_cmn, new_signacc, minramp, maxramp, new_anyr, $
		  new_sig1acc, sigok_id, sigto_id, sigfrom_id, lislist,$
		  sigfrom, sigto, read_cont, ramp_cont, sigch, rp_sigfrom_id,$
		  rp_sigok_id, rp_sigto_id, rp_sigfrom, rp_sigto, rp_read_cont,$
		  sig_port_ch, sig_port_nch, sigportch_id, sigportnch_id    

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue OF

          'ACCEPT': BEGIN
          	WIDGET_CONTROL, sigportch_id, GET_VALUE=val
          	chm=FLOAT(val(0))
          	WIDGET_CONTROL, sigportnch_id, GET_VALUE=val
          	nchm=FLOAT(val(0))
		sigtnacc = {chop_meas:chm,star_meas:nchm}
		
		sig1acc = new_sig1acc
		signacc = new_signacc
		minsig = minramp  
                maxsig = maxramp  
		anysig = new_anyr
                WIDGET_CONTROL, event.top, /DESTROY
          END

          'CANCEL': BEGIN

                WIDGET_CONTROL, event.top, /DESTROY

          END

	  'STANDARD': BEGIN
        	CASE event.value of
	
	        	0: new_sig1acc = event.select
					
		ENDCASE
	  END

	  'SIGFROM': BEGIN
			WIDGET_CONTROL, event.id, GET_VALUE=value
                        sigfrom = fix(value)
			sigfrom = sigfrom(0)
 			WIDGET_CONTROL, sigto_id, /SENSITIVE
 			WIDGET_CONTROL, sigto_id, /INPUT_FOCUS
 	  END
                    
	  'SIGTO':  BEGIN
			WIDGET_CONTROL, event.id, GET_VALUE=value
                        sigto = fix(value)
			sigto = sigto(0)
 			WIDGET_CONTROL, sigok_id, /SENSITIVE
 			WIDGET_CONTROL, sigok_id, /INPUT_FOCUS
	  END

	  'RESET': BEGIN
 			WIDGET_CONTROL, sigfrom_id, SET_VALUE='0'
 			WIDGET_CONTROL, sigto_id, SET_VALUE='0'
	     		new_signacc = 0
			  IF sigch NE -1 THEN $
			    str_sigch = strtrim(string(sigch),2) ELSE $
			    str_sigch = '?'

			  read_str = 'No Signals will be discarded from '+$
					str_sigch+' per Chopper Plateau '
        		  WIDGET_CONTROL, read_cont, SET_VALUE = read_str
                   END

	     		
	  'SIGOK':  BEGIN
			IF sigfrom EQ 0 and sigto EQ 0 THEN BEGIN 
				new_signacc = 0

			  IF sigch NE -1 THEN $
			    str_sigch = strtrim(string(sigch),2) ELSE $
			    str_sigch = '?'

			  read_str = 'No Signals will be discarded from '+$
					str_sigch+' per Chopper Plateau '
        		  WIDGET_CONTROL, read_cont, SET_VALUE = read_str

			  RETURN
			ENDIF
                        IF sigfrom EQ 0 or sigto EQ 0 or sigfrom gt sigto $
			  THEN  BEGIN
					PIA_DISP_PRINT_FILE, "", $
                			GROUP = event.top, $
                			TITLE = "Warning to YOU", $
                			WIDTH = 30, $
                			HEIGHT = 4, /MODAL, $
                			TEXT = ["Non-acceptable Values"]   
			ENDIF ELSE BEGIN

			  new_signacc = sigfrom			  

			  FOR i=sigfrom+1,sigto DO $
				new_signacc = [new_signacc,i] 	

			  str_sigfrom = strtrim(string(sigfrom),2)
			  str_sigto = strtrim(string(sigto),2)

			  IF sigch NE -1 THEN $
			    str_sigch = strtrim(string(sigch),2) ELSE $
			    str_sigch = '?'

			  read_str = 'All Signals between '+str_sigfrom+$
					' and '+str_sigto+$ 
					' from '+str_sigch+$ 
					' per Chopper Plateau will be discarded'
        		  WIDGET_CONTROL, read_cont, SET_VALUE = read_str

 			  WIDGET_CONTROL, sigto_id, SENSITIVE=0
 			  WIDGET_CONTROL, sigok_id, SENSITIVE=0
			ENDELSE
          END

	  'RP_SIGFROM': BEGIN
			WIDGET_CONTROL, event.id, GET_VALUE=value
                        rp_sigfrom = fix(value)
			rp_sigfrom = rp_sigfrom(0)
 			WIDGET_CONTROL, rp_sigto_id, /SENSITIVE
 			WIDGET_CONTROL, rp_sigto_id, /INPUT_FOCUS
 	  END
                    
	  'RP_SIGTO':  BEGIN
			WIDGET_CONTROL, event.id, GET_VALUE=value
                        rp_sigto = fix(value)
			rp_sigto = rp_sigto(0)
 			WIDGET_CONTROL, rp_sigok_id, /SENSITIVE
 			WIDGET_CONTROL, rp_sigok_id, /INPUT_FOCUS
	  END

	  'RP_RESET': BEGIN
 			WIDGET_CONTROL, rp_sigfrom_id, SET_VALUE='0'
 			WIDGET_CONTROL, rp_sigto_id, SET_VALUE='0'
			  rp_limits = [0,0]
			  read_str = $
			   'No Signals will be discarded per raster point'
        		  WIDGET_CONTROL, read_cont, SET_VALUE = read_str
                   END

	  'RP_SIGOK':  BEGIN
			IF rp_sigfrom EQ 0 and rp_sigto EQ 0 THEN BEGIN 
			  rp_limits = [0,0]

			  read_str = $
			   'No Signals will be discarded per raster point '
        		  WIDGET_CONTROL, rp_read_cont, SET_VALUE = read_str

			  RETURN
			ENDIF
                        IF RP_sigfrom EQ 0 or RP_sigto EQ 0 or $
                          RP_sigfrom gt RP_sigto THEN  BEGIN
					PIA_DISP_PRINT_FILE, "", $
                			GROUP = event.top, $
                			TITLE = "Warning to YOU", $
                			WIDTH = 30, $
                			HEIGHT = 4, /MODAL, $
                			TEXT = ["Non-acceptable Values"]   
			ENDIF ELSE BEGIN

			  rp_limits = [rp_sigfrom, rp_sigto]			  

			  read_str = 'All Signals between positions '+ $
			  		STRTRIM(rp_sigfrom,2)+$
					' and '+STRTRIM(rp_sigto,2)+$ 
					' per Raster Point will be discarded'
        		  WIDGET_CONTROL, rp_read_cont, SET_VALUE = read_str

 			  WIDGET_CONTROL, rp_sigto_id, SENSITIVE=0
 			  WIDGET_CONTROL, rp_sigok_id, SENSITIVE=0
			ENDELSE
          END

	  'ASGUPTO': BEGIN
			WIDGET_CONTROL, event.id, GET_VALUE=value
			widid = WIDGET_INFO(event.id)
                        minramp = fix(value(0))
			IF (maxramp NE 0 and minramp(0) NE 0 AND $
			   (maxramp-minramp) LE 1) OR minramp LT 0 THEN BEGIN
				WIDGET_CONTROL, event.id, SET_VALUE='0'
				minramp = 0
				PIA_DISP_PRINT_FILE, "", $
                			GROUP = event.top, $
                			TITLE = "Warning to YOU", $
                			WIDTH = 30, $
                			HEIGHT = 4, /MODAL, $
                			TEXT = ["Non-acceptable Value",$
						"I set it back to 0"]   
			ENDIF ELSE BEGIN	
	        	  firrmp = minramp(0) + 1
			  IF firrmp GT 1 THEN $
 				str_firrmp = STRTRIM(STRING(firrmp),2) ELSE $   
 				str_firrmp = 'First'   

		          lasrmp = maxramp(0) - 1
			  IF lasrmp GT 0 THEN $
		 		str_lasrmp = STRTRIM(STRING(lasrmp),2) ELSE $   
		 		str_lasrmp = 'Last'   

			  ramp_str = 'All Signals between '+str_firrmp+$
					' and '+str_lasrmp+$
					' are taken'
        		  WIDGET_CONTROL, ramp_cont, SET_VALUE=ramp_str
		        ENDELSE

	  END

	  'ASGFROM': BEGIN
			WIDGET_CONTROL, event.id, GET_VALUE=value
			widid = WIDGET_INFO(event.id)
                        maxramp = fix(value(0))
			IF (maxramp NE 0 and minramp(0) NE 0 AND $
			   (maxramp-minramp) LE 1) OR maxramp LT 0 THEN BEGIN
				WIDGET_CONTROL, event.id, SET_VALUE='0'
				maxramp = 0
				PIA_DISP_PRINT_FILE, "", $
                			GROUP = event.top, $
                			TITLE = "Warning to YOU", $
                			WIDTH = 30, $
                			HEIGHT = 4, /MODAL, $
                			TEXT = ["Non-acceptable Value",$
						"I set it back to 0"]   
			ENDIF ELSE BEGIN	

	        	  firrmp = minramp(0) + 1
			  IF firrmp GT 1 THEN $
 				str_firrmp = STRTRIM(STRING(firrmp),2) ELSE $   
 				str_firrmp = 'First'   

		          lasrmp = maxramp(0) - 1
			  IF lasrmp GT 0 THEN $
		 	    str_lasrmp = STRTRIM(STRING(lasrmp),2) ELSE $   
		 	    str_lasrmp = 'Last'   

			  ramp_str = 'All Signals between '+str_firrmp+$
					' and '+str_lasrmp+$
					' are taken'
        		  WIDGET_CONTROL, ramp_cont, SET_VALUE=ramp_str
			ENDELSE
	  END

	  'INDDES': BEGIN
			WIDGET_CONTROL, event.id, GET_VALUE=value
                        new_anyr = [new_anyr,fix(value)]
                        indno = WHERE(new_anyr ne 0)
			new_anyr = new_anyr(indno)
			str_anyr = STRING(new_anyr)
			WIDGET_CONTROL, lislist, SET_VALUE = str_anyr

	  END

	  'INDRES': BEGIN
			WIDGET_CONTROL, event.id, GET_VALUE=value
			res = fix(value)
			indno = WHERE(new_anyr eq res(0), count)
			IF count NE 0 THEN BEGIN
				new_anyr(indno) = 0 
                        	indno = WHERE(new_anyr ne 0, count)
				IF count ne 0 THEN BEGIN  
					new_anyr = new_anyr(indno)
					str_anyr = STRING(new_anyr)
				ENDIF ELSE str_anyr = ''
				WIDGET_CONTROL, lislist, SET_VALUE = str_anyr
			ENDIF
	  END
	  ELSE:		
       	ENDCASE
	RETURN
END

; ****************************************************************************
;  PIA SIGDISC - menu definition procedure
; ****************************************************************************

PRO pia_sigdisc, GROUP=group, nsig=nsig

@phtacc
COMMON rp_limits, rp_limits

; Definitions common to all instances

	COMMON pia_sigdisc_cmn, new_signacc, minramp, maxramp, new_anyr, $
		  new_sig1acc, sigok_id, sigto_id, sigfrom_id, lislist,$
		  sigfrom, sigto, read_cont, ramp_cont, sigch, rp_sigfrom_id,$
		  rp_sigok_id, rp_sigto_id, rp_sigfrom, rp_sigto, rp_read_cont,$
		  sig_port_ch, sig_port_nch, sigportch_id, sigportnch_id  



	IF (KEYWORD_SET(nsig))	THEN sigch = nsig	ELSE $
		BEGIN 
			MESSAGE, /INFO,$
			 ': Please provide # of signals per chopper plateau'
			RETURN
		END

	sigfrom = fix(min(signacc))
	sigto = fix(max(signacc))
	IF N_ELEMENTS(rp_limits) EQ 0 THEN rp_limits = [0,0]
	rp_sigfrom = rp_limits(0)
	rp_sigto = rp_limits(1)
	IF N_ELEMENTS(sigtnacc) EQ 0 THEN $
	 sigtnacc = {chop_meas:0.5,star_meas:0.}
	sig_port_ch = STRMID(STRTRIM(sigtnacc.chop_meas,2),0,4)
	sig_port_nch = STRMID(STRTRIM(sigtnacc.star_meas,2),0,4)

	num = sigto - sigfrom
	num = findgen(num+1)
	IF sigto GT 0 THEN new_signacc = num + sigfrom ELSE new_signacc = 0 

	new_sig1acc = sig1acc
	new_signacc = signacc

	IF N_ELEMENTS(anysig) NE 0 THEN	new_anyr = anysig ELSE new_anyr=0

	str_sig1acc = strtrim(string(sig1acc),2)
	str_sigfrom = strtrim(string(sigfrom),2)
	str_sigto = strtrim(string(sigto),2)

	rp_str_sigfrom = strtrim(string(rp_sigfrom),2)
	rp_str_sigto = strtrim(string(rp_sigto),2)

	IF sigch NE -1 THEN $
		str_sigch = strtrim(string(sigch),2) ELSE $
		str_sigch = '?'


	minramp = minsig
	str_minr = strtrim(string(minramp(0)),2)  

	maxramp = maxsig
	str_maxr = strtrim(string(maxramp(0)),2)  

	IF not KEYWORD_SET(group) THEN group = !pia_top_wid
	base = WIDGET_BASE(TITLE = 'PIA Signal selection menu', $ 
		 		/COLUMN, /MODAL, GROUP=group)

        label = WIDGET_LABEL(base, VALUE='Standard Choices')
	stdbase = WIDGET_BASE(base, /COLUMN, /FRAME)
	
	stdbut = cw_bgroup(stdbase, $
			/NONEXCLUSIVE, $
			SET_VALUE = sig1acc, $
			UVALUE = 'STANDARD', $
			["Discard first Signal per Chopper Plateau"])
	portcbase = WIDGET_BASE(stdbase, /ROW)
	sigportch_id = WIDGET_TEXT(portcbase, /EDITABLE, VAL=SIG_PORT_CH, $
				UVAL='JUNK',XSIZE=6)
	label = WIDGET_LABEL(portcbase, $
	  VAL='Disc. fraction / ch.pl - chopped case')
				
	portncbase = WIDGET_BASE(stdbase, /ROW)
	sigportnch_id = WIDGET_TEXT(portncbase, /EDITABLE, VAL=SIG_PORT_NCH, $
				UVAL='JUNK',XSIZE=6)
	label = WIDGET_LABEL(portncbase, $
	  VAL='Disc. fraction / ch.pl - staring & raster case')
				

        label = WIDGET_LABEL(base, VALUE='Special Choices')

	rodbase = WIDGET_BASE(base, /COLUMN, /FRAME)
	junkbase = WIDGET_BASE(rodbase, /ROW)
        junktit = WIDGET_LABEL(junkbase, $
	 VALUE='Discard Signals per Chopper Plateau (or measurement if staring):')

	sigbase = WIDGET_BASE(rodbase, /ROW)
        label = WIDGET_LABEL(sigbase, VALUE='  From:' )
        sigfrom_id = WIDGET_TEXT(sigbase, /EDITABLE, XSIZE=3, YSIZE=1, $
                        VALUE=str_sigfrom, UVALUE='SIGFROM')
        label = WIDGET_LABEL(sigbase, VALUE='  To:' )
        sigto_id = WIDGET_TEXT(sigbase, /EDITABLE, XSIZE=3, YSIZE=1, $
                        VALUE=str_sigto, UVALUE='SIGTO')
	dummy = WIDGET_LABEL(sigbase, VALUE='       ')
	sigok_id = WIDGET_BUTTON(sigbase, VALUE='OK', UVALUE='SIGOK')	
	sigreset = WIDGET_BUTTON(sigbase, VALUE='Reset', UVALUE='RESET')	
	
	WIDGET_CONTROL, sigto_id, SENSITIVE=0
	WIDGET_CONTROL, sigok_id, SENSITIVE=0
	
	IF sigfrom EQ 0 AND sigto EQ 0 THEN read_str = 'No signals' ELSE $
	read_str = 'All Signals between '+str_sigfrom+$
				' and '+str_sigto 
	
	read_str = read_str + ' from '+str_sigch+$ 
				' per Chopper Plateau will be discarded'

        read_cont = WIDGET_TEXT(rodbase, VALUE = read_str)


 	junkbase = WIDGET_BASE(rodbase, /ROW)
        junktit = WIDGET_LABEL(junkbase, $
	 VALUE='Discard Signals per Raster Point (only for raster measurements):')

	sigbase = WIDGET_BASE(rodbase, /ROW)
        label = WIDGET_LABEL(sigbase, VALUE='  From:' )
        rp_sigfrom_id = WIDGET_TEXT(sigbase, /EDITABLE, XSIZE=3, YSIZE=1, $
                        VALUE=rp_str_sigfrom, UVALUE='RP_SIGFROM')
        label = WIDGET_LABEL(sigbase, VALUE='  To:' )
        rp_sigto_id = WIDGET_TEXT(sigbase, /EDITABLE, XSIZE=3, YSIZE=1, $
                        VALUE=rp_str_sigto, UVALUE='RP_SIGTO')
	dummy = WIDGET_LABEL(sigbase, VALUE='       ')
	rp_sigok_id = WIDGET_BUTTON(sigbase, VALUE='OK', UVALUE='RP_SIGOK')	
	rp_sigreset = WIDGET_BUTTON(sigbase, VALUE='Reset', UVALUE='RP_RESET')	
	
	WIDGET_CONTROL, rp_sigto_id, SENSITIVE=0
	WIDGET_CONTROL, rp_sigok_id, SENSITIVE=0
	
	IF rp_sigfrom EQ 0 AND rp_sigto EQ 0 THEN read_str = 'No signals' ELSE $
	read_str = 'All Signals between '+rp_str_sigfrom+$
				' and '+rp_str_sigto 
	
	read_str = read_str + ' per raster point will be discarded'

        rp_read_cont = WIDGET_TEXT(rodbase, VALUE = read_str)

	junklabel = WIDGET_LABEL(rodbase, VALUE='       ')

	junkbase = WIDGET_BASE(rodbase, /ROW)
        junktit = WIDGET_LABEL(junkbase, $
			VALUE='Discard Ramps per Measurement:')

	arobase = WIDGET_BASE(rodbase, /ROW)
        label = WIDGET_LABEL(arobase, VALUE='From beginning up to:' )
        aroupto = WIDGET_TEXT(arobase, /EDITABLE, XSIZE=5, YSIZE=1, $
                   VALUE=str_minr, UVALUE='ASGUPTO') 
        label = WIDGET_LABEL(arobase, VALUE='To the end from  :' )
        arofrom = WIDGET_TEXT(arobase, /EDITABLE, XSIZE=5, YSIZE=1, $
                        VALUE=str_maxr, UVALUE='ASGFROM')
  
        firrmp = minramp(0) + 1
	IF firrmp GT 1 THEN $
 		str_firrmp = STRTRIM(STRING(firrmp),2) ELSE $   
 		str_firrmp = 'First'   

        lasrmp = maxramp(0) - 1
	IF lasrmp GT 0 THEN $
 		str_lasrmp = STRTRIM(STRING(lasrmp),2) ELSE $   
 		str_lasrmp = 'Last'   

	ramp_str = 'All Ramps between '+str_firrmp+' and '+str_lasrmp+$
			' are taken'
        ramp_cont = WIDGET_TEXT(rodbase, VALUE = ramp_str)


	junklabel = WIDGET_LABEL(rodbase, VALUE='       ')

	junkbase = WIDGET_BASE(rodbase, /ROW)
        junktit = WIDGET_LABEL(junkbase, $
			VALUE='Discard Individual Signals per Measurement:')

	indbase = WIDGET_BASE(rodbase, /ROW)
        label = WIDGET_LABEL(indbase, VALUE='Discard:' )
        inddes = WIDGET_TEXT(indbase, /EDITABLE, XSIZE=5, YSIZE=1, $
                        VALUE='', UVALUE='INDDES')  
        label = WIDGET_LABEL(indbase, VALUE='Reselect:' )
        indres = WIDGET_TEXT(indbase, /EDITABLE, XSIZE=5, YSIZE=1, $
                        VALUE='', UVALUE='INDRES')  

	lisbase = WIDGET_BASE(rodbase, /ROW)  

	str_anyr = STRING(new_anyr)

	lislist = WIDGET_TEXT(lisbase, VALUE=str_anyr, XSIZE=60)

	junklabel = WIDGET_LABEL(rodbase, VALUE='       ')

        control = WIDGET_BASE(base,/ROW)

        junk = WIDGET_LABEL(control, VALUE = '           ')
        accept = WIDGET_BUTTON(control, VALUE = '  OK  ', $
                        /FRAME, UVALUE = 'ACCEPT')
        junk = WIDGET_LABEL(control, VALUE = '                          ')
        cancel = WIDGET_BUTTON(control, VALUE = '  Cancel  ', $
                        /FRAME, UVALUE = 'CANCEL')

        WIDGET_CONTROL, base, /REALIZE, TLB_SET_XOFFSET=150, $
                        TLB_SET_YOFFSET=150

        xMANAGER,No_BLOCK=1, "pia_sigdisc", base, GROUP=group
	
        RETURN
END

