;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_SPDDISC
;
; PURPOSE:
;	Menu for PIA Chopper Plateau selection.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_SPDDISC
;
; INPUTS:
;	none
;	
; OPTIONAL INPUTS:
;	
; KEYWORD PARAMETERS:
;	GROUP
;		The group leader of the widget hirarchy
;	NCHP
;		Number of chopper plateaux			
; OUTPUTS:
;	none
;	
; SIDE EFFECTS:
;	Selection parameters in phtacc are altered
;  	
; COMMON BLOCKS:
;	pia_spddsc_cmn	for internal use
;	phtacc
;
; PROCEDURES USED:
;	none
;	
; MODIFICATION HISTORY:
;	Written by C.Gabriel (ESA/ESTEC)		February 1995
;	Oct 95 Version 3.5
;	XSIZE deleted from button (IDL V4 problem) (CG)	January 1996 
;	Modal keyword according to IDL>=5.0 (CG)	January 1999
;	V7.3
;-

; ****************************************************************************
;  Event handling routine for PIA Chopper Plateau selection menu
; ****************************************************************************

PRO pia_spddisc_event, event

@phtacc

	COMMON pia_spddsc_cmn, new_spdnacc, minspd, maxspd, new_anyspd, $
		      spdok_id, spdto_id, lislist,$
		      spdfrom, spdto, read_cont, spd_cont, spdch 

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue OF

          'ACCEPT': BEGIN
		spdnacc = new_spdnacc
		minscp = minspd(0) 
                maxscp = maxspd(0)  
		anyscp = new_anyspd  
                WIDGET_CONTROL, event.top, /DESTROY
          END

          'CANCEL': BEGIN

                WIDGET_CONTROL, event.top, /DESTROY

          END

	  'SPDFROM': BEGIN
			WIDGET_CONTROL, event.id, GET_VALUE=value
                        spdfrom = fix(value)
			spdfrom = spdfrom(0)
 			WIDGET_CONTROL, spdto_id, /SENSITIVE
 			WIDGET_CONTROL, spdto_id, /INPUT_FOCUS
 	  END
                    
	  'SPDTO':  BEGIN
			WIDGET_CONTROL, event.id, GET_VALUE=value
                        spdto = fix(value)
			spdto = spdto(0)
 			WIDGET_CONTROL, spdok_id, /SENSITIVE
 			WIDGET_CONTROL, spdok_id, /INPUT_FOCUS
	  END

	  'SPDOK':  BEGIN
			IF spdfrom EQ 0 and spdto EQ 0 THEN BEGIN 
				new_spdnacc = 0

			  str_spdch = strtrim(string(spdch),2)
			  read_str = 'No Chopper Plateaux from '+$
					str_spdch+' will be discarded '
        		  WIDGET_CONTROL, read_cont, SET_VALUE = read_str

			  RETURN
			ENDIF
                        IF spdfrom EQ 0 or spdto EQ 0 or spdfrom gt spdto $
			  THEN  BEGIN
					PIA_DISP_PRINT_FILE, "", $
                			GROUP = event.top, $
                			TITLE = "Warning to YOU", $
                			WIDTH = 30, $
                			HEIGHT = 4, /MODAL, $
                			TEXT = ["Non-acceptable Values"]   
			ENDIF ELSE BEGIN

			  new_spdnacc = spdfrom			  

			  FOR i=spdfrom+1,spdto DO $
				new_spdnacc = [new_spdnacc,i] 	

			  str_spdfrom = strtrim(string(spdfrom),2)
			  str_spdto = strtrim(string(spdto),2)
			  str_spdch = strtrim(string(spdch),2)
			  read_str = 'All Chopper Plateaux between '+$
					str_spdfrom+$
					' and '+str_spdto+$ 
					' from '+str_spdch+$ 
					' will be discarded'
        		  WIDGET_CONTROL, read_cont, SET_VALUE = read_str

 			  WIDGET_CONTROL, spdto_id, SENSITIVE=0
 			  WIDGET_CONTROL, spdok_id, SENSITIVE=0
			ENDELSE
          END

	  'ASGUPTO': BEGIN
			WIDGET_CONTROL, event.id, GET_VALUE=value
                        minspd = fix(value)
	        	firspd = minspd(0) + 1
			IF firspd GT 1 THEN $
 				str_firspd = STRTRIM(STRING(firspd),2) ELSE $   
 				str_firspd = 'First'   

		        lasspd = maxspd(0) - 1
			IF lasspd GT 0 THEN $
		 		str_lasspd = STRTRIM(STRING(lasspd),2) ELSE $   
		 		str_lasspd = 'Last'   

			spd_str = 'All Signals between '+str_firspd+$
					' and '+str_lasspd+$
					' are taken'
        		WIDGET_CONTROL, spd_cont, SET_VALUE=spd_str
		

	  END

	  'ASGFROM': BEGIN
			WIDGET_CONTROL, event.id, GET_VALUE=value
                        maxspd = fix(value)
	        	firspd = minspd(0) + 1
			IF firspd GT 1 THEN $
 				str_firspd = STRTRIM(STRING(firspd),2) ELSE $   
 				str_firspd = 'First'   

		        lasspd = maxspd(0) - 1
			IF lasspd GT 0 THEN $
		 	  str_lasspd = STRTRIM(STRING(lasspd),2) ELSE $   
		 	  str_lasspd = 'Last'   

			spd_str = 'All Signals between '+str_firspd+$
					' and '+str_lasspd+$
					' are taken'
        		WIDGET_CONTROL, spd_cont, SET_VALUE=spd_str
	  END

	  'INDDES': BEGIN
			WIDGET_CONTROL, event.id, GET_VALUE=value
                        new_anyspd = [new_anyspd,fix(value)]
                        indno = WHERE(new_anyspd ne 0)
			new_anyspd = new_anyspd(indno)
			str_anyspd = STRING(new_anyspd)
			WIDGET_CONTROL, lislist, SET_VALUE = str_anyspd

	  END

	  'INDRES': BEGIN
			WIDGET_CONTROL, event.id, GET_VALUE=value
			res = fix(value)
			indno = WHERE(new_anyspd eq res(0), count)
			IF count NE 0 THEN BEGIN
				new_anyspd(indno) = 0 
                        	indno = WHERE(new_anyspd ne 0, count)
				IF count ne 0 THEN BEGIN  
					new_anyspd = new_anyspd(indno)
					str_anyspd = STRING(new_anyspd)
				ENDIF ELSE str_anyspd = ''
				WIDGET_CONTROL, lislist, SET_VALUE = str_anyspd
			ENDIF
	  END
			
       	ENDCASE
	RETURN
END

; ****************************************************************************
;  PIA SPDDISC - menu definition procedure
; ****************************************************************************

PRO pia_spddisc, GROUP=group, nchp = nchp

@phtacc

; Definitions common to all instances

	COMMON pia_spddsc_cmn, new_spdnacc, minspd, maxspd, new_anyspd, $
		      spdok_id, spdto_id, lislist,$
		      spdfrom, spdto, read_cont, spd_cont, spdch 


	IF KEYWORD_SET(nchp) THEN spdch = nchp ELSE spdch = 0

	spdfrom = fix(min(spdnacc))
	spdto = fix(max(spdnacc))

	num = spdto - spdfrom
	num = findgen(num+1)

	IF spdto GT 0 THEN new_spdnacc = num + spdfrom ELSE new_spdnacc = 0 

	new_spdnacc = spdnacc
	new_anyspd = 0

	str_spdfrom = strtrim(string(spdfrom),2)
	str_spdto = strtrim(string(spdto),2)
	str_spdch = strtrim(string(spdch),2)
	str_anyspd = '0'

	minspd = minscp
	str_minr = strtrim(string(minspd(0)),2)  

	maxspd = maxscp
	str_maxr = strtrim(string(maxspd(0)),2)  

	IF not KEYWORD_SET(group) THEN group = !pia_top_wid
	rodbase = WIDGET_BASE(TITLE = 'PIA Chopper Plateau selection menu', $ 
		 		/COLUMN, /MODAL, GROUP=group)

	junkbase = WIDGET_BASE(rodbase, /ROW)
        junktit = WIDGET_LABEL(junkbase, $
			VALUE='Discard Chopper Plateau Signals:')

	spdbase = WIDGET_BASE(rodbase, /ROW)
        label = WIDGET_LABEL(spdbase, VALUE='  From:' )
        spdall = WIDGET_TEXT(spdbase, /EDITABLE, XSIZE=3, YSIZE=1, $
                        VALUE=str_spdfrom, UVALUE='SPDFROM')
        label = WIDGET_LABEL(spdbase, VALUE='  To:' )
        spdto_id = WIDGET_TEXT(spdbase, /EDITABLE, XSIZE=3, YSIZE=1, $
                        VALUE=str_spdto, UVALUE='SPDTO')
	dummy = WIDGET_LABEL(spdbase, VALUE='       ')
	spdok_id = WIDGET_BUTTON(spdbase, VALUE='OK', UVALUE='SPDOK')	
	
	WIDGET_CONTROL, spdto_id, SENSITIVE=0
	WIDGET_CONTROL, spdok_id, SENSITIVE=0
	
	read_str = 'All Chopper Plateau Signals between '+str_spdfrom+$
				' and '+str_spdto+$ 
				' from '+str_spdch+$ 
				' will be discarded'

        read_cont = WIDGET_TEXT(rodbase, VALUE = read_str)

	junklabel = WIDGET_LABEL(rodbase, VALUE='       ')

	junkbase = WIDGET_BASE(rodbase, /ROW)
        junktit = WIDGET_LABEL(junkbase, $
			VALUE='Discard Chopper Plateaux Region:')

	arobase = WIDGET_BASE(rodbase, /ROW)
        label = WIDGET_LABEL(arobase, VALUE='From beginning up to:' )
        aroupto = WIDGET_TEXT(arobase, /EDITABLE, XSIZE=5, YSIZE=1, $
                   VALUE=str_minr, UVALUE='ASGUPTO') 
        label = WIDGET_LABEL(arobase, VALUE='To the end from  :' )
        arofrom = WIDGET_TEXT(arobase, /EDITABLE, XSIZE=5, YSIZE=1, $
                        VALUE=str_maxr, UVALUE='ASGFROM')
  
        firspd = minspd(0) + 1
	IF firspd GT 1 THEN $
 		str_firspd = STRTRIM(STRING(firspd),2) ELSE $   
 		str_firspd = 'First'   

        lasspd = maxspd(0) - 1
	IF lasspd GT 0 THEN $
 		str_lasspd = STRTRIM(STRING(lasspd),2) ELSE $   
 		str_lasspd = 'Last'   

	spd_str = 'All Chopper Plateaux between '+str_firspd+' and '+$
		str_lasspd+' are taken'
        spd_cont = WIDGET_TEXT(rodbase, VALUE = spd_str)


	junklabel = WIDGET_LABEL(rodbase, VALUE='       ')

	junkbase = WIDGET_BASE(rodbase, /ROW)
        junktit = WIDGET_LABEL(junkbase, $
			VALUE='Discard Individual Chopper Plateaux:')

	indbase = WIDGET_BASE(rodbase, /ROW)
        label = WIDGET_LABEL(indbase, VALUE='Discard:' )
        inddes = WIDGET_TEXT(indbase, /EDITABLE, XSIZE=5, YSIZE=1, $
                        VALUE='', UVALUE='INDDES')  
        label = WIDGET_LABEL(indbase, VALUE='Reselect:' )
        indres = WIDGET_TEXT(indbase, /EDITABLE, XSIZE=5, YSIZE=1, $
                        VALUE='', UVALUE='INDRES')  

	lisbase = WIDGET_BASE(rodbase, /ROW)  
	lislist = WIDGET_TEXT(lisbase, VALUE='', XSIZE=60)

	junklabel = WIDGET_LABEL(rodbase, VALUE='       ')

        control = WIDGET_BASE(rodbase,/ROW)

        junk = WIDGET_LABEL(control, VALUE = '                          ')
        accept = WIDGET_BUTTON(control, VALUE = '  OK  ', $
                        /FRAME, UVALUE = 'ACCEPT')
        junk = WIDGET_LABEL(control, VALUE = '                          ')
        cancel = WIDGET_BUTTON(control, VALUE = '  Cancel  ', $
                        /FRAME, UVALUE = 'CANCEL')

        WIDGET_CONTROL, rodbase, /REALIZE, TLB_SET_XOFFSET=150, $
                        TLB_SET_YOFFSET=150

        xMANAGER,No_BLOCK=1, "pia_spddisc", rodbase, GROUP=group
	
        RETURN
END

