;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_SPECPHOT
;
; PURPOSE:
;	Widget user interface to process PHT-S on AA level.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_SPECPHOT
;
; INPUTS:
;	(none)
;
; KEYWORD PARAMETERS:
;	GROUP		The group leader of this widget hirarchy.
;
; OUTPUTS:
;	(none)
;
; PROCEDURES USED:
;	PIA Procedure(s):
;		decode_admn
;		pia_aapview
;		pia_disp_hdr
;		pia_get_rpid
;		pia_get_step
;		pia_open_iaap
;		sep_rp_chop
;	Astronomical Library:
;		fxpar
;	Internal:
;		pia_specphot_cleanup
;		pia_specphot_event
;		pia_specphot_rpchop
;
; COMMON BLOCKS:
;	phtslwavelen
;
; MODIFICATION HISTORY:
;	Written by: 	C. Gabriel, ESA/VILSPA		October 1995
;	Oct 95 Version 3.5
;	Plot + overplot of all spectra included		April 1996
;	F_lambda plotting added (CG)			April 1996
;	F_lambda plot in W/m^2/um now (CG)		June 1996
;	mnbr variable bug fixed (CG)			June 1996
;	help added (CG)					July 1996
;	Separation into RPID and CH.POS added (CG)	July 1996
;	PIA_SPECPHOT_RPCHOP routine added for simplification
;	 using pia_get_rpid and pia_get_step and 	
;	 adding possibility of adding several RPIDs(CG) December 1997
;	V6.6
;	Use of coded bitflag system (CG)			May 1999
;	V7.4 
;-

PRO PIA_SPECPHOT_RPCHOP, flux, unc, flag, rpid, cstp, flout, flounc, flpos

	rpid_ch=[1B,1B]
	npoints = FIX(max(rpid(0,*)))
	nlines = FIX(max(rpid(1,*)))

	IF (npoints * nlines) GT 1 THEN $
				pia_get_rpid, [npoints,nlines], rpid_ch
                	
        steps = max(cstp)

        IF steps GT 1 AND steps NE min(cstp) THEN BEGIN
	  pia_get_step, steps
	  mulch = 1
	ENDIF


	rpid_copy = rpid
	add0=''	
	add1=''

	ch0 = WHERE(rpid(0,*) EQ rpid_ch(0,0) )
	   		
	IF N_ELEMENTS(rpid_ch(0,*)) GT 1 THEN $
	 FOR I=1,N_ELEMENTS(rpid_ch(0,*))-1 DO BEGIN
	   IF rpid_ch(0,i) NE rpid_ch(0,0) THEN BEGIN
	    nch0 = WHERE(rpid(0,*) EQ rpid_ch(0,i) )
	    ch0 = [ch0,nch0]
	    add0=add0+'+'+STRTRIM(rpid_ch(0,i),2)
	   ENDIF
	 ENDFOR  
	 
	ch1 = WHERE(rpid(1,*) EQ rpid_ch(1,0))
	IF N_ELEMENTS(rpid_ch(1,*)) GT 1 THEN $
	 FOR I=1,N_ELEMENTS(rpid_ch(1,*))-1 DO BEGIN
	   IF rpid_ch(1,i) NE rpid_ch(1,0) THEN BEGIN
	    nch1 = WHERE(rpid(1,*) EQ rpid_ch(1,i))
	    add1=add1+'+'+STRTRIM(rpid_ch(1,i),2)
	    ch1 = [ch1,nch1]
	   ENDIF
	 ENDFOR  

	flpos = '  RPid [' + $
		STRTRIM(string(FIX(rpid_ch(0,0))),2)+add0+','+$
		STRTRIM(string(FIX(rpid_ch(1,0))),2)+add1+']'

	rpid_copy(0,ch0)=-1b
	rpid_copy(1,ch1)=-1b

	list = WHERE(cstp EQ steps AND rpid_copy(0,*) EQ -1B $
		AND rpid_copy(1,*) EQ -1B, n)

	IF steps GT 1 THEN $
	flpos = flpos + '    CH.step: ' +STRTRIM(cstp(list(0)),2)


	IF n EQ 0 THEN BEGIN
	  PRINT, 'Warning: no position found, returning'
	 RETURN 
	ENDIF ELSE IF n GT 1 THEN BEGIN
	        npix = N_ELEMENTS(flux(*,0))
	        flout = FLTARR(npix)
	        flounc = flout
		FOR I=0,npix-1 DO BEGIN
		 indacc = WHERE(flag(i,list) EQ 0, n)
		 IF n GT 0 THEN BEGIN
		  weight_mean, flux(i,list(indacc)), unc(i,list(indacc)), $
		    out, ounc 
		  flout(i) = out
		  flounc(i) = ounc
		 ENDIF
		ENDFOR
	ENDIF ELSE BEGIN
		list = list(0)
		flout = flux(*,list)
		flounc = unc(*,list)
	ENDELSE

	RETURN
	END
; ***************************************************************************
; PIA_SPECPHOT_CLEANUP  -  clean-up routine for PIA_MAPW
; ***************************************************************************

PRO PIA_SPECPHOT_CLEANUP, id_top

	WIDGET_CONTROL, id_top, GET_UVALUE=hsave
	HANDLE_FREE, hsave
	RETURN
	END 
 
; ***************************************************************************
; PIA_SPECPHOT_EVENT  -  event handling routine for PIA_SPECPHOT
; ***************************************************************************

PRO PIA_SPECPHOT_EVENT, event 
@phtslwavlen
@colour_indices
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
COMMON pia_multi_fit_resu, xres, yres, parres, parsigres, parres_nam

	WIDGET_CONTROL, event.id, GET_UVALUE=action 
	WIDGET_CONTROL, event.top, GET_UVALUE=hsave
	HANDLE_VALUE, hsave, save
	HANDLE_VALUE, save.hpar, par

	CASE action OF 

; select an AAP measurement from the PHTAAP common block

	'FOMA':	BEGIN
		; select a PHTAAP structure
		PIA_OPEN_IAAP, aap, DTYPE="SL", GROUP=event.top, ERROR=err

		IF err THEN RETURN

		; get some parameters from the PHTAAP structure
		par.detector	= aap.det
		par.admn	= aap.admn
		DECODE_ADMN, par.admn, tmp
		par.admn_decoded = tmp

		; define the number of pixels of the detector
		CASE par.detector OF
		'SS':	par.npixel = 64
		'SL':	par.npixel = 64
		ELSE:	par.npixel = 1
		ENDCASE

		; get some parameters from the AAP header
		HANDLE_VALUE, aap.hdr, hdr

		keyword = "EOHAPLID"
		plid     = FXPAR( hdr, keyword, COUNT=count )
		IF count LE 0 THEN $
			MESSAGE, /INFO, 'Warning: missing keyword '+keyword

		keyword = "EOHAOSN"
		osn      = FXPAR( hdr, keyword, COUNT=count )
		IF count LE 0 THEN $
			MESSAGE, /INFO, 'Warning: missing keyword '+keyword

		keyword = "EOHAAOTN"
		par.aotn = FXPAR( hdr, keyword, COUNT=count)
		IF count LE 0 THEN $
			MESSAGE, /INFO, 'Warning: missing keyword '+keyword
		par.aotn = STRTRIM(par.aotn,2)

		keyword = "ATTRA"
		par.ra   = FXPAR( hdr, keyword, COUNT=count )
;		IF count LE 0 THEN $
;			MESSAGE, /INFO, 'Warning: missing keyword '+keyword

		keyword = "ATTDEC"
		par.dec  = FXPAR( hdr, keyword, COUNT=count )
;		IF count LE 0 THEN $
;			MESSAGE, /INFO, 'Warning: missing keyword '+keyword

		keyword = "ATTRROTA"
		par.rota = FXPAR( hdr, keyword, COUNT=count )
		IF count LE 0 THEN BEGIN
;			MESSAGE, /INFO, 'Warning: missing keyword '+keyword
			par.rota = 0.
		ENDIF

		keyword = "ATTRNPTS"
		par.npts = FXPAR( hdr, keyword, COUNT=count )
		IF count LE 0 THEN BEGIN
;			MESSAGE, /INFO, 'Warning: missing keyword '+keyword
			HANDLE_VALUE, aap.rpid, rpid, /NO_COPY
			par.npts = MAX(rpid(0,*))
			HANDLE_VALUE, aap.rpid, rpid, /SET, /NO_COPY
		ENDIF

		keyword = "ATTRNLNS"
		par.nlns = FXPAR( hdr, keyword, COUNT=count )
		IF count LE 0 THEN BEGIN
;			MESSAGE, /INFO, 'Warning: missing keyword '+keyword
			HANDLE_VALUE, aap.rpid, rpid, /NO_COPY
			par.nlns = MAX(rpid(1,*))
			HANDLE_VALUE, aap.rpid, rpid, /SET, /NO_COPY
		ENDIF

		keyword = "ATTRDPTS"
		par.dpts = FXPAR( hdr, keyword, COUNT=count )
		IF count LE 0 THEN BEGIN
;			MESSAGE, /INFO, 'Warning: missing keyword '+keyword
			par.dpts = 90.
		ENDIF

		keyword = "ATTRDLNS"
		par.dlns = FXPAR( hdr, keyword, COUNT=count )
		IF count LE 0 THEN BEGIN
;			MESSAGE, /INFO, 'Warning: missing keyword '+keyword
			par.dlns = 90.
		ENDIF

		; fill the info panel
		HANDLE_VALUE, save.hid, id
		WIDGET_CONTROL, id.aotn, SET_VALUE=STRING(par.aotn)
		sdet = par.detector
		IF STRMID(sdet,0,1) EQ 'C' THEN sdet = sdet + '00'
		WIDGET_CONTROL, id.det, SET_VALUE=STRING(sdet)
		decode_admn, par.admn, measname
		WIDGET_CONTROL, id.admn, SET_VALUE=measname
		WIDGET_CONTROL, id.plid, SET_VALUE=STRING(plid)
		WIDGET_CONTROL, id.osn, SET_VALUE=STRTRIM(osn,2)
		WIDGET_CONTROL, id.raster, SET_VALUE= $
			STRING(par.npts,par.nlns,FORMAT="(i4,' x ',i4)")

		; save the AAP data structure locally
		HANDLE_VALUE, save.haap, aap, /SET, /NO_COPY

		; enable/disable menu items and set control flags
		WIDGET_CONTROL, id.mplf, SENSITIVE=1
		WIDGET_CONTROL, id.mplfl, SENSITIVE=1
		WIDGET_CONTROL, id.mplb, SENSITIVE=1
		WIDGET_CONTROL, id.spfit, SENSITIVE=1
		WIDGET_CONTROL, id.mshh, SENSITIVE=1
		WIDGET_CONTROL, id.msha, SENSITIVE=1
		par.aapin = 1
		par.mapin = 0
		; store the local parameters
		HANDLE_VALUE, save.hpar, par, /SET, /NO_COPY

		END

; quit the mapping application

	'QUIT': WIDGET_CONTROL, event.top, /DESTROY

; plot spectrum 

	'PLOTF':	BEGIN

                zoom_color = -1
		zoom_psymch = 4

		; check input data
		IF NOT par.aapin THEN RETURN
		IF N_ELEMENTS(slwavelen) EQ 0 THEN set_slwavelen

		; produce the spectra
		WIDGET_CONTROL, event.top, /HOURGLASS
		HANDLE_VALUE, save.haap, aap
		IF par.detector EQ 'SS' THEN wavlen = slwavelen(0:63) ELSE $
					     wavlen = slwavelen(64:127)
					     
		handle_value, aap.mnfl, mnfl
		handle_value, aap.mnfu, mnfu
		handle_value, aap.rpid, rpid
		handle_value, aap.cstp, cstp
		handle_value, aap.flag, flag
		get_validflag, flag, 'AAP', redflag, det=aap.det
		flag = redflag
		
		
; take care of bi-dimensional data arrays
		IF N_ELEMENTS(mnfl(0,*)) GT 1 THEN $
		 PIA_SPECPHOT_RPCHOP, $
		    mnfl, mnfu, flag, rpid, cstp, flux, unc, flpos ELSE BEGIN
		    flpos = ''
		    flux = mnfl
		    unc = mnfu
		ENDELSE
		 
		title = par.admn_decoded
		ytitle = ' Flux Density ' + flpos + '  [Jy]'
		xtitle = ' !4k 	   [l!3m]'
		pia_xplot, wavlen, flux, unc, title=title,$
			ytitle=ytitle, xtitle=xtitle, annotation=title+ytitle, $
			legend=title, overplot=0, $
			Color=zoom_color, psym=zoom_psymch
			

		HANDLE_VALUE, save.hid, id

		END

; plot spectrum 

	'OPLOTFS':	BEGIN

                IF zoom_color EQ -1 THEN zoom_color = green ELSE $
                        zoom_color = zoom_color + 1
                IF zoom_color EQ 9 then zoom_color = 4
                zoom_psymch = zoom_psymch + 1
                IF zoom_psymch EQ 8 THEN zoom_psymch = 1

		; check input data
		IF NOT par.aapin THEN RETURN
		IF N_ELEMENTS(slwavelen) EQ 0 THEN set_slwavelen

		; produce the spectra
		WIDGET_CONTROL, event.top, /HOURGLASS
		HANDLE_VALUE, save.haap, aap
		IF par.detector EQ 'SS' THEN wavlen = slwavelen(0:63) ELSE $
					     wavlen = slwavelen(64:127)
					     
		handle_value, aap.mnfl, mnfl
		handle_value, aap.mnfu, mnfu
		handle_value, aap.rpid, rpid
		handle_value, aap.cstp, cstp
		handle_value, aap.flag, flag
		get_validflag, flag, 'AAP', redflag, det=aap.det
		flag = redflag
		
; take care of bi-dimensional data arrays
		IF N_ELEMENTS(mnfl(0,*)) GT 1 THEN $
		  PIA_SPECPHOT_RPCHOP, $
		    mnfl, mnfu, flag, rpid, cstp, flux, unc, flpos ELSE BEGIN
		    flpos = ''
		    flux = mnfl
		    unc = mnfu
		ENDELSE
		 
		title = par.admn_decoded
		ytitle = ' Flux Density ' + flpos + '  [Jy]'
		xtitle = ' !4k 	   [l!3m]'
		pia_xplot, wavlen, flux, unc, title=title,$
			ytitle=ytitle, xtitle=xtitle, annotation=title+ytitle, $
			legend=title, overplot=1, $
			Color=zoom_color, psym=zoom_psymch

			
		HANDLE_VALUE, save.hid, id

		END

; plot spectrum 

	'OPLOTFN':	BEGIN

                IF zoom_color EQ -1 THEN zoom_color = green ELSE $
                        zoom_color = zoom_color + 1
                IF zoom_color EQ 9 then zoom_color = 4
                zoom_psymch = zoom_psymch + 1
                IF zoom_psymch EQ 8 THEN zoom_psymch = 1

		; check input data
		IF NOT par.aapin THEN RETURN
		IF N_ELEMENTS(slwavelen) EQ 0 THEN set_slwavelen

		; produce the spectra
		WIDGET_CONTROL, event.top, /HOURGLASS
		HANDLE_VALUE, save.haap, aap
		IF par.detector EQ 'SS' THEN wavlen = slwavelen(0:63) ELSE $
					     wavlen = slwavelen(64:127)
					     
		handle_value, aap.mnfl, mnfl
		handle_value, aap.mnfu, mnfu
		handle_value, aap.rpid, rpid
		handle_value, aap.cstp, cstp
		handle_value, aap.flag, flag
		get_validflag, flag, 'AAP', redflag, det=aap.det
		flag = redflag
		
; take care of bi-dimensional data arrays
		IF N_ELEMENTS(mnfl(0,*)) GT 1 THEN $
		  PIA_SPECPHOT_RPCHOP, $
		    mnfl, mnfu, flag, rpid, cstp, flux, unc, flpos ELSE BEGIN
		    flpos = ''
		    flux = mnfl
		    unc = mnfu
		ENDELSE
		 
		 
		title = par.admn_decoded
		ytitle = ' Flux Density ' + flpos + '  [Jy]'
		xtitle = ' !4k 	   [l!3m]'
		pia_xplot, wavlen, flux, unc, title=title,$
			ytitle=ytitle, xtitle=xtitle, annotation=title+ytitle, $
			legend=title, overplot=-1, $
			Color=zoom_color, psym=zoom_psymch
			
		HANDLE_VALUE, save.hid, id

		END

; plot spectrum 

	'PLOTFLAM':	BEGIN

                zoom_color = -1
		zoom_psymch = 4

		; check input data
		IF NOT par.aapin THEN RETURN
		IF N_ELEMENTS(slwavelen) EQ 0 THEN set_slwavelen

		; produce the spectra
		WIDGET_CONTROL, event.top, /HOURGLASS
		HANDLE_VALUE, save.haap, aap
		IF par.detector EQ 'SS' THEN wavlen = slwavelen(0:63) ELSE $
					     wavlen = slwavelen(64:127)
					     
		handle_value, aap.mnfl, mnfl
		handle_value, aap.mnfu, mnfu
		handle_value, aap.rpid, rpid
		handle_value, aap.cstp, cstp
		handle_value, aap.flag, flag
		get_validflag, flag, 'AAP', redflag, det=aap.det
		flag = redflag
		
; take care of bi-dimensional data arrays
		IF N_ELEMENTS(mnfl(0,*)) GT 1 THEN $
		  PIA_SPECPHOT_RPCHOP, $
		    mnfl, mnfu, flag, rpid, cstp, flux, unc, flpos ELSE BEGIN
		    flpos = ''
		    flux = mnfl
		    unc = mnfu
		ENDELSE		 
		 
; Convert Fnu to Flambda
		light_sp = 299792500D0
		conv_fct = light_sp / wavlen^2 * 1.e-20
		flux = flux * conv_fct
		unc = unc * conv_fct
		
		 		
		title = par.admn_decoded
		ytitle = '    Flux Density' + flpos + '   [W/m^2/!4l!3m]'
		xtitle = ' !4k 	   [l!3m]'
		pia_xplot, wavlen, flux, unc, title=title,$
			ytitle=ytitle, xtitle=xtitle, annotation=title+ytitle, $
			legend=title, overplot=0, $
			Color=zoom_color, psym=zoom_psymch
			

		HANDLE_VALUE, save.hid, id

		END

; plot spectrum 

	'OPLOTFLAMS':	BEGIN

                IF zoom_color EQ -1 THEN zoom_color = green ELSE $
                        zoom_color = zoom_color + 1
                IF zoom_color EQ 9 then zoom_color = 4
                zoom_psymch = zoom_psymch + 1
                IF zoom_psymch EQ 8 THEN zoom_psymch = 1

		; check input data
		IF NOT par.aapin THEN RETURN
		IF N_ELEMENTS(slwavelen) EQ 0 THEN set_slwavelen

		; produce the spectra
		WIDGET_CONTROL, event.top, /HOURGLASS
		HANDLE_VALUE, save.haap, aap
		IF par.detector EQ 'SS' THEN wavlen = slwavelen(0:63) ELSE $
					     wavlen = slwavelen(64:127)
					     
		handle_value, aap.mnfl, mnfl
		handle_value, aap.mnfu, mnfu
		handle_value, aap.rpid, rpid
		handle_value, aap.cstp, cstp
		handle_value, aap.flag, flag
		get_validflag, flag, 'AAP', redflag, det=aap.det
		flag = redflag
		
; take care of bi-dimensional data arrays
		IF N_ELEMENTS(mnfl(0,*)) GT 1 THEN $
		  PIA_SPECPHOT_RPCHOP, $
		    mnfl, mnfu, flag, rpid, cstp, flux, unc, flpos ELSE BEGIN
		    flpos = ''
		    flux = mnfl
		    unc = mnfu
		ENDELSE		 
		 
; Convert Fnu to Flambda
		light_sp = 299792500D0
		conv_fct = light_sp / wavlen^2 * 1.e-20
		flux = flux * conv_fct
		unc = unc * conv_fct
		
		 		
		title = par.admn_decoded
		ytitle = '    Flux Density' + flpos + '   [W/m^2/!4l!3m]'
		xtitle = ' !4k 	   [l!3m]'
		pia_xplot, wavlen, flux, unc, title=title,$
			ytitle=ytitle, xtitle=xtitle, annotation=title+ytitle, $
			legend=title, overplot=1, $
			Color=zoom_color, psym=zoom_psymch
			
			
		HANDLE_VALUE, save.hid, id

		END

; plot spectrum 

	'OPLOTFLAMN':	BEGIN

                IF zoom_color EQ -1 THEN zoom_color = green ELSE $
                        zoom_color = zoom_color + 1
                IF zoom_color EQ 9 then zoom_color = 4
                zoom_psymch = zoom_psymch + 1
                IF zoom_psymch EQ 8 THEN zoom_psymch = 1

		; check input data
		IF NOT par.aapin THEN RETURN
		IF N_ELEMENTS(slwavelen) EQ 0 THEN set_slwavelen

		; produce the spectra
		WIDGET_CONTROL, event.top, /HOURGLASS
		HANDLE_VALUE, save.haap, aap
		IF par.detector EQ 'SS' THEN wavlen = slwavelen(0:63) ELSE $
					     wavlen = slwavelen(64:127)
					     
		handle_value, aap.mnfl, mnfl
		handle_value, aap.mnfu, mnfu
		handle_value, aap.rpid, rpid
		handle_value, aap.cstp, cstp
		handle_value, aap.flag, flag
		get_validflag, flag, 'AAP', redflag, det=aap.det
		flag = redflag
		
; take care of bi-dimensional data arrays
		IF N_ELEMENTS(mnfl(0,*)) GT 1 THEN $
		  PIA_SPECPHOT_RPCHOP, $
		    mnfl, mnfu, flag, rpid, cstp, flux, unc, flpos ELSE BEGIN
		    flpos = ''
		    flux = mnfl
		    unc = mnfu
		ENDELSE		 
		 
; Convert Fnu to Flambda
		light_sp = 299792500D0
		conv_fct = light_sp / wavlen^2 * 1.e-20
		flux = flux * conv_fct
		unc = unc * conv_fct
		
		 		
		title = par.admn_decoded
		ytitle = '    Flux Density' + flpos + '   [W/m^2/!4l!3m]'
		xtitle = ' !4k 	   [l!3m]'
		pia_xplot, wavlen, flux, unc, title=title,$
			ytitle=ytitle, xtitle=xtitle, annotation=title+ytitle, $
			legend=title, overplot=-1, $
			Color=zoom_color, psym=zoom_psymch
			
			
		HANDLE_VALUE, save.hid, id

		END

; plot spectrum 

	'PLOTB':	BEGIN

                zoom_color = -1
		zoom_psymch = 4

		; check input data
		IF NOT par.aapin THEN RETURN
		IF N_ELEMENTS(slwavelen) EQ 0 THEN set_slwavelen

		; produce the spectra
		WIDGET_CONTROL, event.top, /HOURGLASS
		HANDLE_VALUE, save.haap, aap
		IF par.detector EQ 'SS' THEN wavlen = slwavelen(0:63) ELSE $
					     wavlen = slwavelen(64:127)
					     
		handle_value, aap.mnbr, mnfl
		handle_value, aap.mnbu, mnfu
		handle_value, aap.rpid, rpid
		handle_value, aap.cstp, cstp
		handle_value, aap.flag, flag
		get_validflag, flag, 'AAP', redflag, det=aap.det
		flag = redflag
		
; take care of bi-dimensional data arrays
		IF N_ELEMENTS(mnfl(0,*)) GT 1 THEN $
		  PIA_SPECPHOT_RPCHOP, $
		    mnfl, mnfu, flag, rpid, cstp, flux, unc, flpos ELSE BEGIN
		    flpos = ''
		    flux = mnfl
		    unc = mnfu
		ENDELSE		 
		 
					 
		title = par.admn_decoded
		ytitle = '    Surface Brightness ' + flpos + '   [MJy/sr]'
		xtitle = ' !4k 	   [l!3m]'
		pia_xplot, wavlen, flux, unc, title=title,$
			ytitle=ytitle, xtitle=xtitle, annotation=title+ytitle, $
			legend=title, overplot=0, $
			Color=zoom_color, psym=zoom_psymch
			

		HANDLE_VALUE, save.hid, id

		END

; plot spectrum 

	'OPLOTBS':	BEGIN

                IF zoom_color EQ -1 THEN zoom_color = green ELSE $
                        zoom_color = zoom_color + 1
                IF zoom_color EQ 9 then zoom_color = 4
                zoom_psymch = zoom_psymch + 1
                IF zoom_psymch EQ 8 THEN zoom_psymch = 1

		; check input data
		IF NOT par.aapin THEN RETURN
		IF N_ELEMENTS(slwavelen) EQ 0 THEN set_slwavelen

		; produce the spectra
		WIDGET_CONTROL, event.top, /HOURGLASS
		HANDLE_VALUE, save.haap, aap
		IF par.detector EQ 'SS' THEN wavlen = slwavelen(0:63) ELSE $
					     wavlen = slwavelen(64:127)
					     
		handle_value, aap.mnbr, mnfl
		handle_value, aap.mnbu, mnfu
		handle_value, aap.rpid, rpid
		handle_value, aap.cstp, cstp
		handle_value, aap.flag, flag
		get_validflag, flag, 'AAP', redflag, det=aap.det
		flag = redflag
		
; take care of bi-dimensional data arrays
		IF N_ELEMENTS(mnfl(0,*)) GT 1 THEN $
		  PIA_SPECPHOT_RPCHOP, $
		    mnfl, mnfu, flag, rpid, cstp, flux, unc, flpos ELSE BEGIN
		    flpos = ''
		    flux = mnfl
		    unc = mnfu
		ENDELSE		 
		 
		title = par.admn_decoded
		ytitle = '    Surface Brightness ' + flpos + '   [MJy/sr]'
		xtitle = ' !4k 	   [l!3m]'
		pia_xplot, wavlen, flux, unc, title=title,$
			ytitle=ytitle, xtitle=xtitle, annotation=title+ytitle, $
			legend=title, overplot=1, $
			Color=zoom_color, psym=zoom_psymch

		HANDLE_VALUE, save.hid, id

		END

; plot spectrum 

	'OPLOTBN':	BEGIN

                IF zoom_color EQ -1 THEN zoom_color = green ELSE $
                        zoom_color = zoom_color + 1
                IF zoom_color EQ 9 then zoom_color = 4
                zoom_psymch = zoom_psymch + 1
                IF zoom_psymch EQ 8 THEN zoom_psymch = 1

		; check input data
		IF NOT par.aapin THEN RETURN
		IF N_ELEMENTS(slwavelen) EQ 0 THEN set_slwavelen

		; produce the spectra
		WIDGET_CONTROL, event.top, /HOURGLASS
		HANDLE_VALUE, save.haap, aap
		IF par.detector EQ 'SS' THEN wavlen = slwavelen(0:63) ELSE $
					     wavlen = slwavelen(64:127)
					     
		handle_value, aap.mnbr, mnfl
		handle_value, aap.mnbu, mnfu
		handle_value, aap.rpid, rpid
		handle_value, aap.cstp, cstp
		handle_value, aap.flag, flag
		get_validflag, flag, 'AAP', redflag, det=aap.det
		flag = redflag
		
; take care of bi-dimensional data arrays
		IF N_ELEMENTS(mnfl(0,*)) GT 1 THEN $
		  PIA_SPECPHOT_RPCHOP, $
		    mnfl, mnfu, flag, rpid, cstp, flux, unc, flpos ELSE BEGIN
		    flpos = ''
		    flux = mnfl
		    unc = mnfu
		ENDELSE		 

		title = par.admn_decoded
		ytitle = '    Surface Brightness ' + flpos + '   [MJy/sr]'
		xtitle = ' !4k 	   [l!3m]'
		pia_xplot, wavlen, flux, unc, title=title,$
			ytitle=ytitle, xtitle=xtitle, annotation=title+ytitle, $
			legend=title, overplot=-1, $
			Color=zoom_color, psym=zoom_psymch

		HANDLE_VALUE, save.hid, id

		END

; produce spectrum and fit lines

	'PFITLINES':	BEGIN

		; check input data
		IF NOT par.aapin THEN RETURN
		IF N_ELEMENTS(slwavelen) EQ 0 THEN set_slwavelen

		; produce the spectra
		WIDGET_CONTROL, event.top, /HOURGLASS
		HANDLE_VALUE, save.haap, aap
		IF par.detector EQ 'SS' THEN wavlen = slwavelen(0:63) ELSE $
					     wavlen = slwavelen(64:127)
					     
		handle_value, aap.mnfl, mnfl
		handle_value, aap.mnfu, mnfu
		handle_value, aap.rpid, rpid
		handle_value, aap.cstp, cstp
		handle_value, aap.flag, flag
		get_validflag, flag, 'AAP', redflag, det=aap.det
		flag = redflag
		
; take care of bi-dimensional data arrays
		IF N_ELEMENTS(mnfl(0,*)) GT 1 THEN $
		  PIA_SPECPHOT_RPCHOP, $
		    mnfl, mnfu, flag, rpid, cstp, flux, unc, flpos ELSE BEGIN
		    flpos = ''
		    flux = mnfl
		    unc = mnfu
		ENDELSE		 
		 
		pia_multi_fit_nomodal, wavlen, flux, weight=1./unc^2,$
			psym=4

		HANDLE_VALUE, save.hid, id
		WIDGET_CONTROL, id.refit, SENSITIVE=1

		END

	'PFITLINES_M':	BEGIN

		; check input data
		IF NOT par.aapin THEN RETURN
		IF N_ELEMENTS(slwavelen) EQ 0 THEN set_slwavelen

		; produce the spectra
		WIDGET_CONTROL, event.top, /HOURGLASS
		HANDLE_VALUE, save.haap, aap
		IF par.detector EQ 'SS' THEN wavlen = slwavelen(0:63) ELSE $
					     wavlen = slwavelen(64:127)
					     
		handle_value, aap.mnbr, mnfl
		handle_value, aap.mnbu, mnfu
		handle_value, aap.rpid, rpid
		handle_value, aap.cstp, cstp
		handle_value, aap.flag, flag
		get_validflag, flag, 'AAP', redflag, det=aap.det
		flag = redflag
		
; take care of bi-dimensional data arrays
		IF N_ELEMENTS(mnfl(0,*)) GT 1 THEN $
		  PIA_SPECPHOT_RPCHOP, $
		     mnfl, mnfu, flag, rpid, cstp, flux, unc, flpos ELSE BEGIN
		    flpos = ''
		    flux = mnfl
		    unc = mnfu
		ENDELSE		 

		pia_multi_fit_nomodal, wavlen, flux, weight=1./unc^2,$
			psym=4
		HANDLE_VALUE, save.hid, id
		WIDGET_CONTROL, id.refit, SENSITIVE=1

		END

; show fit results
	'FITRES': BEGIN
		IF NOT par.aapin THEN RETURN
		IF N_ELEMENTS(parsigres) LE 1 THEN BEGIN
			MESSAGE, /INFO, 'invalid results, returning'
			RETURN
		END
		parres = parres(0:N_ELEMENTS(parsigres)-1)

		TEXT = [" Fitting Results "]
		TEXT = [TEXT, " ==================", " "]
                TEXT = [TEXT, 'Data: '+ par.admn_decoded]
                          	   
		TEXT = [TEXT, " ", "Fitting parameters found:"]
		FOR I=0,n_elements(parres)-1 DO $
		 	TEXT=[TEXT,STRING(parres(i))+ $
		 		" +/- "+STRING(parsigres(i))+ $
		 		"     "+ parres_nam(i)]

		TEXT= [TEXT," "]

		pia_disp_print_file, "Spectrum_fitting_Results", $
                    	   TITLE = "Fitting results", $
                    	   WIDTH = 30, $
                    	   HEIGHT = 40, $
                    	   TEXT = text
	END

		

; show FITS header
	'SHH':	BEGIN
		IF NOT par.aapin THEN RETURN
		HANDLE_VALUE, save.haap, aap
		HANDLE_VALUE, aap.hdr, hdr, /NO_COPY
		PIA_DISP_HDR, hdr, par.admn, 'PHTAAP', GROUP=event.top
		HANDLE_VALUE, aap.hdr, hdr, /SET, /NO_COPY
		END

; show data arrays

	'SHA':	BEGIN
		IF NOT par.aapin THEN RETURN
		HANDLE_VALUE, save.haap, aap
		PIA_AAPVIEW, aap, GROUP=event.top
		END

	'HELP': BEGIN
	   IF !VERSION.OS NE 'vms' THEN $
    spawn, '$w3net $PIA_HTML/um/astrophys_appl_window.html#spec_phot &' ELSE $
    spawn, 'w3net /pia_dsk/pia/html/um/astrophys_appl_window.html#spec_phot',/nowait
      	   END

	ELSE: 
	ENDCASE 
	RETURN 
	END 
 
; ***************************************************************************
; PIA_SPECPHOT  -  PIA_SPECPHOT main routine
; ***************************************************************************

PRO PIA_SPECPHOT, GROUP=group 

; define program parameters

	id = { $
		mplf:0L,	$
		mplfl:0L,	$
		mplb:0L,	$
		spfit:0L,	$
		refit:0L,	$
		mpmap:0L,	$
		mpsim:0L,	$
		mshh:0L,	$
		msha:0L,	$
		mshm:0L,	$
		mshs:0L,	$
		admn:0L,	$
		plid:0L,	$
		osn:0L,		$
		aotn:0L,	$
		det:0L,		$
		raster:0L	$
	}

	; make a dummy trans structure
	trans = PIA_MKTRANS([0,0],[0,0],[1,1],0)

	par = { $
		aapin:0,	$	; AAP data present flag
		mapin:0,	$	; maps produced flag
		detector:'',	$	; PHTAAP detector code
		admn:'',	$	; PHTAAP administration string
		admn_decoded:'', $	; admn, decoded string
		aotn:'',	$	; AOT name
		ra:0.,		$	; right ascension of center of map
		dec:0.,		$	; declination of center of map
		rota:0.,	$
		npts:0,		$	; # points per raster line
		nlns:0,		$	; # raster lines
		dpts:0.,	$	; distance of raster points
		dlns:0.,	$	; distance of raster lines
		datatype:0,	$	; mean, median, 1st, 3rd quartil
		npixel:1,	$	; the number of pixels of the detector
		fitpar:0,	$	; fitted parameters
		fitsigpar:0	$	; sigma on fitted parameters
	}

; set up widget hierarchy

	id_base = WIDGET_BASE( TITLE="PIA Spectro-photometry", /COLUMN ) 

	id_menu = WIDGET_BASE( id_base, /ROW ) 

	id_0 = WIDGET_BUTTON( id_menu, VAL="    File    ", /MENU ) 
	id_1 = WIDGET_BUTTON( id_0, VAL="Select measurement", UV="FOMA" ) 
	id_1 = WIDGET_BUTTON( id_0, VAL="Quit", UVA="QUIT" ) 

	id_0 = WIDGET_BUTTON( id_menu, VAL="   Plot   ", /MENU )
	id.mplf = WIDGET_BUTTON( id_0, VAL="Flux Density Spectrum F_nu", /MENU )
	id_1 = WIDGET_BUTTON( id.mplf, VAL=" New ", UVA="PLOTF")
	id_1 = WIDGET_BUTTON( id.mplf, VAL=" Overplot ", /MENU )
	id_2 = WIDGET_BUTTON( id_1, VAL="Synchronized",UVA="OPLOTFS")
	id_2 = WIDGET_BUTTON( id_1, VAL="Not synchronized",UVA="OPLOTFN")
	
	id.mplfl = WIDGET_BUTTON( id_0, VAL="Flux Density Spectrum F_lambda", $
			/MENU )
	id_1 = WIDGET_BUTTON( id.mplfl, VAL=" New ", UVA="PLOTFLAM")
	id_1 = WIDGET_BUTTON( id.mplfl, VAL=" Overplot ", /MENU )
	id_2 = WIDGET_BUTTON( id_1, VAL="Synchronized",UVA="OPLOTFLAMS")
	id_2 = WIDGET_BUTTON( id_1, VAL="Not synchronized",UVA="OPLOTFLAMN")

	id.mplb = WIDGET_BUTTON( id_0, VAL="Surface Brightness Spectrum",/MENU)
	id_1 = WIDGET_BUTTON( id.mplb, VAL=" New ", UVA="PLOTB")
	id_1 = WIDGET_BUTTON( id.mplb, VAL=" Overplot ", /MENU )
	id_2 = WIDGET_BUTTON( id_1, VAL="Synchronized",UVA="OPLOTBS")
	id_2 = WIDGET_BUTTON( id_1, VAL="Not synchronized",UVA="OPLOTBN")
	

	id_0 = WIDGET_BUTTON( id_menu, VAL="  Process  ", /MENU )
	id.spfit = WIDGET_BUTTON( id_0, VAL="Fit spectrum", /MENU )
	id_1 = WIDGET_BUTTON( id.spfit, VAL="Flux Density", UVA="PFITLINES")
	id_1 = WIDGET_BUTTON( id.spfit, VAL="Surface Brightness", $
		UVA="PFITLINES_M")
	id.refit = WIDGET_BUTTON(id_0, VAL="Show fit results", UVA="FITRES")
	
	id_0 = WIDGET_BUTTON( id_menu, VAL="    Show    ", /MENU )
	id.mshh = WIDGET_BUTTON( id_0, VAL="Header", UVA="SHH" )
	id.msha = WIDGET_BUTTON( id_0, VAL="Data arrays", UVA="SHA" )

	id_0 = WIDGET_BUTTON( id_menu, VAL=" Help ", UVA=" HELP " , /frame) 

	id_info = WIDGET_BASE( id_base, /COLUMN )

	id_0 = WIDGET_BASE( id_info, /ROW )
	id_1 = WIDGET_LABEL( id_0, $
		VALUE="Measurement:      " )
	id.admn = WIDGET_LABEL( id_0, VALUE="                              " )

	id_0 = WIDGET_BASE( id_info, /ROW )
	id_1 = WIDGET_LABEL( id_0, $
		VALUE="Proposal ID:                                      " )
	id.plid = WIDGET_LABEL( id_0, VALUE="                  " )

	id_0 = WIDGET_BASE( id_info, /ROW )
	id_1 = WIDGET_LABEL( id_0, $
		VALUE="Observation sequence number:      " )
	id.osn = WIDGET_LABEL( id_0, VALUE="        " )

	id_0 = WIDGET_BASE( id_info, /ROW )
	id_1 = WIDGET_LABEL( id_0, $
		VALUE="AOT:                                                 " )
	id.aotn = WIDGET_LABEL( id_0, VALUE="      " )

	id_0 = WIDGET_BASE( id_info, /ROW )
	id_1 = WIDGET_LABEL( id_0, $
		VALUE="Detector:                                           " )
	id.det = WIDGET_LABEL( id_0, VALUE="     " )

	id_0 = WIDGET_BASE( id_info, /ROW )
	id_1 = WIDGET_LABEL( id_0, $
		VALUE="Raster (points x lines):                   " )
	id.raster = WIDGET_LABEL( id_0, VALUE="             " )

; realize widget

	hsave = HANDLE_CREATE()
	hid = HANDLE_CREATE( hsave, VALUE=id )
	hpar = HANDLE_CREATE( hsave, VALUE=par )
	haap = HANDLE_CREATE( hsave )
	save = { hid:hid, hpar:hpar, haap:haap }
	HANDLE_VALUE, hsave, save, /SET, /NO_COPY

	WIDGET_CONTROL, id_base, /REALIZE, SET_UVALUE=hsave
	WIDGET_CONTROL, id.mplf, SENSITIVE=0
	WIDGET_CONTROL, id.mplfl, SENSITIVE=0
	WIDGET_CONTROL, id.mplb, SENSITIVE=0
	WIDGET_CONTROL, id.spfit, SENSITIVE=0
	WIDGET_CONTROL, id.refit, SENSITIVE=0
	WIDGET_CONTROL, id.mshh, SENSITIVE=0
	WIDGET_CONTROL, id.msha, SENSITIVE=0

	xMANAGER,No_BLOCK=1, "PIA_SPECPHOT", id_base, GROUP=group, $
		CLEANUP="PIA_SPECPHOT_CLEANUP" 

	RETURN 
	END 
