;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO PIA_STRUCTURES_HELP, erd=erd, srd=srd, scp=scp, $
                                 spd=spd, aap=aap, aar=aar, $
                                 ppap=ppap, ppae=ppae, ppas=ppas,  $
                                 plap=plap, plae=plae, plas=plas,  $
                                 psap=psap, psae=psae, psas=psas,  $
                                 pcap=pcap, pcae=pcae, pcas=pcas
;+
; NAME:
;       PIA_STRUCTURES_HELP
;
; PURPOSE:
;	Print information on the dynamical PIA buffers 
;
; CATEGORY:
;	PIA - help
;
; CALLING SEQUENCE:
;       pia_structures_help, [/phterd], [/phtsrd], ...
;
; INPUT KEYWORDS:
;	phterd: To obtain info on phterd
;	phtsrd: To obtain info on phtsrd
;	phtscp: To obtain info on phtscp
;	phtspd: To obtain info on phtspd
;	phtaap: To obtain info on phtaap
;       phtaar: To obtain info on phtaar
;       PPAP:   PHT-P point source photometry sub-structure
;       PPAE:   PHT-P extended source photometry sub-structure
;       PPAS:   PHT-P scan & slew photometry sub-structure
;       PLAP:   PHT-SL point source spectroscopy sub-structure
;       PLAE:   PHT-SL extended source spectroscopy sub-structure
;       PLAS:   PHT-SL Raster mode spectroscopy sub-structure
;       PSAP:   PHT-SS point source spectroscopy sub-structure
;       PSAE:   PHT-SS extended source spectroscopy sub-structure
;       PSAS:   PHT-SS Raster mode spectroscopy sub-structure
;       PCAP:   PHT-C point source photometry sub-structure
;       PCAE:   PHT-C extended source photometry sub-structure
;       PCAS:   PHT-C scan & slew photometry sub-structure
;
; PROCEDURES USED: 
;       Common Block(s) or @ procedure(s):
;               phterd
;               phtsrd
;               phtscp
;               phtspd
;               phtaap
;               phtaar
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel  (ESA-SAI)		July 1996
;       AAR structures added:    IH (MPIK)              Mai  1997
;	V6.3
;
;-
;
@phterd
@phtsrd
@phtscp
@phtspd
@phtaap
@phtaar
;
        IF KEYWORD_SET(erd) THEN BEGIN
            PRINT, 'PHTERD structure:'
            PRINT, '-----------------'
            PRINT, ' '
            tt = tag_names(phterd)
            for i=0,N_Tags(phterd) - 1 DO PRINT, tt(i)+': '+phterd_desc(i)
            PRINT, ' '
        ENDIF
        IF KEYWORD_SET(srd) THEN BEGIN
            PRINT, 'PHTsrd structure:'
            PRINT, '-----------------'
            PRINT, ' '
            tt = tag_names(phtsrd)
            for i=0,N_Tags(phtsrd) - 1 DO PRINT, tt(i)+': '+phtsrd_desc(i)
            PRINT, ' '
        ENDIF
        IF KEYWORD_SET(scp) THEN BEGIN
            PRINT, 'PHTscp structure:'
            PRINT, '-----------------'
            PRINT, ' '
            tt = tag_names(phtscp)
            for i=0,N_Tags(phtscp) - 1 DO PRINT, tt(i)+': '+phtscp_desc(i)
            PRINT, ' '
        ENDIF
        IF KEYWORD_SET(spd) THEN BEGIN
            PRINT, 'PHTspd structure:'
            PRINT, '-----------------'
            PRINT, ' '
            tt = tag_names(phtspd)
            for i=0,N_Tags(phtspd) - 1 DO PRINT, tt(i)+': '+phtspd_desc(i)
            PRINT, ' '
        ENDIF
        IF KEYWORD_SET(aap) THEN BEGIN
            PRINT, 'PHTaap structure:'
            PRINT, '-----------------'
            PRINT, ' '
            tt = tag_names(phtaap)
            for i=0,N_Tags(phtaap) - 1 DO PRINT, tt(i)+': '+phtaap_desc(i)
            PRINT, ' '
        ENDIF
        IF KEYWORD_SET(aar) THEN BEGIN
            PHTAAR_DESC = [ $
                            "Internal Name", $
                            "Data Type", $
                            " Header", $
                            "Data" $
                          ]
            PRINT, 'PHTaar structure:'
            PRINT, '-----------------'
            PRINT, ' '
            tt = tag_names(phtaar)
            for i=0,N_Tags(phtaar) - 1 DO PRINT, tt(i)+': '+phtaar_desc(i)
            Print, ' '
            Print, 'Data is a pointer to an AAR sub-structure of TYPE:
            Print, ' '                
            Print, '   PPAP, PPAE, PPAS, PLAP, PLAE, PLAS, PSAP, PSAE, PSAS, ' + $
              'PCAP, PCAE, PCAS'
            PRINT, ' '
        ENDIF
        IF KEYWORD_SET(PPAP) THEN BEGIN
            PRINT, 'PHTaar PPAP PHT-P point source photometry sub-structure:'
            PRINT, '--------------------------------------------------------'
            PRINT, ' '
            tmp_PPAP={ppap_type}
            tt = tag_names(tmp_ppap)
            for i=0,N_Tags(tmp_ppap) - 1 DO PRINT, tt(i)+': '+ppap_desc(i)
            PRINT, ' '
        ENDIF
        IF KEYWORD_SET(PPAE) THEN BEGIN
            PRINT, 'PHTaar PPAE PHT-P extended source photometry sub-structure:'
            PRINT, '-----------------------------------------------------------'
            PRINT, ' '
            tmp_PPAe={ppae_type}
            tt = tag_names(tmp_ppae)
            for i=0,N_Tags(tmp_ppae) - 1 DO PRINT, tt(i)+': '+ppae_desc(i)
            PRINT, ' '
        ENDIF
        IF KEYWORD_SET(PPAS) THEN BEGIN
            PRINT, 'PHTaar PPAS PHT-P scan & slew photometry sub-structure:'
            PRINT, '-------------------------------------------------------'
            PRINT, ' '
            tmp_PPAS={ppas_type}
            tt = tag_names(tmp_ppas)
            for i=0,N_Tags(tmp_ppas) - 1 DO PRINT, tt(i)+': '+ppas_desc(i)
            PRINT, ' '
        ENDIF
        IF KEYWORD_SET(PLAP) THEN BEGIN
            PRINT, 'PHTaar PLAP PHT-SL point source spectroscopy sub-structure:'
            PRINT, '-----------------------------------------------------------'
            PRINT, ' '
            tmp_PLAP={plap_type}
            tt = tag_names(tmp_plap)
            for i=0,N_Tags(tmp_plap) - 1 DO PRINT, tt(i)+': '+plap_desc(i)
            PRINT, ' '
        ENDIF
        IF KEYWORD_SET(PLAE) THEN BEGIN
            PRINT, 'PHTaar PLAE PHT-SL extended source spectroscopy sub-structure:'
            PRINT, '--------------------------------------------------------------'
            PRINT, ' '
            tmp_PLAE={plae_type}
            tt = tag_names(tmp_plae)
            for i=0,N_Tags(tmp_plae) - 1 DO PRINT, tt(i)+': '+plae_desc(i)
            PRINT, ' '
        ENDIF
        IF KEYWORD_SET(PLAS) THEN BEGIN
            PRINT, 'PHTaar PLAS PHT-SL Raster mode spectroscopy sub-structure:'
            PRINT, '----------------------------------------------------------'
            PRINT, ' '
            tmp_PLAS={plas_type}
            tt = tag_names(tmp_plas)
            for i=0,N_Tags(tmp_plas) - 1 DO PRINT, tt(i)+': '+plas_desc(i)
            PRINT, ' '
        ENDIF
        IF KEYWORD_SET(PSAP) THEN BEGIN
            PRINT, 'PHTaar PSAP PHT-SS point source spectroscopy sub-structure:'
            PRINT, '----------------------------------------------------------'
            PRINT, ' '
            tmp_PSAP={psap_type}
            tt = tag_names(tmp_psap)
            for i=0,N_Tags(tmp_psap) - 1 DO PRINT, tt(i)+': '+psap_desc(i)
            PRINT, ' '
        ENDIF
        IF KEYWORD_SET(PSAE) THEN BEGIN
            PRINT, 'PHTaar PSAE PHT-SS extended source spectroscopy sub-structure:'
            PRINT, '--------------------------------------------------------------'
            PRINT, ' '
            tmp_PSAE={psae_type}
            tt = tag_names(tmp_psae)
            for i=0,N_Tags(tmp_psae) - 1 DO PRINT, tt(i)+': '+psae_desc(i)
            PRINT, ' '
        ENDIF
        IF KEYWORD_SET(PSAS) THEN BEGIN
            PRINT, 'PHTaar PSAS PHT-SS Raster mode spectroscopy sub-structure:'
            PRINT, '----------------------------------------------------------'
            PRINT, ' '
            tmp_PSAS={psas_type}
            tt = tag_names(tmp_psas)
            for i=0,N_Tags(tmp_psas) - 1 DO PRINT, tt(i)+': '+psas_desc(i)
            PRINT, ' '
        ENDIF
        IF KEYWORD_SET(PCAP) THEN BEGIN
            PRINT, 'PHTaar PCAP PHT-C point source photometry sub-structure:'
            PRINT, '--------------------------------------------------------'
            PRINT, ' '
            tmp_PCAP={pcap_type}
            tt = tag_names(tmp_pcap)
            for i=0,N_Tags(tmp_pcap) - 1 DO PRINT, tt(i)+': '+pcap_desc(i)
            PRINT, ' '
        ENDIF
        IF KEYWORD_SET(PCAE) THEN BEGIN
            PRINT, 'PHTaar PCAE  PHT-C extended source photometry sub-structure:'
            PRINT, '------------------------------------------------------------'
            PRINT, ' '
            tmp_PCAE={pcae_type}
            tt = tag_names(tmp_pcae)
            for i=0,N_Tags(tmp_pcae) - 1 DO PRINT, tt(i)+': '+pcae_desc(i)
            PRINT, ' '
        ENDIF
        IF KEYWORD_SET(PCAS) THEN BEGIN
            PRINT, 'PHTaar PCAS PHT-C scan & slew photometry sub-structure:'
            PRINT, '-------------------------------------------------------'
            PRINT, ' '
            tmp_PCAS={pcas_type}
            tt = tag_names(tmp_pcas)
            for i=0,N_Tags(tmp_pcas) - 1 DO PRINT, tt(i)+': '+pcas_desc(i)
            PRINT, ' '
        ENDIF
        RETURN
    END
