;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_VIEW
;
; PURPOSE:
;	Menu for PIA FileViewer. Access different types of PHT-FITS files
;	per filetype and detector, and display their contents.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_VIEW
;
; INPUTS:
;	(none)
;	
; KEYWORD PARAMETERS:
;	GROUP : The group leader of the widget hirarchy
;	
; OUTPUTS:
;	(none)
;	
; SIDE EFFECTS:
;	(none)
;	
; RESTRICTIONS:
;	(none)
;	
; COMMON BLOCKS:
;	PIA_VIEW	for internal use
;	
; PROCEDURES USED:
;	PIA Procedure(s):
;		pia_filefilter
;		pia_filetype
;		pia_open_fxb
;		pia_read_cs
;		pia_read_erd
;		pia_read_unkn
;		pia_view_erd
;		pia_view_txt
;		pia_view_unkn
;		pia_xplot
;		read_cs
;		read_erd
;	Astronomical Library:
;		fxbclose
;		fxbfind
;		fxbread
;	Internal:
;		pia_view_plot_cleanup
;		pia_view_plot_event
;		pia_view_plot
;		pia_view_cleanup
;		pia_view_event
;
; MODIFICATION HISTORY:
;	Written by: D. Skaley, MPIK/Heidelberg		August 1994
;	Oct 95 Version 3.5
;-


PRO PIA_VIEW_PLOT_CLEANUP, event_id

	WIDGET_CONTROL, event_id, GET_UVALUE=save, /NO_COPY
	HANDLE_VALUE, save.id, waste, /NO_COPY
	HANDLE_VALUE, save.status, waste, /NO_COPY
	HANDLE_VALUE, save.columns, waste, /NO_COPY
	HANDLE_VALUE, save.values, waste, /NO_COPY
	RETURN
	END


PRO PIA_VIEW_PLOT_EVENT, event

	WIDGET_CONTROL, event.id, GET_UVALUE=action
	WIDGET_CONTROL, event.top, GET_UVALUE=save
	HANDLE_VALUE, save.id, id
	HANDLE_VALUE, save.status, status, /NO_COPY
	HANDLE_VALUE, save.values, values, /NO_COPY
	HANDLE_VALUE, save.columns, columns, /NO_COPY

	CASE action OF

	'QUIT':	BEGIN
		WIDGET_CONTROL, event.top, /DESTROY
		RETURN
		END

	'NAME':	BEGIN
		status.selname = values(event.index)
		status.selcolumn = columns(event.index)
		END

	'CLRX':	BEGIN
		status.xname = 'Index'
		status.xcolumn = 0
		WIDGET_CONTROL, id.xname, SET_VALUE=status.xname
		END

	'NEWX':	BEGIN
		status.xname = status.selname
		status.xcolumn = status.selcolumn
		WIDGET_CONTROL, id.xname, SET_VALUE=status.xname
		END

	'NEWY':	BEGIN
		status.yname = status.selname
		status.ycolumn = status.selcolumn
		WIDGET_CONTROL, id.yname, SET_VALUE=status.yname
		END

	'PLOT': IF status.ycolumn NE 0 THEN BEGIN
		overplot = 0
		GOTO, do_plot
		END

	'OPL1': IF status.ycolumn NE 0 THEN BEGIN
		overplot = -1
		GOTO, do_plot
		END

	'OPL2': IF status.ycolumn NE 0 THEN BEGIN
		WIDGET_CONTROL, id.oplotval, GET_VALUE=val
		overplot = FIX(val(0))
		GOTO, do_plot
		END

	ELSE:
	ENDCASE
	GOTO, skip_plot

do_plot:
	HANDLE_VALUE, save.parent_status, parent_status
	FXBREAD, parent_status.fxbunit, yarray, status.ycolumn
	IF status.xcolumn NE 0 THEN BEGIN
		FXBREAD, parent_status.fxbunit, xarray, status.xcolumn
		PIA_XPLOT, xarray, yarray, GROUP=event.top, $
			xtitle=status.xname, ytitle=status.yname, $
			OVERPLOT=overplot, LEGEND=status.yname
	ENDIF ELSE BEGIN
		PIA_XPLOT, yarray, GROUP=event.top, $
			xtitle=status.xname, ytitle=status.yname, $
			OVERPLOT=overplot, LEGEND=status.yname
	ENDELSE

skip_plot:
	HANDLE_VALUE, save.status, status, /SET, /NO_COPY
	HANDLE_VALUE, save.values, values, /SET, /NO_COPY
	HANDLE_VALUE, save.columns, columns, /SET, /NO_COPY
	RETURN

	END


PRO PIA_VIEW_PLOT, header, parent_status, GROUP=group

	FXBFIND, header, 'TTYPE', columns, values, n_found

	id 	= { xname:0L, yname:0L, oplotval:0L }
	status 	= {	selname:'', 	$
			selcolumn:0, 	$
			xname:'Index', 	$
			xcolumn:0, 	$
			yname:'', 	$
			ycolumn:0 	$
		}

	id_base = WIDGET_BASE( TITLE='FileView - Plot Curves', /COLUMN )

	id_0 = WIDGET_BASE( id_base, /ROW )
	 id_1 = WIDGET_BASE( id_0, /COLUMN )
	  id_2 = WIDGET_LABEL( id_1, VALUE='Select data to be plotted: ' )
	  id_2 = WIDGET_LIST( id_1, VALUE=values, UVALUE='NAME', $
				XSIZE=16, YSIZE=13 )
	 id_1 = WIDGET_BASE( id_0, /COLUMN )
	  id_2 = WIDGET_LABEL( id_1, VALUE=' ' )
	  id_2 = WIDGET_BASE( id_1, /ROW )
	   id_3 = WIDGET_BUTTON( id_2, VALUE='>> X-axis >>', UVALUE='NEWX' )
	   id.xname = WIDGET_TEXT( id_2, VALUE=status.xname, XSIZE=16 )
	  id_2 = WIDGET_BASE( id_1, /ROW )
	   id_3 = WIDGET_BUTTON( id_2, VALUE='Clear X-axis', UVALUE='CLRX' )
	  id_2 = WIDGET_BASE( id_1, /ROW )
	   id_3 = WIDGET_BUTTON( id_2, VALUE='>> Y-axis >>', UVALUE='NEWY' )
	   id.yname = WIDGET_TEXT( id_2, VALUE=' ', XSIZE=16 )
	  id_2 = WIDGET_BUTTON( id_1, VALUE='Plot (new window)', UVALUE='PLOT' )	
	  id_2 = WIDGET_BUTTON( id_1, $
		VALUE='Overplot (same window, new axis)', UVALUE='OPL1' )
	  id_2 = WIDGET_BUTTON( id_1, $
		VALUE='Overplot (same window, existing axis)', UVALUE='OPL2' )
	  id_2 = WIDGET_BASE( id_1, /ROW )
	   id_3 = WIDGET_LABEL( id_2, VALUE="Overplot axis #: " )
	   id.oplotval = WIDGET_TEXT( id_2, VALUE='99', XSIZE=16, /EDIT )
	  id_2 = WIDGET_BUTTON( id_1, VALUE='    Quit    ', UVALUE='QUIT' )


	save =	{ id:			HANDLE_CREATE(), $
		  status:		HANDLE_CREATE(), $
		  columns:		HANDLE_CREATE(), $
		  values:		HANDLE_CREATE(), $
		  parent_status:	HANDLE_CREATE() $
		}

	HANDLE_VALUE, save.id, id, /SET, /NO_COPY
	HANDLE_VALUE, save.status, status, /SET, /NO_COPY
	HANDLE_VALUE, save.columns, columns, /SET, /NO_COPY
	HANDLE_VALUE, save.values, values, /SET, /NO_COPY
	HANDLE_VALUE, save.parent_status, parent_status, /SET, /NO_COPY
	WIDGET_CONTROL, id_base, /REALIZE, SET_UVALUE=save, /NO_COPY
	xMANAGER,No_BLOCK=1, "PIA_VIEW_PLOT", id_base, GROUP=group, $
		CLEANUP="PIA_VIEW_PLOT_CLEANUP"

	RETURN
	END


; ****************************************************************************
;  CLEANUP routine for PIA FileView
; ****************************************************************************

PRO PIA_VIEW_CLEANUP, event_id

; if a file is opened then close it

	WIDGET_CONTROL, event_id, GET_UVALUE=save, /NO_COPY
	HANDLE_VALUE, save.id, waste, /NO_COPY
	HANDLE_VALUE, save.status, status, /NO_COPY
	IF status.fxbunit NE 0L THEN FXBCLOSE, status.fxbunit
	RETURN
	END

; ****************************************************************************
;  Event handling routine for PIA FileView
; ****************************************************************************

PRO PIA_VIEW_EVENT, event

	COMMON PIA_VIEW, ftyps, dtyps

	WIDGET_CONTROL, event.id, GET_UVALUE=action
	WIDGET_CONTROL, event.top, GET_UVALUE=save
	HANDLE_VALUE, save.id, id
	HANDLE_VALUE, save.status, status
	WIDGET_CONTROL, event.top, /HOURGLASS

	CASE action OF

; Quit FileView

	'QUIT':	BEGIN
		WIDGET_CONTROL, event.top, /DESTROY
		END

;  Select a file with 'pickfile'

	'SELF':	BEGIN
		filter = PIA_FILEFILTER( status.ftyp, status.dtyp )
		filename = pickfile( PATH=status.defpath, FILTER=filter, $
			/READ, GROUP=event.top, GET_PATH=newpath )
		IF filename NE "" THEN BEGIN
			WIDGET_CONTROL, id.filename, SET_VALUE=filename
			status.defpath = newpath
			HANDLE_VALUE, save.status, status, /SET
			GOTO, open_fxb
		ENDIF
		END

; Open file

	'OPEN':	BEGIN
open_fxb:
		WIDGET_CONTROL, event.top, /HOURGLASS

		; if already opened, close old file
		IF status.fxbunit NE 0L THEN BEGIN
			FXBCLOSE, status.fxbunit
			status.fxbunit = 0L
			WIDGET_CONTROL, id.ncol, SET_VALUE=' '
			WIDGET_CONTROL, id.nrow, SET_VALUE=' '
			WIDGET_CONTROL, id.nax1, SET_VALUE=' '
			WIDGET_CONTROL, id.cfr, SET_VALUE=' '
			WIDGET_CONTROL, id.cto, SET_VALUE=' '
			WIDGET_CONTROL, id.rfr, SET_VALUE=' '
			WIDGET_CONTROL, id.rto, SET_VALUE=' '
			HANDLE_VALUE, save.status, status, /SET
		ENDIF

		; open new file
		WIDGET_CONTROL, id.filename, GET_VALUE=filename
		status.filename = STRTRIM(filename(0),2)
		IF status.filename EQ "" THEN BEGIN
			MESSAGE, /INFO, "No file selected."
			RETURN
		ENDIF
		PIA_FILETYPE, status.filename, p, d
		status.product = p
		status.detector = d
		PIA_OPEN_FXB, status.filename, fxbunit, header, dims
		status.fxbunit = fxbunit
		status.dims = dims
		WIDGET_CONTROL, id.ncol, $
			SET_VALUE=STRING(dims(1),FORMAT='(I9)')
		WIDGET_CONTROL, id.nrow, $
			SET_VALUE=STRING(dims(2),FORMAT='(I9)')
		WIDGET_CONTROL, id.nax1, $
			SET_VALUE=STRING(dims(0),FORMAT='(I9)')
		IF status.ftyp EQ '*' THEN BEGIN
			WIDGET_CONTROL, id.col, /SENSITIVE
		ENDIF
		WIDGET_CONTROL, id.row, /SENSITIVE
		WIDGET_CONTROL, id.clos, /SENSITIVE
		WIDGET_CONTROL, id.vhea, /SENSITIVE
		WIDGET_CONTROL, id.vtab, /SENSITIVE
		WIDGET_CONTROL, id.vplt, /SENSITIVE
		HANDLE_VALUE, save.status, status, /SET, /NO_COPY
		HANDLE_VALUE, save.header, header, /SET, /NO_COPY
		END

	'CLOS':	BEGIN
		IF status.fxbunit NE 0L THEN BEGIN
			FXBCLOSE, status.fxbunit
			status.fxbunit = 0L
			WIDGET_CONTROL, id.ncol, SET_VALUE=' '
			WIDGET_CONTROL, id.nrow, SET_VALUE=' '
			WIDGET_CONTROL, id.nax1, SET_VALUE=' '
			WIDGET_CONTROL, id.cfr, SET_VALUE=' '
			WIDGET_CONTROL, id.cto, SET_VALUE=' '
			WIDGET_CONTROL, id.rfr, SET_VALUE=' '
			WIDGET_CONTROL, id.rto, SET_VALUE=' '
			WIDGET_CONTROL, id.col, SENSITIVE=0
			WIDGET_CONTROL, id.row, SENSITIVE=0
			WIDGET_CONTROL, id.clos, SENSITIVE=0
			WIDGET_CONTROL, id.vhea, SENSITIVE=0
			WIDGET_CONTROL, id.vtab, SENSITIVE=0
			WIDGET_CONTROL, id.vplt, SENSITIVE=0
			HANDLE_VALUE, save.status, status, /SET, /NO_COPY
		ENDIF ELSE BEGIN
			MESSAGE, /INFO, 'File was not opened.'
		ENDELSE
		END

; View header

	'VHEA':	BEGIN
		IF status.fxbunit EQ 0L THEN BEGIN
			MESSAGE, /INFO, 'No file is opened.'
			RETURN
		ENDIF

		HANDLE_VALUE, save.header, header, /NO_COPY
		IF N_ELEMENTS(header) EQ 0 THEN BEGIN
			MESSAGE, /INFO, 'No header defined.'
		ENDIF ELSE BEGIN
			PIA_VIEW_TXT, header, TITLE='Header View', $
				NAME=status.filename, GROUP=event.top
			HANDLE_VALUE, save.header, header, /SET, /NO_COPY
		ENDELSE
		END

; View table

	'VTAB':	BEGIN
		IF status.fxbunit EQ 0L THEN BEGIN
			MESSAGE, /INFO, 'No file is opened.'
			RETURN
		END

		WIDGET_CONTROL, id.rfr, GET_VALUE=value
		from = LONG(STRTRIM(value(0),2))
		WIDGET_CONTROL, id.rto, GET_VALUE=value
		to = LONG(STRTRIM(value(0),2))
		rows = [ from, to ]

		IF status.product EQ "*" THEN BEGIN
			MESSAGE, /INFO, 'Unknown file type.'
			RETURN
		END

		CASE status.ftyp OF

		'CS':	BEGIN
			PIA_READ_CS, status.fxbunit, table, rows
			PIA_VIEW_CS, table, rows, $
				NAME=status.filename, GROUP=event.top
			END

		'ERD':	BEGIN
			IF status.detector EQ "*" THEN BEGIN
				MESSAGE, /INFO, 'Unknown file type.'
				RETURN
			END
			PIA_READ_ERD, status.fxbunit, status.detector, $
				table, rows
			PIA_VIEW_ERD, status.detector, table, rows, $
				NAME=status.filename, GROUP=event.top
			END

		'*':	BEGIN
			WIDGET_CONTROL, id.cfr, GET_VALUE=value
			from = LONG(STRTRIM(value(0),2))
			WIDGET_CONTROL, id.cto, GET_VALUE=value
			to = LONG(STRTRIM(value(0),2))
			columns = [ from, to ]

			PIA_READ_UNKN, status.fxbunit, table, rows, columns
			PIA_VIEW_UNKN, table, rows, columns, $
				NAME=status.filename, GROUP=event.top
			END

		ELSE:	BEGIN
			MESSAGE, /INFO, "Function not yet implemented."
			RETURN
			END
		ENDCASE
		END

; Plot curves

	'VPLT':	BEGIN
		IF status.fxbunit EQ 0L THEN BEGIN
			MESSAGE, /INFO, 'No file is opened.'
			RETURN
		ENDIF ELSE BEGIN
			HANDLE_VALUE, save.header, header, /NO_COPY
			PIA_VIEW_PLOT, header, status, GROUP=event.top
			HANDLE_VALUE, save.header, header, /SET, /NO_COPY
		ENDELSE
		END

; Select file type

	'FTYP':	BEGIN
		status.ftyp = ftyps(event.index)
		; allow to select columns only for UNKN (*) type
		IF status.fxbunit NE 0 THEN BEGIN
			IF status.ftyp EQ '*' THEN BEGIN
				WIDGET_CONTROL, id.col, /SENSITIVE
			ENDIF ELSE BEGIN
				WIDGET_CONTROL, id.col, SENSITIVE=0
			ENDELSE
		ENDIF
		HANDLE_VALUE, save.status, status, /SET, /NO_COPY
		END

	'DTYP': BEGIN
		status.dtyp = dtyps(event.index)
		HANDLE_VALUE, save.status, status, /SET, /NO_COPY
		END

;  pressed <RETURN> in 'Filename' widget

	'FNAM':	BEGIN
		GOTO, open_fxb
		END

	ELSE:	MESSAGE, /INFO, 'Function not yet implemented.'
	ENDCASE

	RETURN
	END

; ****************************************************************************
;  PIA FileView - menu definition procedure
; ****************************************************************************

PRO PIA_VIEW, GROUP=group


; Definitions common to all instances

	COMMON PIA_VIEW, ftyps, dtyps

; Definition of file types:
; file_types	-  Possible file types.
;		   Defines what appears in the list widget and can contain
;		   any strings. The largest string determines XSIZE of the
;		   list widget: 12 seems ok.
; ftyps		-  Possible file types.
;		   Values must correspond to filetypes known by PIA_FILEFILTER.
;		   Sequence must correspond to file_types
; det_types     -  Possible detector types.
;                  Defines what appears in the list widget and can contain
;                  any strings.
; dtyps         -  Possible detector types.
;		   Values must correspond to det.types known by PIA_FILEFILTER.
;		   Sequence must correspond to det_types

	file_types = [ $
		'Cal-A       ', $
		'CS          ', $
		'ERD         ', $
		'SPD         ', $
		'AAR         ', $
		'All         ' $
	]

	ftyps =	[ $
		'CALA',	$
		'CS',	$
		'ERD',	$
		'SPD',	$
		'AAR',	$
		'*'	$
	]

	det_types = [ $
		'P1/P2/P3    ',	$
		'P1',		$
		'P2',		$
		'P3',		$
		'C100/C200',	$
		'C100',		$
		'C200',		$
		'SS/SL',	$
		'SS',		$
		'SL',		$
		'All'		$
	]

	dtyps = [ $
		'P',	$
		'P1',	$
		'P2',	$
		'P3',	$
		'C',	$
		'C1',	$
		'C2',	$
		'S',	$
		'SS',	$
		'SL',	$
		'*'	$
	]

; Definitions for individual instances

	save = { $
		id:	HANDLE_CREATE(), $
		status:	HANDLE_CREATE(), $
		header:	HANDLE_CREATE() $
	}

	id = { $
		clos:		0L, $
		vhea:		0L, $
		vtab:		0L, $
		vplt:		0L, $
	 	filename:	0L, $
		nax1:		0L, $
		ncol:		0L, $
		nrow:		0L, $
		col:		0L, $
		cfr:		0L, $
		cto:		0L, $
		row:		0L, $
		rfr:		0L, $
		rto:		0L $
	}

	status = { $
		defpath:	'', $	; selected default directory
		filename:	'', $	; selected filename (incl. dir)
		ftyp:		'', $	; selected file_types value
		dtyp:		'', $	; selected det_types value
		fxbunit:	0L, $	; unit for opened FITS file
		product:	'', $	; product type of opened file
		detector:	'', $	; detector type for opened file
		dims:		[ 0L, 0L, 0L ] $ ; FITS table dimensions
	}

; Set-up widget hierarchy

	offset = [0,0]
	IF N_ELEMENTS(group) NE 0 THEN $
	  IF WIDGET_INFO( group, /VALID_ID ) THEN BEGIN
		WIDGET_CONTROL, group, TLB_GET_OFFSET=offset, TLB_GET_SIZE=sz
		offset(1) = offset(1) + sz(1)
	ENDIF

	id_base = WIDGET_BASE( TITLE="PIA FileView", /COLUMN, $
				XOFFSET=offset(0), YOFFSET=offset(1)+35 )

	id_menu = WIDGET_BASE( id_base, /ROW )
	 id_1 = WIDGET_BUTTON( id_menu, VALUE='    File    ', /MENU )
	  id_2 = WIDGET_BUTTON( id_1, VALUE='Select File...', UVALUE='SELF' )
	  id_2 = WIDGET_BUTTON( id_1, VALUE='Open File', UVALUE='OPEN' )
	  id.clos = WIDGET_BUTTON( id_1, VALUE='Close File', $
					UVALUE='CLOS' )
	  id_2 = WIDGET_BUTTON( id_1, VALUE='Quit', UVALUE='QUIT' )
	 id_1 = WIDGET_BUTTON( id_menu, VALUE='    View    ', /MENU )
	  id.vhea = WIDGET_BUTTON( id_1, VALUE='View Header', $
					UVALUE='VHEA' )
	  id.vtab = WIDGET_BUTTON( id_1, VALUE='View Table', $
					UVALUE='VTAB' )
	  id.vplt = WIDGET_BUTTON( id_1, VALUE='Plot Curves...', $
					UVALUE='VPLT' )
	 id_1 = WIDGET_LABEL( id_menu, VALUE='                        ' )
	 id_1 = WIDGET_BUTTON( id_menu, VALUE='    Help    ', UVALUE='HELP' )

	id_0 = WIDGET_BASE( id_base, /ROW )
	 id_1 = WIDGET_LABEL( id_0, VALUE='Selected File:' )
	 id_1 = WIDGET_LABEL( id_0, VALUE=' ' )
	id.filename = WIDGET_TEXT( id_base, /EDITABLE, XSIZE=40, $
					YSIZE=1, VALUE=' ', UVALUE='FNAM')

	id_types = WIDGET_BASE( id_base, /ROW )
	 id_1 = WIDGET_BASE( id_types, /COLUMN )
	  id_2 = WIDGET_LABEL( id_1, VALUE='Select Filetype:' )
	  id_2 = WIDGET_LIST( id_1, YSIZE=6, VALUE=file_types, UVALUE='FTYP' )
	 id_1 = WIDGET_LABEL( id_types, VALUE='                        ' )
	 id_1 = WIDGET_BASE( id_types, /COLUMN )
	  id_2 = WIDGET_LABEL( id_1, VALUE='Select Detector:' )
	  id_2 = WIDGET_LIST( id_1, YSIZE=6, VALUE=det_types, UVALUE='DTYP' )

	id_info = WIDGET_BASE( id_base, /ROW )
	 id_1 = WIDGET_BASE( id_info, /COLUMN )
	  id_2 = WIDGET_LABEL( id_1, VALUE='Dimensions: ' )
	 id_1 = WIDGET_BASE( id_info, /COLUMN )
	  id_2 = WIDGET_BASE( id_1, /ROW )
	   id_3 = WIDGET_LABEL( id_2, VALUE='No. columns:   ' )
	   id.ncol = WIDGET_LABEL( id_2, VALUE=' ' )
	  id_2 = WIDGET_BASE( id_1, /ROW )
	   id_3 = WIDGET_LABEL( id_2, VALUE='No. rows:      ' )
	   id.nrow = WIDGET_LABEL( id_2, VALUE=' ' )
	  id_2 = WIDGET_BASE( id_1, /ROW )
	   id_3 = WIDGET_LABEL( id_2, VALUE='No. char/row:  ' )
	   id.nax1 = WIDGET_LABEL( id_2, VALUE=' ' )

	id.col = WIDGET_BASE( id_base, /ROW )
	 id_0 = WIDGET_LABEL( id.col, VALUE='Select Columns:' )
	 id_0 = WIDGET_LABEL( id.col, VALUE='  From:' )
	 id.cfr = WIDGET_TEXT( id.col, /EDITABLE, $
			XSIZE=5, YSIZE=1, VALUE='', UVALUE='CFR')
	 id_0 = WIDGET_LABEL( id.col, VALUE='  To:' )
	 id.cto = WIDGET_TEXT( id.col, /EDITABLE, $
			XSIZE=5, YSIZE=1, VALUE='', UVALUE='CTO')

	id.row = WIDGET_BASE( id_base, /ROW )
	 id_0 = WIDGET_LABEL( id.row, VALUE='Select Rows:     ' )
	 id_0 = WIDGET_LABEL( id.row, VALUE='  From:' )
	 id.rfr = WIDGET_TEXT( id.row, /EDITABLE, $
			XSIZE=5, YSIZE=1, VALUE='', UVALUE='RFR')
	 id_0 = WIDGET_LABEL( id.row, VALUE='  To:' )
	 id.rto = WIDGET_TEXT( id.row, /EDITABLE, $
			XSIZE=5, YSIZE=1, VALUE='', UVALUE='RTO')


; Define initial settings

	status.defpath=!FITDIR

	WIDGET_CONTROL, id.clos, SENSITIVE=0
	WIDGET_CONTROL, id.vhea, SENSITIVE=0
	WIDGET_CONTROL, id.vtab, SENSITIVE=0
	WIDGET_CONTROL, id.vplt, SENSITIVE=0
	WIDGET_CONTROL, id.col, SENSITIVE=0
	WIDGET_CONTROL, id.row, SENSITIVE=0

;  Store values for individual instances with base widget

	HANDLE_VALUE, save.id, id, /SET, /NO_COPY
	HANDLE_VALUE, save.status, status, /SET, /NO_COPY
	WIDGET_CONTROL, id_base, /REALIZE, SET_UVALUE=save, /NO_COPY
	xMANAGER,No_BLOCK=1, "PIA_VIEW", id_base, GROUP=group, CLEANUP="PIA_VIEW_CLEANUP"

	RETURN
	END
