;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_VIEW_CS
;	
; PURPOSE:
;	Write values from the binary table CS (Compact Status) FITS file
;	to a text widget. The table values must have been read already.
;	
; CATEGORY:
;	PIA - graphics
;	
; CALLING SEQUENCE:
;	PIA_VIEW_CS, table, rows
;	
; INPUTS:
;	table :	The table values of the CS file.
;
;	rows :	2-dimensional array denoting the range of rows
;		which are contained in 'table'.
;	
; KEYWORD PARAMETERS:
;	NAME :	The name of the CS file which will be written out as an
;		informational string.
;
;	GROUP :	The group leader of the widget.
;	
; OUTPUTS:
;	(none)
;	
; SIDE EFFECTS:
;	(none)
;
; RESTRICTIONS:
;	(none)
;	
; COMMON BLOCKS:
;	(none)
;	
; PROCEDURES USED:
;	PIA Procedure(s):
;		pia_view_txt
;	
; MODIFICATION HISTORY:
;	Written by:	D. Skaley, MPIK/Heidelberg	August 1994
;	Oct 95 Version 3.5
;-

PRO PIA_VIEW_CS, table, rows, NAME=name, GROUP=group

;  Number of rows

	nrow = rows(1)-rows(0)+1

;  Produce properly formatted text from table numbers

;  Headline

	record = $
	'      UKST      UKEN     IKST     IKEN'+ $
	'      UTST              UTEN          OSN'+ $
	' SUBS OPFO F1TS F2TS F1PS F2PS C1PS C2PS C3PS CMOD CAMP CSTE CINC'+ $
	' CRES DETA  DRS MUX1 MUX2 XSTA D1OF D1GA D2OF D2GA FREQ NNDR  NDR'+ $
	' INTT MEAT MPC1 MPC2 MPC3  MET'
	text = [ record, ' ' ]

;  Format of one row of numbers

	format="(2I10,2I9,I10,A8,I10,A8,I5,32I5)"

; Fill in all rows into text

	FOR i = 0, nrow-1 DO BEGIN
		utst_frac = '.       '
		strput, utst_frac, strtrim(table.utst(1,i),2), 1
		uten_frac = '.       '
		strput, uten_frac, strtrim(table.uten(1,i),2), 1
		record = STRING( FORMAT=format, $
			table.ukst(i), $
			table.uken(i), $
			table.ikst(i), $
			table.iken(i), $
			table.utst(0,i), utst_frac, $
			table.uten(0,i), uten_frac, $
			table.osn(i),  $
			table.subs(i), $
			table.opfo(i), $
			table.f1ts(i), $
			table.f2ts(i), $
			table.f1ps(i), $
			table.f2ps(i), $
			table.c1ps(i), $
			table.c2ps(i), $
			table.c3ps(i), $
			table.cmod(i), $
			table.camp(i), $
			table.cste(i), $
			table.cinc(i), $
			table.cres(i), $
			table.deta(i), $
			table.drs(i), $
			table.mux1(i), $
			table.mux2(i), $
			table.xsta(i), $
			table.d1of(i), $
			table.d1ga(i), $
			table.d2of(i), $
			table.d2ga(i), $
			table.freq(i), $
			table.nndr(i), $
			table.ndr(i), $
			table.intt(i), $
			table.meat(i), $
			table.mpc1(i), $
			table.mpc2(i), $
			table.mpc3(i), $
			table.met(i) $
		)

		text = [ text, record ]
	ENDFOR

	PIA_VIEW_TXT, text, TITLE="CS Table View", NAME=name, GROUP=group

	RETURN
END
