;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_VIEW_ERD
;	
; PURPOSE:
;	Write values from the binary table ERD (Edited Raw Data) FITS file
;	to a text widget. The table values must have been read already.
;	
; CATEGORY:
;	PIA - graphics
;	
; CALLING SEQUENCE:
;	PIA_VIEW_ERD, erdtype, table, rows, NAME=name, GROUP=group
;	
; INPUTS:
;	erdtype : The ERD type: 'C1'=C100, 'C2'=C200, 'P'=P1,P2,P3, 'S'=S1,S2
;
;	table :	The table values of the ERD file.
;
;	rows :	2-dimensional array denoting the range of rows
;		which are contained in 'table'.
;	
; KEYWORD PARAMETERS:
;	NAME :	The name of the ERD file which will be written out as an
;		informational string.
;
;	GROUP :	The group leader of the widget.
;	
; OUTPUTS:
;	(none)
;	
; SIDE EFFECTS:
;	(none)
;
; RESTRICTIONS:
;	(none)
;	
; COMMON BLOCKS:
;	(none)
;	
; PROCEDURES USED:
;	PIA Procedure(s):
;		pia_view_txt
; MODIFICATION HISTORY:
;	Written by:	D. Skaley, MPIK/Heidelberg	August 1994
;	Oct 95 Version 3.5
;	
;-

PRO PIA_VIEW_ERD, erdtype, table, rows, NAME=name, GROUP=group

;  Number of rows

	nrow = rows(1)-rows(0)+1

;  Produce properly formatted text from table numbers

;  Headline

;	record = $
;	'      UKST      UKEN     IKST     IKEN'+ $
;	'      UTST              UTEN          OSN'+ $
;	' SUBS OPFO F1TS F2TS F1PS F2PS C1PS C2PS C3PS CMOD CAMP CSTE CINC'+ $
;	' CRES DETA  DRS MUX1 MUX2 XSTA D1OF D1GA D2OF D2GA FREQ NNDR  NDR'+ $
;	' INTT MEAT MPC1 MPC2 MPC3  MET'

	CASE erdtype OF
	'C1': BEGIN
	record = $
	' TKEY RPID(2) PIXF PCS1 PCS2 CREV TEMP CPOS MBV PIXR PIXO PIX(9)'
	END
	ELSE:	RETURN
	ENDCASE
	text = [ record, ' ' ]

;  Format of one row of numbers

	format="(I5,2A4,I5,I5,I5,I5,I5,I5,I5,I5,I5,9I5)"

; Fill in all rows into text

	FOR i = 0, nrow-1 DO BEGIN
		CASE erdtype OF
		'C1':	record = STRING( FORMAT=format, $
				table.tkey(i),  $
				table.rpid(0,i),  $
				table.rpid(1,i),  $
				table.pixf(i),  $
				table.pcs1(i),  $
				table.pcs2(i),  $
				table.crev(i),  $
				table.temp(i),  $
				table.cpos(i),  $
				table.mbv(i),  $
				table.pixr(i),  $
				table.pixo(i),  $
				table.pix(0,i),  $
				table.pix(1,i),  $
				table.pix(2,i),  $
				table.pix(3,i),  $
				table.pix(4,i),  $
				table.pix(5,i),  $
				table.pix(6,i),  $
				table.pix(7,i),  $
				table.pix(8,i)  $
			)
		ELSE:
		ENDCASE
		text = [ text, record ]
	ENDFOR

	PIA_VIEW_TXT, text, TITLE="ERD Table View", NAME=name, GROUP=group

	RETURN
END
