;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_VIEW_TXT
;	
; PURPOSE:
;	Create a text widget and write a string array to it.
;	To write out a table of binary values, the values must be formatted
;	first into a string array.
;	
; CATEGORY:
;	PIA - graphics
;	
; CALLING SEQUENCE:
;	PIA_VIEW_TXT, text
;	
; INPUTS:
;	text :	An array of strings which will be written to the text widget.
;
; KEYWORD PARAMETERS:
;	TITLE :	The title of the widget.
;
;	NAME :	The name of the file from which the text/values come.
;
;	GROUP :	The group leader of the widget.
;	
; OUTPUTS:
;	(none)
;	
; SIDE EFFECTS:
;	(none)
;
; RESTRICTIONS:
;	(none)
;	
; COMMON BLOCKS:
;	(none)
;	
; PROCEDURES USED:
;	PIA Procedure(s):
;		pia_prtdef
;	Internal:
;		pia_view_txt_event
;
; MODIFICATION HISTORY:
;	Written by:	D. Skaley, MPIK/Heidelberg	August 1994
;	Oct 95 Version 3.5
;-

PRO PIA_VIEW_TXT_EVENT, event

	COMMON PIA_PRINT, prt

	WIDGET_CONTROL, event.id, GET_UVALUE=action
	CASE action OF

	'DEFP': PIA_PRTDEF, GROUP=event.top

	'PRNT':	BEGIN
		IF N_ELEMENTS(prt) EQ 0 THEN BEGIN
			MESSAGE, /INFO, "Printer is not defined"
			RETURN
		ENDIF
		CASE !version.os OF
		'vms':	home = "sys$login:"
		'unix':	home = GETENV("HOME")
		ELSE:	home = ""
		ENDCASE
		IF prt.filename NE "" THEN filename = prt.filename $
		ELSE filename = home + "idl_piaview.txt"

		WIDGET_CONTROL, event.top, GET_UVALUE=text, /NO_COPY
		OPENW, lun, filename, /GET_LUN
		PRINTF, lun, text, FORMAT="((A80))"
		FREE_LUN, lun
		WIDGET_CONTROL, event.top, SET_UVALUE=text, /NO_COPY

		IF prt.print AND prt.command NE "" THEN BEGIN
			cmd = prt.command + " " + filename
			SPAWN, cmd
		ENDIF

		END

	'QUIT':	WIDGET_CONTROL, event.top, /DESTROY

	ENDCASE
	RETURN
END

PRO PIA_VIEW_TXT, text, TITLE=title, NAME=name, GROUP=group

	IF NOT KEYWORD_SET(title) THEN title='Text View'

	id_base = WIDGET_BASE( TITLE=title, /COLUMN )

	id_0 = WIDGET_BASE( id_base, /ROW )
	 id_1 = WIDGET_BUTTON( id_0, VALUE="     File     ", /MENU )
	  id_2 = WIDGET_BUTTON( id_1, VALUE="Define Printer...", UVALUE="DEFP" )
	  id_2 = WIDGET_BUTTON( id_1, VALUE="Print", UVALUE="PRNT" )
	  id_2 = WIDGET_BUTTON( id_1, VALUE="Quit", UVALUE="QUIT" )
	 id_1 = WIDGET_LABEL( id_0, VALUE='    File:  '+name )

	length = n_elements(text) < 24	; maximum of 24 lines
	id_0 = WIDGET_TEXT( id_base, XSIZE=80, YSIZE=length, /SCROLL, $
		VALUE=text, FONT='*-terminal-medium-r-normal-*-iso8859-*' )

	WIDGET_CONTROL, id_base, /REALIZE, SET_UVALUE=text
	xMANAGER,No_BLOCK=1, "PIA_VIEW_TXT", id_base, GROUP=group

	RETURN
END
