;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_VIEW_UNKN
;	
; PURPOSE:
;	Write values from the binary table genaral binary FITS file
;	to a text widget. The table values must have been read already.
;	
; CATEGORY:
;	PIA - graphics
;	
; CALLING SEQUENCE:
;	PIA_VIEW_UNKN, table, rows, columns
;	
; INPUTS:
;	table :	The table values of the FITS binary table.
;
;	rows :	2-dimensional array denoting the range of rows
;		which are contained in 'table'.
;	
;	columns : 2-dimensional array denoting the range of columns
;		which are contained in 'table'.
;	
; KEYWORD PARAMETERS:
;	NAME :	The name of the FITS file which will be written out as an
;		informational string.
;
;	GROUP :	The group leader of the widget.
;	
; OUTPUTS:
;	(none)
;	
; SIDE EFFECTS:
;	(none)
;
; RESTRICTIONS:
;	(none)
;	
; COMMON BLOCKS:
;	(none)
;	
; PROCEDURES USED:
;	PIA Procedure(s):
;		pia_view_txt
;	
; MODIFICATION HISTORY:
;	Written by:	D. Skaley, MPIK/Heidelberg	August 1994
;	Oct 95 Version 3.5
;-

PRO PIA_VIEW_UNKN, table, rows, columns, NAME=name, GROUP=group

	nrow = rows(1)-rows(0)+1
	ncol = columns(1)-columns(0)+1

;  Retrieve keywords from table handles

	id = HANDLE_INFO( table, /FIRST_CHILD )
	HANDLE_VALUE, id, keywords

;  Produce headline and format for numbers
;  headline is built from keywords skipping first four characters of each

	text = STRARR(nrow+2)

	FOR i = 0, ncol-1 DO BEGIN

		; get values
		id = HANDLE_INFO( id, /SIBLING )
		HANDLE_VALUE, id, values

		; get keyword
		keyw = keywords(i)
		keyw = STRMID(keyw,4,STRLEN(keyw))

		; width of column
		w1 = STRLEN(STRTRIM(MIN(values),2))
		w2 = STRLEN(STRTRIM(MAX(values),2))
		w3 = STRLEN(STRTRIM(keyw))
		width = max( [w1, w2, w3] )+1

		; values may be multi-dim array

		nrep = N_ELEMENTS(values)/nrow
		s_row = STRARR(nrow+2)
		s_row(1) = ' '		; blank line

		FOR j = 0, nrep-1 DO BEGIN

			; append keyword to headline
			format = "(A"+STRTRIM(width,2)+")"
			s_row(0) = STRING(keyw,FORMAT=format)

			; produce row of formatted values
			format = "(I"+STRTRIM(width,2)+")"
			k1 = j*nrow
			k2 = k1+nrow-1
			s_row(2) = STRING(values(k1:k2),FORMAT=format)

			; append row to text
			text = text+s_row

		ENDFOR

	ENDFOR

	PIA_VIEW_TXT, text, TITLE="FITS Table View", NAME=name, GROUP=group

	RETURN
END
