;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME: 
;	PIA_Wellcome	
;
; PURPOSE:
;	Display a wellcome text file using widgets and the widget manager, 
;	giving the possibility of printing it. The purpose is to get an 
;	acknowledgement from the user under which conditions he might use
;	the PIA package. 
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_wellcome
;
; INPUTS:
;     (none)
;
; KEYWORD PARAMETERS:
;	(none)
;
; OUTPUTS:
;	No explicit outputs.  A file viewing widget is created.
;
; COMMON BLOCKS:
;	pia_wellcome_cmn (internal)
;
; SIDE EFFECTS:
;	Triggers the xMANAGER,No_BLOCK=1 if it is not already in use.
;
; PROCEDURE:
;	Creates a widget to display a text, giving the chance of printing it.
;
; PROCEDURES USED:
;       INTERNAL:
;		PIA_wellcome_evt
;
; MODIFICATION HISTORY:
;	Written by: Carlos GABRIEL (ESA/VILSPA-SAI)  		November 1995
;	Free_lun instead of close - get_lun used (CG)		May 1996
;	No /modal now (CG)					January 1999
;	V7.3
;-
; *********************************************************************
; *
; *********************************************************************
PRO PIA_wellcome_evt, event

COMMON pia_wellcome_cmn, text

WIDGET_CONTROL, GET_UVALUE = retval, event.id

CASE retval OF

	"EXIT": WIDGET_CONTROL, event.top, /DESTROY
	
	"PRINT": BEGIN
		lines = N_ELEMENTS(a) 	
		filename = !PRINT + 'tmp.txt'
	        OPENW,unit,filename, /get_lun
	        PRINTF,unit
	        FOR i=0,lines-1 DO $
	           PRINTF,unit,a(i)
	  	PRINTF,unit,string(12B)
	  	FREE_LUN,unit
	  	
	    	IF !VERSION.OS NE 'vms' THEN BEGIN
	      		spawn,'lpr -P$pslaser '+filename
	    	ENDIF ELSE BEGIN
	      		spawn,'print/queue=pslaser/notify/delete '+filename
	    	ENDELSE
	  	
	  END

	  ELSE:
	  
ENDCASE
END


; *********************************************************************
; *
; *
; *
; *********************************************************************
PRO PIA_Wellcome


filebase = WIDGET_BASE(TITLE = "Welcome to PIA", $	;create the base
		/COLUMN, $
		SPACE = 20, $
		XPAD = 20, $
		YPAD = 20)

act_base = WIDGET_BASE(filebase, /ROW)

filequit = WIDGET_BUTTON(act_base, $			;create a Done Button
		VALUE = " Acknowledged ", $
		UVALUE = "EXIT")

filep_id = WIDGET_BUTTON(act_base, $			;create a Done Button
		VALUE = " Print ", $
		UVALUE = "PRINT")


text= ["                      Welcome to the PHT Interactive Analysis PIA        ", ' ', ' ', $
'PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT Consortium.',' ',$ 
'The ISOPHOT Consortium is led by the Max-Planck-Institut fuer Astronomie (MPIA), Heidelberg, Germany.',$
'Contributing ISOPHOT Consortium institutes to the PIA development are: ', $
'DIAS (Dublin Institute for advanced studies, Ireland)', $
'MPIK (Max-Planck-Institut fuer Kernphysik, Heidelberg, Germany),',$
'RAL (Rutherford Appleton Laboratory, Chilton, UK),', $
'AIP (Astronomisches Institut Potsdam, Germany), and MPIA.', $
' ', $
'When publishing ISOPHOT Data reduced with this analysis package, please mention this in the ', $
'acknowledgement in the following way:', '', $
'"The ISOPHOT data presented in this paper was reduced using PIA, which is a joint development by the ',$ 
'ESA Astrophysics Division and the ISOPHOT consortium."',$
'', $
'No warranties for installation/support/maintenance can be given.', '']



IF n_elements(font) gt 0 then $
 filetext = WIDGET_TEXT(filebase, $			;create a text widget
		XSIZE = 100, $			;to display the file's
		YSIZE = 25, $			;contents
		/SCROLL, FONT = font, $
		VALUE = text) $
ELSE filetext = WIDGET_TEXT(filebase, $			;create a text widget
		XSIZE = 100, $			;to display the file's
		YSIZE = 25, $			;contents
		/SCROLL, $
		VALUE = text)


WIDGET_CONTROL, filebase, /REALIZE			;instantiate the widget

xMANAGER,No_BLOCK=1, "PIA_WELLCOME", $			;register it with the
		filebase, $				;widget manager
		GROUP_LEADER = GROUP, $
		EVENT_HANDLER = "PIA_wellcome_evt"

END  ;--------------------- procedure PIA_disp_print_File ---------------------
