;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_WRITE_ICS
;
; PURPOSE:
;	Write a PHT-CS (Compact Status Data) structure from a temporary 
;	structure CSDAT (PHTCS type) onto an IDL savefile. Ask first
;	the interactive user if he/she wants to save the file under the 
;	"normal" name, or for a different one.  
;
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;       PIA_WRITE_ICS, CSDAT
;
; INPUT:
;       CSDAT : PHTCS temporary structure
;
; KEYWORD PARAMETERS:
;	none
;
; OUTPUTS:
;	none
;
; METHOD: 
;	WIDGETS + IDL save
;
; COMMON BLOCKS:
;	pht_wrtics_cmn		for internal use
;
; PROCEDURES USED:
;	Internal:
;		pia_write_ics_event
;		
; MODIFICATION HISTORY:
;       Written by C. Gabriel                      	December 1995
;	Path keyword added (Jacosta)			May 1997
;
;-
PRO pia_write_ics_event, event

COMMON pht_wrtics_cmn, file, phtics, text1 

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue OF

          'SAVE': BEGIN

       		SAVE, PHTICS, FILE= file, /XDR
                WIDGET_CONTROL, event.top, /DESTROY

          END

          'CANCEL': BEGIN

                WIDGET_CONTROL, event.top, /DESTROY

          END

	 ELSE:
	 
        ENDCASE

        RETURN
        END


;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

PRO PIA_WRITE_ICS, CSDAT, PATH = path 
	COMMON pht_wrtics_cmn, file, phtics, text1 

;
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  PIA_WRITE_ICS, PHTICS'

	phtics = csdat
;  Write it out: Widget ask for name: default: adm naming convention 
	FILE='CS'+PHTICS.UNIT+'.ICS'
	IF KEYWORD_SET(PATH) then file= path+file $ 
	  ELSE file = !INTDIR + file 
	junk = FINDFILE(file, COUNT=count)

	IF count GT 0 THEN BEGIN
		MESSAGE, /INFO, $
		  'Compact Status file not written, already present"
		RETURN
	ENDIF 

	textbase = WIDGET_BASE(TITLE = 'Saving CS structures with PIA', $ 
		XSIZE=850, /COLUMN)

	lbase = WIDGET_BASE(textbase, /ROW)
	label = WIDGET_LABEL(lbase, VALUE = 'Save under:       ')
	text2 = WIDGET_TEXT(lbase, VALUE=FILE, XSIZE=60, YSIZE=1)


	textcontrol = WIDGET_BASE(textbase,/ROW)

	junk = WIDGET_LABEL(textcontrol, VALUE = '                          ')
	save = WIDGET_BUTTON(textcontrol, VALUE = '  Save  ', $
			/FRAME, UVALUE = 'SAVE') 	
	junk = WIDGET_LABEL(textcontrol, VALUE = '                          ')
	cancel = WIDGET_BUTTON(textcontrol, VALUE = '  Cancel  ', $
			/FRAME, UVALUE = 'CANCEL') 	

        WIDGET_CONTROL, textbase, /REALIZE, TLB_SET_XOFFSET=150, $
                        TLB_SET_YOFFSET=150


        xMANAGER,No_BLOCK=1, "pia_write_ics", textbase, GROUP=group
	
        RETURN
END

