;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_WRITE_IMAP
;
; PURPOSE:
;	Write out the map parameter and the map to a save file from
;	within the pia_mapdraw routine
;
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;	WRITE_INTMAP, MAP, MAPPAR
;
; INPUTS:
;	MAP : the map array
;	MAPPAR: the parameter par in the PIA_MAPDRAW.PRO
;
; KEYWORD PARAMETERS:
;
; OUTPUTS:
;	IDL save file
;
; PROCEDURES USED:
;	PIA Procedure(s):
;	Astronomical Library:
;	Internal:
;
; COMMON BLOCKS:
;	(none)
;
; MODIFICATION HISTORY:
;	Written by: 	Wai Ming Tai, DIAS	Feb 1996
;-
PRO pia_write_imap_event, event
common phtwrtimap_cmn, file, imap, imappar, imaphdr, text1, imap_type

 
        WIDGET_CONTROL, event.id, GET_UVALUE=uvalue
 
        CASE uvalue OF
 
          'SAVE': BEGIN
 
                SAVE, imap, imappar , imaphdr, imap_type, $
		  FILENAME=file, /XDR
                WIDGET_CONTROL, event.top, /DESTROY
 
          END
 
          'CANCEL': BEGIN
                WIDGET_CONTROL, event.top, /DESTROY
 
          END
 
          'TEXT2': BEGIN
 
                WIDGET_CONTROL, event.id, GET_VALUE=file
                file = STRTRIM(file(0),2)
                junk = FINDFILE(file, COUNT=count)
                text = $
   'The file '+file +' has now been found '+STRTRIM(STRING(count),2)+' time(s)'
                WIDGET_CONTROL, text1, SET_VALUE=text
 
          END
        ENDCASE
 
        RETURN
        END
 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

PRO PIA_WRITE_IMAP, MAP, MAPPAR, MAPHDR, MAP_TYPE
common phtwrtimap_cmn, file, imap, imappar, imaphdr, text1, imap_type

	ON_ERROR, 2

;
; Check the number of parameters.
;

	if n_params() LT 4 then message, $
	  'Syntax: PIA_WRITE_IMAP, MAP, MAPPAR, HEADER, MAP_TYPE'

; get the file name

	imap = map
	imappar = mappar
	imaphdr = maphdr
	imap_type = map_type
	CASE imap_type of
	  0: file=mappar.admn+'.IMAP'
	  1: file=mappar.admn+'.IMAP_UNC'
	  2: file=mappar.admn+'.IMAP_EXP'
	ELSE:
	ENDCASE
	file = !intdir + file
	junk = findfile(file, count=count)

	textbase = WIDGET_BASE(TITLE = 'Saving Map with PIA', $
                XSIZE=850, /COLUMN)

        lbase = WIDGET_BASE(textbase, /ROW)
        label = WIDGET_LABEL(lbase, VALUE = 'Save under:       ')
        text2 = WIDGET_TEXT(lbase,  $
          VAL = FILE, /EDITABLE,  $
          XSIZE=60, YSIZE=1, /FRAME, UVALUE = 'TEXT2')
 
        lbase = WIDGET_BASE(textbase, /ROW)
        label = WIDGET_LABEL(lbase, VALUE = 'But be careful:  ')
        text1 = WIDGET_TEXT(lbase, $
          VAL = $
     'The file '+FILE +' has been found '+STRTRIM(STRING(count),2)+' time(s)',$
          XSIZE=60, YSIZE=1)
 
        lbase = WIDGET_BASE(textbase, /ROW)
        label = WIDGET_LABEL(lbase, VALUE = 'Another name? ')
        text3 = WIDGET_TEXT(lbase, $
          VAL = 'You can enter a new name in the upper field and press enter ',$
          XSIZE=60, YSIZE=1)
 
        textcontrol = WIDGET_BASE(textbase,/ROW)
        junk = WIDGET_LABEL(textcontrol, VALUE = '                         ')
        save = WIDGET_BUTTON(textcontrol, VALUE = '  Save  ', $
                        /FRAME, UVALUE = 'SAVE')
        junk = WIDGET_LABEL(textcontrol, VALUE = '                         ')
        cancel = WIDGET_BUTTON(textcontrol, VALUE = '  Cancel  ', $
                        /FRAME, UVALUE = 'CANCEL')
 
        WIDGET_CONTROL, textbase, /REALIZE, TLB_SET_XOFFSET=150, $
                        TLB_SET_YOFFSET=150
 
 
        xMANAGER,No_BLOCK=1, "pia_write_imap", textbase, GROUP=group

	RETURN
	END
	
