;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_WRITE_ISCP
;
; PURPOSE:
;	Write a PHT-SCP (Signal per Chopper Plateau) measurement from a 
;	temporary structure SCPDAT (PHTSCP type) onto an IDL savefile.
;	Ask first the interactive user if he/she wants to save the file 
;	under the "normal" name, or for a different one. 
; 
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;       PIA_WRITE_ISCP, SCPDAT [, tmphdr]
;
; INPUT:
;       SCPDAT : PHTSCP temporary structure
;
; OPTIONAL INPUT:
;       tmphdr 	: temporary header
;
;; KEYWORD PARAMETERS:
;	none
;
; OUTPUTS:
;	none
;
; METHOD: 
;	WIDGETS + IDL save
;
; COMMON BLOCKS:
;	pht_wrtierd_cmn		for internal use
;
; PROCEDURES USED:
;	Internal:
;		pia_write_iscp_event
;		
; MODIFICATION HISTORY:
;       Written by:	C. Gabriel, ESA/ESTEC		October 1994
;	Modified by:	CG				February 1995
;	Oct 95 Version 3.5
;	Extension for ANDR,AVSD and ARSI (CG)		January 1996
;	Save directory system variable used (CG)	February 1996
;-
PRO pia_write_iscp_event, event

COMMON pht_wrtiscp_cmn, file, phtiscp, text1 

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue OF

          'SAVE': BEGIN

       		SAVE, PHTISCP, FILE=!INTDIR+file, /XDR
                WIDGET_CONTROL, event.top, /DESTROY

          END

          'CANCEL': BEGIN

                WIDGET_CONTROL, event.top, /DESTROY

          END

	  'TEXT2': BEGIN

		WIDGET_CONTROL, event.id, GET_VALUE=file
		file = STRTRIM(file(0),2)
		junk = FINDFILE(file, COUNT=count)
		text = $
   'The file '+file +' has now been found '+STRTRIM(STRING(count),2)+' time(s)' 
		WIDGET_CONTROL, text1, SET_VALUE=text
		 
          END
        ENDCASE

        RETURN
        END



        PRO PIA_WRITE_ISCP, SCPDAT, tmphdr 


	COMMON pht_wrtiscp_cmn, file, phtiscp, text1 

;
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  PIA_WRITE_ISCP, PHTISCP [, tmphdr]'

	IF KEYWORD_SET(tmphdr) THEN hdr = tmphdr ELSE hdr = scpdat.hdr

	phtiscp = {UNIT: SCPDAT.UNIT, $
        DET: SCPDAT.DET, $
        ADMN: SCPDAT.ADMN, $
        ORDR: SCPDAT.ORDR, $
        DIMS: SCPDAT.DIMS, $
        HDR:  HDR, $
        TIME: SCPDAT.TIME, $
        AVER: SCPDAT.AVER, $
        AVUN: SCPDAT.AVUN, $
        MEDI: SCPDAT.MEDI, $
        Q1ME: SCPDAT.Q1ME, $
        Q3ME: SCPDAT.Q3ME, $
        FLAG: SCPDAT.FLAG, $
        CHOP: SCPDAT.CHOP, $
        STEP: SCPDAT.STEP, $
        FCSN: SCPDAT.FCSN, $
        TEMP: SCPDAT.TEMP, $
        FCS1: SCPDAT.FCS1, $
        FCS2: SCPDAT.FCS2, $
        TKEY: SCPDAT.TKEY, $
        RPID: SCPDAT.RPID, $
        ARSI: SCPDAT.ARSI, $
        ANDR: SCPDAT.ANDR, $
        AVSD: SCPDAT.AVSD}


;  Write it out: Widget ask for name: default: adm naming convention 
	FILE=PHTISCP.ADMN+'.ISCP'
	junk = FINDFILE(!INTDIR+FILE, COUNT=count)

	textbase = WIDGET_BASE(TITLE = 'Saving SCP structures with PIA', $ 
		XSIZE=850, /COLUMN)

	lbase = WIDGET_BASE(textbase, /ROW)
	label = WIDGET_LABEL(lbase, VALUE = 'Save under:       ')
	text2 = WIDGET_TEXT(lbase,  $
	  VAL = FILE, /EDITABLE,  $
	  XSIZE=80, YSIZE=1, /FRAME, UVALUE = 'TEXT2')

	lbase = WIDGET_BASE(textbase, /ROW)
	label = WIDGET_LABEL(lbase, VALUE = 'But be careful:  ')
	text1 = WIDGET_TEXT(lbase, $
	  VAL = $
     'The file '+FILE +' has been found '+STRTRIM(STRING(count),2)+' time(s)',$
	  XSIZE=80, YSIZE=1)

	lbase = WIDGET_BASE(textbase, /ROW)
	label = WIDGET_LABEL(lbase, VALUE = 'Another name? ')
	text3 = WIDGET_TEXT(lbase, $
	  VAL = 'You can enter a new name in the upper field and press enter ',$
	  XSIZE=80, YSIZE=1)

	textcontrol = WIDGET_BASE(textbase,/ROW)

	junk = WIDGET_LABEL(textcontrol, VALUE = '                          ')
	save = WIDGET_BUTTON(textcontrol, VALUE = '  Save  ', $
			/FRAME, UVALUE = 'SAVE') 	
	junk = WIDGET_LABEL(textcontrol, VALUE = '                          ')
	cancel = WIDGET_BUTTON(textcontrol, VALUE = '  Cancel  ', $
			/FRAME, UVALUE = 'CANCEL') 	

        WIDGET_CONTROL, textbase, /REALIZE, TLB_SET_XOFFSET=150, $
                        TLB_SET_YOFFSET=150


        xMANAGER,No_BLOCK=1, "pia_write_iscp", textbase, GROUP=group
	
        RETURN
END

