;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_XSURFACE
;
; PURPOSE:
;	This routine provides a graphical interface to the SURFACE and
;	SHADE_SURFACE commands.  Different controls are provided to change 
;	the viewing angle and other plot parameters.  It is an extension
;	of the Xsurface routine provided by IDL
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_XSURFACE, Data
;
; INPUT PARAMETERS:
;	Data:	The two-dimensional array to display as a wire-mesh or
;		shaded surface.
;
; KEYWORD PARAMETERS:
;	GROUP:	The widget ID of the widget that calls XSURFACE.  When this
;		keyword is specified, the death of the caller results in the
;		death of XSURFACE.
;
; SIDE EFFECTS:
;	The xMANAGER,No_BLOCK=1 is initiated if it is not already running.
;
; RESTRICTIONS:
;	PIA_XSURFACE does not accept any of the keywords that the IDL command 
;	SURFACE does except the LEGO keyword.
;
; PROCEDURE:
;	Create and register the widget with the xMANAGER,No_BLOCK=1 and then exit.
;
; PROCEDURES USED:
;       PIA Procedure(s):
;               pia_xsur2face
;
; MODIFICATION HISTORY:
;	Written by: Carlos GABRIEL (adapted from Steve Richards)
;	Oct 95 Version 3.5
;	Hypertext Help added, CG		October 1995
;	Draw widget enlarged (CG)		January 1996
;	Contours option added (CG)		January 1996
;	Printer definition added (WMT)          March   1996
;	No use of common blocks, thus allowing for 
;	any number of parallel pia_xsurface (CG) January 1998
;	V7.0
;
;-

;------------------------------------------------------------------------------
;	procedure PIA_XSurface_draw
;------------------------------------------------------------------------------

PRO PIA_XSurface_draw, pia_xs, ps=ps

if not keyword_set(ps) then ps=0

;COMMON pia_xs_orientation, zrot, thedata, xrot, skirt, shade, axes, thedraw, $
;		xmargin, ymargin, upper, lego, contour, levels
;COMMON pia_xs_customi, stitle, ssubtitle, sxtitle, sytitle, sztitle, scharsize


zrot = pia_xs.ori.zrot
thedata = pia_xs.ori.thedata
xrot = pia_xs.ori.xrot
skirt = pia_xs.ori.skirt
shade = pia_xs.ori.shade
axes = pia_xs.ori.axes
thedraw = pia_xs.ori.thedraw
xmargin = pia_xs.ori.xmargin
ymargin = pia_xs.ori.ymargin
upper = pia_xs.ori.upper
lego = pia_xs.ori.lego
contour = pia_xs.ori.contour
levels = pia_xs.ori.levels

stitle=pia_xs.cust.stitle
ssubtitle=pia_xs.cust.ssubtitle
sxtitle=pia_xs.cust.sxtitle
sytitle=pia_xs.cust.sytitle
sztitle=pia_xs.cust.sztitle
scharsize=pia_xs.cust.scharsize

if ps eq 0 then WSET, thedraw

IF(shade EQ 0) THEN BEGIN
  IF(skirt EQ 0) THEN BEGIN
    SURFACE, thedata, $
		XSTYLE = axes, $
		YSTYLE = axes, $
		ZSTYLE = axes, $
		title = stitle, $
		subtitle = ssubtitle, $
		xtitle = sxtitle, $
		ytitle = sytitle, $
		ztitle = sztitle, $
		charsize=scharsize, $
		lego=lego, $
		UPPER_ONLY = upper, $
		XMARGIN = xmargin, $
		YMARGIN = ymargin, $
		AZ = zrot, $
		AX = xrot, /SAVE 
    IF contour THEN $
      CONTOUR, thedata, /T3D, /NOERASE, Title='Contour Plot', $
      	levels=levels, ZVALUE=max(thedata)
  ENDIF ELSE BEGIN
    SURFACE, thedata, $
		XSTYLE = axes, $
		YSTYLE = axes, $
		ZSTYLE = axes, $
		title = stitle, $
		subtitle = ssubtitle, $
		xtitle = sxtitle, $
		ytitle = sytitle, $
		ztitle = sztitle, $
		charsize=scharsize, $
		lego=lego, $
		UPPER_ONLY = upper, $
		XMARGIN = xmargin, $
		YMARGIN = ymargin, $
		AZ = zrot, $
		AX = xrot, $
		SKIRT = 0., /SAVE
    IF contour THEN $
      CONTOUR, thedata, /T3D, /NOERASE, Title='Contour Plot', $
      	 levels=levels, ZVALUE=max(thedata)
  ENDELSE
ENDIF ELSE BEGIN
  IF(skirt EQ 0) THEN BEGIN
    SHADE_SURF, thedata, $
		XSTYLE = axes, $
		YSTYLE = axes, $
		ZSTYLE = axes, $
		title = stitle, $
		subtitle = ssubtitle, $
		xtitle = sxtitle, $
		ytitle = sytitle, $
		ztitle = sztitle, $
		charsize=scharsize, $
		UPPER_ONLY = upper, $
		XMARGIN = xmargin, $
		YMARGIN = ymargin, $
		AZ = zrot, $
		AX = xrot, /SAVE 
    IF contour THEN $
      CONTOUR, thedata, /T3D, /NOERASE, Title='Contour Plot', $
      	 levels=levels, ZVALUE=max(thedata)
    ENDIF ELSE BEGIN 
      SHADE_SURF, thedata, $
		XSTYLE = axes, $
		YSTYLE = axes, $
		ZSTYLE = axes, $
		title = stitle, $
		subtitle = ssubtitle, $
		xtitle = sxtitle, $
		ytitle = sytitle, $
		ztitle = sztitle, $
		charsize=scharsize, $
		UPPER_ONLY = upper, $
		XMARGIN = xmargin, $
		YMARGIN = ymargin, $
		AZ = zrot, $
		AX = xrot, $
		SKIRT = 0., /SAVE
    IF contour THEN $
      CONTOUR, thedata, /T3D, /NOERASE, Title='Contour Plot', $
      	levels=levels, ZVALUE=max(thedata)
   ENDELSE
ENDELSE

END


;------------------------------------------------------------------------------
;	procedure PIA_XSurface_ev
;------------------------------------------------------------------------------

PRO PIA_XSurface_ev, event

;COMMON pia_xs_orientation, zrot, thedata, xrot, skirt, shade, axes, thedraw, $
;		xmargin, ymargin, upper, lego, contour, levels 
;COMMON pia_xs_customi, stitle, ssubtitle, sxtitle, sytitle, sztitle, scharsize
COMMON PIA_PRINT, prt

WIDGET_CONTROL, event.top, GET_UVALUE=id
HANDLE_VALUE, id, pia_xs

zrot = pia_xs.ori.zrot
thedata = pia_xs.ori.thedata
xrot = pia_xs.ori.xrot
skirt = pia_xs.ori.skirt
shade = pia_xs.ori.shade
axes = pia_xs.ori.axes
thedraw = pia_xs.ori.thedraw
xmargin = pia_xs.ori.xmargin
ymargin = pia_xs.ori.ymargin
upper = pia_xs.ori.upper
lego = pia_xs.ori.lego
contour = pia_xs.ori.contour
levels = pia_xs.ori.levels

stitle=pia_xs.cust.stitle
ssubtitle=pia_xs.cust.ssubtitle
sxtitle=pia_xs.cust.sxtitle
sytitle=pia_xs.cust.sytitle
sztitle=pia_xs.cust.sztitle
scharsize=pia_xs.cust.scharsize

WIDGET_CONTROL, event.id, GET_UVALUE = eventval		;find the user value
							;of the widget where
							;the event occured
CASE eventval OF

  "       0": BEGIN
		zrot = (zrot + 15) mod 360
		IF(zrot LT 0) THEN zrot = 360 + zrot
		pia_xs.ori.zrot = zrot
		PIA_XSurface_draw, pia_xs
		WIDGET_CONTROL, event.id, SET_BUTTON = 0
	      END

  "       1": BEGIN
		zrot = (zrot - 15) mod 360
		IF(zrot LT 0) THEN zrot = 360 + zrot
		pia_xs.ori.zrot = zrot
		PIA_XSurface_draw, pia_xs
		WIDGET_CONTROL, event.id, SET_BUTTON = 0
	      END

  "       2": BEGIN
		xrot = (xrot - 15) mod 360
		IF(xrot LT 0) THEN xrot = 360 + xrot
		pia_xs.ori.xrot = xrot
		pia_xsurface_draw, pia_xs
		WIDGET_CONTROL, event.id, SET_BUTTON = 0
	      END

  "       3": BEGIN
		xrot = (xrot + 15) mod 360
		IF(xrot LT 0) THEN xrot = 360 + xrot
		pia_xs.ori.xrot = xrot
		pia_xsurface_draw, pia_xs
		WIDGET_CONTROL, event.id, SET_BUTTON = 0
	      END

  "       4": BEGIN	;shrink
		xmargin = xmargin * 1.2
		ymargin = ymargin * 1.2
		pia_xs.ori.xmargin = xmargin
		pia_xs.ori.ymargin = ymargin
		pia_xsurface_draw, pia_xs
		WIDGET_CONTROL, event.id, SET_BUTTON = 0
	      END

  "       5": BEGIN	;grow
		xmargin = xmargin * 0.8
		ymargin = ymargin * 0.8
		pia_xs.ori.xmargin = xmargin
		pia_xs.ori.ymargin = ymargin
		pia_xsurface_draw, pia_xs
		WIDGET_CONTROL, event.id, SET_BUTTON = 0
	      END

  "SKIRTON": IF(event.select EQ 1) THEN BEGIN
		skirt = 1
		pia_xs.ori.skirt = skirt
		pia_xsurface_draw, pia_xs
	     ENDIF

  "SKIRTOFF":  IF(event.select EQ 1) THEN BEGIN
		skirt = 0
		pia_xs.ori.skirt = skirt
		pia_xsurface_draw, pia_xs
	      ENDIF

  "SHADEOFF":  IF(event.select EQ 1) THEN BEGIN
		shade = 0
		pia_xs.ori.shade = shade
		pia_xsurface_draw, pia_xs
	      ENDIF

  "SHADEON":  IF(event.select EQ 1) THEN BEGIN
		shade = 1
		pia_xs.ori.shade = shade
		pia_xsurface_draw, pia_xs
	      ENDIF

  "AXESOFF":  IF(event.select EQ 1) THEN BEGIN
		AXES = 4
		pia_xs.ori.axes = axes
		pia_xsurface_draw, pia_xs
	      ENDIF

  "AXESON":  IF(event.select EQ 1) THEN BEGIN
		AXES = 0
		pia_xs.ori.axes = axes
		pia_xsurface_draw, pia_xs
	      ENDIF

  "CONTOFF":  IF(event.select EQ 1) THEN BEGIN
		contour = 0
		pia_xs.ori.contour = contour
		pia_xsurface_draw, pia_xs
	      ENDIF

  "CONTON":  IF(event.select EQ 1) THEN BEGIN
		contour = 1
		pia_xs.ori.contour = contour
		pia_xsurface_draw, pia_xs
	      ENDIF

  "XLOADCT": XLoadct, ncolors=!D.N_COLORS-12, bottom=1, GROUP = event.top

  "XPALETTE": XPalette, GROUP = event.top

  "EXIT": BEGIN
    handle_free, id	
    WIDGET_CONTROL, event.top, /DESTROY
   END

  "PRINT": begin
                WIDGET_CONTROL, event.top, /HOURGLASS
 
                ; ask for printer device if necessary
                IF N_ELEMENTS(prt) EQ 0 THEN PIA_PRTDEF
                IF N_ELEMENTS(prt) EQ 0 THEN RETURN
                IF prt.device EQ "" THEN PIA_PRTDEF
                IF prt.device EQ "" THEN RETURN
 
                ; save present device before changing
                this_device = !D.NAME
                SET_PLOT, prt.device, COPY=prt.copy, INTERPOL=prt.interpolate
 
                ; put together the device command
                cmd = "DEVICE"
                IF prt.filename NE "" THEN BEGIN
                   filename = prt.filename
                   cmd = cmd + ", FILENAME=" + "'" + filename + "'"
                ENDIF ELSE BEGIN
                        filename = STRLOWCASE("idl."+!D.NAME)
                ENDELSE
                IF prt.keys NE "" THEN cmd = cmd + prt.keys
                IF cmd NE "DEVICE" THEN BEGIN
                   IF NOT EXECUTE(cmd) THEN BEGIN
 
                      MESSAGE, /INFO, "Could not set-up device: check keywords"
                      RETURN
                   ENDIF
                ENDIF
 
                ; smaller character size for printout than on screen
                orig_charsize = !P.CHARSIZE
                !P.CHARSIZE = 0.6
 
                ; generate image
                pia_xsurface_draw,/ps, pia_xs
 
 
                ; reset character size
                !P.CHARSIZE = orig_charsize
 
                ; close plot and reset device
                DEVICE, /CLOSE
                SET_PLOT, this_device
 
                ; send printfile to printer
                IF prt.print AND prt.command NE "" THEN BEGIN
                        cmd = prt.command + " " + filename
                        SPAWN, cmd
                ENDIF
                END

   "DEFPRT": PIA_PRTDEF

  "HELP":  BEGIN
	   IF !VERSION.OS NE 'vms' THEN $
                spawn, '$w3net $PIA_HTML/um/xsurface.html &' ELSE $
                spawn, 'w3net /pia_dsk/pia/html/um/xsurface.html',/nowait
	END
	
  ELSE:; MESSAGE, "Event User Value Not Found"

ENDCASE

IF eventval NE "EXIT" THEN BEGIN
  handle_value, id, pia_xs, /SET
  WIDGET_CONTROL, event.top, SET_UVALUE=id 
ENDIF

END ;============= end of XSurface event handling routine task =============



;------------------------------------------------------------------------------
;	procedure XSurface
;------------------------------------------------------------------------------

PRO PIA_XSurface, DATA, GROUP = GROUP, xtitle=xtitle, ytitle=ytitle, $
		charsize=charsize, ztitle=ztitle, wlego=wlego, title=title, $
		subtitle=subtitle, contours=contours, clevels=clevels
    
;COMMON pia_xs_orientation, zrot, thedata, xrot, skirt, shade, axes, thedraw, $
;		xmargin, ymargin, upper, lego, contour, levels

;COMMON pia_xs_customi, stitle, ssubtitle, sxtitle, sytitle, sztitle, scharsize

;IF(XRegistered("PIA_XSurface")) THEN BEGIN 		;we want to allow up
;							;to four versions of
;    							;xsurface running, for
;							;comparison between
;							;different data
;							;Just use four similar
;							;routines w. different
;							;common block names;;;;
;
; PIA_XSur2face, DATA, GROUP = GROUP, xtitle=xtitle, ytitle=ytitle, $
;		charsize=charsize, ztitle=ztitle, wlego=wlego, title=title,$
;		subtitle=subtitle, contours=contours, clevels=clevels;
;
; RETURN
;ENDIF

IF KEYWORD_SET(wlego) THEN lego = 1 ELSE lego = 0
IF KEYWORD_SET(title) THEN stitle = title ELSE stitle = ''
IF KEYWORD_SET(subtitle) THEN ssubtitle = subtitle ELSE ssubtitle = ''
IF KEYWORD_SET(xtitle) THEN sxtitle = xtitle ELSE sxtitle = ''
IF KEYWORD_SET(ytitle) THEN sytitle = ytitle ELSE sytitle = ''
IF KEYWORD_SET(ztitle) THEN sztitle = ztitle ELSE sztitle = ''
IF KEYWORD_SET(charsize) THEN scharsize = charsize ELSE scharsize = 1
IF KEYWORD_SET(contours) THEN contour=contours ELSE contour = 0
IF KEYWORD_SET(clevels) THEN levels=clevels ELSE levels=-1.

thesize = SIZE(DATA)
zrot = 30.
xrot = 30.
skirt = 0
shade = 0
axes = 0
xmargin = [10.0, 3.0]
ymargin = [4.0, 2.0]
upper = 0

PIA_XS_base = WIDGET_BASE(TITLE = "PIA_XSurface", $
		/COLUMN)

XPdMenu, [	'"  Done  "			EXIT',		$
		'"Tools"	{',				$
				'"XLoadct"	XLOADCT',	$
				'"XPalette"	XPALETTE',	$
				'}',                            $
                '"Printer"   {',                                  $
                           '"Define Printer"       DEFPRT',           $
                           '"Print Image"       PRINT',           $ 
                           '}',					$
                '"  Help  "       		HELP' ],	$
	 PIA_XS_base

thebase = WIDGET_BASE(PIA_XS_base, /ROW)

ver	= widget_info(/version)
case ver.style OF
'OPEN LOOK': BEGIN
	  XSurfacepalette = WIDGET_BASE(thebase, $
				/COLUMN, $
				/FRAME, $
				/EXCLUSIVE)
	END
ELSE:	    BEGIN
	  XSurfacepalette = WIDGET_BASE(thebase, $
				/COLUMN, $
				/FRAME)
	END
ENDCASE

controls = [							$
		[						$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 248B, 255B, 063B, 000B],			$
		[128B, 007B, 000B, 224B, 001B],			$
		[112B, 000B, 000B, 000B, 014B],			$
		[136B, 000B, 016B, 000B, 016B],			$
		[052B, 000B, 048B, 000B, 056B],			$
		[172B, 000B, 080B, 000B, 032B],			$
		[124B, 000B, 144B, 000B, 040B],			$
		[164B, 007B, 016B, 001B, 048B],			$
		[012B, 248B, 031B, 062B, 056B],			$
		[036B, 000B, 000B, 228B, 033B],			$
		[004B, 000B, 000B, 008B, 062B],			$
		[012B, 000B, 000B, 016B, 048B],			$
		[036B, 000B, 000B, 016B, 032B],			$
		[008B, 000B, 000B, 008B, 000B],			$
		[112B, 000B, 000B, 004B, 000B],			$
		[128B, 007B, 000B, 002B, 000B],			$
		[000B, 248B, 031B, 001B, 000B],			$
		[000B, 000B, 144B, 000B, 000B],			$
		[000B, 000B, 080B, 000B, 000B],			$
		[000B, 000B, 048B, 000B, 000B],			$
		[000B, 000B, 016B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B]			$
		],						$
;		dnz.bmdef
		[						$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 252B, 255B, 031B, 000B],			$
		[128B, 007B, 000B, 224B, 001B],			$
		[112B, 000B, 000B, 000B, 014B],			$
		[008B, 000B, 008B, 000B, 017B],			$
		[028B, 000B, 012B, 000B, 044B],			$
		[004B, 000B, 010B, 000B, 053B],			$
		[020B, 000B, 009B, 000B, 062B],			$
		[012B, 128B, 008B, 224B, 037B],			$
		[028B, 124B, 248B, 031B, 048B],			$
		[132B, 039B, 000B, 000B, 036B],			$
		[124B, 016B, 000B, 000B, 032B],			$
		[012B, 008B, 000B, 000B, 048B],			$
		[004B, 008B, 000B, 000B, 036B],			$
		[000B, 016B, 000B, 000B, 016B],			$
		[000B, 032B, 000B, 000B, 014B],			$
		[000B, 064B, 000B, 224B, 001B],			$
		[000B, 128B, 248B, 031B, 000B],			$
		[000B, 000B, 009B, 000B, 000B],			$
		[000B, 000B, 010B, 000B, 000B],			$
		[000B, 000B, 012B, 000B, 000B],			$
		[000B, 000B, 008B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B]			$
		],						$
		;upz.bm
		[						$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 128B, 255B, 001B, 000B],			$
		[000B, 064B, 169B, 002B, 000B],			$
		[000B, 160B, 254B, 007B, 000B],			$
		[000B, 160B, 068B, 000B, 000B],			$
		[000B, 016B, 032B, 000B, 000B],			$
		[000B, 016B, 032B, 000B, 000B],			$
		[000B, 016B, 032B, 000B, 000B],			$
		[000B, 016B, 032B, 000B, 000B],			$
		[000B, 008B, 016B, 000B, 000B],			$
		[000B, 008B, 016B, 000B, 000B],			$
		[000B, 008B, 144B, 001B, 000B],			$
		[000B, 008B, 112B, 006B, 000B],			$
		[000B, 008B, 016B, 008B, 000B],			$
		[000B, 008B, 008B, 016B, 000B],			$
		[000B, 008B, 006B, 096B, 000B],			$
		[000B, 008B, 001B, 128B, 000B],			$
		[000B, 136B, 000B, 000B, 001B],			$
		[000B, 200B, 015B, 240B, 003B],			$
		[000B, 008B, 008B, 016B, 000B],			$
		[000B, 008B, 008B, 016B, 000B],			$
		[000B, 008B, 008B, 016B, 000B],			$
		[000B, 008B, 008B, 016B, 000B],			$
		[000B, 008B, 008B, 016B, 000B],			$
		[000B, 008B, 008B, 016B, 000B],			$
		[000B, 008B, 008B, 016B, 000B],			$
		[000B, 008B, 008B, 016B, 000B],			$
		[000B, 008B, 008B, 016B, 000B],			$
		[000B, 008B, 008B, 016B, 000B],			$
		[000B, 016B, 004B, 008B, 000B],			$
		[000B, 016B, 004B, 008B, 000B],			$
		[000B, 016B, 005B, 008B, 000B],			$
		[000B, 080B, 004B, 008B, 000B],			$
		[000B, 032B, 147B, 004B, 000B],			$
		[000B, 160B, 042B, 005B, 000B],			$
		[000B, 064B, 149B, 002B, 000B],			$
		[000B, 128B, 255B, 001B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B]			$
		],						$
		;dnx.bm
		[						$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 128B, 255B, 001B, 000B],			$
		[000B, 064B, 149B, 002B, 000B],			$
		[000B, 160B, 042B, 005B, 000B],			$
		[000B, 032B, 147B, 004B, 000B],			$
		[000B, 080B, 004B, 008B, 000B],			$
		[000B, 016B, 005B, 008B, 000B],			$
		[000B, 016B, 004B, 008B, 000B],			$
		[000B, 016B, 004B, 008B, 000B],			$
		[000B, 008B, 008B, 016B, 000B],			$
		[000B, 008B, 008B, 016B, 000B],			$
		[000B, 008B, 008B, 016B, 000B],			$
		[000B, 008B, 008B, 016B, 000B],			$
		[000B, 008B, 008B, 016B, 000B],			$
		[000B, 008B, 008B, 016B, 000B],			$
		[000B, 008B, 008B, 016B, 000B],			$
		[000B, 008B, 008B, 016B, 000B],			$
		[000B, 008B, 008B, 016B, 000B],			$
		[000B, 008B, 008B, 016B, 000B],			$
		[000B, 200B, 015B, 240B, 003B],			$
		[000B, 136B, 000B, 000B, 001B],			$
		[000B, 008B, 001B, 128B, 000B],			$
		[000B, 008B, 006B, 096B, 000B],			$
		[000B, 008B, 008B, 016B, 000B],			$
		[000B, 008B, 016B, 008B, 000B],			$
		[000B, 008B, 112B, 006B, 000B],			$
		[000B, 008B, 144B, 001B, 000B],			$
		[000B, 008B, 016B, 000B, 000B],			$
		[000B, 008B, 016B, 000B, 000B],			$
		[000B, 016B, 032B, 000B, 000B],			$
		[000B, 016B, 032B, 000B, 000B],			$
		[000B, 016B, 032B, 000B, 000B],			$
		[000B, 016B, 032B, 000B, 000B],			$
		[000B, 160B, 068B, 000B, 000B],			$
		[000B, 160B, 254B, 007B, 000B],			$
		[000B, 064B, 169B, 002B, 000B],			$
		[000B, 128B, 255B, 001B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B]			$
		],						$
		;shrink.bm
		[						$
		[000B, 000B, 008B, 000B, 000B],			$
		[000B, 000B, 008B, 000B, 000B],			$
		[000B, 000B, 073B, 000B, 000B],			$
		[000B, 000B, 042B, 000B, 000B],			$
		[000B, 000B, 028B, 000B, 000B],			$
		[000B, 000B, 008B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[128B, 255B, 255B, 255B, 001B],			$
		[128B, 000B, 000B, 000B, 001B],			$
		[128B, 000B, 000B, 000B, 001B],			$
		[128B, 000B, 000B, 000B, 001B],			$
		[128B, 000B, 000B, 000B, 001B],			$
		[128B, 000B, 000B, 000B, 001B],			$
		[128B, 000B, 000B, 000B, 001B],			$
		[128B, 000B, 000B, 000B, 001B],			$
		[128B, 000B, 000B, 000B, 001B],			$
		[132B, 000B, 000B, 000B, 033B],			$
		[136B, 000B, 000B, 000B, 017B],			$
		[144B, 000B, 000B, 000B, 009B],			$
		[191B, 000B, 000B, 000B, 253B],			$
		[144B, 000B, 000B, 000B, 009B],			$
		[136B, 000B, 000B, 000B, 017B],			$
		[132B, 000B, 000B, 000B, 033B],			$
		[128B, 000B, 000B, 000B, 001B],			$
		[128B, 000B, 000B, 000B, 001B],			$
		[128B, 000B, 000B, 000B, 001B],			$
		[128B, 000B, 000B, 000B, 001B],			$
		[128B, 000B, 000B, 000B, 001B],			$
		[128B, 000B, 000B, 000B, 001B],			$
		[128B, 000B, 000B, 000B, 001B],			$
		[128B, 000B, 000B, 000B, 001B],			$
		[128B, 000B, 000B, 000B, 001B],			$
		[128B, 255B, 255B, 255B, 001B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 008B, 000B, 000B],			$
		[000B, 000B, 028B, 000B, 000B],			$
		[000B, 000B, 042B, 000B, 000B],			$
		[000B, 000B, 073B, 000B, 000B],			$
		[000B, 000B, 008B, 000B, 000B],			$
		[000B, 000B, 008B, 000B, 000B]			$
		],						$
		;grow.bm
		[						$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[248B, 255B, 255B, 255B, 031B],			$
		[008B, 000B, 000B, 000B, 016B],			$
		[008B, 000B, 008B, 000B, 016B],			$
		[008B, 000B, 028B, 000B, 016B],			$
		[008B, 000B, 042B, 000B, 016B],			$
		[008B, 000B, 073B, 000B, 016B],			$
		[008B, 000B, 008B, 000B, 016B],			$
		[008B, 000B, 008B, 000B, 016B],			$
		[008B, 000B, 008B, 000B, 016B],			$
		[008B, 000B, 008B, 000B, 016B],			$
		[008B, 000B, 008B, 000B, 016B],			$
		[008B, 000B, 000B, 000B, 016B],			$
		[008B, 000B, 000B, 000B, 016B],			$
		[008B, 001B, 000B, 000B, 016B],			$
		[136B, 000B, 000B, 128B, 016B],			$
		[072B, 000B, 000B, 000B, 017B],			$
		[232B, 063B, 000B, 000B, 018B],			$
		[072B, 000B, 000B, 252B, 023B],			$
		[136B, 000B, 000B, 000B, 018B],			$
		[008B, 001B, 000B, 000B, 017B],			$
		[008B, 000B, 000B, 128B, 016B],			$
		[008B, 000B, 000B, 000B, 016B],			$
		[008B, 000B, 000B, 000B, 016B],			$
		[008B, 000B, 000B, 000B, 016B],			$
		[008B, 000B, 016B, 000B, 016B],			$
		[008B, 000B, 016B, 000B, 016B],			$
		[008B, 000B, 016B, 000B, 016B],			$
		[008B, 000B, 016B, 000B, 016B],			$
		[008B, 000B, 146B, 000B, 016B],			$
		[008B, 000B, 084B, 000B, 016B],			$
		[008B, 000B, 056B, 000B, 016B],			$
		[008B, 000B, 016B, 000B, 016B],			$
		[008B, 000B, 000B, 000B, 016B],			$
		[248B, 255B, 255B, 255B, 031B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B],			$
		[000B, 000B, 000B, 000B, 000B]			$
		]						$
	   ]

FOR i = 0,N_ELEMENTS(controls(0,0,*))-1 DO $
  toss = WIDGET_BUTTON(XSurfacepalette, $
		VALUE = controls(*,*,i), $
		UVALUE = STRING(i))

XSurfacedisplay = WIDGET_DRAW(thebase, $
		XSIZE = 475, $
		YSIZE = 400, $
		RETAIN = 2)

XSurfacecontrols = WIDGET_BASE(pia_xs_base, $
		/ROW)

skirtbase = WIDGET_BASE(XSurfacecontrols, $
		/COLUMN, $
		/EXCLUSIVE, $
		/FRAME)

skirtoff = WIDGET_BUTTON(skirtbase, $
		VALUE = "No Skirt", $
		UVALUE = "SKIRTOFF")

skirton = WIDGET_BUTTON(skirtbase, $
		VALUE = "Skirt", $
		UVALUE = "SKIRTON")

shadebase = WIDGET_BASE(XSurfacecontrols, $
		/COLUMN, $
		/EXCLUSIVE, $
		/FRAME)

shadeoff = WIDGET_BUTTON(shadebase, $
		VALUE = "Wire Frame", $
		UVALUE = "SHADEOFF")

shadeon = WIDGET_BUTTON(shadebase, $
		VALUE = "Shaded Surface", $
		UVALUE = "SHADEON")


axesbase = WIDGET_BASE(XSurfacecontrols, $
		/COLUMN, $
		/EXCLUSIVE, $
		/FRAME)

axeson = WIDGET_BUTTON(axesbase, $
		VALUE = "Show Axes", $
		UVALUE = "AXESON")

axesoff = WIDGET_BUTTON(axesbase, $
		VALUE = "Hide Axes", $
		UVALUE = "AXESOFF")


contbase = WIDGET_BASE(XSurfacecontrols, $
		/COLUMN, $
		/EXCLUSIVE, $
		/FRAME)

conton = WIDGET_BUTTON(contbase, $
		VALUE = "Contours", $
		UVALUE = "CONTON")

contoff = WIDGET_BUTTON(contbase, $
		VALUE = "No Contours", $
		UVALUE = "CONTOFF")

WIDGET_CONTROL, pia_xs_base, /REALIZE, $		;create the widgets
	TLB_SET_XOFFSET = 0, TLB_SET_YOFFSET = 350	;that is defined

IF contour THEN WIDGET_CONTROL, conton, /SET_BUTTON ELSE $
	WIDGET_CONTROL, contoff, /SET_BUTTON
WIDGET_CONTROL, skirtoff, /SET_BUTTON
WIDGET_CONTROL, shadeoff, /SET_BUTTON
WIDGET_CONTROL, axeson, /SET_BUTTON
WIDGET_CONTROL, XSurfacedisplay, GET_VALUE = temp & thedraw = temp

IF(N_PARAMS() gt 0) THEN BEGIN
	thedata = DATA
	levels = min(thedata) + findgen(6) * (max(thedata)-min(thedata)) / 6.
ENDIF
	
pia_xs_ori = {zrot:zrot, thedata:thedata, xrot:xrot, skirt:skirt, shade:shade, $
	      axes:axes, thedraw:thedraw, $
	      xmargin:xmargin, ymargin:ymargin, upper:upper, $
	      lego:lego, contour:contour, levels:levels}
pia_xs_cust = {stitle:stitle, ssubtitle:ssubtitle, sxtitle:sxtitle, $
		sytitle:sytitle, sztitle:sztitle, scharsize:scharsize}
pia_xs = {ori:pia_xs_ori,cust:pia_xs_cust}

IF(N_PARAMS() gt 0) THEN $
	pia_xsurface_draw, pia_xs


id = handle_create()
handle_value, id, pia_xs, /SET
WIDGET_CONTROL, PIA_XS_base, SET_UVALUE=id 


xMANAGER,No_BLOCK=1, "PIA_XSurface", PIA_XS_base, $		;register the widgets
		EVENT_HANDLER = "PIA_XSurface_ev", $	;with the xMANAGER,No_BLOCK=1
		GROUP_LEADER = GROUP 

RETURN
END ;================ end of XSurface background task =====================



