;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO IA_START
;+
; NAME:
;	IA_START
;
; PURPOSE:
;	To initialize the Interactive Analysis with the relevant 
;	parameters from Calibration G files or elsewhere, which 
;	do not change at all or just do it infrequently
;
; CATEGORY:
;	PIA - initialisation
;
; CALLING SEQUENCE:
;	IA_START
;
; INPUTS:
;	None
;
; OUTPUTS:
;	None
;
; COMMON BLOCKS:
;               adm
;               adm_init
;               colour_indices
;               phtaap
;               phtcla
;               phtcs
;               phtdarkcur
;               phtdietrans
;               phterd
;               phtfilter_prop
;               phtiiph
;               phtscp
;               phtsm
;               phtsmc
;		gencho_sm
;               phtspd
;               phtsrd
;		
; PROCEDURE:
;	Calibration G files are used eventually together with parameters
;	which are direcly written into this routine and do not change
;	frequently. 
;
; PROCEDURES USED:
;	PIA LIB: darkcur_init
;	         darkcur_str_init
;	         die_trans_init
;	         fcspow_str_init
;	         phtcap_init
;	         phtfilter_prop_init
;	         respons_str_init
;	         scp_init
;	         set_colours
;	         smc_init
;	         spd_init
;	         srd_init
;	         write_acc
;
;	         phtaap_init (batch file)
;	         phtcla_init (batch file)
;	         phtcs_init (batch file)
;	         phterd_init (batch file)
;	         phtiiph_init (batch file)
;	         phtscp_init (batch file)
;                phtsm_init (batch file)
;	         phtsmc_init (batch file)
;	         gencho_sm_init (batch file)
;	         phtspd_init (batch file)
;	         phtsrd_init (batch file)
;
; MODIFICATION HISTORY:
;	Written by:	Carlos Gabriel, ESA/VILSPA	October 1995
;	Modified (last) by CG				January 1997
;	V5.5.1
;	Initialisation of PIA_BUFINFO added to avoid
;	 problems (CG)					May 1997
;	V6.3 
;	Initialisation of "zoom" variables (CG)		October 1997
;	V6.5
;	Initialisation of signal fractions discard (CG)
;	 and inclusion of cal.menues init (JA)		January 1998
;	V7.0
;	Initialisation of dynamic calibration CBs (CG)	November 1998
;	V7.3
;       
;-

; all the common structures are defined and initialized

@adm
@adm_init
@phtcs
@phtcs_init
@phterd
@phterd_init
@phtsrd
@phtsrd_init
@phtdrift
@phtdrift_init
@phtscp
@phtscp_init
@phtsm
@phtsm_init
@phtsmc
@phtsmc_init
@gencho_sm
@gencho_sm_init
@phtiiph
@phtiiph_init
@phtspd
@phtspd_init
@phtaap
@phtaap_init
@phtaar
@phtaar_init
@phtcla
@phtcla_init
@phtdietrans
@phtdarkcur
@colour_indices
;;@phtw2jy
phtw2jy_init
@phtfilter_prop
@splitramp_par
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color

; Initialize zoom common for avoiding problems
	zoom_psymch = 4
	zoom_color = -1

;
 On_ERROR,2                                          ;Return to caller
; 
; Read Cal G files  
;
 
 DIE_TRANS_INIT

;
; Initialize the acceptance block - Use Pipeline criteria 
;
 SIGF = {chop_meas:0.5, star_meas:0.}
 WRITE_ACC, 1, 1, 0, 0, 0, 0, 0, -1.2, 1.0, $
	SIGF, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0

;
; Set to Pseudo color
;
 device, pseudo_color=8
;
; Initialize the colour indices 
;
 set_colours
;
; Initialize dark currents & filter properties
;
 darkcur_init
 phtfilter_prop_init
;
; Initialize capacitances
;
 phtcap_init
; 
;
; Initialize the diverse structures used for calibration purposes
;
 darkcur_str_init
 fcspow_str_init
 fcspre_str_init
 respons_str_init
; 
; Initialize some system variables
;
  defsysv,'!PIA_bufinfo', exists=i
  IF i NE 0 THEN BEGIN 
    !PIA_BUFINFO.level = 'ERD'
    !PIA_BUFINFO.det = 'P1'
  ENDIF ELSE BEGIN
    bufinfo = {level:'ERD',det:'P1'}
    DEFSYSV, '!PIA_BUFINFO', bufinfo 
  ENDELSE

 respchk_str_init
 splitramp_par_init

; Initialize flag system
piaflag_info

; Initialize  CBs needed for dynamic PHT-S calibration 
phtdyncaldb_init         ; dynamical calibration database
phtdyncal_init           ; dynamical calibration structure per measurement 

; initialize the printer
 pia_prtinit


 RETURN
 END
