;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       ID2WHEELS
;
; PURPOSE:
;       Returns the wheels corresponding to filter and aperture id's 
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	id2wheels, det, filt_id, aper_id, wheels, lambda, area
;
; INPUT:
;	det:		Detector name
;	filt_id:	Official filter identifier - (string)      
;	aper_id:	Official aperture identifier - (string)       
;	wheels:		3-array containing the wheel positions
;
; OUTPUT:
;	wheels:		3-array containing the wheel positions
;
; OPTIONAL OUTPUT:
;	lambda:		Central Wavelength
;	area:		Aperture area (in mm^2)
;
; COMMON BLOCKS:
;	phtapertures:	Apertures and their sizes
;	phtfilter:	Filters' IDs
;
; MODIFICATION HISTORY:
;       Written by: Carlos GABRIEL (ESA-SAI)	November 1995
;	Bug with C filters fixed (CG)		December 1995
;	STRTRIM used for filters ID (CG)	February 1996
;	phtapert used now (CG)			February 1998
;	V7.0
;-
PRO id2wheels, det, filt_id, aper_id, wheels, lambda, area

@phtfilter 	
@phtapert

	ON_ERROR, 2
	
;
; Check the number of parameters
;
	IF N_PARAMS() LT 4 THEN MESSAGE, $
	   'Syntax: ID2WHEELS, DET, FILT_ID, APER_ID, WHEELS [, lambda, area] '

	wheels = INTARR(3)
	
; initialize phtfilter and/or phtapertures if not yet

	IF N_ELEMENTS(c1filters) EQ 0 THEN phtfilter_init
	IF N_ELEMENTS(p_as) EQ 0 THEN aperture_size_init

	allcfilters = ['Free_ap',c1filters, c2filters,'C_cut']
	allpfilters = [p1filters, p2filters, p3filters]
	  
	CASE STRMID(det,0,1) OF
	
		'C': BEGIN
			ind = WHERE(STRTRIM(allcfilters,2) EQ $
				STRTRIM(filt_id,2), n)
			IF n NE 0 THEN BEGIN
			  wheels(1) = ind + 1
			  wheels(0) = 11
			  wheels(2) = -1
			ENDIF
			lambda = FLOAT(STRMID(filt_id,3,4))
			IF STRMID(det,0,2) EQ 'C2' THEN area = c2_mm ^2 ELSE $
							area = c1_mm ^ 2
	  	END

		'P': BEGIN

			ind = WHERE(STRTRIM(allpfilters,2) EQ $
				STRTRIM(filt_id,2), n)
			IF n NE 0 THEN BEGIN
			  wheels(2) = ind + 1
			  wheels(0) = 1
			ENDIF
			ind = WHERE(P_diamy(*,0) EQ FIX(aper_id),n)
			IF n NE 0 THEN $
			  wheels(1) = ind + 1
			
			lambda = FLOAT(STRMID(filt_id,3,4))
			area = P_AREA(wheels(1)-1,0)
		END
		ELSE:

	ENDCASE
	  	
	RETURN
	END
