;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
function int_to_text,idb,conv_table,hkdat,i

;+
; NAME:
;       INT_TO_TEXT
;
; PURPOSE:
;       To convert idb element number i of the status part  
;       into an string array hkout containing the converted
;       status data
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       Result = INT_TO_TEXT, Idb, Conv_table, Hkdat, I 
;
; INPUTS:
;       Idb         :database array
;       I           :idb element number (must be in STS part)
;       Hkdat       :array containing the fits data
;       Conv_table  :conversion table for element i
;
; OUTPUTS:
;       Returns a string array containing the converted status data
;
; PROCEDURE:
;       Add two one byte words to one two byte word, look
;       for the bits dtermined by length and offset in the
;       idb with the idb and function.
;       Look for corresponding value in conv_table.        
;
; PROCEDURES USED:
;       None
;
; MODIFICATION HISTORY:
;       Written by:	Andreas Karch
;	Oct 95 Version 3.5
;-

;read a whole  two -byte word

  rawvalue=256*hkdat(idb(15,i)-628,*)+hkdat(idb(15,i)-627,*)
 
;check offset and length of required bits
 bitnums=long(indgen(idb(17,i))+idb(16,i))

; calculate proper value
 value=0l
 for j=0l,n_elements(bitnums)-1 do begin
  junk=rawvalue and 2l^bitnums(j)
  value=value+junk/(2l^bitnums(j))*(2l^j)
 endfor


;  return matching string
; return value if this hk should not be converted
if conv_table(16) eq 'conv flag not set' then begin 
  return, value
;else return the corresponding table entry
endif else begin
  return, conv_table(value+1)
endelse
; (add 1 because conv_table(0) is conv_ar !!)

end
