;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       IS_FILE_EXIST
;
; PURPOSE:
;       This is part of the pia support routines.
;	It is used for checking if a file exist
;
; CATEGORY:
;       PIA - utilities
;
; CALLING SEQUENCE:
;       IS_FILE_EXIST, FILE
;
; INPUT:
;	FILE: filename to check
; OUTPUT:
;
; COMMON BLOCKS:
;
; PROCEDURES USED:
;       PIA LIB:
;	Astronomical Library:
; MODIFICATION HISTORY:
;	Written by: Wai-Ming Tai (DIAS)			Sept 1996
;	Not official bug-fixing for VMS (CG)		Jul 1998
;
;-
FUNCTION is_file_exist, file
  CASE !VERSION.OS OF 
 
  'vms': BEGIN 

	     cd, current=here
	     
       ; VMS directories can be files, NAME.DIR, or paths DEVICE:[NAME.NAME].
       ; If the "[]" method is used, tack on a wildcard spec (*.*), otherwise
       ; the value of dir is a filename and it can remain the same.

;            if(strpos(file,']') gt -1)then file = file+ "*.*" 
            context = 0L 
            resultant = STRING(BYTARR(256)+32B) 

       ; See if either Name.dir file exists in the current directory or
       ; if a path specified see if there is any files in that dir.
       ; Use vms LIB$ routines via Call External

            result = CALL_EXTERNAL("LIBRTL", "LIB$FIND_FILE", file , resultant,$
		 context, here, 0L, 0L, 0L, VALUE = [0, 0, 0, 0, 1, 1, 1]) 
            toss = CALL_EXTERNAL("LIBRTL", "LIB$FIND_FILE_END", context) 

            RETURN, (result EQ 65537) 
         END 
  'windows': BEGIN 
            RETURN,1    ; Hook into common dialogs for windows 
                        ; when this really works. 
         END 
  ELSE:  BEGIN 
      ; Use the unix command test to check this. Have to use sh5 on ultrix 
      ; Test sets the shell status variable and echo prints it out. This is  
      ; then captured by spawn and placed in result 
 
        if(!version.os ne 'ultrix')then $ 
            spawn, ['test -r '+file+' ; echo $?'], result, /sh $ 
        else $ 
            spawn, ['/bin/sh5 -c "test -r '+file+' ";echo $?'], $ 
                   result, /sh 
 
        return, (not fix(result(0)) )  ;convert result to int and NOT it. 
 
      END 
  ENDCASE 
END 
