PRO	LIN, X, A, F, PDER
;+
; NAME:
;	GS_LIN
;
; PURPOSE:
;	Evaluate the sum of a Gaussian and a 1st-order polynomial
;	and optionally return the value of its partial derivatives.
;	Normally, this function is used by CURVEFIT to fit the
;	sum of a line and a varying background to actual data.
;
; CATEGORY:
;	E2 - Curve and surface fitting.
;
; CALLING SEQUENCE:
;	GS_LIN, X, A, F [, Pder]
;
; INPUTS:
;	X:	The values of the independent variable.
;	A:	The parameters of the equation described in PROCEDURE below.
;
; OUTPUTS:
;	F:	The value of the function at each X(i).
;
; OPTIONAL OUTPUT PARAMETERS:
;	Pder:	An array of the size (N_ELEMENTS(X),5) that contains the
;		partial derivatives.  Pder(i,j) represents the derivative
;		at the i'th point with respect to j'th parameter.
;
; COMMON BLOCKS:
;	None.
;
; SIDE EFFECTS:
;	None.
;
; RESTRICTIONS:
;	None.
;
; PROCEDURE:
;	F = A(0)*EXP(-Z^2/2) + A(3) + A(4)*X 
;	Z = (X-A(1))/A(2)
;
; MODIFICATION HISTORY:
;	Written by P. Merluzzi                        September 1995
;-
	ON_ERROR,2                        ;Return to caller if an error occurs
	F = A(0)*X + A(1) 
	IF N_PARAMS(0) LE 3 THEN RETURN ;NEED PARTIAL?

	PDER = FLTARR(N_ELEMENTS(X),2) ;YES, MAKE ARRAY.
	PDER(0,0) = X		;COMPUTE PARTIALS
	PDER(0,1) = 1
	RETURN
END
