;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       CREATE_MAPPAR
;
; PURPOSE:
;       Create a structure array for defining the parameters in GEN_MAP
;
; CALLING SEQUENCE:
;       CREATE_MAPPAR, par
;
; INPUTS:
;       (none)
;
; KEYWORD PARAMETERS:
;       (none)
;
; OUTPUTS:
;       PAR		The structure with defined field names and types
;
; PROCEDURES USED:
;       PIA Function:
;              	PIA_MKTRANS	Creates a transformation structure
;
; MODIFICATION HISTORY:
;       Written by:             Carlos Gabriel, ESA/VILSPA      April 1999
;       Modified (last) by:         
;	Program header added 	Min Hur, IPAC/Caltech		April 1999
;-

PRO create_mappar, par

	trans = PIA_MKTRANS([0,0],[0,0],[1,1],0)
	par = { $
		mapmethod:0,	$	; Mapping method type
		dropfct:0.3,	$	; Mapping method type
		shx:0.,	$
		shy:0.,	$
		aapin:0,	$	; AAP data present flag
		mapin:0,	$	; maps produced flag
		detector:'',	$	; PHTAAP detector code
		filter:'',	$	; Filter_id
		aper:'',	$	; Aperture_id
		admn:'',	$	; PHTAAP administration string
		admn_decoded:'', $	; admn, decoded string
		aotn:'',	$	; AOT name
		rota:0.,	$	; rotation angle of map
		rota_orig:0.,	$	; rotation angle of map as in AAP
		ra:0.,		$	; right ascension of center of map
		dec:0.,		$	; declination of center of map
		npts:0,		$	; # points per raster line
		nlns:0,		$	; # raster lines
		dpts:0.,	$	; distance of raster points
		dlns:0.,	$	; distance of raster lines
		trans:trans,	$	; transformation structure
		trans_ra:0.,	$	; ra from pia_mapset
		trans_dec:0.,	$	; dec from pia_mapset
		datatype:0,	$	; mean, median, 1st, 3rd quartil
		pixsize:[0.,0.], $	; chosen map pixel size
		npixel:1,	$	; the number of pixels of the detector
		pixselect:[1,1,1,1,1,1,1,1,1], $ ; detector pixel selection
		ffield:0,	$	; automatic flat fielding
		bkg_flat:'',    $       ; flat background 
		grd_back:''    $       ; gradient background
	}

	RETURN
	END
