FUNCTION mapsim_defparm, oldpar=oldpar

;+
; NAME:
;       MAPSIM_DEFPARM
;
; PURPOSE:
;       Create a structure to hold mapping parameters and set default values
;
; CALLING SEQUENCE:
;       PAR = MAPSIM_DEFPARM([oldpar=oldpar])
;
; OPT. INPUTS:
;	OLDPAR		The structure containing the parameters
;
; OUTPUTS:
;       PAR		The structure containing the default parameters if
;			oldpar (input) is not given or the parameters in oldpar
;
; MODIFICATION HISTORY:
;       Written by:             Carlos Gabriel, ESA/VILSPA      April 1999
;       Modified (last) by:     Min Hur, IPAC/Caltech           April 1999
;                               Program header added
;-

	IF NOT KEYWORD_SET(oldpar) THEN $
	   par={resol:7.5, impix:700, nr_src:1, pos_src:[0.,0.], br_bck:10.,$
	       br_src:1., f_or_br:0, rad_src:3, rad_zsrc:0, br_gbck:[0.,0.], $
	       bck_pos1:[0.,0.], bck_pos2:[0.,0.], filt:5} $
	ELSE BEGIN
	   nr = oldpar.nr_src
	   old = N_ELEMENTS(oldpar.br_src)
	   pos_src = FLTARR(2,nr)
	   br_src = FLTARR(nr)
	   f_or_br = INTARR(nr)
	   rad_src = FLTARR(nr)
	   rad_zsrc = FLTARR(nr)
	   IF nr GE old THEN BEGIN
		pos_src(*,0:old-1) = oldpar.pos_src
		br_src(0:old-1) = oldpar.br_src
		f_or_br(0:old-1) = oldpar.f_or_br
		rad_src(0:old-1) = oldpar.rad_src
		rad_zsrc(0:old-1) = oldpar.rad_zsrc
	   ENDIF ELSE BEGIN
		pos_src = oldpar.pos_src(*,0:nr-1)
		br_src = oldpar.br_src(0:nr-1)
		f_or_br = oldpar.f_or_br(0:nr-1)
		rad_src = oldpar.rad_src(0:nr-1)
		rad_zsrc = oldpar.rad_zsrc(0:nr-1)
	   ENDELSE	   	       

	   par={resol:oldpar.resol, impix:oldpar.impix, nr_src:nr, $
	   	pos_src:pos_src, bck_pos1:oldpar.bck_pos1, f_or_br:f_or_br, $
	       bck_pos2:oldpar.bck_pos2,br_src:br_src, rad_src:rad_src, $
	       rad_zsrc:rad_zsrc, br_bck:oldpar.br_bck, br_gbck:oldpar.br_gbck, $
	       filt:oldpar.filt}
	 ENDELSE
	   
	RETURN, par
	END	
