;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_MAPSIM
;
; PURPOSE:
;       Overall GUI for the mapping simulation
;
; CATEGORY:
;       PIA - widget
;
; CALLING SEQUENCE:
;       PIA_MAPSIM, GROUP=group, mpar=mpar, rpar=rpar
;
; INPUTS:
;       MPAR            The structure containing the mapping parameters
;
;	RPAR		The structure containing the raster parameters
;
; KEYWORD PARAMETERS:
;       GROUP           The widget group leader
;
; OPT. OUTPUTS:
;       AAP and SRD structure loaded into the PIA buffer or saved to a file
;	Option to save the simulated sky image(s)
;
; PROCEDURES USED:
;       PIA Procedure(s):
;		pia_mapsim_mpar
;		pia_mapsim_rpar
;		gen_map
;		pia_mapdraw
;		pia_pickfile (function)
;		id_give_filter (function)
;		get_omega (function)
;		gen_raster
;		gen_srd
;		fill_aap
;		fill_srd
;		pcont_saveint
;
; COMMON BLOCKS:
;	PIA_MAPSIM_EVENT
;	PIA_MAPDR_AREAS
;	COLOUR_INDICES
;	
;
; MODIFICATION HISTORY:
;       Written by:             Carlos Gabriel, ESA/VILSPA      April 1999
;       Program header added    Min Hur, IPAC/Caltech           April 1999
;
;	xstyle and ystyle correctly used by
;	 overplotting raster positions (CG)		
;	+ old commented lines deleted (CG)			December 1999
;
;	Correct the mirrored raster positions in the third 
;	display - i.e., the plot showing the raster positions 
;	overplotted on top of the sky image (MH)		Jan 2000
;
;	Added two more display options for MJy/sr scale (MH)	Jan 2000		
;-

PRO pia_mapsim_event, EVENT

COMMON PIA_MAPDR_AREAS, wsize, area
@colour_indices

	WIDGET_CONTROL, event.id, GET_UVALUE=action
	WIDGET_CONTROL, event.top, GET_UVALUE=hsave
	HANDLE_VALUE, hsave, save
	HANDLE_VALUE, save.hmpar, mpar
	HANDLE_VALUE, save.hrpar, rpar
	HANDLE_VALUE, save.hid, id
	WIDGET_CONTROL, event.top, /HOURGLASS
	
	CASE action OF
	
	   "MPAR": BEGIN
	   	PIA_MAPSIM_MPAR, mpar, GROUP=event.top
		HANDLE_VALUE, save.hmpar, mpar, /SET
		
	   END
	   
	   "RPAR": BEGIN
	   	PIA_MAPSIM_RPAR, rpar, GROUP=event.top
		HANDLE_VALUE, save.hrpar, rpar, /SET
		
	   END

	   "GMPAR": BEGIN
	   	gen_map, skyc, par=mpar, mappar=mappar, skypure=skypure, $
			maphdr=mmaphdr, /graph
		handle_value, save.hmpar, mpar, /SET
		handle_value, save.hmappar, mappar, /SET
		handle_value, save.hsky, skypure, /SET
		handle_value, save.hmap, skyc, /SET
		handle_value, save.hmmaphdr, mmaphdr, /SET
		WIDGET_CONTROL, id.plot, SENSITIVE = 1
		WIDGET_CONTROL, id.skypur, SENSITIVE = 1
		WIDGET_CONTROL, id.skyimg1, SENSITIVE = 1
		WIDGET_CONTROL, id.skyimg2, SENSITIVE = 1
		WIDGET_CONTROL, id.rasimg, SENSITIVE = 0
		WIDGET_CONTROL, id.zooimg1, SENSITIVE = 0
		WIDGET_CONTROL, id.zooimg2, SENSITIVE = 0
		WIDGET_CONTROL, id.save, SENSITIVE = 1
		WIDGET_CONTROL, id.savmap, SENSITIVE = 1
		WIDGET_CONTROL, id.rasmap, SENSITIVE = 0
		WIDGET_CONTROL, id.srdmap, SENSITIVE = 0
		WIDGET_CONTROL, id.aapsim, SENSITIVE = 1
		WIDGET_CONTROL, id.aappia, SENSITIVE = 0
		WIDGET_CONTROL, id.srdpia, SENSITIVE = 0
	
	   END

	   "QUIT": WIDGET_CONTROL, event.top, /DESTROY
	   
	   "SKYSIM": BEGIN
	   	gen_map, skyc, par=mpar, mappar=mappar, skypure=skypure, $
			maphdr=mmaphdr
		handle_value, save.hmappar, mappar, /SET
		handle_value, save.hsky, skypure, /SET
		handle_value, save.hmap, skyc, /SET
		handle_value, save.hmmaphdr, mmaphdr, /SET
		WIDGET_CONTROL, id.plot, SENSITIVE = 1
		WIDGET_CONTROL, id.skypur, SENSITIVE = 1
		WIDGET_CONTROL, id.skyimg1, SENSITIVE = 1
		WIDGET_CONTROL, id.skyimg2, SENSITIVE = 1
		WIDGET_CONTROL, id.rasimg, SENSITIVE = 0
		WIDGET_CONTROL, id.zooimg1, SENSITIVE = 0
		WIDGET_CONTROL, id.zooimg2, SENSITIVE = 0
		WIDGET_CONTROL, id.save, SENSITIVE = 1
		WIDGET_CONTROL, id.savmap, SENSITIVE = 1
		WIDGET_CONTROL, id.rasmap, SENSITIVE = 0
		WIDGET_CONTROL, id.srdmap, SENSITIVE = 0
		WIDGET_CONTROL, id.aapsim, SENSITIVE = 1	
		WIDGET_CONTROL, id.aappia, SENSITIVE = 0
		WIDGET_CONTROL, id.srdpia, SENSITIVE = 0
	   END
	   
	   "SKYIMG1": BEGIN
		handle_value, save.hmap, skyc
		handle_value, save.hmappar, mappar
		handle_value, save.hmmaphdr, mmaphdr
	   	PIA_MAPDRAW, skyc, mappar.trans, mappar, mmaphdr, 1, $
		  title="Convolved simulated map",  $
		  headline="Convolved simulated map (Jy/beam) - " + mappar.filter
	   END

	   "SKYIMG2": BEGIN
		handle_value, save.hmap, skyc
		handle_value, save.hmappar, mappar
		handle_value, save.hmmaphdr, mmaphdr
		  tmpmappar=mappar
		  tmpmappar.datatype=0
		  filt=id_give_filter(tmpmappar.detector,tmpmappar.filter)
		  fd=filt-1
		  IF fd GE 8 THEN ind_om = fd - 8 ELSE ind_om = fd-1
	 		omega = get_omega(tmpmappar.detector, 0, ind_om)
	 		omega = omega(0)
	 		Epsilon = 0.3
		  skyc2 = skyc / omega / (1.-epsilon^2) * 1.0E-06
		  tmpmaphdr=mmaphdr
		  FXADDPAR, tmpmaphdr, 'DATATYPE',0
	   	PIA_MAPDRAW, skyc2, tmpmappar.trans, tmpmappar, tmpmaphdr, 1, $
		  title="Convolved simulated map",  $
		  headline="Convolved simulated map (MJy/sr) - " + mappar.filter
	   END

	   "SKYPUR": BEGIN
		handle_value, save.hsky, sky
		handle_value, save.hmappar, mappar
		handle_value, save.hmmaphdr, mmaphdr
	   	PIA_MAPDRAW, sky, mappar.trans, mappar, mmaphdr, -1, $
		  title="Simulated sky",  $
		  headline="Simulated sky - Irrelevant Scale "
	   END
		  	 	
	   "SMAP": BEGIN
		handle_value, save.hmap, imap
		handle_value, save.hmappar, imappar
		handle_value, save.hmmaphdr, imaphdr
		tfile=imappar.admn+'.IMAP_SIM'
		filter = '*.IMAP_SIM'
		filename = pia_pickfile(path=!intdir, file=tfile, $
		  group=event.top, $
		  filter=filter, get_path = pathvar, /write, /overwrite)
		if filename NE '' then begin
		   SAVE, imap, imappar , imaphdr, $
                     FILENAME=filename(0)
		   !INTDIR = pathvar
		endif
	    END	
	   	
	    "LOAD": BEGIN
		filter = '*.IMAP_SIM'
		filename = pia_pickfile(path=!intdir,  $
		  group=event.top, $
		  filter=filter, get_path = pathvar)
		IF filename NE '' THEN BEGIN
		  RESTORE, filename
		  handle_value, save.hmap, imap, /SET
		  handle_value, save.hmappar, imappar, /SET
		  handle_value, save.hmmaphdr, imaphdr, /SET
		  WIDGET_CONTROL, id.plot, SENSITIVE = 1
		  WIDGET_CONTROL, id.skypur, SENSITIVE = 0
		  WIDGET_CONTROL, id.skyimg1, SENSITIVE = 1
		  WIDGET_CONTROL, id.skyimg2, SENSITIVE = 1
		  WIDGET_CONTROL, id.rasimg, SENSITIVE = 0
		  WIDGET_CONTROL, id.zooimg1, SENSITIVE = 0
		  WIDGET_CONTROL, id.zooimg2, SENSITIVE = 0
		  WIDGET_CONTROL, id.save, SENSITIVE = 1
		  WIDGET_CONTROL, id.savmap, SENSITIVE = 1
		  WIDGET_CONTROL, id.rasmap, SENSITIVE = 0
		  WIDGET_CONTROL, id.aappia, SENSITIVE = 0
		  WIDGET_CONTROL, id.srdpia, SENSITIVE = 0
		ENDIF
	    END

	   "RASSIM": BEGIN
		handle_value, save.hmap, skyc
		handle_value, save.hmpar, mpar
		handle_value, save.hmappar, mappar
		handle_value, save.hrpar, rpar
		gen_raster, skyc, mappar, rpar, phtiaap=phtiaap,$
			raster_coord=r_coord, raster_pos=r_pos, $
			sky_v=sky_v, sky_h=sky_h, zoomd=zoomd, $
			dersrd=rpar.dersrd

		IF rpar.dersrd THEN BEGIN
		   gen_srd, phtiaap, phtisrd, rpar=rpar
		   handle_value, save.hsrd, phtisrd, /SET
		   WIDGET_CONTROL, id.srdpia, SENSITIVE = 1
		   WIDGET_CONTROL, id.srdmap, SENSITIVE = 1
		ENDIF ELSE BEGIN
		   WIDGET_CONTROL, id.srdpia, SENSITIVE = 0
		   WIDGET_CONTROL, id.srdmap, SENSITIVE = 0
		ENDELSE
		
		handle_value, save.haap, phtiaap, /SET
		handle_value, save.hr_coord, r_coord, /SET
		handle_value, save.hr_pos, r_pos, /SET
		handle_value, save.hsky_v, sky_v, /SET
		handle_value, save.hsky_h, sky_h, /SET
		handle_value, save.hzoomd, zoomd, /SET
		WIDGET_CONTROL, id.rasmap, SENSITIVE = 1
		WIDGET_CONTROL, id.rasimg, SENSITIVE = 1
		WIDGET_CONTROL, id.zooimg1, SENSITIVE = 1
		WIDGET_CONTROL, id.zooimg2, SENSITIVE = 1
		WIDGET_CONTROL, id.aappia, SENSITIVE = 1
	   END
	
	   "GRPAR": BEGIN
		handle_value, save.hmap, skyc
		handle_value, save.hmpar, mpar
		handle_value, save.hmappar, mappar
		handle_value, save.hrpar, rpar
		gen_raster, skyc, mappar, rpar, phtiaap=phtiaap,$
			raster_coord=r_coord, raster_pos=r_pos, $
			sky_v=sky_v, sky_h=sky_h, zoomd=zoomd, /GRAPH

		IF rpar.dersrd THEN BEGIN
		   gen_srd, phtiaap, phtisrd, rpar=rpar, /GRAPH
		   handle_value, save.hsrd, phtisrd, /SET
		   WIDGET_CONTROL, id.srdpia, SENSITIVE = 1
		   WIDGET_CONTROL, id.srdmap, SENSITIVE = 1
		ENDIF ELSE BEGIN
		   WIDGET_CONTROL, id.srdpia, SENSITIVE = 0
		   WIDGET_CONTROL, id.srdmap, SENSITIVE = 0
		ENDELSE
		   			
		handle_value, save.hrpar, rpar, /SET
		handle_value, save.hzoomd, zoomd, /SET
		
		handle_value, save.haap, phtiaap, /SET
		handle_value, save.hr_coord, r_coord, /SET
		handle_value, save.hr_pos, r_pos, /SET
		handle_value, save.hsky_v, sky_v, /SET
		handle_value, save.hsky_h, sky_h, /SET
		WIDGET_CONTROL, id.rasmap, SENSITIVE = 1
		WIDGET_CONTROL, id.rasimg, SENSITIVE = 1
		WIDGET_CONTROL, id.zooimg1, SENSITIVE = 1
		WIDGET_CONTROL, id.zooimg2, SENSITIVE = 1
		WIDGET_CONTROL, id.aappia, SENSITIVE = 1
	   END

	   "RASIMG": BEGIN
		handle_value, save.hmap, skyc
		handle_value, save.hmappar, mappar
		handle_value, save.hmmaphdr, mmaphdr

	   	PIA_MAPDRAW, skyc, mappar.trans, mappar, mmaphdr, 1, $
		  title="Convolved simulated map",  /NO_PRINT, $
		  headline="Convolved map + raster positions - " + mappar.filter

		handle_value, save.hsky_v, sky_v 
		handle_value, save.hsky_h, sky_h
		handle_value, save.hr_coord, raster_coord
		im_pos = area * 1. / [wsize(0),wsize(1),wsize(0),wsize(1)]
		
		plot,sky_h,sky_v, xstyle=5,ystyle=5,ticklen=0., $
			position=im_pos, /nodata, /noerase

		
		dims = N_ELEMENTS(raster_coord(0,*))
		raster_coord(0,*) = raster_coord(0,*) * (-1.) 

		xyouts,raster_coord(0,*),raster_coord(1,*),$	
			 /data,'_',charsize=2.5,alignment=0.5,$
			 color=127,orientation=45
		xyouts,raster_coord(0,*),raster_coord(1,*),$
		  /data,'_',charsize=2.5,alignment=0.5,$
		  color=127,orientation=-45
		
		IF rpar.p32 NE 0 THEN BEGIN 
		  IF mappar.detector EQ 'C1' THEN BEGIN
		      start=6
		      step=39
		  ENDIF ELSE IF mappar.detector EQ 'C2' THEN BEGIN
		      start=3
		      step=21
		  ENDIF ELSE PRINT, 'Wrong detector name'
		      		      		    
		  for n=start,dims-1,step do xyouts,raster_coord(0,n),raster_coord(1,n),$
		   /data,'_',alignment=0.5,color=red,charsize=2.5,orientation=45
		  for n=start,dims-1,step do xyouts,raster_coord(0,n),raster_coord(1,n),$
			 /data,'_',alignment=0.5,color=red,charsize=2.5,orientation=-45
		 ENDIF
		 
		 END
	    
	   "ZOOIMG1": BEGIN
		handle_value, save.hzoomd, zoomd
		handle_value, save.hrpar, rpar
		handle_value, save.hr_pos, r_pos
		handle_value, save.hmappar, mappar
		handle_value, save.hmmaphdr, mmaphdr
		trans = mappar.trans
		midv = N_ELEMENTS(zoomd.skyrds(0,*)) / 2.
		trans.crpix = [midv-0.5, midv-0.5]
		
	   		
	   	PIA_MAPDRAW, zoomd.skyrds, trans, mappar, mmaphdr, 1, $
		  title="Convolved simulated map", /NO_GRID, /NO_PRINT, $
		  headline="Map + raster + det.pixel in S/C coord. (Jy/beam) - " + mappar.filter

		im_pos = area * 1. / [wsize(0),wsize(1),wsize(0),wsize(1)]
		IF mappar.detector EQ 'C1' THEN half_dia=67.75 ELSE $
						half_dia=90.70
						

		xrange=[min(zoomd.yout)-half_dia,max(zoomd.yout)+half_dia]
		 xrange=-xrange		
		yrange=[min(zoomd.zout)-half_dia,max(zoomd.zout)+half_dia]		
		plot,zoomd.sky_ys,zoomd.sky_zs, xstyle=1,ystyle=1,ticklen=0., $
			position=im_pos, xrange=xrange, yrange=yrange,$
			/nodata, /noerase, $
			xtitle= "Spacecraft Y axis  [arcsec]",$
			ytitle= "Spacecraft Z axis  [arcsec]"
			 
		
		dims = N_ELEMENTS(r_pos(0,*))
		if rpar.p32 EQ 0 then $
		  xyouts,r_pos(0,*),r_pos(1,*),$	
		    /data,STRTRIM(indgen(dims)+1,2),alignment=0.5,color=magenta

		xyouts,0.0,0.0,/data,'_',charsize=2.5,alignment=0.5,$
			 color=red,orientation=45
		xyouts,0.0,0.0,/data,'_',charsize=2.5,alignment=0.5,$
		  color=red,orientation=-45

		xyouts,r_pos(0,*),r_pos(1,*),$
		 	/data,'_',charsize=2.5,alignment=0.5,$
			 color=white,orientation=45
		xyouts,r_pos(0,*),r_pos(1,*),$
			 /data,'_',charsize=2.5,alignment=0.5,$
			 color=white,orientation=-45

		  oplot,zoomd.yout,zoomd.zout,psym=3
		  pnum = N_ELEMENTS(zoomd.yout(*,0))
		  xyouts,zoomd.yout(*,0),zoomd.zout(*,0),$
		    	STRTRIM(indgen(pnum)+1,2),color=yellow,alignment=1
		 
	    END
	    
	   "ZOOIMG2": BEGIN
		handle_value, save.hzoomd, zoomd
		handle_value, save.hrpar, rpar
		handle_value, save.hr_pos, r_pos
		handle_value, save.hmappar, mappar
		handle_value, save.hmmaphdr, mmaphdr
		trans = mappar.trans
		midv = N_ELEMENTS(zoomd.skyrds(0,*)) / 2.
		trans.crpix = [midv-0.5, midv-0.5]
		
		  tmpmappar=mappar
		  tmpmappar.datatype=0
		  filt=id_give_filter(tmpmappar.detector,tmpmappar.filter)
		  fd=filt-1
		  IF fd GE 8 THEN ind_om = fd - 8 ELSE ind_om = fd-1
	 		omega = get_omega(tmpmappar.detector, 0, ind_om)
	 		omega = omega(0)
	 		Epsilon = 0.3
		  skyrds2 = zoomd.skyrds / omega / (1.-epsilon^2) * 1.0E-06
		  tmpmaphdr=mmaphdr
		  FXADDPAR, tmpmaphdr, 'DATATYPE',0

	   	PIA_MAPDRAW, skyrds2, tmpmappar.trans, tmpmappar, tmpmaphdr, 1, $
		  title="Convolved simulated map", /NO_GRID, /NO_PRINT, $
		  headline="Map + raster + det.pixel in S/C coord. (MJy/sr) - " + mappar.filter

		im_pos = area * 1. / [wsize(0),wsize(1),wsize(0),wsize(1)]
		IF mappar.detector EQ 'C1' THEN half_dia=67.75 ELSE $
						half_dia=90.70
						

		xrange=[min(zoomd.yout)-half_dia,max(zoomd.yout)+half_dia]
		 xrange=-xrange		
		yrange=[min(zoomd.zout)-half_dia,max(zoomd.zout)+half_dia]		
		plot,zoomd.sky_ys,zoomd.sky_zs, xstyle=1,ystyle=1,ticklen=0., $
			position=im_pos, xrange=xrange, yrange=yrange,$
			/nodata, /noerase, $
			xtitle= "Spacecraft Y axis  [arcsec]",$
			ytitle= "Spacecraft Z axis  [arcsec]"
			 
		
		dims = N_ELEMENTS(r_pos(0,*))
		if rpar.p32 EQ 0 then $
		  xyouts,r_pos(0,*),r_pos(1,*),$	
		    /data,STRTRIM(indgen(dims)+1,2),alignment=0.5,color=magenta

		xyouts,0.0,0.0,/data,'_',charsize=2.5,alignment=0.5,$
			 color=red,orientation=45
		xyouts,0.0,0.0,/data,'_',charsize=2.5,alignment=0.5,$
		  color=red,orientation=-45

		xyouts,r_pos(0,*),r_pos(1,*),$
		 	/data,'_',charsize=2.5,alignment=0.5,$
			 color=white,orientation=45
		xyouts,r_pos(0,*),r_pos(1,*),$
			 /data,'_',charsize=2.5,alignment=0.5,$
			 color=white,orientation=-45

		  oplot,zoomd.yout,zoomd.zout,psym=3
		  pnum = N_ELEMENTS(zoomd.yout(*,0))
		  xyouts,zoomd.yout(*,0),zoomd.zout(*,0),$
		    	STRTRIM(indgen(pnum)+1,2),color=yellow,alignment=1
		 
	    END
	    
	    "AAPPIA": BEGIN
	    	handle_value, save.haap, tmp
		admn = tmp.admn
		IF STRMID(admn,2,2) EQ '99' THEN STRPUT,admn,'01',2
		tmp.admn=admn
		fill_aap, tmp
		END

	    "SRDPIA": BEGIN
	    	handle_value, save.hsrd, tmp
		admn = tmp.admn
		IF STRMID(admn,2,2) EQ '99' THEN STRPUT,admn,'01',2
		tmp.admn=admn
		fill_srd, tmp
		END

	    "SAAP": BEGIN
	    	handle_value, save.haap, tmp
		mnam = fxpar(tmp.hdr, 'PIA_MNAM')
		pcont_saveint, junk, 'AAP', tmpdata=tmp, mnam=mnam
	    	END
	    		
	    "SSRD": BEGIN
	    	handle_value, save.hsrd, tmp
		mnam = fxpar(tmp.hdr, 'PIA_MNAM')
		pcont_saveint, junk, 'SRD', tmpdata=tmp, mnam=mnam
	    	END
	    		
	   ELSE:
	ENDCASE

	IF action NE "QUIT" THEN BEGIN
	 HANDLE_VALUE, hsave, save, /SET
	 WIDGET_CONTROL, event.top, SET_UVALUE=hsave
	ENDIF

	RETURN
	END
	        
	      
	
	
	
PRO PIA_mapsim, GROUP=group, mpar=mpar, rpar=rpar


;	IF getenv('SIMDATA') EQ '' THEN BEGIN
;		PRINT, 'Please, define an environment variable SIMDATA'
;		PRINT, "(eg: IDL> setenv,'SIMDATA=/iso/pht-dev/mapsim3/simdata/')"
;		PRINT, 'for in- and output of data prior to start PIA_MAPSIM'
;		RETURN
;	ENDIF ELSE defsysv,'!simdata',getenv('SIMDATA')
		
	id = {skysim:0l, par:0l, plot:0l, aapsim:0L, $
		skyimg1:0l, skyimg2:0l, skypur:0L, rasimg:0L, zooimg1:0L, zooimg2:0L, load:0L, $
		aappia:0L, srdpia:0L, save:0L, savmap:0L, rasmap:0L, srdmap:0L }
		
	IF not KEYWORD_SET(mpar) THEN mpar=mapsim_defparm()
	IF not KEYWORD_SET(rpar) THEN rpar=mapsim_defparr()
	mbase = WIDGET_BASE(TITLE= "PIA Map simulation", /COLUMN)
	
	actions = WIDGET_BASE(mbase, /ROW)
	
	id.par  = WIDGET_BUTTON(actions, VAL="Parameters", /MENU, $
			XSIZE=100, YSIZE=50, /ALIGN_CENTER)
	edpar  = WIDGET_BUTTON(id.par, VAL="Edit/change sky map parameters", $
			UVAL="MPAR")
	edpar  = WIDGET_BUTTON(id.par, VAL="Edit/change data parameters", $
			UVAL="RPAR")
	id.skysim = WIDGET_BUTTON(actions, VAL="Sky Simulation", /MENU, $
			XSIZE=100, YSIZE=50, /ALIGN_CENTER)
	skysim = WIDGET_BUTTON(id.skysim, VAL="Using parameter table", $
			UVAL="SKYSIM")
	gskysim = WIDGET_BUTTON(id.skysim, VAL="Using graphic derivation", $
			UVAL="GMPAR")
	id.aapsim = WIDGET_BUTTON(actions, VAL="Data Simulation", /MENU, $
			XSIZE=100, YSIZE=50, /ALIGN_CENTER)
	aapsim = WIDGET_BUTTON(id.aapsim, VAL="Using parameter table",$
			UVAL="RASSIM")
	gaapsim = WIDGET_BUTTON(id.aapsim, VAL="Using graphic derivation",$
			UVAL="GRPAR")
	id.plot = WIDGET_BUTTON(actions, VAL="Display", /MENU, $
			XSIZE=100, YSIZE=50, /ALIGN_CENTER)
	id.skyimg1 = WIDGET_BUTTON(id.plot, VAL="Convolved Sky Image (Jy/beam)", $
			UVAL="SKYIMG1")
	id.skyimg2 = WIDGET_BUTTON(id.plot, VAL="Convolved Sky Image (MJy/sr)", $
			UVAL="SKYIMG2")
	id.skypur = WIDGET_BUTTON(id.plot, VAL="Pure Sky Image", $
			UVAL="SKYPUR")
	id.rasimg = WIDGET_BUTTON(id.plot, VAL="Image + Measured Positions", UVAL="RASIMG")
	id.zooimg1 = WIDGET_BUTTON(id.plot, $
		VAL=" ... + Det.Pixel pos. (in S/C coord) (Jy/beam)", $
		UVAL="ZOOIMG1")
	id.zooimg2 = WIDGET_BUTTON(id.plot, $
		VAL=" ... + Det.Pixel pos. (in S/C coord) (MJy/sr)", $
		UVAL="ZOOIMG2")
	WIDGET_CONTROL, id.plot, SENSITIVE = 0
	WIDGET_CONTROL, id.skypur, SENSITIVE = 0
	WIDGET_CONTROL, id.skyimg1, SENSITIVE = 0
	WIDGET_CONTROL, id.skyimg2, SENSITIVE = 0
	WIDGET_CONTROL, id.rasimg, SENSITIVE = 0
	WIDGET_CONTROL, id.zooimg1, SENSITIVE = 0
	WIDGET_CONTROL, id.zooimg2, SENSITIVE = 0
	WIDGET_CONTROL, id.aapsim, SENSITIVE = 0
	
	controls = WIDGET_BASE(mbase, /ROW)

	id.load = WIDGET_BUTTON(controls, VAL="Load map", UVAL="LOAD", $
			XSIZE=100, YSIZE=50, /ALIGN_CENTER)
	id_data = WIDGET_BUTTON(controls, VAL="Data -> PIA", /MENU, $
			XSIZE=100, YSIZE=50, /ALIGN_CENTER)
	id.aappia = WIDGET_BUTTON(id_data, VAL="AAP -> PIA", UVAL="AAPPIA", $
			XSIZE=100, YSIZE=50, /ALIGN_CENTER)
	id.srdpia = WIDGET_BUTTON(id_data, VAL="SRD -> PIA", UVAL="SRDPIA", $
			XSIZE=100, YSIZE=50, /ALIGN_CENTER)
	id.save = WIDGET_BUTTON(controls, VAL="Save ...", /MENU, $
			XSIZE=100, YSIZE=50, /ALIGN_CENTER)
	id.savmap = WIDGET_BUTTON(id.save, VAL="Generated map", UVAL="SMAP")
	id.rasmap = WIDGET_BUTTON(id.save, VAL="Generated AAP", UVAL="SAAP")
	id.srdmap = WIDGET_BUTTON(id.save, VAL="Generated SRD", UVAL="SSRD")
	WIDGET_CONTROL, id.load, SENSITIVE = 1
	WIDGET_CONTROL, id.aappia, SENSITIVE = 0
	WIDGET_CONTROL, id.srdpia, SENSITIVE = 0
	WIDGET_CONTROL, id.save, SENSITIVE = 0
	WIDGET_CONTROL, id.savmap, SENSITIVE = 0
	WIDGET_CONTROL, id.rasmap, SENSITIVE = 0
	WIDGET_CONTROL, id.srdmap, SENSITIVE = 0
	
	quit = WIDGET_BUTTON(controls, VAL="QUIT",UVAL="QUIT", $
			XSIZE=100, YSIZE=50, /ALIGN_CENTER) 
	
	hsave = HANDLE_CREATE()
	hid = HANDLE_CREATE(hsave, VALUE=id)
	hmpar = HANDLE_CREATE(hsave, VALUE=mpar)
	hrpar = HANDLE_CREATE(hsave, VALUE=rpar)
	haap = HANDLE_CREATE( hsave )
	hsrd = HANDLE_CREATE( hsave )
	hmap = HANDLE_CREATE( hsave )
	hmappar = HANDLE_CREATE( hsave )
	hmmaphdr = HANDLE_CREATE( hsave )
	hrmaphdr = HANDLE_CREATE( hsave )
	hsky = HANDLE_CREATE( hsave )
	hsky_h = HANDLE_CREATE( hsave )
	hsky_v = HANDLE_CREATE( hsave )
	hr_pos = HANDLE_CREATE( hsave )
	hr_coord = HANDLE_CREATE( hsave )
	hzoomd = HANDLE_CREATE( hsave )
	save = { hid:hid, hmpar:hmpar, hrpar:hrpar, hmap:hmap, hmappar:hmappar,$
		 hmmaphdr:hmmaphdr, hrmaphdr:hrmaphdr, hsky:hsky, haap:haap,$
		 hr_coord:hr_coord,hr_pos:hr_pos,hsky_h:hsky_h,hsky_v:hsky_v,$
		 hzoomd:hzoomd, hsrd:hsrd}
	HANDLE_VALUE, hsave, save, /SET
	
	WIDGET_CONTROL, mbase, /REALIZE, SET_UVALUE=hsave
	
	
	xMANAGER,No_BLOCK=1, "PIA_MAPSIM", mbase, GROUP=group
	RETURN
	END
