;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_MAPSIM_MPAR
;
; PURPOSE:
;       GUI for changing the mapping parameters
;
; CATEGORY:
;       PIA - widget
;
; CALLING SEQUENCE:
;       PIA_MAPSIM_MPAR, par, GROUP=GROUP
;
; INPUTS:
;       PAR             The structure containing the parameters
;
; KEYWORD PARAMETERS:
;       GROUP           The widget group leader
;
; OUTPUTS:
;       Default or changed mapping parameters
;
; PROCEDURES USED:
;       PIA Procedure(s):
;               mapsim_defparm (function)
;               pia_disp_print_file
;
; COMMON BLOCKS:
;	PIA_MAPSIM_MPAR_EVENT
;	PIA_MSIM_CMN
;
; MODIFICATION HISTORY:
;       Written by:             Carlos Gabriel, ESA/VILSPA      April 1999
;       Program header added    Min Hur, IPAC/Caltech           April 1999                               
;-

PRO PIA_MAPSIM_MPAR_EVENT, event

COMMON PIA_MSIM_CMN, parres

	WIDGET_CONTROL, event.id, GET_UVALUE=action
	WIDGET_CONTROL, event.top, GET_UVALUE=hsave
	HANDLE_VALUE, hsave, save
	HANDLE_VALUE, save.hpar, par
	HANDLE_VALUE, save.hid, id
	
	CASE action OF
	
	   "FLUX": BEGIN
	     fbrid = WIDGET_INFO(event.id,/parent)
	     WIDGET_CONTROL, fbrid, SET_VALUE = '  Jy  '
	   END  
	
	   "BRIG": BEGIN
	     fbrid = WIDGET_INFO(event.id,/parent)
	     WIDGET_CONTROL, fbrid, SET_VALUE = 'MJy/sr'
	   END  
	
	   "DEFAULT": BEGIN
	     par = mapsim_defparm() 
	     WIDGET_CONTROL, event.top, /DESTROY
	     pia_mapsim_mpar, par
	    END
	   
	   "QUIT": BEGIN
	     WIDGET_CONTROL, id.resol, GET_VALUE=val
	     par.resol = val(0)	  
	     WIDGET_CONTROL, id.impix, GET_VALUE=val
	     par.impix = val(0)	  
	     WIDGET_CONTROL, id.nr_src, GET_VALUE=val
	     par.nr_src = val(0)
	     pos_cell = par.nr_src
	     
; For contradictory number of sources	     
	     IF N_ELEMENTS(id.srcx) NE pos_cell THEN BEGIN
	        PIA_DISP_PRINT_FILE, '', /MODAL, $
			GROUP=event.top, TITLE='Contradiction', $
			TEXT=["Number of sources not matching   ",$
			      "data entered - Hit after changing",$
			      "the number of sources, please!!"],$
			WIDTH=40, HEIGHT=5
		RETURN
	     ENDIF
			  
	     
	     FOR I=0,pos_cell-1 DO BEGIN	  
	      WIDGET_CONTROL, id.srcx(i), GET_VALUE=val
	      par.pos_src(0,i) = val(0)	  
	      WIDGET_CONTROL, id.srcy(i), GET_VALUE=val
	      par.pos_src(1,i) = val(0)
	      WIDGET_CONTROL, id.f_or_br(i), GET_VALUE=val
	       IF STRTRIM(val(0),2) EQ 'Jy' THEN $
	       	par.f_or_br(i) = 0 ELSE par.f_or_br(i) = 1 
	      WIDGET_CONTROL, id.br_src(i), GET_VALUE=val
	      par.br_src(i) = val(0)
	      WIDGET_CONTROL, id.rad_src(i), GET_VALUE=val
	      par.rad_src(i) = val(0)
	      WIDGET_CONTROL, id.rad_zsrc(i), GET_VALUE=val
	      par.rad_zsrc(i) = val(0)
	     ENDFOR	  
	     WIDGET_CONTROL, id.br_bck, GET_VALUE=val
	     par.br_bck = val(0)
	     WIDGET_CONTROL, id.br_gbck1, GET_VALUE=val
	     par.br_gbck(0) = val(0)
	     WIDGET_CONTROL, id.br_gbck2, GET_VALUE=val
	     par.br_gbck(1) = val(0)
	     WIDGET_CONTROL, id.bck_pos1x, GET_VALUE=val
	     par.bck_pos1(0) = val(0)
	     WIDGET_CONTROL, id.bck_pos1y, GET_VALUE=val
	     par.bck_pos1(1) = val(0)
	     WIDGET_CONTROL, id.bck_pos2x, GET_VALUE=val
	     par.bck_pos2(0) = val(0)
	     WIDGET_CONTROL, id.bck_pos2y, GET_VALUE=val
	     par.bck_pos2(1) = val(0)
	     
	     WIDGET_CONTROL, id.filt, GET_VALUE=val
	     par.filt = val(0)	  
	     
	     HANDLE_VALUE, save.hpar, par, /SET
	     
	     WIDGET_CONTROL, event.top, /destroy 
	   END
	   
	   "NRSRC": BEGIN
	     WIDGET_CONTROL, id.nr_src, GET_VALUE=val
	     oldval = par.nr_src
	     par.nr_src = val(0)
	     IF par.nr_src NE oldval THEN BEGIN

; we need to look for changes the user might have made
	     WIDGET_CONTROL, id.resol, GET_VALUE=val
	     par.resol = val(0)	  
	     WIDGET_CONTROL, id.impix, GET_VALUE=val
	     par.impix = val(0)	  
	     pos_cell = N_ELEMENTS(id.srcx)
	     FOR I=0,pos_cell-1 DO BEGIN	  
	      WIDGET_CONTROL, id.srcx(i), GET_VALUE=val
	      par.pos_src(0,i) = val(0)	  
	      WIDGET_CONTROL, id.srcy(i), GET_VALUE=val
	      par.pos_src(1,i) = val(0)
	      WIDGET_CONTROL, id.f_or_br(i), GET_VALUE=val
	       IF STRTRIM(val(0),2) EQ 'Jy' THEN $
	       	par.f_or_br(i) = 0 ELSE par.f_or_br(i) = 1 
	      WIDGET_CONTROL, id.br_src(i), GET_VALUE=val
	      par.br_src(i) = val(0)
	      WIDGET_CONTROL, id.rad_src(i), GET_VALUE=val
	      par.rad_src(i) = val(0)
	      WIDGET_CONTROL, id.rad_zsrc(i), GET_VALUE=val
	      par.rad_zsrc(i) = val(0)
	     ENDFOR	  

	     WIDGET_CONTROL, id.br_bck, GET_VALUE=val
	     par.br_bck = val(0)
	     WIDGET_CONTROL, id.br_gbck1, GET_VALUE=val
	     par.br_gbck(0) = val(0)
	     WIDGET_CONTROL, id.br_gbck2, GET_VALUE=val
	     par.br_gbck(1) = val(0)
	     WIDGET_CONTROL, id.bck_pos1x, GET_VALUE=val
	     par.bck_pos1(0) = val(0)
	     WIDGET_CONTROL, id.bck_pos1y, GET_VALUE=val
	     par.bck_pos1(1) = val(0)
	     WIDGET_CONTROL, id.bck_pos2x, GET_VALUE=val
	     par.bck_pos2(0) = val(0)
	     WIDGET_CONTROL, id.bck_pos2y, GET_VALUE=val
	     par.bck_pos2(1) = val(0)
	     
	     WIDGET_CONTROL, id.filt, GET_VALUE=val
	     par.filt = val(0)	  
		  par = mapsim_defparm(oldpar=par)
	     
	     	  WIDGET_CONTROL, event.top, /HOURGLASS
		  WIDGET_CONTROL, event.top, /DESTROY
		  pia_mapsim_mpar, par
	     ENDIF
	   END 
		
	   ELSE:
	   
	ENDCASE  

	parres = par
	
	RETURN
	END      
	   
	


PRO PIA_MAPSIM_MPAR, par, GROUP=GROUP

COMMON PIA_MSIM_CMN, parres

	srcx = LONARR(par.nr_src)
	srcy = srcx
	f_or_br= srcx
	br_src = srcx
	rad_src = srcx
	rad_zsrc = srcx
	IF not KEYWORD_SET(group) THEN GROUP=!PIA_TOP_WID
	
	id={resol:0L, impix:0L, nr_src:0L, srcx:srcx, srcy:srcy, f_or_br:f_or_br, $
	    br_src:br_src, rad_src:rad_src, rad_zsrc:rad_zsrc, br_bck:0L, br_gbck1:0L, br_gbck2:0L, $
	    bck_pos1x:0l, bck_pos1y:0l,bck_pos2x:0l,bck_pos2y:0l,filt:0L}
	

	parbase = WIDGET_BASE(TItLE="PIA Map Simulation Parameters", /COLUMN,$
			/modal, GROUP_LEADER=GROUP)
			
; Map
	label = WIDGET_LABEL(parbase, VAL="Map parameters")
	mapbase = WIDGET_BASE(parbase, /COLUMN, /FRAME)

	resbase = WIDGET_BASE(mapbase, /ROW)
	label = WIDGET_LABEL(resbase, VAL="Skybin size S (arcsec):", XSIZE=200)
	id.resol = WIDGET_TEXT(resbase, XSIZE=7, $
		VAL=STRMID(STRTRIM(par.resol,2),0,5), UVAL="junk")
	label = WIDGET_LABEL(resbase, VAL='Skybin = SxS ', XSIZE=100)

	label= WIDGET_LABEL(mapbase, VAL="")
	
	mbase = WIDGET_BASE(mapbase, /ROW)
	label = WIDGET_LABEL(mbase, VAL="Sky sidelength L (arcsec):", XSIZE=200)
	id.impix = WIDGET_TEXT(mbase, XSIZE=7, $
		VAL=STRMID(STRTRIM(par.impix,2),0,5), UVAL="junk",$
			/EDITABLE)
	label = WIDGET_LABEL(mbase, VAL="Skymap = LxL", XSIZE=100)
	
	label= WIDGET_LABEL(mapbase, VAL="")
	
	mbase0 = WIDGET_BASE(mapbase, /COLUMN, /FRAME)

	mbase = WIDGET_BASE(mbase0, /ROW)
	label = WIDGET_LABEL(mbase, VAL="Nr. of sources:", XSIZE=150)
	id.nr_src = WIDGET_TEXT(mbase, XSIZE=7, $
		VAL=STRMID(STRTRIM(par.nr_src,2),0,5), UVAL="NRSRC",$
			/EDITABLE)
	label = WIDGET_LABEL(mbase, VAL="Hit for changing", XSIZE=150)
	
	mbase2 = WIDGET_BASE(mbase0, /COLUMN)
	label = WIDGET_LABEL(mbase2, XSIZE=420,$
VAL='        Y-pos     Z-pos     Radius/Ydim["]  Zdim["]       Flux/Brightness ' )
	FOR isrc = 0, par.nr_src - 1 DO BEGIN
	 mbase = WIDGET_BASE(mbase2, /ROW)
	 label = WIDGET_LABEL(mbase, VAL="S."+STRTRIM(isrc+1,2)+":")
	 val = par.pos_src(*,isrc)
	 id.srcx(isrc) = WIDGET_TEXT(mbase, XSIZE=7, $
	 	VAL=STRMID(STRTRIM(val(0),2),0,5), UVAL="junk",$
			/EDITABLE)
	 id.srcy(isrc) = WIDGET_TEXT(mbase, XSIZE=7, $
	 	VAL=STRMID(STRTRIM(val(1),2),0,5), UVAL="junk",$
			/EDITABLE)
	 label = WIDGET_LABEL(mbase, XSIZE=20,VAL="     ")
	 val = par.rad_src(isrc)
	 id.rad_src(isrc) = WIDGET_TEXT(mbase, XSIZE=6, $
	 	VAL=STRMID(STRTRIM(val(0),2),0,4), UVAL="junk",$
			/EDITABLE)
	 label = WIDGET_LABEL(mbase, XSIZE=20,VAL="    ")
	 val = par.rad_zsrc(isrc)
	 id.rad_zsrc(isrc) = WIDGET_TEXT(mbase, XSIZE=6, $
	 	VAL=STRMID(STRTRIM(val(0),2),0,4), UVAL="junk",$
			/EDITABLE)
	 label = WIDGET_LABEL(mbase, XSIZE=20,VAL="    ")
	 val = par.br_src(isrc)
	 label = WIDGET_LABEL(mbase, XSIZE=20,VAL="     ")
	 id.br_src(isrc) = WIDGET_TEXT(mbase, XSIZE=7, $
	 	VAL=STRMID(STRTRIM(val(0),2),0,6), UVAL="junk",$
			/EDITABLE)
	 CASE par.f_or_br(isrc) OF
	 	0: val='  Jy  '
		1: val='MJy/sr'
	 ENDCASE
	 id.f_or_br(isrc) = WIDGET_BUTTON(mbase, VALUE=val, /MENU)
	 id_flux = WIDGET_BUTTON(id.f_or_br(isrc), VALUE = '  Jy  ', $
	 			UVAL="FLUX")
	 id_brig = WIDGET_BUTTON(id.f_or_br(isrc), VALUE = 'MJy/sr', $
	 			UVAL="BRIG")
	ENDFOR
	label= WIDGET_LABEL(mbase0, VAL="Y-Pos & Z-Pos within [-L/2,L/2]")
	label= WIDGET_LABEL(mbase0, VAL="If Z-dim=0 > circular source")
	
	
	label= WIDGET_LABEL(mapbase, VAL="")
	
	mbase0 = WIDGET_BASE(mapbase, /COLUMN, /FRAME)

	mbase = WIDGET_BASE(mbase0, /ROW)
	label = WIDGET_LABEL(mbase, VAL="Flat Background [MJy/sr]:", XSIZE=150)
	id.br_bck = WIDGET_TEXT(mbase, VAL=STRMID(STRTRIM(par.br_bck,2),0,5), $
		UVAL="junk", XSIZE=5, /EDITABLE)
	mbase = WIDGET_BASE(mbase0, /ROW)
	label = WIDGET_LABEL(mbase, VAL="Gradient Bckgr. [MJy/sr] ", XSIZE=150)
	label = WIDGET_LABEL(mbase, VAL="- GBR 1:", XSIZE=50)
	id.br_gbck1 = WIDGET_TEXT(mbase, VAL=STRMID(STRTRIM(par.br_gbck(0),2),0,5), $
		UVAL="junk", XSIZE=5, /EDITABLE)
	label = WIDGET_LABEL(mbase, VAL="- GBR 2:", XSIZE=50)
	id.br_gbck2 = WIDGET_TEXT(mbase, VAL=STRMID(STRTRIM(par.br_gbck(1),2),0,5), $
		UVAL="junk", XSIZE=5, /EDITABLE)

	mbase = WIDGET_BASE(mbase0, /ROW)
	label = WIDGET_LABEL(mbase, VAL="Grad. Bckgr. Positions  ", XSIZE=146)

	mbas2 = WIDGET_BASE(mbase, /COLUMN)

	mbas3 = WIDGET_BASE(mbas2, /ROW)
	label = WIDGET_LABEL(mbas3, VAL="- Y-Pos:", XSIZE=50)
	id.bck_pos1x = WIDGET_TEXT(mbas3, VAL=STRMID(STRTRIM(par.bck_pos1(0),2),0,5), $
		UVAL="junk", XSIZE=5, /EDITABLE)
	label = WIDGET_LABEL(mbas3, VAL=" ", XSIZE=50)
	id.bck_pos2x = WIDGET_TEXT(mbas3, VAL=STRMID(STRTRIM(par.bck_pos2(0),2),0,5), $
		UVAL="junk", XSIZE=5, /EDITABLE)

	mbas3 = WIDGET_BASE(mbas2, /ROW)
	label = WIDGET_LABEL(mbas3, VAL="- Z-Pos:", XSIZE=50)
	id.bck_pos1y = WIDGET_TEXT(mbas3, VAL=STRMID(STRTRIM(par.bck_pos1(1),2),0,5), $
		UVAL="junk", XSIZE=5, /EDITABLE)
	label = WIDGET_LABEL(mbas3, VAL=" ", XSIZE=50)
	id.bck_pos2y = WIDGET_TEXT(mbas3, VAL=STRMID(STRTRIM(par.bck_pos2(1),2),0,5), $
		UVAL="junk", XSIZE=5, /EDITABLE)
	
	label= WIDGET_LABEL(mbase0, VAL="Y-Pos & Z-Pos within [-L/2,L/2]")

  	label= WIDGET_LABEL(mapbase, VAL="")
	
	mbase = WIDGET_BASE(mapbase, /ROW)
	label = WIDGET_LABEL(mbase, VAL="Convolution Filter: ", XSIZE=150)
	id.filt = WIDGET_TEXT(mbase, VAL=STRMID(STRTRIM(par.filt,2),0,3),$
		 UVAL="FILT",/EDITABLE, XSIZE=5)
	label= WIDGET_LABEL(mapbase, $
	  VAL ='1=C1_90_Red 2=C1_50 3=C1_60 4=C1_70 5=C1_100 6=C1_105 7=C1_90')
	label= WIDGET_LABEL(mapbase, $
	  VAL= "8=C2_160 9=C2_200 10=C2_180 11=C2_135 12=C2_120")

	label= WIDGET_LABEL(parbase, VAL="")
	label= WIDGET_LABEL(parbase, VAL="")
		
; Controls
	cbase= WIDGET_BASE(parbase, /ROW)
	DEF = WIDGET_BUTTON(cbase, VAL="  Set Default parameters  ", $
		UVAL="DEFAULT")
	QUIT = WIDGET_BUTTON(cbase, VAL="           Quit            ", $
		UVAL="QUIT")
	
	hsave = HANDLE_CREATE()
	hpar = HANDLE_CREATE(hsave, VALUE=par)
	hid = HANDLE_CREATE(hsave, VALU=id)
	
	save = {hpar:hpar, hid:hid}
	HANDLE_VALUE, hsave, save, /SET
	
	WIDGET_CONTROL, parbase, /REALIZE, SET_UVALUE=hsave
	
	xMANAGER,No_BLOCK=1, "PIA_MAPSIM_MPAR", parbase, GROUP=group
	
	HANDLE_VALUE, hsave, save
	HANDLE_VALUE, save.hpar, par
	
	par = parres
	
	RETURN
	END	
	
	
	
	  
	
	
	  
	
	
	 
