;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_MAPSIM_RPAR
;
; PURPOSE:
;       GUI for changing the raster parameters
;
; CATEGORY:
;       PIA - widget
;
; CALLING SEQUENCE:
;       PIA_MAPSIM_RPAR, par, det=det, GROUP=GROUP
;
; INPUTS:
;       PAR             The structure containing the parameters
;	DET		The detector id - C1 or C2
;
; KEYWORD PARAMETERS:
;       GROUP           The widget group leader
;
; OUTPUTS:
;       Default or changed raster parameters
;
; PROCEDURES USED:
;       PIA Procedure(s):
;               mapsim_defparr (function)
;		pia_disp_print_file
;
; COMMON BLOCKS:
;	PIA_MAPSIM_OWNT_EVENT
;	PIA_MAPSIM_RPAR_EVENT
;	PIA_MSIM_CMN
;
; MODIFICATION HISTORY:
;       Written by:             Carlos Gabriel, ESA/VILSPA      April 1999
;       Program header added    Min Hur, IPAC/Caltech           April 1999
;	Seed parameter added (CG)				March 2000
;	V8.2
;                               
;-

PRO PIA_MAPSIM_OWNT_EVENT, event

COMMON PIA_MSIM_CMN, parres

	WIDGET_CONTROL, event.id, GET_UVALUE=action
	WIDGET_CONTROL, event.top, GET_UVALUE=hhsav
	HANDLE_VALUE, hhsav, ssav
	HANDLE_VALUE, ssav.hpar, par
	HANDLE_VALUE, ssav.hid, id
	
	CASE action OF
	
	   "OWNT": BEGIN
        	CASE event.value of
		
	        	0: par.ownt = event.select
						
		ENDCASE
	   	
	 	WIDGET_CONTROL, id.inttime, SENSITIVE=par.ownt
	 	WIDGET_CONTROL, id.onptime, SENSITIVE=par.ownt
	 	WIDGET_CONTROL, id.tsweep, SENSITIVE=par.ownt
	 	WIDGET_CONTROL, id.rpchpl, SENSITIVE=par.ownt
		
		HANDLE_VALUE, ssav.hpar, par, /SET
		HANDLE_VALUE, hhsav, ssav, /SET
		WIDGET_CONTROL, event.top, SET_UVALUE=hhsav
	   END

	   "OK": BEGIN
		IF par.ownt THEN BEGIN
		 WIDGET_CONTROL, id.inttime, GET_VALUE=val
	     	 par.inttime = val(0)	   
		 WIDGET_CONTROL, id.onptime, GET_VALUE=val
	     	 par.onptime = val(0)	   
		 WIDGET_CONTROL, id.tsweep, GET_VALUE=val
	     	 par.tsweep = val(0)	   
		 WIDGET_CONTROL, id.rpchpl, GET_VALUE=val
	     	 par.rpchpl = val(0)
		ENDIF
		WIDGET_CONTROL, event.top, /DESTROY	
		parres = par
	   END
	   
	   "CANC": BEGIN
		WIDGET_CONTROL, event.top, /DESTROY	
	   END
	   
	   ELSE:
	ENDCASE
	
	RETURN
	END
	

PRO PIA_MAPSIM_OWNT, par, GROUP=group

COMMON PIA_MSIM_CMN, parres
	
; parameters for this instance

        id = {ownt:0L, inttime:0L, onptime:0L, tsweep:0L, rpchpl:0L  }

; set up dialog widgets

        id_base = WIDGET_BASE( TITLE="Set Timing Parameters", /COLUMN, $
                        /modal, group=group )

        id_0 = WIDGET_BASE( id_base, /ROW )
        id_1 = WIDGET_BUTTON( id_0, VAL="     OK     ", UVA="OK" )
        id_1 = WIDGET_BUTTON( id_0, VAL="   Cancel   ", UVA="CANC" )

        id_0 = WIDGET_BASE( id_base, /COLUMN , /FRAME)
	id.ownt = cw_bgroup(id_0, $
			/NONEXCLUSIVE, COLUMN=1, $
			SET_VALUE = [par.ownt], $
			UVALUE = 'OWNT', $
		["Self chosen parameters (if not, defaults taken)"])
	
	label = WIDGET_LABEL(id_0, VAL=" ")

        id_1 = WIDGET_BASE( id_0, /ROW )
	label = WIDGET_LABEL(id_1, VAL="Ramp integration time:", $
		XSIZE=200, /ALIGN_LEFT )
	id.inttime = WIDGET_TEXT(id_1, $
		VAL=STRMID(STRTRIM(par.inttime,2),0,5), $
			UVAL="junk", /EDITABLE, XSIZE=8)
	
	label = WIDGET_LABEL(id_0, VAL=" ")

        id_1 = WIDGET_BASE( id_0, /ROW )
	label = WIDGET_LABEL(id_1, VAL="On position time:", $
		XSIZE=200, /ALIGN_LEFT )
	id.onptime = WIDGET_TEXT(id_1, $
		VAL=STRMID(STRTRIM(par.onptime,2),0,5), $
			UVAL="junk", /EDITABLE, XSIZE=8)

	label = WIDGET_LABEL(id_0, VAL=" ")

        id_1 = WIDGET_BASE( id_0, /ROW )
	label = WIDGET_LABEL(id_1, VAL="Sweep time (only P22):", $
		XSIZE=200, /ALIGN_LEFT )
	id.tsweep = WIDGET_TEXT(id_1, $
		VAL=STRMID(STRTRIM(par.tsweep,2),0,5), $
			UVAL="junk", /EDITABLE, XSIZE=8)
	
	label = WIDGET_LABEL(id_0, VAL=" ")

        id_1 = WIDGET_BASE( id_0, /ROW )
	label = WIDGET_LABEL(id_1, VAL="Ramps per chopper pl. (only P32):", $
		XSIZE=200, /ALIGN_LEFT )
	id.rpchpl = WIDGET_TEXT(id_1, $
		VAL=STRMID(STRTRIM(par.rpchpl,2),0,5), $
			UVAL="junk", /EDITABLE, XSIZE=8)
	
	IF NOT par.ownt THEN BEGIN
	 WIDGET_CONTROL, id.inttime, SENSITIVE=0
	 WIDGET_CONTROL, id.onptime, SENSITIVE=0
	 WIDGET_CONTROL, id.tsweep, SENSITIVE=0
	 WIDGET_CONTROL, id.rpchpl, SENSITIVE=0
	ENDIF
	
	hhsav = HANDLE_CREATE()
	hid = HANDLE_CREATE(hhsav, VALUE=id)
	hpar = HANDLE_CREATE(hhsav, VALUE=par)
	ssav = {hid:hid, hpar:hpar}
	
	HANDLE_VALUE, hhsav, ssav, /SET
	
	WIDGET_CONTROL, id_base, /REALIZE, SET_UVALUE=hhsav
	
	xMANAGER, No_BLOCK=1, "PIA_MAPSIM_OWNT", id_base, GROUP=group
	
	par = parres
	
	RETURN
	END	

;*********************************
PRO PIA_MAPSIM_RPAR_EVENT, event

COMMON PIA_MSIM_CMN, parres

	WIDGET_CONTROL, event.id, GET_UVALUE=action
	WIDGET_CONTROL, event.top, GET_UVALUE=hsave
	HANDLE_VALUE, hsave, save
	HANDLE_VALUE, save.hpar, par
	HANDLE_VALUE, save.hid, id
	
	CASE action OF
	
	   "OWNT": BEGIN
	     PIA_MAPSIM_OWNT, par, GROUP=event.top
	     HANDLE_VALUE, save.hpar, par, /SET
	   END
	   
	   "DEFAULT": BEGIN
	     par = mapsim_defparr() 
	     WIDGET_CONTROL, event.top, /DESTROY
	     pia_mapsim_rpar, par, det=id.det
	    END
	   
	  'DERSRD': BEGIN
        	CASE event.value of
		
	        	0: par.dersrd = event.select
						
		ENDCASE
	     HANDLE_VALUE, save.hpar, par, /SET
	     WIDGET_CONTROL, id.srddet, sensitive=par.dersrd
	  END
	  
	  'DETINC': BEGIN
        	CASE event.value of
		
                        0: par.trans = event.select
		
	        	1: par.glitch = event.select
			
		ENDCASE
	     HANDLE_VALUE, save.hpar, par, /SET
	     
	  END
	  
	   "QUIT": BEGIN
	     WIDGET_CONTROL, id.xpos_rst, GET_VALUE=val
	     par.pos_rst(0) = val(0)	  
	     WIDGET_CONTROL, id.ypos_rst, GET_VALUE=val
	     par.pos_rst(1) = val(0)	  
	     WIDGET_CONTROL, id.npts, GET_VALUE=val
	     par.nrpts= val(0)	     	  
	     WIDGET_CONTROL, id.nlns, GET_VALUE=val
	     par.nrlns = val(0)	  
	     WIDGET_CONTROL, id.dpts, GET_VALUE=val
	     par.dpts = val(0)	  
	     WIDGET_CONTROL, id.dlns, GET_VALUE=val
	     par.dlns = val(0)	  
	     WIDGET_CONTROL, id.roll, GET_VALUE=val
	     par.roll = val(0)	  
	     WIDGET_CONTROL, id.orie, GET_VALUE=val
	     par.orie = val(0)	  
	     WIDGET_CONTROL, id.rota, GET_VALUE=val
	     par.rota = val(0)	  
	     WIDGET_CONTROL, id.p32, GET_VALUE=val
	     par.p32 = val(0)	  
	     WIDGET_CONTROL, id.noise, GET_VALUE=val
	     par.noise = val(0)	  
	     WIDGET_CONTROL, id.inoise, GET_VALUE=val
	     par.sigunc = val(0)	  
	     WIDGET_CONTROL, id.unflat, GET_VALUE=val
	     par.unflat = val(0)	
	     WIDGET_CONTROL, id.tr_p, GET_VALUE=val
	     par.tr_p = val(0)	
	     WIDGET_CONTROL, id.tr_e, GET_VALUE=val
	     par.tr_e = val(0)	
	     WIDGET_CONTROL, id.seed, GET_VALUE=val
	     par.seed = val(0)	
	     
	     
;	     IF N_ELEMENTS(par.pos_src(0,*)) GT par.nr_src THEN BEGIN
;	          par.pos_src(*,par.nr_src:*) = 0.
;		  par.rad_src(par.nr_src:*) = 0.
;		  par.br_src(par.nr_src:*) = 0.
;	     ENDIF
	     
	     HANDLE_VALUE, save.hpar, par, /SET
	     
	     WIDGET_CONTROL, event.top, /destroy 
	   END
	   
	   "SLIST": BEGIN
		Text = ['Options for P32 with C100 detector', $
			'==================================',$
			'  Choice  |  Y step  |  Z step  ',$
        		'          | (arcsec) | (arcsec) ',$
        		'--------------------------------',$
        		'     1    |   60     |   15     ',$
        		'     2    |   60     |   23     ',$
        		'     3    |   60     |   46     ',$
        		'     4    |   92     |   69     ',$
        		'     5    |   92     |   92     ',$
        		' ', ' ', $
			'Options for P32 with C200 detector', $
			'==================================',$
        		'  Choice  |  Y step  |  Z step  ',$
        		'--------------------------------',$
        		'     1    |   92     |   31     ',$
        		'     2    |   92     |   46     ',$
        		'     3    |   92     |   92     ']
	       PIA_disp_print_file, '', TEXT=text, /MODAL, $
	       		WIDTH=50, HEIGHT=20, GROUP=event.top
	   END
	       
		
	   ELSE:
	   
	ENDCASE  

	parres = par
	
	RETURN
	END      
	   
	


PRO PIA_MAPSIM_RPAR, par, det=det, GROUP=GROUP

COMMON PIA_MSIM_CMN, parres

	IF not KEYWORD_SET(group) THEN GROUP=!PIA_TOP_WID
	
	id={filt:0L,$
	    xpos_rst:0L, ypos_rst:0L, npts:0L, nlns:0L, dpts:0L, dlns:0L, $
	    p32:0L, roll:0L, unflat:0L, noise:0L, inoise:0L, orie:0L, rota:0L, $
	    tr_p:0L, tr_e:0L, dersrd:0L, det:'', srddet:0L, seed:0L}
	
	IF not KEYWORD_SET(det) THEN det = 'C1'
	id.det = det
   	if det eq 'C1' then begin
      		coeff_e=36.0 
      		coeff_p=0.48
   	endif
   	if det eq 'C2' then begin
      		coeff_e=38.0
      		coeff_p=0.63
   	endif 
	
	trans = {tr_p:coeff_p, tr_e:coeff_e}
	

	parbase = WIDGET_BASE(TItLE="PIA Raster Simulation Parameters", /COLUMN,$
			/modal, GROUP_LEADER=GROUP)
			
; Raster

	label = WIDGET_LABEL(parbase, VAL="Raster/AOT parameters")
	rasbase = WIDGET_BASE(parbase, /COLUMN, /FRAME)

	mbase = WIDGET_BASE(rasbase, /ROW)
	label = WIDGET_LABEL(mbase, VAL="Central pos. Y-Z [arcsec]:", $
		XSIZE=200, /ALIGN_LEFT )
	id.xpos_rst = WIDGET_TEXT(mbase, $
	VAL=STRMID(STRTRIM(par.pos_rst(0),2),0,5), $
			UVAL="junk", /EDITABLE, XSIZE=6)
	id.ypos_rst = WIDGET_TEXT(mbase, $
		VAL=STRMID(STRTRIM(par.pos_rst(1),2),0,5), $
			UVAL="junk", /EDITABLE, XSIZE=6)
	label = WIDGET_LABEL(mbase, VAL="within [-L/2,L/2]", XSIZE=120 )
	
	label= WIDGET_LABEL(rasbase, VAL="")
	
	mbase = WIDGET_BASE(rasbase, /ROW)
	label = WIDGET_LABEL(mbase, VAL="Raster Points & Legs  N-M (<33):", $
		XSIZE=200, /ALIGN_LEFT )
	id.npts = WIDGET_TEXT(mbase, VAL=STRTRIM(par.nrpts,2), UVAL="junk",$
			/EDITABLE, XSIZE=6)
	id.nlns = WIDGET_TEXT(mbase, VAL=STRTRIM(par.nrlns,2), UVAL="junk",$
			/EDITABLE, XSIZE=6)
	
	label= WIDGET_LABEL(rasbase, VAL="")
	
	mbase = WIDGET_BASE(rasbase, /ROW)
	label = WIDGET_LABEL(mbase, VAL='Distances dN - dM [arcsec]:', $
		XSIZE=200, /ALIGN_LEFT )
	id.dpts = WIDGET_TEXT(mbase, VAL=STRMID(STRTRIM(par.dpts,2),0,5),$
		 UVAL="junk",$
			/EDITABLE, XSIZE=6)
	id.dlns = WIDGET_TEXT(mbase, VAL=STRMID(STRTRIM(par.dlns,2),0,5), $
		UVAL="junk",$
			/EDITABLE, XSIZE=6)
	
	label= WIDGET_LABEL(rasbase, VAL="")
	
	mbase = WIDGET_BASE(rasbase, /ROW)
	label = WIDGET_LABEL(mbase, VAL="S/C Roll angle [degrees]:", $
		XSIZE=200, /ALIGN_LEFT )
	id.roll = WIDGET_TEXT(mbase, VAL=STRMID(STRTRIM(par.roll,2),0,5), UVAL="junk",$
			/EDITABLE, XSIZE=6)
	label= WIDGET_LABEL(mbase, VAL="North to Z-S/C axis eastwards")
	
	label= WIDGET_LABEL(rasbase, VAL="")
	
	mbase = WIDGET_BASE(rasbase, /ROW)
	label = WIDGET_LABEL(mbase, VAL="P32 option (0=P22):", $
		XSIZE=200, /ALIGN_LEFT )
	id.p32 = WIDGET_TEXT(mbase, VAL=STRTRIM(par.p32,2), UVAL="junk",$
			/EDITABLE, XSIZE=6)
	but = WIDGET_BUTTON(mbase, VAL=" See list ", UVAL="SLIST")
	
	label= WIDGET_LABEL(rasbase, VAL="")
	
	mbase = WIDGET_BASE(rasbase, /ROW)
	label = WIDGET_LABEL(mbase, VAL="ORIEntation flag (ATTRORIE):", $
		XSIZE=200, /ALIGN_LEFT )
	id.orie = WIDGET_TEXT(mbase, VAL=STRTRIM(par.orie,2), UVAL="junk",$
			/EDITABLE, XSIZE=6)
	label = WIDGET_LABEL(mbase, VAL='0=as ROTA - 1=as S/C')
	
	label= WIDGET_LABEL(rasbase, VAL="")
	
	mbase = WIDGET_BASE(rasbase, /ROW)
	label = WIDGET_LABEL(mbase, VAL="Raster pattern ROTA [degrees]:", $
			XSIZE=200, /ALIGN_LEFT )
	id.rota = WIDGET_TEXT(mbase, VAL=STRMID(STRTRIM(par.rota,2),0,4), UVAL="junk",$
			/EDITABLE, XSIZE=6)
	label = WIDGET_LABEL(mbase, VAL="only by P22 & ORIE=0")
	
	
	label= WIDGET_LABEL(rasbase, VAL="")
	
; Data

	label = WIDGET_LABEL(parbase, VAL="Data parameters")
	rasbase = WIDGET_BASE(parbase, /COLUMN, /FRAME)
	ras2base = WIDGET_BASE(rasbase, /ROW)

	id_srdder = cw_bgroup(ras2base, $
			/NONEXCLUSIVE, COLUMN=1, $
			SET_VALUE = [par.dersrd], $
			UVALUE = 'DERSRD', $
		["SRD derivation"])
	
	id.srddet = cw_bgroup(ras2base, $
			/NONEXCLUSIVE, COLUMN=2, $
			SET_VALUE = [par.trans,par.glitch], $
			UVALUE = 'DETINC', $
		["Transients inclusion", "Glitches inclusion"])
	WIDGET_CONTROL, id.srddet, sensitive=par.dersrd
	
	label= WIDGET_LABEL(rasbase, VAL="")

	mbase = WIDGET_BASE(rasbase, /ROW)
	label = WIDGET_LABEL(mbase, $
	 VAL='Transient parameters E & p:', XSIZE=200, /ALIGN_LEFT )
	id.tr_e = WIDGET_TEXT(mbase, VAL=STRMID(STRTRIM(trans.tr_e,2),0,5),$
		 UVAL="junk",$
			/EDITABLE, XSIZE=6)
	id.tr_p = WIDGET_TEXT(mbase, VAL=STRMID(STRTRIM(trans.tr_p,2),0,5), $
		UVAL="junk",$
			/EDITABLE, XSIZE=6)
	label = WIDGET_LABEL(mbase, $
	 VAL='Tau = E / (S_infty)^p')
	
	label= WIDGET_LABEL(rasbase, VAL="")

	mbase = WIDGET_BASE(rasbase, /ROW)
	label = WIDGET_LABEL(mbase, $
		VAL='Pixel Resp. variation ("Unflatfield")[%]:', $
			XSIZE=250, /ALIGN_LEFT )
	id.unflat = WIDGET_TEXT(mbase, VAL=STRMID(STRTRIM(par.unflat,2),0,5), $
			UVAL="junk", /EDITABLE, XSIZE=6)
	
	label= WIDGET_LABEL(rasbase, VAL="")

	mbase = WIDGET_BASE(rasbase, /ROW)
	label = WIDGET_LABEL(mbase, VAL="Noise level [%]:", $
		XSIZE=250, /ALIGN_LEFT )
	id.noise = WIDGET_TEXT(mbase, VAL=STRMID(STRTRIM(par.noise,2),0,5), $
			UVAL="junk", /EDITABLE, XSIZE=6)
	
	label= WIDGET_LABEL(rasbase, VAL="")

	mbase = WIDGET_BASE(rasbase, /ROW)
	label = WIDGET_LABEL(mbase, VAL="Individual signal uncertainty [%]:", $
		XSIZE=250, /ALIGN_LEFT )
	id.inoise = WIDGET_TEXT(mbase, VAL=STRMID(STRTRIM(par.sigunc,2),0,5), $
			UVAL="junk", /EDITABLE, XSIZE=6)

	label= WIDGET_LABEL(rasbase, VAL="")

	mbase = WIDGET_BASE(rasbase, /ROW)
	label = WIDGET_LABEL(mbase, $
	   VAL="Start parameter for random calculations:", $
		XSIZE=250, /ALIGN_LEFT )
	id.seed = WIDGET_TEXT(mbase, VAL=STRMID(STRTRIM(par.seed,2),0,5), $
			UVAL="junk", /EDITABLE, XSIZE=6)
	label = WIDGET_LABEL(mbase, $
	   VAL='"SEED"', $
		 /ALIGN_LEFT )
	
	label= WIDGET_LABEL(parbase, VAL="")
	label= WIDGET_LABEL(parbase, VAL="")
		
; Controls
	cbase= WIDGET_BASE(parbase, /ROW)
	OWN = WIDGET_BUTTON(cbase, VAL="Set own timing parameters", UVAL="OWNT")
	DEF = WIDGET_BUTTON(cbase, VAL="Default parameters", $
			UVAL="DEFAULT")
	QUIT = WIDGET_BUTTON(cbase, VAL="       Quit       ", $
		UVAL="QUIT")
	
	hsave = HANDLE_CREATE()
	hpar = HANDLE_CREATE(hsave, VALUE=par)
	hid = HANDLE_CREATE(hsave, VALU=id)
	
	save = {hpar:hpar, hid:hid}
	HANDLE_VALUE, hsave, save, /SET
	
	WIDGET_CONTROL, parbase, /REALIZE, SET_UVALUE=hsave
	
	xMANAGER,No_BLOCK=1, "PIA_MAPSIM_RPAR", parbase, GROUP=group
	
	HANDLE_VALUE, hsave, save
	HANDLE_VALUE, save.hpar, par
	
	par = parres
	
	RETURN
	END	
	
	
	
	  
	
	
	  
	
	
	 
