FUNCTION transient, t_arr, sinitial, sfinal, coeff_e, coeff_p, beta

;+
; NAME:
;       TRANSIENT
;
; PURPOSE:
;       Add transient effect to the signal array, t_arr
;
; CALLING SEQUENCE:
;       RESULT = TRANSIENT(t_arr, sinitial, sfinal, coeff_e, coeff_p, beta)
;
; INPUTS:
;       T_ARR		Signal array (SRD level) that needs transient effect
;
;	SINITIAL	Initial signal level
;
;	SFINAL		Final signal level
;
;	COEFF_E		Detector dependent value
;
;	COEFF_P		Detector dependent value
;
;	BETA		Detector dependent value
;
; OUTPUTS:
;       Transient effect added signal array whose size is same as that of t_arr 
;
; MODIFICATION HISTORY:
;       Written by:             Min Hur, IPAC/Caltech     	Sep 1999
;
;       Beta incorporated	Carlos Gabriel, ESA/Vilspa	Dec 1999
;                               
;-

sini = sinitial + (sfinal-sinitial) * beta
RETURN, sfinal + (sini - sfinal) * exp( -1 * t_arr * sfinal^coeff_p / coeff_e )

END
