;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       UNFLAT
;
; PURPOSE:
;       Apply "unflatfield" - the mean responsivity deviation per pixel (in %)
;
; CATEGORY:
;       PIA - processing
;
; CALLING SEQUENCE:
;       UNFLAT, farray, ffct, unf=unf
;
; INPUTS:
;       FARRAY         	Array of brightness distribution (mnbr)
;
;       UNF           	The user defined % deviation. The default is 0.2 
;
; OUTPUTS:
;       unflatfield applied data array
;
; MODIFICATION HISTORY:
;       Written by:             Carlos Gabriel, ESA/Vilspa      April 1999
;	Program header added	Min Hur, IPAC/Caltech		Jan 2000
;
;-

PRO unflat, farray, ffct, unf=unf

	npix = N_ELEMENTS(farray(*,0))
	nele = N_ELEMENTS(farray(0,*))
	
	IF npix LE 1 OR nele LE 1 THEN RETURN
	
	IF not KEYWORD_SET(unf) THEN unf=0.2
	
	seed = nele * 1L
	
	ran = randomn(seed, npix)
	ffct = 1. + ran*unf

; normalize to 1. (too few elements!)
	
	ffct = ffct / AVG(ffct)
	
	FOR Ipix=0,npix-1 DO farray(ipix,*) = farray(ipix,*) * ffct(ipix)
	
	RETURN
	END
	
	
	
	
	  
