;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
PRO mergehdr, p_hdr, e_hdr, h

;+
; NAME:
;	MERGEHDR
;
; PURPOSE:
; 	Merge the primary header and the extended header, note that the NAXIS
; 	line in the primary header is taken out.
;	the hdr could be either a byte array or string array
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	MERGE_HDR, P_hdr, E_Hdr, H
;
; INPUTS:
;	P_hdr: primary header in byte array or string array
;	E_hdr: extended header in byte array or string array
;
; OUTPUTS:
;	H: merged header, NAXIS line and the END line in the primary header 
;          is taken out. Also taken out are the trailing blank lines in the
;          raw byte array.
;
; PROCEDURES USED:
;	None
;
; MODIFICATION HISTORY:
; 	Written by:	W. M. Tai
;	Modified (last) by CG
;	Version 5.x - November 96
;-
;
                       P_HDR = STRING(P_HDR)
	               KEYWORD = STRMID(P_HDR, 0, 8)
		       HEND = WHERE(KEYWORD EQ 'END     ',NHDR)
; take out the endline in the primary hdr
		       IF NHDR GT 0 THEN P_HDR = P_HDR(0:HEND(0) - 1)
	               KEYWORD = STRMID(P_HDR, 0, 8)
		       NOTNAXIS = WHERE(KEYWORD NE 'NAXIS   ')

                       E_HDR = STRING(E_HDR)
	               KEYWORD = STRMID(E_HDR, 0, 8)
		       HEND = WHERE(KEYWORD EQ 'END     ')
		       IF HEND(0) EQ -1 THEN BEGIN
		          fxaddpar, e_hdr, 'END', 0
		          KEYWORD = STRMID(E_HDR, 0, 8) 
		          HEND = WHERE(KEYWORD EQ 'END     ')
		          nvar = e_hdr(hend(0))
		          STRPUT, nvar, '                                   ',8
		          e_hdr(hend) = nvar
		       ENDIF
; Merge the two headers to the hdr variable
		       H = [P_HDR(NOTNAXIS), E_HDR(0:HEND(0))]
END
