;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	mk_att_keys
;
; PURPOSE:
;	add attitude keywords to the file headers
;	
; CATEGORY:
;          PIA - support
;
; CALLING SEQUENCE:
;	MK_ATT_KEYS, level, tdtnr, npts, nlns, dpts, dlns, rota
;
; INPUTS:
;	level:	PIA product level
;	tdtnr: 	TDT number of product to be changed
;	npts:	Number of points of raster map
;	nlns:	Number of lines in raster map
;	dpts:	Distance (arcsec) between raster points
;	dlns:	Distance (arcsec) between raster lines
;	rota:	Rotational angle of raster map w.r.t. north direction
;
; OUTPUTS:
;	The routine changes the related product file, defined by the TDT and
;	product type, on which it is applied on disk
;
; COMMON BLOCKS:
;		phtaap
;		phterd
;		phtscp
;		phtspd
;		phtsrd
;
; PROCEDURES USED:
;	PIA LIB:
;		pia_multmeas
;       ASTRO LIB:
;		fxaddpar
;
; EXAMPLE:
;	To add the missing attitude keywords into the srd product of TDT
;	04300301. a 9x9 map with 30arcsec separationa and a rotation
;	w.r.t to north of 45 deg is asumed.
;
;	mk_att_keys, srd, 04300301, 9, 9, 30, 30, 45
;
; MODIFICATION HISTORY:
; 	Written by:	Carlos Gabriel (ESA/ESTEC)
;	Oct 95 Version 3.5
;			
;-

pro mk_att_keys, level, tdtnr, npoints, nlines, dpts, dlns, rota

@phterd
@phtsrd
@phtscp
@phtspd
@phtaap

if n_params(file) lt 6 then $
 message, 'syntax: mk_att_keys, level, tdtnr, npts, nlns, dpts, dlns, rota '

CASE level of

	'ERD': BEGIN
		admn = STRMID(phterd.admn, 4,8)
		ind = WHERE(admn EQ tdtnr, nind)
		IF nind EQ 0 THEN BEGIN
			MESSAGE, /info, 'Not in buffer, returning'
			RETURN
		ENDIF
		IF nind GT 1 THEN BEGIN
			measlist = phterd(ind).admn
			pia_multmeas, measlist
			ind = ind(measlist)
		ENDIF
		handle_value, phterd(ind).hdr, hdr
; change header

fxaddpar,hdr,'ATTRNPTS',FIX(npoints),after='ATTERROR'
fxaddpar,hdr,'ATTRNLNS',FIX(nlines),after='ATTERROR'
fxaddpar,hdr,'ATTRDPTS',FLOAT(dpts),after='ATTERROR'
fxaddpar,hdr,'ATTRDLNS',FLOAT(dlns),after='ATTERROR'
fxaddpar,hdr,'ATTRROTA',FLOAT(rota),after='ATTERROR'
		handle_value, phterd(ind).hdr, hdr, /set

	END  
	'SRD': BEGIN
		admn = STRMID(phtsrd.admn, 4,8)
		ind = WHERE(admn EQ tdtnr, nind)
		IF nind EQ 0 THEN BEGIN
			MESSAGE, /info, 'Not in buffer, returning'
			RETURN
		ENDIF
		IF nind GT 1 THEN BEGIN
			measlist = phtsrd(ind).admn
			pia_multmeas, measlist
			ind = ind(measlist)
		ENDIF
		handle_value, phtsrd(ind).hdr, hdr
; change header

fxaddpar,hdr,'ATTRNPTS',FIX(npoints),after='ATTERROR'
fxaddpar,hdr,'ATTRNLNS',FIX(nlines),after='ATTERROR'
fxaddpar,hdr,'ATTRDPTS',FLOAT(dpts),after='ATTERROR'
fxaddpar,hdr,'ATTRDLNS',FLOAT(dlns),after='ATTERROR'
fxaddpar,hdr,'ATTRROTA',FLOAT(rota),after='ATTERROR'
		handle_value, phtsrd(ind).hdr, hdr, /set

	END  
	'SCP': BEGIN
		admn = STRMID(phtscp.admn, 4,8)
		ind = WHERE(admn EQ tdtnr, nind)
		IF nind EQ 0 THEN BEGIN
			MESSAGE, /info, 'Not in buffer, returning'
			RETURN
		ENDIF
		IF nind GT 1 THEN BEGIN
			measlist = phtscp(ind).admn
			pia_multmeas, measlist
			ind = ind(measlist)
		ENDIF
		handle_value, phtscp(ind).hdr, hdr
; change header

fxaddpar,hdr,'ATTRNPTS',FIX(npoints),after='ATTERROR'
fxaddpar,hdr,'ATTRNLNS',FIX(nlines),after='ATTERROR'
fxaddpar,hdr,'ATTRDPTS',FLOAT(dpts),after='ATTERROR'
fxaddpar,hdr,'ATTRDLNS',FLOAT(dlns),after='ATTERROR'
fxaddpar,hdr,'ATTRROTA',FLOAT(rota),after='ATTERROR'
		handle_value, phtscp(ind).hdr, hdr, /set

	END  
	'SPD': BEGIN
		admn = STRMID(phtspd.admn, 4,8)
		ind = WHERE(admn EQ tdtnr, nind)
		IF nind EQ 0 THEN BEGIN
			MESSAGE, /info, 'Not in buffer, returning'
			RETURN
		ENDIF
		IF nind GT 1 THEN BEGIN
			measlist = phtspd(ind).admn
			pia_multmeas, measlist
			ind = ind(measlist)
		ENDIF
		handle_value, phtspd(ind).hdr, hdr
; change header

fxaddpar,hdr,'ATTRNPTS',FIX(npoints),after='ATTERROR'
fxaddpar,hdr,'ATTRNLNS',FIX(nlines),after='ATTERROR'
fxaddpar,hdr,'ATTRDPTS',FLOAT(dpts),after='ATTERROR'
fxaddpar,hdr,'ATTRDLNS',FLOAT(dlns),after='ATTERROR'
fxaddpar,hdr,'ATTRROTA',FLOAT(rota),after='ATTERROR'
		handle_value, phtspd(ind).hdr, hdr, /set

	END  
	'AAP': BEGIN
		admn = STRMID(phtaap.admn, 4,8)
		ind = WHERE(admn EQ tdtnr, nind)
		IF nind EQ 0 THEN BEGIN
			MESSAGE, /info, 'Not in buffer, returning'
			RETURN
		ENDIF
		IF nind GT 1 THEN BEGIN
			measlist = phtaap(ind).admn
			pia_multmeas, measlist
			ind = ind(measlist)
		ENDIF
		handle_value, phtaap(ind).hdr, hdr
; change header

fxaddpar,hdr,'ATTRNPTS',FIX(npoints),after='ATTERROR'
fxaddpar,hdr,'ATTRNLNS',FIX(nlines),after='ATTERROR'
fxaddpar,hdr,'ATTRDPTS',FLOAT(dpts),after='ATTERROR'
fxaddpar,hdr,'ATTRDLNS',FLOAT(dlns),after='ATTERROR'
fxaddpar,hdr,'ATTRROTA',FLOAT(rota),after='ATTERROR'
		handle_value, phtaap(ind).hdr, hdr, /set

	END  

	ELSE: RETURN

ENDCASE




return
end
