;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_PATT_DEFIN
;
; PURPOSE:
;	Simple Menu for choosing pattern processing parameters 
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_PATT_DEFIN, PATT_STR 
;
; INPUT:
;	(none)
;
; OUTPUT:
;	PATT_STR: a structure containing parameters for pattern processing
;
;	
; METHOD:
;	Widgets
;	
; COMMON BLOCKS:
;	phtpatt	
;
; MODIFICATION HISTORY:
;	Written by:	C.Gabriel (ESA/VILSPA)		March 1999
;	V7.4
;-


PRO pia_patt_defin, pattstr

COMMON phtpatt, patt_str

	IF N_ELEMENTS(patt_str) EQ 0 THEN $
	  patt_str={disc_framp:0, log_ramps:8}
		
        base = WIDGET_BASE(TITLE = 'Pattern processing parameters', /column)

        rowbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(rowbase, VAL='Discard first ramp/Chopper? ')
	d_ramp = WIDGET_TEXT(rowbase, VAL=STRTRIM(patt_str.disc_framp,2), $
		XSIZE=4, UVAL='junk', /EDITABLE)
	label = WIDGET_LABEL(rowbase, VAL='  0=no, 1=yes')
		
        rowbase = WIDGET_BASE(base, /ROW)
	label = WIDGET_LABEL(rowbase, VAL='Number of "logical ramps": ')
	l_ramp = WIDGET_TEXT(rowbase, VAL=STRTRIM(patt_str.log_ramps,2), $
		XSIZE=4, UVAL='junk', /EDITABLE)
		

        rowbase = WIDGET_BASE(base, /ROW)

	ok_id = WIDGET_BUTTON(rowbase,   VALUE='       OK       ', $
	    UVALUE='OK',XSIZE=100)
	canc_id = WIDGET_BUTTON(rowbase, VALUE='     Cancel     ', $
	    UVALUE='CANCEL', XSIZE=100)
	
	WIDGET_CONTROL, base, /REALIZE

	ok = 0
	
	WHILE ok EQ 0 DO BEGIN
	  event = WIDGET_EVENT(BASE)
	  WIDGET_CONTROL, event.id, GET_UVALUE=Uvalue
	  
	  CASE 1 OF 
	    uvalue EQ 'OK': BEGIN
	  	WIDGET_CONTROL, d_ramp, GET_VALUE=data
		patt_str.disc_framp=FIX(data(0)) 
	  	WIDGET_CONTROL, l_ramp, GET_VALUE=data
		patt_str.log_ramps=FIX(data(0)) 
		
		ok=1
	    END
	     
	    uvalue EQ 'CANCEL': BEGIN 
	     	ok = 1
	     END
	    
	    ELSE: 
	  ENDCASE
	        
	ENDWHILE
	WIDGET_CONTROL, base, /DESTROY
	pattstr = patt_str

        RETURN
END
