PRO process_erd_to_pattern, tmp, all_sig, all_unc, tmpsrd=tmpsrd, $
	newhdr=newhdr, disc_framp=disc_framp, log_ramps=log_ramps, $
	srdpos=srdpos

@phtacc
@phtsrd
	IF not KEYWORD_SET(newhdr) THEN newhdr=tmp.hdr
	IF not KEYWORD_SET(log_ramps) THEN log_ramps=8
	
; Linearize if not done

	lin_done = fxpar(newhdr,'PR_LINC',count=count)
	IF count EQ 0 THEN BEGIN
	  lin_voltages, tmp, newhdr, /silent
	  MESSAGE, /INFO, ' Linearizing read-out voltages: '+dec_admn(tmp.admn)
	ENDIF
;
; Fill the flags ; first with general acceptance criteria
;

; Decode the pixel flag word
	DECODE_PIXF, tmp.pixf, SUSPECT, CHOPON, CHOPS, DR, OTF 

; Look into the acceptance criteria, fill the acc status array

; Force first discard of DR
	IF NOT drnacc THEN BEGIN
	    DRNACC = 1
	    MESSAGE, /INFO, 'Changing to discarding Destructive Read-outs'
	ENDIF


	npix = pixel_det(tmp.det)
	all_pixels = pixel_det(tmp.det, /ALLPX)
	
	
	  ; Get all severe flags individually per pixel
	get_validflag, tmp.flag, 'ERD', redflag, $
	    det=det, /allpix
	erdflag = redflag
	
	
	FOR ipix=0,npix -1 DO $
	  erdflag(ipix,*) = redflag(ipix,*) * 2
	
	max_step = max(tmp.step)
	
	rastersteps = tmp.step * 0 + 1
	get_rpchopstep, rastersteps, tmp.step, rpchopstep, in_plat_pos 
	
	max_nr_step = max(rpchopstep)
	
; Discard 25% of chopper units (if possible)

	IF max_nr_step GT 8 THEN BEGIN

	      nacc = WHERE(rpchopstep LE (max_nr_step/8)+1, ncount)
	      erdflag(*,nacc) = 2
	
	ENDIF
	
	
; Discard read-outs of first ramp/chopper plateau if desired	
	IF KEYWORD_SET(disc_framp) THEN BEGIN

	   FOR istep=1,max(rpchopstep) DO BEGIN
		ind= WHERE(rpchopstep EQ istep, ncount)
		IF ncount GT 0 THEN $
			FOR ipix=0,npix -1 DO $
	  			erdflag(ipix,ind(0):ind(0)+tmp.nndr+1) = 2
	   ENDFOR

	   p_all_beg = tmp.nndr+1
	ENDIF ELSE p_all_beg = 0

	cut_val = (max(in_plat_pos)-p_all_beg) / log_ramps * 2
	
; Proceed per pixel now

	all_points = N_ELEMENTS(tmp.conp(0,*))
	
	all_sig = fltarr(all_pixels,log_ramps)
	all_unc = all_sig
	all_flag = FIX(all_sig)
	all_flag2 = all_flag
; Other needed elements
	all_stim = fltarr(log_ramps)
	all_chop = all_stim
	all_fcsn = all_stim
	all_temp = all_stim
	all_fcs1 = all_stim
	all_fcs2 = all_stim
	all_tkey = all_stim
	all_rpid = BYTARR(2,log_ramps)
	all_resi = all_sig
	all_nros = all_sig
	all_stim = all_stim * 1.D0
	all_step = FIX(all_stim)
	
	FOR ipix=0,npix-1 DO BEGIN

; Compute dV/dt for ALL pairs 

	    timdif = tmp.time(1) - tmp.time(0)
	    dVdt = REFORM(tmp.conp(ipix,1:*) - tmp.conp(ipix,0:all_points-2))
	    dVdt = [0,dVdt] / timdif
	    
	    dVdt_flag = REFORM(erdflag(ipix,1:*)+erdflag(ipix,0:all_points-2))
	    dVdt_flag = [2,dVdt_flag]
	    
	    indacc = WHERE(dVdt_flag eq 0, nacc)
	    
; take only accepted points

	    dVdt = dVdt(indacc)
	    step = tmp.step(indacc)
	    nr_step = rpchopstep(indacc)
	    in_plat = in_plat_pos(indacc)
	    
; divide into different steps -> median -> average of medians
	    med_step = FLTARR(max_step)
	    dVdt_red = dVdt(nacc/2+1:*)
	    step_red = step(nacc/2+1:*)
	    	    	
;            med_step= med(dVdt_red)

	    FOR istep=1,max_step DO BEGIN
	       ind_step = WHERE(step_red EQ istep, np)
	       if (np gt 0) then begin $
	               med_step(istep-1) = med(dVdt_red(ind_step))
	               if med_step(istep-1) eq 0 then begin 
	                  MESSAGE, /INFO, "Can't compute med -> taking average" 
	                  med_step(istep-1)=avg(dVdt_red(ind_step))
	                  endif
	             endif $
	             else begin 
	               ind_step=where(step EQ istep, np)
	               med_step(istep-1) = med(dVdt(ind_step))
	             endelse 	    
	    ENDFOR
	    
	    
; separate cases - insure that only corrected values are in dVdt

	    stepflag = intarr(N_ELEMENTS(dVdt)) + 2
	    
	    CASE max_step of
	    
	    2: BEGIN
	    
		med_of_steps = med_step(1)
		;med_of_steps = (med_step(0)+med_step(1)) / 2

	       	FOR chop_unit=1,max_nr_step,2 DO BEGIN
	          ind = WHERE(nr_step EQ chop_unit OR $
	          		nr_step EQ (chop_unit+1), ncount)
	          ind_src = WHERE(nr_step EQ (chop_unit+1), ncount)
	          
	          IF ncount GT 0 THEN BEGIN
	          if(med(dVdt(ind_src)) ne 0) then $
	              dVdt(ind) = dVdt(ind) / med(dVdt(ind_src))$
	          else  begin 
	               dVdt(ind) = dVdt(ind) / avg (dVdt(ind_src))
	               MESSAGE, /INFO, "Can't compute med -> taking average" 
                  endelse 
	          stepflag(ind) = 0
	          ENDIF    
		ENDFOR
		
		dVdt = dVdt * med_of_steps	

	       END 	

	    3: BEGIN
	    
		med_of_steps = med_step(1)
		;med_of_steps = (med_step(0)+med_step(1)) / 2
	       	FOR chop_unit=1,max_nr_step,3 DO BEGIN
	          ind = WHERE(nr_step GE chop_unit AND $
	          		nr_step LE (chop_unit+2), ncount)
	          ind_src = WHERE(nr_step EQ (chop_unit+1), ncount)
	          
	          IF ncount GT 0 THEN BEGIN
	          if(med(dVdt(ind_src)) ne 0) then $
	              dVdt(ind) = dVdt(ind) / med(dVdt(ind_src))$
	          else  begin 
	               dVdt(ind) = dVdt(ind) / avg (dVdt(ind_src))
	               MESSAGE, /INFO, "Can't compute med -> taking average" 
                  endelse 
	          stepflag(ind) = 0
	          ENDIF    
		ENDFOR
		
		dVdt = dVdt * med_of_steps	

	       END 	

	    4: BEGIN
		

	        ;med_of_steps = fltarr(2)
	        ;med_of_steps(0) = (med_step(0)+med_step(1)) / 2
	        ;med_of_steps(1) = (med_step(2)+med_step(3)) / 2
	        
	        med_of_steps = med_step(1)
	        
	       	FOR chop_unit=1,max_nr_step,4 DO BEGIN
	          ind = WHERE(nr_step GE chop_unit AND $
	          		nr_step LE (chop_unit+3), ncount)
	          ind_src = WHERE(nr_step EQ (chop_unit+1) OR $
	          		nr_step EQ (chop_unit+3), ncount)
	          
	          IF ncount GT 0 THEN BEGIN
	            if (med(dVdt(ind_src)) ne 0) then $
	                 dVdt(ind) = dVdt(ind) / med(dVdt(ind_src)) $
	            else begin 
	                dVdt(ind) = dVdt(ind) / avg(dVdt(ind_src))  
	                MESSAGE, /INFO, "Can't compute med -> taking average" 	                
                  endelse  
	            stepflag(ind) = 0
	          ENDIF    
		ENDFOR

;		ind_bg1 = WHERE(step LE 2)
;		ind_bg2 = WHERE(step GE 3)
;		dVdt(ind_bg1) = dVdt(ind_bg1) * med_of_steps
;		dVdt(ind_bg2) = dVdt(ind_bg2) * med_of_steps

		dVdt = dVdt * med_of_steps	

	       END 	

	    ELSE: BEGIN
	       MESSAGE, /INFO, 'Not implemented case, returning'
	       RETURN
	    END
	    ENDCASE
	    
	    
	    
	    step_ok = WHERE(stepflag EQ 0, ncount)
	    dVdt = dVdt(step_ok)
	    step = step(step_ok)
	    nr_step = nr_step(step_ok)
	    in_plat = in_plat(step_ok)
	    	

; Create logical ramps	      
	    
	    signal1 = FLTARR(log_ramps)
	    uncert1 = signal1

	    signal2 = FLTARR(log_ramps)
	    uncert2 = signal2

;   cut_val and pbeg defined above
	    	
; First pattern: Background
	    IF max_step EQ 3 THEN BEGIN
	    	modval = nr_step mod 3 
		modswitch = 1
	    ENDIF ELSE BEGIN
	        modval = nr_step mod 4
	    	modswitch = 0
	    ENDELSE
	    
	    pbeg=p_all_beg
	    FOR ipor = 0, log_ramps/2 - 1 DO BEGIN
	     pend = pbeg + cut_val 
	     ind = WHERE(modval EQ 1 AND $
	                 in_plat GE pbeg AND in_plat LE pend, ncount)
	     IF ncount GT 0 THEN BEGIN
	       signal1(ipor) = biweight_mean([dVdt(ind)], sig)
	       uncert1(ipor) = sig / SQRT(ncount)
	       all_flag(ipix,ipor) = 1

	       IF ipix EQ 0 THEN BEGIN
	        mid_point = pbeg + (pend - pbeg) / 2
		all_stim(ipor) = tmp.time(mid_point)
		all_chop(ipor) = tmp.chop(mid_point)
		all_fcsn(ipor) = tmp.fcsn(mid_point)
		all_temp(ipor) = biweight_mean([tmp.temp(ind)])
		all_fcs1(ipor) = tmp.fcs1(mid_point)
		all_fcs2(ipor) = tmp.fcs2(mid_point)
		all_tkey(ipor) = tmp.tkey(mid_point)
		all_rpid(*,ipor) = tmp.rpid(*,mid_point)
		all_resi(ipix,ipor) = tmp.time(pend)-tmp.time(pbeg)
		all_nros(ipix,ipor) = pend - pbeg
		all_step(ipor) = 1
	       ENDIF
	     ENDIF ELSE all_flag(ipix,ipor) = 0	     
	     pbeg = pend + 1
	    ENDFOR
	    
	    plbeg = pbeg
; First pattern: Source
	    pbeg=p_all_beg
	    FOR ipor = log_ramps/2, log_ramps - 1 DO BEGIN
	     pend = pbeg + cut_val - 1 
	     ind = WHERE(modval EQ 2 AND $
	                 in_plat GE pbeg AND in_plat LE pend, ncount)
	     IF ncount GT 0 THEN BEGIN
	       signal1(ipor) = biweight_mean([dVdt(ind)], sig)
	       uncert1(ipor) = sig / SQRT(ncount)
	       all_flag(ipix,ipor) = 1

	       IF ipix EQ 0 THEN BEGIN
	        mid_point = pbeg + (pend - pbeg) / 2 + plbeg
		all_stim(ipor) = tmp.time(mid_point)
		all_chop(ipor) = tmp.chop(mid_point)
		all_fcsn(ipor) = tmp.fcsn(mid_point)
		all_temp(ipor) = biweight_mean([tmp.temp(ind+plbeg)])
		all_fcs1(ipor) = tmp.fcs1(mid_point)
		all_fcs2(ipor) = tmp.fcs2(mid_point)
		all_tkey(ipor) = tmp.tkey(mid_point)
		all_rpid(*,ipor) = tmp.rpid(*,mid_point)
		all_resi(ipix, ipor) = tmp.time(pend)-tmp.time(pbeg)
		all_nros(ipix,ipor) = pend - pbeg
		all_step(ipor) = 2
	       ENDIF
	     ENDIF ELSE all_flag(ipix,ipor) = 0	     
	     pbeg = pend + 1
	    ENDFOR
;           
	    IF modswitch THEN modval_req = 0 ELSE modval_req = 3

; Second pattern: Background
	    pbeg=p_all_beg
	    FOR ipor = 0, log_ramps/2 - 1 DO BEGIN
	     pend = pbeg + cut_val 
	     ind = WHERE(modval EQ modval_req AND $
	                 in_plat GE pbeg AND in_plat LE pend, ncount)
	     IF ncount GT 0 THEN BEGIN
	       signal2(ipor) = biweight_mean([dVdt(ind)], sig)
	       uncert2(ipor) = sig / SQRT(ncount)
	       all_flag2(ipix,ipor) = 1
	     ENDIF ELSE all_flag2(ipix,ipor) = 0	     
	     pbeg = pend + 1
	    ENDFOR
	    
	    plbeg = pbeg
; Second pattern: Source
	    IF not modswitch THEN BEGIN
	     pbeg=p_all_beg
	     FOR ipor = log_ramps/2, log_ramps - 1 DO BEGIN
	      pend = pbeg + cut_val - 1 
	      ind = WHERE(modval EQ 0 AND $
	                 in_plat GE pbeg AND in_plat LE pend, ncount)
	      IF ncount GT 0 THEN BEGIN
	       signal2(ipor) = biweight_mean([dVdt(ind)], sig)
	       uncert2(ipor) = sig / SQRT(ncount)
	       all_flag(ipix,ipor) = 1
	      ENDIF ELSE all_flag2(ipix,ipor) = 0	     
	      pbeg = pend + 1
	     ENDFOR
	    ENDIF ELSE all_flag2(ipix,log_ramps/2:log_ramps-1) = 0
; Fill the array
	    
;	    all_sig(ipix,*) = (signal1+signal2)/2.
;	    differr=abs(signal1-signal2)/2.
;	    toterr=sqrt(uncert1*uncert1+uncert2*uncert2)/2.

	    FOR ipor = 0, log_ramps - 1 do BEGIN
	       IF all_flag(ipix,ipor) AND all_flag2(ipix,ipor) THEN BEGIN
	         all_sig(ipix,ipor) = (signal1(ipor)+signal2(ipor))/2.
	         differr = abs(signal1(ipor)-signal2(ipor))/2.
		 toterr = sqrt(uncert1(ipor)*uncert1(ipor)+$
		 	uncert2(ipor)*uncert2(ipor))/2.
		 tmpflag = 0
	       ENDIF ELSE IF all_flag(ipix,ipor) THEN BEGIN
	         all_sig(ipix,ipor) = signal1(ipor)
	         differr = 0.
		 toterr = uncert1(ipor)
		 tmpflag = 0
	       ENDIF ELSE BEGIN
	         all_sig(ipix,ipor) = 0.
	         differr = 0.
		 toterr = 0.
	         tmpflag = 2
	       ENDELSE 
	       all_unc(ipix,ipor) = max([differr, toterr])
; change use of all_flag
	       all_flag(ipix,ipor) = tmpflag
	    ENDFOR
	ENDFOR

	
; Now produce the SRD structure
	FXADDPAR, newhdr, 'PR_PATT', 1, $
	   ' Processing ERD to SRD using Pattern procedure ', $
	   BEFORE='XTENSION'
		
	FXADDPAR, newhdr, 'PR_NPATT', log_ramps, $
	   ' Nr of logical ramps derived in pattern processing', $
	   BEFORE='XTENSION'

	DER_SHDR, newhdr, 1, SRDHDR
		
	tmpsrd = {UNIT: tmp.UNIT, $     
        DET:  tmp.DET, $     
	ADMN: tmp.admn, $
        ORDR: tmp.ORDR, $ 
	DIMS: log_ramps, $
	SLDI: log_ramps, $
	RCHP: log_ramps/2, $
        HDR:  srdhdr, $ 
	SLOP: all_sig, $ 
        SLUN: all_unc, $
        FLAG: all_flag, $
        STIM: all_stim, $
        CHOP: all_chop, $
        STEP: all_step, $
        FCSN: all_fcsn, $
        TEMP: all_temp, $ 
        FCS1: all_fcs1, $   
	FCS2: all_fcs2, $ 
        TKEY: all_tkey, $
        RPID: all_rpid, $
	RESI: all_resi, $ 
        NROS: all_nros}
        
; Fill in the buffer
	
	srdpos = N_ELEMENTS(phtsrd)
	FILL_SRD, tmpsrd

	RETURN
	END
