;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PCONT_CHANGE_PATH
;
; PURPOSE:
;       This is part of the pia_control panel support routines.
; 	And therefore is designed entirely with the pia_control,
;	pia_read_ext and pia_man_mea in mind.
;	It is used for changing the path when the user click on
;	the Select File From in the pia_control or pia_read_ext.
;
; CATEGORY:
;       PIA - utilities
;
; CALLING SEQUENCE:
;       PCONT_CHANGE_PATH, WIDGET_HANDLE_ID, PAR, SEL_INDEX
;
; INPUT:
;	WIDGET_HANDLE_ID: the handle structure for the control panel
;	PAR: the parameter for the control panel
;	SEL_INDEX: the selection index for the files, where
;		0 = pipeline fits
;		1 = pia fits
;		2 = internal idl save file
;
; OUTPUT:
;
; COMMON BLOCKS:
;
; PROCEDURES USED:
;       PIA LIB:
;	  pcont_valid_dir
;	  pcont_getdirs
;	  pcont_getfiles
;	Astronomical Library:
; MODIFICATION HISTORY:
;	Written by: Wai-Ming Tai (DIAS)			March 1996
;	Extension with PFITDIR (CG)			October 1997
;	V6.5
;
;-
;------------------------------------------------------------------------
; change path when user click on the Select Files from:
;------------------------------------------------------------------------
pro pcont_change_path, id, par, sel_index

; obtain the path
  widget_control, id.hpathtxt(sel_index), get_value = newpath

  newpath = newpath(0)

; we want to get rid of the trailing / in the path name
  len = STRLEN(newpath) - 1
  IF STRPOS(newpath, '/', len) NE -1 THEN $
    newpath = STRMID(newpath, 0, len)

; we call the pcont_valid_dir to validate the directory
  IF (pcont_valid_dir(newpath(0))) THEN BEGIN
    here = newpath(0) + par.separator
; let's cd to that directory
    CD, here

; get the file filter and gather the files
    widget_control, id.hfilt, get_uvalue = filt
    files = pcont_getfiles(filt(0))

; get the subdirectory
    par.pathtxt(sel_index) = here
    directories = pcont_getdirs()

; set the system variable
; this set the fitdir or xdrdir
    CASE sel_index OF
     0: !FITDIR = here
     1: !PFITDIR = here 
     2: !xdrdir = here 
     ELSE:
    ENDCASE
;
    WIDGET_CONTROL, id.hpathtxt(sel_index), set_uvalue = here
    WIDGET_CONTROL, id.hpathtxt(sel_index), set_value = here
    WIDGET_CONTROL, id.hfiles, SET_VALUE = files
    WIDGET_CONTROL, id.hfiles, SET_UVALUE = files
    WIDGET_CONTROL, id.hsubdir, SET_VALUE = directories
    WIDGET_CONTROL, id.hsubdir, SET_UVALUE = directories
  ENDIF ELSE BEGIN
    msg = 'Warning: Directory does not exist!'
    pcont_msgline, msg, id.hmsgline
    WIDGET_CONTROL, id.hpathtxt(sel_index), SET_VALUE = par.pathtxt(sel_index)
  ENDELSE
end
