;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PCONT_CLRBUF
;
; PURPOSE:
;       This is part of the pia_control panel support routines.
; 	And therefore is designed entirely with the pia_control,
;	pia_man_mea in mind.
;	It is used for clearing the measurement buffer
;
; CATEGORY:
;       PIA - utilities
;
; CALLING SEQUENCE:
;       PCONT_CLRBUF, ID, MEA_PAR, MEALIST
;
; INPUT:
;	ID: the structure for the widget handle, mainly for pia_control
;		pia_man_mea
;	MEA_PAR: the measurement parameter
;	MEALIST: the measurement list
;
; OUTPUT:
;
; COMMON BLOCKS:
;
; PROCEDURES USED:
;       PIA LIB:
;	  yes_no
;	  erd_init
;	  srd_init
;	  smc_init
;	  scp_init
;	  spd_init
;	  cla_init
;	  cs_init
;	Astronomical Library:
; MODIFICATION HISTORY:
;	Written by: Wai-Ming Tai (DIAS)			March 1996
;	Modified (last) by CG 				October 1996
;	V5.x
;	Choice on meas to be deleted included (CG)	May 1997
;	V6.3
;
;-
pro pcont_clrbuf, id, mea_par, mealist

@pia_on_line
; Well better be safe than sorry, we asked if the user really want
; to do that.
;	msg = 'Are you sure to clear the ' + mea_par.thedtype + $
;		' buffer?'
;	res = yes_no(msg)


; only proceed if the user press the yes button
;	if res EQ 1 then begin

	case mea_par.thedtype of
	  'ERD': BEGIN
	     measnames = pickmeas(FTYPE="ERD", DTYPE=mea_par.thedet, /multi, $
	          posi=posi)
	     IF measnames(0) EQ '' THEN RETURN
	      meas = 0L

              FOR I=0,N_ELEMENTS(measnames) - 1 DO BEGIN
	  	measadd = WHERE(phterd.admn EQ measnames(I),n)
	        IF n GT 1 THEN measadd = measadd(posi(i))
		meas = [meas,measadd(0)]
	      ENDFOR
	      
	      erd_init, index=meas(1:*)
	   END
	  'SRD': BEGIN
	     measnames = pickmeas(FTYPE="SRD", DTYPE=mea_par.thedet, /multi, $ 
	          posi=posi)
	     IF measnames(0) EQ '' THEN RETURN
	      meas = 0L

              FOR I=0,N_ELEMENTS(measnames) - 1 DO BEGIN
	  	measadd = WHERE(phtsrd.admn EQ measnames(I),n)
	        IF n GT 1 THEN measadd = measadd(posi(i))
		meas = [meas,measadd(0)]
	      ENDFOR
	      
	      srd_init, index=meas(1:*)
	   END
	  'SMC': smc_init, index=meas(1:*)
	  'SCP': BEGIN
	     measnames = pickmeas(FTYPE="SCP", DTYPE=mea_par.thedet, /multi, $ 
	          posi=posi)
	     IF measnames(0) EQ '' THEN RETURN
	      meas = 0L

              FOR I=0,N_ELEMENTS(measnames) - 1 DO BEGIN
	  	measadd = WHERE(phtscp.admn EQ measnames(I),n)
	        IF n GT 1 THEN measadd = measadd(posi(i))
		meas = [meas,measadd(0)]
	      ENDFOR
	      
	      scp_init, index=meas(1:*)
	   END
	  'SPD': BEGIN
	     measnames = pickmeas(FTYPE="SPD", DTYPE=mea_par.thedet, /multi, $
	          posi=posi)
	     IF measnames(0) EQ '' THEN RETURN
	      meas = 0L

              FOR I=0,N_ELEMENTS(measnames) - 1 DO BEGIN
	  	measadd = WHERE(phtspd.admn EQ measnames(I),n)
	        IF n GT 1 THEN measadd = measadd(posi(i))
		meas = [meas,measadd(0)]
	      ENDFOR
	      
	      spd_init, index=meas(1:*)
	   END
	  'CLA': BEGIN
	     measnames = pickmeas(FTYPE="CLA", DTYPE=mea_par.thedet, /multi, $
	          posi=posi)
	     IF measnames(0) EQ '' THEN RETURN
	      meas = 0L

              FOR I=0,N_ELEMENTS(measnames) - 1 DO BEGIN
	  	measadd = WHERE(phtcla.admn EQ measnames(I),n)
	        IF n GT 1 THEN measadd = measadd(posi(i))
		meas = [meas,measadd(0)]
	      ENDFOR
	      
	      cla_init, index=meas(1:*)
	   END
	  'AAP': BEGIN
	     measnames = pickmeas(FTYPE="AAP", DTYPE=mea_par.thedet, /multi, $
	          posi=posi)
	     IF measnames(0) EQ '' THEN RETURN
	      meas = 0L

              FOR I=0,N_ELEMENTS(measnames) - 1 DO BEGIN
	  	measadd = WHERE(phtaap.admn EQ measnames(I),n)
	        IF n GT 1 THEN measadd = measadd(posi(i))
		meas = [meas,measadd(0)]
	      ENDFOR
	      
	      aap_init, index=meas(1:*)
	   END
	  'AAR': BEGIN
	     measnames = pickmeas(FTYPE="AAR", DTYPE=mea_par.thedet, /multi, $
	          posi=posi)
	     IF measnames(0) EQ '' THEN RETURN
	      meas = 0L

              FOR I=0,N_ELEMENTS(measnames) - 1 DO BEGIN
	  	measadd = WHERE(phtaar.admn EQ measnames(I),n)
	        IF n GT 1 THEN measadd = measadd(posi(i))
		meas = [meas,measadd(0)]
	      ENDFOR
	      
	      aar_init, index=meas(1:*)
	   END
	  'CS':  cs_init
	else:	
	endcase

	mealist = ''
	mea_par.themea = ''

	msg = 'Measurements: ( No measurements in the ' + $
	  mea_par.thedtype + ' buffer)'
    	widget_control, id.hmsgline, set_value = msg
    	widget_control, id.hmeainfo, set_value = 'Measurements:'
	widget_control, id.hmealist, set_value = ['']

	msg = mea_par.thedtype + ' buffer has been cleared!'
	pcont_msgline, msg, id.hmsgline
;	endif
end
