;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PCONT_GETDIRS
;
; PURPOSE:
;       This is part of the pia_control panel support routines.
; 	And therefore is designed entirely with the pia_control,
;	pia_read_ext and pia_man_mea in mind.
;	It is used for getting the subdirectory.
;
; CATEGORY:
;       PIA - utilities
;
; CALLING SEQUENCE:
;       PCONT_GETDIRS
;
; INPUT:
; OUTPUT:
;
; COMMON BLOCKS:
;
; PROCEDURES USED:
;       PIA LIB:
;	Astronomical Library:
; MODIFICATION HISTORY:
;	Written by: Wai-Ming Tai (DIAS)			March 1996
;
;-
;------------------------------------------------------------------------------ 
;       procedure GETDIR 
;------------------------------------------------------------------------------ 
; This routine finds the files or directories at the current directory level. 
; It must be called with either files or directories as a keyword. 
;------------------------------------------------------------------------------ 
 
function pcont_getdirs 
 
WIDGET_CONTROL, /HOUR 
 
IF (!VERSION.OS EQ "vms") THEN BEGIN                    ;version is VMS who's 
  retval = ['[-]'] 
  results = findfile("*.DIR")                           ;directories have an 
  IF(KEYWORD_SET(results)) THEN BEGIN                   ;extension of ".dir" 
    endpath = STRPOS(results(0), "]", 0) + 1 
    results = strmid(results, endpath, 100) 
    dirs = WHERE(STRPOS(results, ".DIR", 0) NE -1, found) 
    IF (found GT 0) THEN BEGIN 
      results = results(dirs) 
      retval = [retval, results] 
    ENDIF 
  ENDIF 
ENDIF ELSE IF !VERSION.OS EQ "windows" THEN BEGIN 
  message,"Unsupported on this platform" 
ENDIF ELSE BEGIN 
  retval = ['../'] 
  SPAWN, "ls -laL", results ,/sh   ;use /sh and added -a switch to get .* dirs 
  numfound = N_ELEMENTS(results) 
  IF(KEYWORD_SET(results)) THEN BEGIN                   ;extension of ".dir" 
    firsts = STRUPCASE(STRMID(results, 0, 1)) 
    dirs = (where(firsts EQ "D", found)) 
    IF (found GT 0) THEN BEGIN 
      results = results(dirs) 
      spaceinds = WHERE(BYTE(results(0)) EQ 32) 
      spaceindex = spaceinds(N_ELEMENTS(spaceinds)-1) 
      retval = [retval, STRMID(results, spaceindex + 1, 100)] 
 
    ; get rid of "." and ".." that ls -laL picks up 
      retval = retval(WHERE( (retval ne '.')and(retval ne '..')) )   
 
    ENDIF 
  ENDIF 
ENDELSE 
RETURN, retval 
END ; function pcont_getdirs 
 
