;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PCONT_GETFILES
;
; PURPOSE:
;       This is part of the pia_control panel support routines.
; 	And therefore is designed entirely with the pia_control,
;	pia_read_ext and pia_man_mea in mind.
;	It is used for getting the files with a given file filter.
;
; CATEGORY:
;       PIA - utilities
;
; CALLING SEQUENCE:
;       PCONT_GETFILES, FILTER
;
; INPUT:
;	FILTER: the file filter
; OUTPUT:
;
; COMMON BLOCKS:
;
; PROCEDURES USED:
;       PIA LIB:
;	Astronomical Library:
; MODIFICATION HISTORY:
;	Written by: Wai-Ming Tai (DIAS)			March 1996
;	KEYWORD Sort added (CG)				February 1998
;	V7.1
;
;-
;------------------------------------------------------------------------------ 
 
FUNCTION pcont_getfiles, filter, NOSORT=NOSORT 
 
WIDGET_CONTROL, /HOUR 
 
IF (!VERSION.OS EQ "vms") THEN BEGIN 
  results = findfile(filter) 
  IF (KEYWORD_SET(results)) THEN BEGIN 
    endpath = STRPOS(results(0), "]", 0) + 1 
    results = strmid(results, endpath, 100) 
    dirs = WHERE(STRPOS(results, ".DIR", 0) EQ -1, found) 
    IF (found GT 0) THEN BEGIN 
      results = results(dirs) 
      return, results 
    ENDIF 
  ENDIF 
ENDIF ELSE IF !VERSION.OS EQ "windows" THEN BEGIN 
  message,"Unsupported on this platform" 
ENDIF ELSE BEGIN 
  SPAWN, ["/bin/sh", "-c", "ls -laL " + filter + $ 
          " 2> /dev/null"], results, /NOSHELL     ;added -a to get all files 
  IF(KEYWORD_SET(results)) THEN BEGIN 
    firsts = STRUPCASE(STRMID(results, 0, 1)) 
    fileinds = (WHERE(((firsts EQ "F") OR (firsts EQ "-") OR $ 
                       (firsts EQ "l")), found)) 
    IF (found GT 0) THEN BEGIN 
      results = results(fileinds) 
      FOR i = 0, N_ELEMENTS(results) - 1 DO BEGIN 
        spaceinds = WHERE(BYTE(results(i)) EQ 32) 
        spaceindex = spaceinds(N_ELEMENTS(spaceinds) - 1) 
        results(i) = STRMID(results(i), spaceindex + 1, 100) 
      ENDFOR 
; sort them to get the right order
      IF not KEYWORD_SET(nosort) THEN BEGIN
       res_red = LONG(STRMID(results,4,8))
       sind = bsort([res_red])
       results = results(sind)
      ENDIF
      RETURN, results 
    ENDIF 
  ENDIF 
ENDELSE 
RETURN, "" 
END 
