;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PCONT_REFRESH
;
; PURPOSE:
;       This is part of the pia_control panel support routines.
; 	And therefore is designed entirely with the pia_control,
;	pia_read_ext and pia_man_mea in mind.
;	It is used for refreshing the content of the data type
;	and the file selection box.
;
; CATEGORY:
;       PIA - utilities
;
; CALLING SEQUENCE:
;       PCONT_REFRESH, ID, SEL_PAR, PAR, SELECTION = SELECTION,
;		UPDATE = UPDATE
;
; INPUT:
;	ID: the structure for the widget handle
;	SEL_PAR: the selection parameter
;	PAR: the parameter
;	
; OUTPUT:
;
; OPTIONAL INPUT:
;	SELECTION: the selection index for the pipeline, pia fits or
;		internal idl save file. A string type!
;	UPDATE: to indicate this is just an update when user
;		click on the file type box or the detectors box
;
; COMMON BLOCKS:
;
; PROCEDURES USED:
;       PIA LIB:
;	  pcont_getfiles
;	  pcont_getdirs
;	Astronomical Library:
; MODIFICATION HISTORY:
;	Written by: Wai-Ming Tai (DIAS)			March 1996
;
;-
;------------------------------------------------------------------------
; refresh the detector box and subdirectories box
; basically, when the user select either pipeline fits, pia fits or
; internal save file exclusive button, it calls refresh with selection
; and when the user click on the detector box or the file type box
; it calls refresh with the update keyword
;------------------------------------------------------------------------
pro pcont_refresh, id, sel_par, par, selection = selection, update = update

	if keyword_set(selection) then begin
; convert the string type to int
	  sel = fix(selection)
	  handle_value, sel_par(sel), spar
	  ftype_ind = 0
	  det_ind = 0

; what I am doing here is to preserve the selection in the file type
; and the detectors when I change the select files from box, except
; when the detector is P as in the pipeline erd, p detectors are
; one selection and for others, they are seperate.
; so it is just inherit the P1 for the pia fits and internal

	  tmp = where(spar.filetype EQ par.theftype, matches)
	  if matches GT 0 then ftype_ind = tmp(0)
; just ignore the P detecor
	  if par.thedet NE 'P1, P2, P3' then begin
	    tmp = where(spar.detectors EQ par.thedet, matches)
	    if matches GT 0 then det_ind = tmp(0)
	  endif
	  filter = spar.filters(spar.nftype * ftype_ind + det_ind)
	  cd, par.pathtxt(sel)
	  filelist = pcont_getfiles(filter)
          directories = pcont_getdirs()

	  widget_control, id.hfilt, set_uvalue = filter
	  widget_control, id.hfiles, set_uvalue = filelist
	  widget_control, id.hftype, set_uvalue = spar.filetype
	  widget_control, id.hdet, set_uvalue = spar.detectors
          WIDGET_CONTROL, id.hsubdir, SET_UVALUE = directories

; create the array for displaying the pathtxt
	  tmppath = intarr(3)
	  tmppath(sel) = 1
	  widget_control, id.hpathtxt(0), sensitive = tmppath(0)
	  widget_control, id.hpathtxt(1), sensitive = tmppath(1)
	  widget_control, id.hpathtxt(2), sensitive = tmppath(2)
	  widget_control, id.hftype, set_value = spar.filetype
	  widget_control, id.hdet, set_value = spar.detectors
	  widget_control, id.hfilt, set_value = filter
          WIDGET_CONTROL, id.hsubdir, SET_VALUE = directories
	  widget_control, id.hfiles, set_value = filelist
	  widget_control, id.hftype, set_list_select = ftype_ind
	  widget_control, id.hdet, set_list_select  = det_ind
	  widget_control, id.hfilerow, set_value = ''
	  widget_control, id.hfilecol, set_value = ''
	  par.sel_index = sel
	  par.theftype = spar.filetype(ftype_ind)
	  par.thedet = spar.detectors(det_ind)
 	  par.ftype_index = ftype_ind
	  par.det_index = det_ind
	endif
	if keyword_set(update) then begin
; update is called when the user click on the file type box or
; the detectors box.
	  handle_value, sel_par(par.sel_index), spar
	  filter = spar.filters(spar.nftype * par.ftype_index + $
		par.det_index)
	  filelist = pcont_getfiles(filter)
	  widget_control, id.hfilt, set_uvalue = filter
	  widget_control, id.hfiles, set_uvalue = filelist
	  widget_control, id.hdet, set_uvalue = spar.detectors
	  widget_control, id.hfilt, set_value = filter
	  widget_control, id.hfiles, set_value = filelist
	endif
end
