;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PCONT_SAVEFITS
;
; PURPOSE:
;       This is part of the pia_control panel support routines.
; 	And therefore is designed entirely with the pia_control,
;	pia_read_ext and pia_man_mea in mind.
;	It is used for saving the measurement to the fits file
;
; CATEGORY:
;       PIA - utilities
;
; CALLING SEQUENCE:
;       PCONT_SAVEFITS, ID, DATATYPE, MLIST_INDEX, MEALIST
;
; INPUT:
;	ID: the structure for the widget handle
;	DATATYPE: the data type
;	MLIST_INDEX: the index of the selected measurement 
;	MEALIST: the measurement list
; OUTPUT:
;
; COMMON BLOCKS:
;	  phtsrd
;	  phtscp
;	  phtspd
;	  phtsmc
;
; PROCEDURES USED:
;       PIA LIB:
;	  pia_load_isrd
;	  pia_load_iscp
;	  pia_load_ispd
;	  pia_sm_load_ismc
;	  write_srd
;	  write_scp
;	  write_spd
;	  write_smc
;	  write_srd
;	  pia_pickfile
;	  pcont_msgline
;	Astronomical Library:
; MODIFICATION HISTORY:
;	Written by: Wai-Ming Tai (DIAS)			March 1996
;       Modified by Stefan Bogun (MPIA)			August 1996
;	V5.x	
;	pia_pickfile1 replaced (CG)			February 1999 
;	V7.4
;
;-
pro pcont_savefits, id, datatype, mlist_index, mealist
@phtsrd
@phtsmc
@phtscp
@phtspd
@phtaap

	case datatype of
	'SRD': begin
		pia_load_isrd, phtsrd(mealist(mlist_index).index), $
		  tmpdata

		tfile = tmpdata.admn + '_SRD.FITS'
		filename = pia_pickfile(file = tfile, $
		  path = !intdir, filter='*_SRD.FITS', get_path=newpath,$
		  /write, /overwrite)

		if filename NE '' then begin

;		  if newpath NE '' then filename = newpath + filename $
;		  else filename = !INTDIR + filename

		  write_srd, tmpdata, filename = filename
		endif

	       end
	'SMC': begin
		pia_sm_load_ismc, phtsmc(mealist(mlist_index).index), $
		tmpdata

		tfile = 'P2SM' + strmid(tmpdata.admn,4,8) + '.FITS'
		filename = pia_pickfile(file = tfile, $
		  path = !intdir, filter='P2SM*.FITS', get_path=newpath,$
		  /write, /overwrite)

		if filename NE '' then begin

;		  if newpath NE '' then filename = newpath + filename $
;		  else filename = !INTDIR + filename

		  write_smc, tmpdata
		endif
 
	       end
	'SCP': begin
		pia_load_iscp, phtscp(mealist(mlist_index).index), $
		tmpdata

		tfile = tmpdata.admn + '_SCP.FITS'
		filename = pia_pickfile(file = tfile, $
		  path = !intdir, filter='*_SCP.FITS', get_path=newpath,$
		  /write, /overwrite)

		if filename NE '' then begin

;		  if newpath NE '' then filename = newpath + filename $
;		  else filename = !INTDIR + filename

		  write_scp, tmpdata, filename=filename
		endif
 
	       end
	'SPD': begin
		pia_load_ispd, phtspd(mealist(mlist_index).index), $
		tmpdata

		tfile = tmpdata.admn + '_SPD.FITS'
		filename = pia_pickfile(file = tfile, $
		  path = !intdir, filter='*_SPD.FITS', get_path=newpath,$
		  /write, /overwrite)

		if filename NE '' then begin

;		  if newpath NE '' then filename = newpath + filename $
;		  else filename = !INTDIR + filename

  	  	  write_spd, tmpdata, filename=filename
		endif

	       end
	'AAP': begin
		pia_load_iaap, phtaap(mealist(mlist_index).index), $
		   tmpdata

		IF STRMID(tmpdata.det,0,1) NE 'S' THEN BEGIN
		     MESSAGE, /INFO,'Only implemented for PHT-S so far, returning'
		     RETURN
		ENDIF

		tfile = tmpdata.admn + '_AAP.FITS'
		filename = pia_pickfile(file = tfile, $
		  path = !intdir, filter='*_AAP.FITS', get_path=newpath,$
		  /write, /overwrite)

		if filename NE '' then begin

;		  if newpath NE '' then filename = newpath + filename $
;		  else filename = !INTDIR + filename

  	  	  write_aap_SL, tmpdata, filename=filename
		endif

	       end
	ELSE: 
	endcase

	msg = 'File: '+ filename + ' has been saved'
 	pcont_msgline, msg, id.hmsgline
end
