;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PCONT_SAVEINT
;
; PURPOSE:
;       This is part of the pia_control panel support routines.
; 	And therefore is designed entirely with the pia_control,
;	pia_read_ext and pia_man_mea in mind.
;	It is used for saving the measurement to the internal IDL
;	save file.
;
; CATEGORY:
;       PIA - utilities
;
; CALLING SEQUENCE:
;       PCONT_SAVEINT, ID, DATATYPE, MEA_INDEX, MEALIST
;
; INPUT:
;	ID: the structure for the widget handle
;	DATATYPE: the data type
;       MEA_INDEX: the index of the selected measurement 
;       MEALIST: the measurement list
; OUTPUT:
;
; KEYWORDS:
;	NO_BUFCONT: 	set if call not coming from buffer control
;	TMPDATA:	the structure to be saved if not using buffer control
;
; COMMON BLOCKS:
;         phtsrd
;         phtscp
;         phtspd
;         phtsmc
;	  phterd
;	  phtcs
;
; PROCEDURES USED:
;       PIA LIB:
;	  pia_load_ierd
;	  pia_load_isrd
;	  pia_load_iscp
;	  pia_load_ismc
;	  pia_load_ispd
;	  pia_load_ics
;	  pia_load_idrift
;	  pia_load_idynresp
;	  pia_write_ics
;	  pia_pickfile
;	  pcont_msgline
;	Astronomical Library:
; MODIFICATION HISTORY:
;	Written by: Wai-Ming Tai (DIAS)			March 1996
;	Save phtaap added (CG)				June 1996
;       SMD out, SMC int (SB)                           August 1996
;	Message added to SCP level, 
;	 keyword NO_BUFCONT added +
;	 saving for drift structure (CG)		May 1997
;	V6.3
;	pia_pickfile1 replaced (CG)			February 1999
;	V7.4
;	Saving phtdynresp included (JAcosta)		February 2000
;	V8.2
;
;-
;------------------------------------------------------------------------
; save the measurement to internal files
;------------------------------------------------------------------------
pro pcont_saveint, id, datatype, mea_index, mealist, tmpdata=tmpdata, $
	mnam=mnam
@phterd
@phtsrd
@phtsmc
@phtscp
@phtspd
@phtaap
@phtdrift
@phtdynresp
@phtcs

  IF KEYWORD_SET(tmpdata) THEN BEGIN 
    no_bufcont=1
    filen = tmpdata.admn 
  ENDIF ELSE BEGIN
    no_bufcont=0
    filen = mealist(mea_index).uname
  ENDELSE
; forcing a name through a keyword  
  IF KEYWORD_SET(mnam) THEN filen = mnam 

  case datatype of
    'ERD': begin
           tfile = filen + '.IERD'
           filename = pia_pickfile(file = tfile, $
             path = !intdir, filter='*.IERD', get_path=newpath,$
             /write, /overwrite)
           if filename NE '' then begin
	     IF KEYWORD_SET(tmpdata) THEN phtierd=tmpdata ELSE $
              pia_load_ierd, phterd(mealist(mea_index).index), $
               phtierd 
             save, phtierd, file=filename, /xdr
	     msg = 'File: '+ filename + ' has been saved'
	     IF NOT no_bufcont THEN pcont_msgline, msg, id.hmsgline
           endif
           end
    'SRD': begin
           tfile = filen + '.ISRD'
           filename = pia_pickfile(file = tfile, $
           path = !intdir, filter='*.ISRD', get_path=newpath,$
             /write, /overwrite)
           if filename NE '' then begin
	     IF KEYWORD_SET(tmpdata) THEN phtisrd=tmpdata ELSE $
             pia_load_isrd, phtsrd(mealist(mea_index).index), $
               phtisrd
             save, phtisrd, file=filename, /xdr
	     msg = 'File: '+ filename + ' has been saved'
	     IF NOT no_bufcont THEN pcont_msgline, msg, id.hmsgline
           endif
           end
     'DRIFT': begin
           tfile = filen + '.IDRIFT'
           filename = pia_pickfile(file = tfile, $
           path = !intdir, filter='*.IDRIFT', get_path=newpath,$
             /write, /overwrite)
           if filename NE '' then begin
	     IF KEYWORD_SET(tmpdata) THEN phtidrift=tmpdata ELSE $
             pia_load_idrift, phtdrift(mealist(mea_index).index), $
               phtidrift
             save, phtidrift, file=filename, /xdr
	     msg = 'File: '+ filename + ' has been saved'
	     IF NOT no_bufcont THEN pcont_msgline, msg, id.hmsgline
           endif
           end
     'DYNR': begin
           tfile = filen + '.IDYNR'
           filename = pia_pickfile(file = tfile, $
           path = !intdir, filter='*.IDYNR', get_path=newpath,$
             /write, /overwrite)
           if filename NE '' then begin
	     IF KEYWORD_SET(tmpdata) THEN phtidrift=tmpdata ELSE $
             pia_load_idynresp, phtdynresp(mealist(mea_index).index), $
               phtidynresp
             save, phtidynresp, file=filename, /xdr
	     msg = 'File: '+ filename + ' has been saved'
	     IF NOT no_bufcont THEN pcont_msgline, msg, id.hmsgline
           endif
           end
   'SMC': begin
           tfile = filen + '.ISMC'
           filename = pia_pickfile(file = tfile, $
           path = !intdir, filter='*.ISMC', get_path=newpath,$
             /write, /overwrite)
           if filename NE '' then begin
;             if newpath NE '' then filename = newpath + filename	
	     IF KEYWORD_SET(tmpdata) THEN phtismc=tmpdata ELSE $
             pia_sm_load_ismc, phtsmc(mealist(mea_index).index), $
               phtismc
             save, phtismc, file=filename, /xdr
	     msg = 'File: '+ filename + ' has been saved'
	     IF NOT no_bufcont THEN pcont_msgline, msg, id.hmsgline
           endif
           end
    'SCP': begin
           tfile = filen + '.ISCP'
           filename = pia_pickfile(file = tfile, $
           path = !intdir, filter='*.ISCP', get_path=newpath,$
             /write, /overwrite)
           if filename NE '' then begin
	     IF KEYWORD_SET(tmpdata) THEN phtiscp=tmpdata ELSE $
             pia_load_iscp, phtscp(mealist(mea_index).index), $
               phtiscp
             save, phtiscp, file=filename, /xdr
	     msg = 'File: '+ filename + ' has been saved'
	     IF NOT no_bufcont THEN pcont_msgline, msg, id.hmsgline
           endif
           end
    'SPD': begin
           tfile = filen + '.ISPD'
           filename = pia_pickfile(file = tfile, $
           path = !intdir, filter='*.ISPD', get_path=newpath,$
             /write, /overwrite)
           if filename NE '' then begin
	     IF KEYWORD_SET(tmpdata) THEN phtispd=tmpdata ELSE $
             pia_load_ispd, phtspd(mealist(mea_index).index), $
               phtispd
             save, phtispd, file=filename, /xdr
	     msg = 'File: '+ filename + ' has been saved'
	     IF NOT no_bufcont THEN pcont_msgline, msg, id.hmsgline
           endif
           end
    'AAP': begin
           tfile = filen + '.IAAP'
           filename = pia_pickfile(file = tfile, $
           path = !intdir, filter='*.IAAP', get_path=newpath,$
             /write, /overwrite)
           if filename NE '' then begin
	     IF KEYWORD_SET(tmpdata) THEN phtiaap=tmpdata ELSE $
             pia_load_iaap, phtaap(mealist(mea_index).index), $
               phtiaap
             save, phtiaap, file=filename, /xdr
	     msg = 'File: '+ filename + ' has been saved'
	     IF NOT no_bufcont THEN pcont_msgline, msg, id.hmsgline
           endif
           end
   ELSE:
   endcase

; filename empty means the user press cancel or the given filename is
; empty
   if filename NE '' then begin
     ; change !INTDIR to newpath
     !INTDIR = newpath
     admn = tfile
     indcs = WHERE(phtcs.unit EQ STRMID(admn,4,8), count)

     IF count GT 0 THEN BEGIN
       PIA_LOAD_ICS, phtcs(indcs(0)), tmpcs
       PIA_WRITE_ICS, tmpcs, path = newpath
     ENDIF ELSE BEGIN 
       IF NOT no_bufcont THEN pcont_msgline, $
        'Compact Status not found in common, not saved', id.hmsgline ELSE $
        PRINT, 'Compact Status not found in common, not saved'
     ENDELSE
     endif
end
