;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PCONT_UPDATEMEA
;
; PURPOSE:
;       This is part of the pia_control panel support routines.
; 	And therefore is designed entirely with the pia_control,
;	pia_read_ext and pia_man_mea in mind.
;	It is used for updating the measurement list
;
; CATEGORY:
;       PIA - utilities
;
; CALLING SEQUENCE:
;       PCONT_UPDATEMEA, DATATYPE, DET, ID, MEA_PAR, MEALIST
;
; INPUT:
;	ID: the structure for the widget handle
;	DATATYPE: the datatype
;	DET: the detectors
;	MEA_PAR: the measurement parameter
;	MEALIST: the measurement list
; OUTPUT:
;
; COMMON BLOCKS:
;	  phterd
;	  phtsrd
;	  phtscp
;	  phtspd
;	  phtsmc
;	  phtcla
;
; PROCEDURES USED:
;       PIA LIB:
;	  decode_tdt2mea
;	  decode_hdr2mea
;	  decode_cs2mea
;	Astronomical Library:
; MODIFICATION HISTORY:
;	Written by: Wai-Ming Tai (DIAS)			March 1996
;       Modified by Stefan Bogun (MPIA)			August 1996
;	V5.x	
;-
;-----------------------------------------------------------------
; update the measurement list either:
; - when user read in the files
; - when user select the data type
; - when user select the detector
;-----------------------------------------------------------------
pro pcont_updatemea, datatype, det, decodeflag, id, mea_sel_par, mealist
@phterd
@phtsrd
@phtscp
@phtspd
@phtsmc
@phtaap
@phtaar
@phtcla

  case datatype of
    'ERD': begin
	admn = phterd.admn
	hdr  = phterd.hdr
	end
    'SRD': begin
	admn = phtsrd.admn
	hdr  = phtsrd.hdr
	end
    'SCP': begin
	admn = phtscp.admn
	hdr  = phtscp.hdr
	end
    'SPD': begin
	admn = phtspd.admn
	hdr  = phtspd.hdr
	end
    'SMC': begin
	admn = phtsmc.admn
	hdr  = phtsmc.hdr
	end
    'AAP': begin
	admn = phtaap.admn
	hdr  = phtaap.hdr
	end
    'AAR': begin
	admn = phtaar.admn
	hdr  = phtaar.hdr
	end
    'CLA': begin
           admn = phtcla.admn
	   hdr = phtcla.hdr
           end
    ELSE:
  endcase

  msg = 'Measurements: ( NO measurements in the ' + $
	  datatype + ' buffer)'
  msginfo = 'Measurements:'
  list = ['']
  nbuf = n_elements(admn) - 1

  if (nbuf gt 0) and ( det EQ 'ALL' ) then $
    ind = indgen(nbuf) + 1 $
  else ind = where(strmid(admn, 0, 2) EQ strmid(det, 0, 2), nbuf) 

  if nbuf gt 0 then begin
    mealist = replicate({ mea, index: 0, filename: '', decodename: '',  $
		uname: '' }, nbuf)

    if decodeflag GT 0 then begin
      for i = 0, nbuf - 1 do begin
        mealist(i).index = ind(i)
        mealist(i).filename = admn(ind(i))
        decode_tdt2mea, mealist(i).filename, strl
        handle_value, hdr(ind(i)), tmphdr
        decode_hdr2mea, tmphdr, strl2, nname, ADMN= admn(ind(i))
        ; write the header back if the PIA_MNAM has been included
        handle_value, hdr(ind(i)), tmphdr,/set
        decode_cs2mea, mealist(i).filename, strl1
        mealist(i).uname = nname
      
        mealist(i).decodename = strl +': ' + strl1 + ', ' + strl2 + ', ' + nname
      endfor
    endif else begin
      for i = 0, nbuf - 1 do begin
        mealist(i).filename = admn(ind(i))
        decode_tdt2mea, mealist(i).filename, strl
        handle_value, hdr(ind(i)), tmphdr
        decode_hdr2mea, tmphdr, strl1, nname, ADMN= admn(ind(i))
        ; write the header back if the PIA_MNAM has been included
        handle_value, hdr(ind(i)), tmphdr,/set
        mealist(i).decodename = strl +': ' + strl1+ ', ' + nname
        mealist(i).index = ind(i)
      endfor
    endelse
    
    msginfo = strtrim(string(nbuf), 2) + ' measurements'
    msg = 'Measurements: (' + strtrim(string(nbuf),2) + $
	  ' measurements in the ' + datatype+ ' buffer)'
    list = mealist.decodename
  endif 
;  if mea_sel_par.thedet EQ 'PG' or STRMID(mea_sel_par.thedtype,0,2) eq 'AA' $
;  	then widget_control, id.hmeaplot, sensitive = 0 $
  if mea_sel_par.thedet EQ 'PG'  $
  	then widget_control, id.hmeaplot, sensitive = 0 $
  else widget_control, id.hmeaplot, sensitive = 1
  widget_control, id.hmeainfo, set_value = msginfo
  widget_control, id.hmealist, set_value = list
  widget_control, id.hmsgline, set_value = msg
end
