;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PCONT_VALID_DIR
;
; PURPOSE:
;       This is part of the pia_control panel support routines.
; 	And therefore is designed entirely with the pia_control,
;	pia_read_ext and pia_man_mea in mind.
;	It is used for checking if a directory is valid
;
; CATEGORY:
;       PIA - utilities
;
; CALLING SEQUENCE:
;       PCONT_VALID_DIR, DIR
;
; INPUT:
;	DIR: directory path
; OUTPUT:
;
; COMMON BLOCKS:
;
; PROCEDURES USED:
;       PIA LIB:
;	Astronomical Library:
; MODIFICATION HISTORY:
;	Written by: Wai-Ming Tai (DIAS)			March 1996
;
;-
FUNCTION pcont_valid_dir, dir 
  WIDGET_CONTROL, /HOUR 
  CASE !VERSION.OS OF 
 
  'vms': BEGIN 
            CD, current = here   ; get pwd

       ; VMS directories can be files, NAME.DIR, or paths DEVICE:[NAME.NAME].
       ; If the "[]" method is used, tack on a wildcard spec (*.*), otherwise
       ; the value of dir is a filename and it can remain the same.

            if(strpos(dir,']') gt -1)then dir = dir + "*.*" 
            context = 0L 
            resultant = STRING(BYTARR(256)+32B) 

       ; See if either Name.dir file exists in the current directory or
       ; if a path specified see if there is any files in that dir.
       ; Use vms LIB$ routines via Call External

            result = CALL_EXTERNAL("LIBRTL", "LIB$FIND_FILE", dir, resultant,$
		 context, here, 0L, 0L, 0L, VALUE = [0, 0, 0, 0, 1, 1, 1]) 
            toss = CALL_EXTERNAL("LIBRTL", "LIB$FIND_FILE_END", context) 

            RETURN, (result EQ 65537) 
         END 
  'windows': BEGIN 
            RETURN,1    ; Hook into common dialogs for windows 
                        ; when this really works. 
         END 
  ELSE:  BEGIN 
      ; Can't CD to a directory unless the user has execute permission.  
      ; Use the unix command test to check this. Have to use sh5 on ultrix 
      ; Test sets the shell status variable and echo prints it out. This is  
      ; then captured by spawn and placed in result 
 
        if(!version.os ne 'ultrix')then $ 
            spawn, ['test -d '+dir +' -a -x '+dir+' ; echo $?'], result, /sh $ 
        else $ 
            spawn, ['/bin/sh5 -c "test -d '+dir+' -a -x '+dir+' ";echo $?'], $ 
                   result, /sh 
 
        return, (not fix(result(0)) )  ;convert result to int and NOT it. 
 
      END 
  ENDCASE 
END 
