;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PCONT_VIEWHDR
;
; PURPOSE:
;       This is part of the pia_control panel support routines.
; 	And therefore is designed entirely with the pia_control,
;	pia_read_ext and pia_man_mea in mind.
;	It is used for viewing the external fits header
;
; CATEGORY:
;       PIA - utilities
;
; CALLING SEQUENCE:
;       PCONT_VIEWHDR, SELECTION, ID, FILETYPE, FILENAME, GROUP=GROUP
;
; INPUT:
;	ID: the structure for the widget handle
;	SELECTION: the selection for pipeline, pia fits or internal
;	FILETYPE: the file type
;	FILENAME: the filename
;	
; OPTIONAL INPUT:
;	GROUP: the event group
; OUTPUT:
;
; COMMON BLOCKS:
;         phtsrd
;         phtscp
;         phtspd
;         phtsmc
;	  phterd
;	  phtcla
;
; PROCEDURES USED:
;       PIA LIB:
;	  pia_view_txt
;	  pcont_msgline
;	Astronomical Library:
;	  fxhread
; MODIFICATION HISTORY:
;	Written by: Wai-Ming Tai (DIAS)			March 1996
;       Modified by Stefan Bogun (MPIA)			August 1996
;	V5.x	
;
;-
;------------------------------------------------------------------------
; view the fits header from the fits file
;------------------------------------------------------------------------
pro pcont_viewhdr, selection, id, filetype, filename, group = group
@phterd
@phtsrd
@phtscp
@phtspd
@phtsmc
@phtaap
@phtcla

  if selection GT 1 then begin

    on_ioerror, print_error
    restore, filename
    case filetype of
      'ERD': hdr = phtierd.hdr
      'SRD': hdr = phtisrd.hdr
      'SMC': hdr = phtismc.hdr
      'SCP': hdr = phtiscp.hdr
      'SPD': hdr = phtispd.hdr
      'CLA': hdr = phticla.hdr
      ELSE:  pcont_msgline, 'Select "ALL" in the "file type" could not invoke this function', id.hmsgline
    endcase
    if filetype NE 'ALL' then $
      pia_disp_print_file, '', TEXT=hdr, title="FITS Header View", $
       group = group

; end of reading the internal file fits header
; start the external fits header

  endif else begin

    read_fits_header, filename, hdr, status
    if status EQ 0 then $
      pia_disp_print_file, '', TEXT=hdr, title="FITS Header View", $
       group = group

  endelse
return
	
print_error:
  msg = "!!! Unable to open file or file is the wrong type"
  pcont_msgline, msg, id.hmsgline
  return
end
