;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PCONT_VMEAHDR
;
; PURPOSE:
;       This is part of the pia_control panel support routines.
; 	And therefore is designed entirely with the pia_control,
;	pia_read_ext and pia_man_mea in mind.
;	It is used for viewing the measurement's fits header
;
; CATEGORY:
;       PIA - utilities
;
; CALLING SEQUENCE:
;       PCONT_VMEAHDR, THEMEA, DET, GROUP=GROUP
;
; INPUT:
;	THEMEA: index of the measurement in the relevant structure
;	DET: the detector type
;	
; KEYWORDS:
;	GROUP: the event group
;	NAMING: the name provided by the user
;	GET: get the name provided by the user
;
; OUTPUT:
;
; COMMON BLOCKS:
;         phtsrd
;         phtscp
;         phtspd
;         phtsmc
;	  phterd
;	  phtcla
;
; PROCEDURES USED:
;       PIA LIB:
;	  pia_disp_hdr
;	Astronomical Library:
; MODIFICATION HISTORY:
;	Written by: Wai-Ming Tai (DIAS)			March 1996
;       SMD out, SMC int (SB)                           August 1996
;	Display chosen measurement fixed (CG)		May 1997
;	V6.3
;	Keyword GET added to obtain current name (JA)   December 1997
;	V6.6
;	Input argument is now the index in the array 
;	not the admn anymore (JA)			January 1998
;
;-
;------------------------------------------------------------------------
; view the measurement's fits header from the measurement buffer
;------------------------------------------------------------------------
PRO pcont_vmeahdr, themea, det, NAMING=naming, GROUP = group, GET=get
@phterd
@phtsrd
@phtscp
@phtspd
@phtsmc
@phtaap
@phtaar
@phtcla

	case det of
	  'ERD': begin
		 admn = phterd.admn
		 hdr = phterd.hdr
		 end
	  'SRD': begin
		 admn = phtsrd.admn
		 hdr = phtsrd.hdr
		 end
	  'SMC': begin
		 admn = phtsmc.admn
		 hdr = phtsmc.hdr
		 end
	  'SCP': begin
		 admn = phtscp.admn
		 hdr = phtscp.hdr
		 end
	  'SPD': begin
		 admn = phtspd.admn
		 hdr = phtspd.hdr
		 end
	  'AAP': begin
		 admn = phtaap.admn
		 hdr = phtaap.hdr
		 end
	  'AAR': begin
		 admn = phtaar.admn
		 hdr = phtaar.hdr
		 end
	  'CLA': begin
		 admn = phtcla.admn
		 hdr = phtcla.hdr
		 end
	else:
	endcase 

	IF n_elements(admn) GT 1 THEN BEGIN
	 ind = where(admn EQ admn(themea), matches)
	 IF matches NE 0 THEN BEGIN
  	  handle_value, hdr(themea), tmphdr
  	  CASE 1 OF 
  	    KEYWORD_SET(GET): BEGIN
  	        naming = FXPAR(tmphdr, 'PIA_MNAM')
  	        IF naming EQ '0' THEN naming = admn(themea)
  	    END
  	    KEYWORD_SET(naming): BEGIN
        	FXADDPAR, tmphdr, 'PIA_MNAM', naming, $
         	"Name chosen for measurement by PIA user", BEFORE='XTENSION'
  	  	handle_value, hdr(themea), $
  	  		tmphdr,/SET
  	    END		
  	    ELSE: $   
	      pia_disp_hdr, tmphdr, admn(themea), det, group=group
	    ENDCASE  
	 ENDIF
	ENDIF
end
