	PRO PHOTOM_INIT, Meas, Text, Fname, Colcor=colcor
;+
; NAME:
;	PHOTOM_INIT
;
; PURPOSE:
;	This routine takes the required values from the phtaap common
;	block and builds them into a text array.
;
; CATEGORY:
;	PIA - Processing
;
; INPUTS:
;	Meas: An array of indices corresponding to measurements within
;	      the phtaap common block
;
; KEYWORD:
;	Colcor: colour correction to be applied - Colcor must be structure
;		as defined by PIA_cc_defin
;
; OUTPUTS:
;	Text: The text array
;	Fname:  A string containing the _last_ observation TDT/Meas number
;	      in a format suitable for a filename
;
; COMMON BLOCKS:
;	phtaap
;
; PROCEDURES USED:
;	None
;
; RESTRICTIONS:
;	None
;
; MODIFICATION HISTORY:
;	Written by:	Huw Morris
;	Oct 95 Version ?.?
;	Modified by:	Huw Morris	Jan 96
;	Filters and apertures replaced by corresponding strings (CG)  Jan.96
;	Polarizer replaced by corresponding string (CG)		February 1996
;	Minor problems with output format fixed (Jacosta)	April 1997
;	Colour correction (KEYWORD colcor) included (CG)	May 1997
;	V6.3
;	Format changed (avoid problems w. neg. fluxes) (CG)	July 1997
;	V6.4
;	PHTAPERT taken now (CG)					February 1998
;	V7.0
;	Displaying apertures in arcsec's (CG)			January 2000
;	V8.2
;
;-


@phtaap
@phtfilter
@phtapert
@phtpolar
@phtslwavlen

	ON_ERROR, 0 	           ; Stay within procedure

; apertures in " only for info

	P_AS = [ 52.0, 79.0, 99.0, 120.0, 127.0, 180.0, 180.0,   $
	              5.0, 7.6, 10.0, 13.8, 18.0, 20.0, 23.0 ]

	IF KEYWORD_SET(COLCOR) THEN ccstr = colcor 
; Initialize filters & apertures
	IF N_ELEMENTS(c1filters) EQ 0 THEN phtfilter_init
	IF N_ELEMENTS(p_area) EQ 0 THEN READ_OMEGA

; Find out how many measurements there are to be displayed
	No_Meas = N_ELEMENTS(Meas) 

	Text = ' '

; Loop over each measurement in turn
	FOR i = 0, No_Meas-1 DO BEGIN

; Extract all the temporary arrays from the phtaap common block
	  admn = phtaap(Meas(i)).admn
	  filter = phtaap(Meas(i)).filt
	  det = phtaap(Meas(i)).det
	  polz = phtaap(Meas(i)).polz
	  aper = phtaap(Meas(i)).aper
	  HANDLE_VALUE, phtaap(Meas(i)).mnfl, Mnfl
	  HANDLE_VALUE, phtaap(Meas(i)).mnfu, Mnfu
	  HANDLE_VALUE, phtaap(Meas(i)).mdfl, Mdfl
	  HANDLE_VALUE, phtaap(Meas(i)).q1fl, Q1fl
	  HANDLE_VALUE, phtaap(Meas(i)).q3fl, Q3fl
	  HANDLE_VALUE, phtaap(Meas(i)).mnbr, Mnbr
	  HANDLE_VALUE, phtaap(Meas(i)).mnbu, Mnbu
	  HANDLE_VALUE, phtaap(Meas(i)).mdbr, Mdbr
	  HANDLE_VALUE, phtaap(Meas(i)).q1br, Q1br
	  HANDLE_VALUE, phtaap(Meas(i)).q3br, Q3br
	  HANDLE_VALUE, phtaap(Meas(i)).dec, Dec
	  HANDLE_VALUE, phtaap(Meas(i)).ra, Ra
	  HANDLE_VALUE, phtaap(Meas(i)).roll, Roll
	  HANDLE_VALUE, phtaap(Meas(i)).flag, Flag


; Decode the filter depending on the detector
          CASE Det OF

           'P1': Detfilt = p1filters(Filter - 1) 

           'P2': Detfilt = p2filters(Filter - 11)

	   'P3': Detfilt = p3filters(Filter - 13)

	   'C1': Detfilt = c1filters(Filter - 2)

	   'C2': Detfilt = c2filters(Filter - 9)

;PHT-S case special
	   ELSE: BEGIN
	          Detfilt = 'Unique'
		  posi = N_ELEMENTS(mnfl(0,*))
		  
	   	  IF posi GT 1 THEN BEGIN
	   	   POS = ['All positions ',$
	   	   	'Position '+STRTRIM(STRING(indgen(posi)+1),2)]
		   chosen_pos = indgen(posi+1)
	   	   PIA_MULTCHOICE, chosen_pos, elemnames=pos, xsize=200
		  ENDIF ELSE chosen_pos = 0
		  
	   	END
          ENDCASE

; Get the TDT and Measurement
          Decode_Admn, Admn, Decstr            ; Decode the administration name
          obs = Decstr

	  Fname = admn

	  IF KEYWORD_SET(colcor) AND detfilt NE 'Unique' THEN $
	    cctxt = 'Colour corrected ' ELSE cctxt = '' 
 	  Text = [Text, cctxt + 'AAP Results - ' + obs]
	  Text = [Text,'=================================================']


; Get the filter mnemonic

          filt = Detfilt
	  IF STRMID(det,0,1) EQ 'P' THEN BEGIN
	   apert = STRTRIM(STRING(format='(f5.1)',p_as(aper-1)),2) +' arcsec' 
	  	polz_id = phtpolar(polz-1)
	  ENDIF ELSE IF STRMID(det,0,1) EQ 'C' THEN BEGIN
	  	apert = 'Unique'
	  	polz_id = phtpolar(polz-11)
	  ENDIF ELSE BEGIN
	  	apert = 'Unique'
	  	polz_id =  'Unique'
	  ENDELSE                                    
; Build up a text array (1 element per line of the data contained in the
; tmpdata array

	  Line = 'Filter:  ' + filt
	  Text = [Text, Line]

	  Line = 'Aperture:  ' + apert
	  Text = [Text, Line]

	  Line = 'Polarizer:  ' + polz_id
	  Text = [Text, Line, ' ']

; Calculate the chopper plateaux in the current measurement
	  No_Chop  = N_ELEMENTS(mnfl(0,*))
	  IF No_chop GT 100 THEN BEGIN
PRINT, 'Only first 100 chopper plateaux/raster positions will be shown'
	  	No_Chop = 100
	  ENDIF

; Separate case for PHT-S
	  IF detfilt NE 'Unique' THEN BEGIN

	   IF KEYWORD_SET(colcor) THEN BEGIN
	   
			     get_cc, detfilt, ccstr.typ, $
			       ccstr.value, cc_val, error=error
			     IF NOT ERROR THEN BEGIN
				mnfl = mnfl / cc_val
				mnfu = mnfu / cc_val
				mnbr = mnbr / cc_val
				mnbu = mnbu / cc_val
				mdfl = mdfl / cc_val
				q1fl = q1fl / cc_val
				q3fl = q3fl / cc_val
				mdbr = mdbr / cc_val
				q1br = q1br / cc_val
				q3br = q3br / cc_val
			     ENDIF ELSE $
			        PRINT, detfilt + $
			         ' could not be corrected'

	   ENDIF
; Loop over each chopper plateau and pixel
	   FOR c = 0, No_Chop-1 DO BEGIN

	     Line = 'Chopper Plateau: ' + STRTRIM(string(c+1),2)
	     Text = [Text, Line, '-------------------']

	     No_Pixel = N_ELEMENTS(mnfl(*,0))
	     FOR p = 0, No_Pixel-1 DO BEGIN

;for testing purposes              
;	    print, 'i: ',i, '  c: ',c,'  p: ',p
;                                      
	    	Line = 'Pixel ' + STRTRIM(string(p+1),2) + ' Mean Flux Density:  ' $
	      + STRTRIM(string(mnfl(p,c)),2) $
	      + '  +/-  ' + STRTRIM(string(mnfu(p,c)),2) + ' Jy'
	    	Text = [Text, Line]

           	 Line = '        Median Flux Density: ' $
	      + STRTRIM(string(mdfl(p,c)),2) $
	      + '  1st Q: ' + STRTRIM(string(q1fl(p,c)),2) $
              + '  3rd Q: ' + STRTRIM(string(q3fl(p,c)),2) + ' Jy'
            	Text = [Text, Line, ' ']
                                                      
           	 Line = '        Mean Surface Brightness: ' $
	      + STRTRIM(string(mnbr(p,c)),2) $
              + '  +/-  ' + STRTRIM(string(mnbu(p,c)),2) + ' MJy/sr'
            	Text = [Text, Line]
                  
            	Line = '        Median Surface Brightness: ' $
	      + STRTRIM(string(mdbr(p,c)),2) $
	      + '  1st Q: ' + STRTRIM(string(q1br(p,c)),2) $
              + '  3rd Q: ' + STRTRIM(string(q3br(p,c)),2) $
	      + ' MJy/sr'
            	Text = [Text, Line]
                                                      
	    	Line = '        Flag: ' + STRTRIM(string(Flag(p,c)),2)
	    	Text = [Text, Line, ' ']

    	     ENDFOR
                                   
	     Line = '        RA: ' + STRTRIM(string(RA(c)),2) $
	    + '    Dec: ' + STRTRIM(string(Dec(c)),2) $
	    + '    Roll: ' + STRTRIM(string(Roll(c)),2)
	     Text = [Text, Line, ' ', ' ']

	  ENDFOR

	ENDIF ELSE BEGIN
; Loop over each chopper plateau and pixel
	   IF det EQ 'SS' THEN wavl = slwavelen(0:63) ELSE wavl = slwavelen(64:127)
	   indradec = WHERE(ra NE ra(0),nrd)
	   IF nrd GT 0 THEN radec_pos = 1 ELSE radec_pos=0
	   
	   TEXT= [Text, $
'|Pix|Ch/RP|WLen| Flux [Jy]   (+/-)  |Br [MJy/sr] (+/-)  |' + $
	   'Median Fl|Median Br|Flag|']      

	     No_Pixel = N_ELEMENTS(mnfl(*,0))
	   
; Loop over chopper plateaux
	   FOR c = 0, No_Chop-1 DO BEGIN

	   IF chosen_pos NE 0 AND c NE chosen_pos-1 THEN GOTO, jump_over 

;	   Line = 'PHT-S Spectrum per Chopper Pos/Raster point '+STRTRIM(string(c+1),2)  
;	   Text = [Text, Line, '-------------------']

; Loop over pixels
	     FOR p = 0, No_Pixel-1 DO BEGIN

Line = $
STRING(format='(I3,I5,2x,f5.2,2x,e9.2,2x,e7.1,2x,e9.2,2x,e7.1,2x,e9.2,1x,e9.2,i3)',$
p+1,c+1,wavl(p),$ 
mnfl(p,c),mnfu(p,c),mnbr(p,c),mnbu(p,c),mdfl(p,c),mdbr(p,c),flag(p,c))
	    	Text = [Text, Line]


    	     ENDFOR
;		Text = [Text, '     ','    ']
;
;	   TEXT= [Text, $
;	   'Pixel  Lambda    Median flux [Jy]   Median Brightness [MJy/sr]   Flag']      
;	     FOR p = 0, No_Pixel-1 DO BEGIN
;
;	Line = STRING(format='(I3,f8.2,f15.4,f20.3,i21)',p+1,wavl(p),$ 
;	 mdfl(p,c),mdbr(p,c),flag(p,c))
;	    	Text = [Text, Line]
;
;    	     ENDFOR
;		Text = [Text, '     ','    ']


	IF radec_pos THEN BEGIN                                   
	     Text = [Text, '     ']
	     Line = '        RA: ' + STRTRIM(string(RA(c)),2) $
	    + '    Dec: ' + STRTRIM(string(Dec(c)),2) $
	    + '    Roll: ' + STRTRIM(string(Roll(c)),2)
	     Text = [Text, Line, ' ']
	ENDIF

jump_over:

	  ENDFOR
	ENDELSE


	ENDFOR

	RETURN
	END
