	PRO PHOTOM_REG_TABLE, Meas, Text, Fname, Colcor=colcor
;+
; NAME:
;	PHOTOM_REG_TABLE
;
; PURPOSE:
;	This routine takes the required values from the phtaap common
;	block and builds them into a text array.
;	The output is a regular fixed column ASCII table compatible 
;	with most import routines of other software.
;
; CATEGORY:
;	PIA - Processing
;
; INPUTS:
;	Meas: An array of indices corresponding to measurements within
;	      the phtaap common block
;
; KEYWORD:
;	Colcor: colour correction to be applied - Colcor must be structure
;		as defined by PIA_cc_defin
;
; OUTPUTS:
;	Text: The text array
;	Fname:  A string containing the _last_ observation TDT/Meas number
;	      in a format suitable for a filename
;
; COMMON BLOCKS:
;	phtaap
;
; PROCEDURES USED:
;	None
;
; RESTRICTIONS:
;	None
;
; MODIFICATION HISTORY:
;	Written by:	Huw Morris
;	Oct 95 Version ?.?
;	Modified by:	Huw Morris	Jan 96
;	Filters and apertures replaced by corresponding strings (CG)  Jan.96
;	Polarizer replaced by corresponding string (CG)		February 1996
;	Minor problems with output format fixed (Jacosta)	April 1997
;	Colour correction (KEYWORD colcor) included (CG)	May 1997
;	V6.3
;	Format changed (avoid problems w. neg. fluxes) (CG)	July 1997
;	V6.4
;	PHTAPERT taken now (CG)					February 1998
;	V7.0
;	Displaying apertures in arcsec's (CG)			January 2000
;	V8.2
;	Major revision of output format to make facilitate
;	interface to further processing like standard 
;	spreadsheet calculations etc. 
;	renamed from PHOTOM_INIT to PHOTOM_REG_TABLE(B.Schulz)	April 2000
;
;-


@phtaap
@phtfilter
@phtapert
@phtpolar
@phtslwavlen

	ON_ERROR, 0 	           ; Stay within procedure


; format definitions

	ffilt	= 'a9'			;filter
	fffilt	= '(f9.4)'		;filter
	tffilt	= '(a9)'		;filter

	fapert	= '(f5.1)'		;aperture
	tfapert = '(a5)'
	hfapert	= 'a5'

	fpol 	= '(a7)'		;polarizer
	hfpol	= 'a7'

	fident	= 'a35'			;meas. identifier
	tfident	= '(a35)'		;meas. identifier

	fobject	= 'a19'			;object name
	tfobject= '(a19)'		;object name

	nform   = '(e10.3)'		;flux results exponential
	hnform  = 'a10'

	iform   = '(i3)'		;3 digit integer numbers
	hiform  = 'a3'

	iform1  = '(i5)'		;5 digit integer numbers
	hiform1 = 'a5'

	fform   = '(f10.5)'		;5 decimal floating numbers
	hfform  = 'a10'

	fform1  = '(f6.1)'		;1 decimal floating numbers
	hfform1 = 'a6'



; apertures in " only for info

	P_AS = [ 52.0, 79.0, 99.0, 120.0, 127.0, 180.0, 180.0,   $
	              5.0, 7.6, 10.0, 13.8, 18.0, 20.0, 23.0 ]

	IF KEYWORD_SET(COLCOR) THEN ccstr = colcor 
; Initialize filters & apertures
	IF N_ELEMENTS(c1filters) EQ 0 THEN phtfilter_init
	IF N_ELEMENTS(p_area) EQ 0 THEN READ_OMEGA

; Find out how many measurements there are to be displayed
	No_Meas = N_ELEMENTS(Meas) 



	Text = ['AAP-Results','===========', systime()]
	

	IF KEYWORD_SET(COLCOR) THEN BEGIN
		IF strpos(colcor.typ, 'bb') GE 0 THEN ccunit = ' K' ELSE ccunit = ''
		Text =[Text, 'color corrected', $
		'reference spectrum: ' + colcor.typ + ', value: ' + $
		strtrim(string(colcor.value),2) + ccunit]
	ENDIF ELSE Text = [Text, 'not color corrected', $
		'reference spectrum: nu*Fnu = const.']
		
	Text = [Text,'-------------------------------------------------------']

	
	hdform = '('+fident+",x,"+fobject+",x,"+hfform+",x,"+hfform+",x,"+hfform1+",x,"+ $
	             hfpol+",x,"+ffilt+",x,"+hfapert+",x,"+hiform+",x,"+hiform1+",x,"+ $
		     hnform+",x,"+hnform+",x,"+hnform+",x,"+hnform+",x,"+hnform+",x,"+ $
		     hnform+",x,"+hnform+",x,"+hnform+",x,"+hnform+",x,"+hnform+",x,"+hiform+')'

	Text = [Text, string(format= hdform, $
		    'Measurement', 'Object', 'RA', 'DEC', 'Roll', $
		    'Pol', 'Filter/', 'Apert', 'Pix', 'Ch/Ra', $
		    'Mean', 'Error', 'Median', '1stQuart', '2ndQuart', $
		    'Brightness', 'Error', 'MedianBr', '1stQuartBr', '2ndQartBr', 'Flg')]

	Text = [Text, string(format= hdform, $
		    '', '', '[deg]', '[deg]', '[deg]', $
		    '', 'Wavel.', '["]', '', 'Step', $
		    '[Jy]', '[Jy]', '[Jy]', '[Jy]', '[Jy]', $
		    '[MJy/sr]', '[MJy/sr]', '[MJy/sr]', '[MJy/sr]', '[MJy/sr]', '')]
	Text = [Text,'']
	
; Loop over each measurement in turn
	FOR i = 0, No_Meas-1 DO BEGIN

; Extract all the temporary arrays from the phtaap common block
	  admn = phtaap(Meas(i)).admn
	  filter = phtaap(Meas(i)).filt
	  det = phtaap(Meas(i)).det
	  polz = phtaap(Meas(i)).polz
	  aper = phtaap(Meas(i)).aper
	  HANDLE_VALUE, phtaap(Meas(i)).hdr, hdr
	  HANDLE_VALUE, phtaap(Meas(i)).mnfl, Mnfl
	  HANDLE_VALUE, phtaap(Meas(i)).mnfu, Mnfu
	  HANDLE_VALUE, phtaap(Meas(i)).mdfl, Mdfl
	  HANDLE_VALUE, phtaap(Meas(i)).q1fl, Q1fl
	  HANDLE_VALUE, phtaap(Meas(i)).q3fl, Q3fl
	  HANDLE_VALUE, phtaap(Meas(i)).mnbr, Mnbr
	  HANDLE_VALUE, phtaap(Meas(i)).mnbu, Mnbu
	  HANDLE_VALUE, phtaap(Meas(i)).mdbr, Mdbr
	  HANDLE_VALUE, phtaap(Meas(i)).q1br, Q1br
	  HANDLE_VALUE, phtaap(Meas(i)).q3br, Q3br
	  HANDLE_VALUE, phtaap(Meas(i)).dec, Dec
	  HANDLE_VALUE, phtaap(Meas(i)).ra, Ra
	  HANDLE_VALUE, phtaap(Meas(i)).roll, Roll
	  HANDLE_VALUE, phtaap(Meas(i)).flag, Flag


; Decode the filter depending on the detector
          CASE Det OF

            'P1': Detfilt = p1filters(Filter - 1)

            'P2': Detfilt = p2filters(Filter - 11)

	    'P3': Detfilt = p3filters(Filter - 13)

	    'C1': Detfilt = c1filters(Filter - 2)

	    'C2': Detfilt = c2filters(Filter - 9)


	    ELSE: Detfilt = '-'			;PHT-S case  special
          ENDCASE

; Get the TDT and Measurement
          Decode_Admn, Admn, Decstr            ; Decode the administration name
          obs = Decstr

	  Fname = admn

	  T_ident = string(obs,form=tfident)

	  T_object = string(STRTRIM(fxpar(hdr,'OBJECT'),2),form=tfobject)

; Get the filter mnemonic

          T_filt = string(Detfilt,form=tffilt)

	  IF STRMID(det,0,1) EQ 'P' THEN BEGIN
	   	T_apert = string(p_as(aper-1),form=fapert)
	  	T_polz_id = string(phtpolar(polz-1),form=fpol)
	  ENDIF ELSE IF STRMID(det,0,1) EQ 'C' THEN BEGIN
	  	T_apert = string('-',form=tfapert)
	  	T_polz_id = string(phtpolar(polz-11),form=fpol)
	  ENDIF ELSE BEGIN
	  	T_apert = string('-',form=tfapert)
	  	T_polz_id = string('-',form=fpol)
	  ENDELSE

; Calculate the chopper plateaux in the current measurement
	  No_Chop  = N_ELEMENTS(mnfl(0,*))
;	  IF No_chop GT 100 THEN BEGIN
;	    PRINT, 'Only first 100 chopper plateaux/raster positions will be shown'
;	    No_Chop = 100
;	  ENDIF

	  IF det EQ 'SS' THEN wavl = slwavelen(0:63)
	  IF det EQ 'SL' THEN wavl = slwavelen(64:127)


	  IF KEYWORD_SET(colcor) AND strmid(det,0,1) NE 'S' THEN BEGIN

	    get_cc, detfilt, ccstr.typ, $
	      ccstr.value, cc_val, error=error

	    IF NOT ERROR THEN BEGIN
	      mnfl = mnfl / cc_val
	      mnfu = mnfu / cc_val
	      mnbr = mnbr / cc_val
	      mnbu = mnbu / cc_val
	      mdfl = mdfl / cc_val
	      q1fl = q1fl / cc_val
	      q3fl = q3fl / cc_val
	      mdbr = mdbr / cc_val
	      q1br = q1br / cc_val
	      q3br = q3br / cc_val
	    ENDIF ELSE $
	       PRINT, detfilt + $
		' could not be corrected'
	
	  ENDIF

; Loop over each chopper plateau and pixel

	  No_Pixel = N_ELEMENTS(mnfl(*,0))
	  FOR p = 0, No_Pixel-1 DO BEGIN

	    T_pixel = string(p+1,form=iform)
	    IF det EQ 'SS' OR det EQ 'SL' THEN $
	      T_filt = string(wavl(p), form=fffilt)

	    FOR c = 0, No_Chop-1 DO BEGIN

	      T_ra    = string(RA(c),form=fform)
	      T_dec   = string(Dec(c),form=fform)
	      T_roll  = string(Roll(c),form=fform1)

	      T_chplat = string(c+1,form=iform1)

	      T_mnfl  = string(mnfl(p,c),form=nform)
	      T_mnfu  = string(mnfu(p,c),form=nform)
	      T_mdfl  = string(mdfl(p,c),form=nform)
	      T_mdf1  = string(q1fl(p,c),form=nform)
	      T_mdf3  = string(q3fl(p,c),form=nform)
	      T_mnsb  = string(mnbr(p,c),form=nform)
	      T_mnsu  = string(mnbu(p,c),form=nform)
	      T_mdsb  = string(mdbr(p,c),form=nform)
	      T_mds1  = string(q1br(p,c),form=nform)
	      T_mds3  = string(q3br(p,c),form=nform)
              T_flag  = string(Flag(p,c),form=iform)


	      Text = [Text, $
	 	      T_ident+ ' '+$
	 	      T_object+ ' '+$
	 	      T_ra+ ' '+$
	 	      T_dec+ ' '+$
	 	      T_roll+ ' '+$
	 	      T_polz_id+ ' '+$
	 	      T_filt+ ' '+$
	 	      T_apert+ ' '+$
	 	      T_pixel+ ' '+$
	 	      T_chplat+ ' '+$
	 	      T_mnfl+ ' '+$
	 	      T_mnfu+ ' '+$
	 	      T_mdfl+ ' '+$
	 	      T_mdf1+ ' '+$
	 	      T_mdf3+ ' '+$
	 	      T_mnsb+ ' '+$
	 	      T_mnsu+ ' '+$
	 	      T_mdsb+ ' '+$
	 	      T_mds1+ ' '+$
	 	      T_mds3+ ' '+$
	 	      T_flag ]
    	    ENDFOR


	  ENDFOR

	  Text = [Text,'']	;insert empty line

	ENDFOR

	RETURN
	END
