;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PHTCS_GET_REC
;
; PURPOSE:
;	Extract a compact status (cs) record using the PHTCS structure
;
; CATEGORY:
;       PIA - initialization
;
; CALLING SEQUENCE:
;	phtcs_get_rec
;
; COMMON BLOCKS:
;	phtcs
;
; RESTRICTIONS:
;	This file should be used after reading the startup file for various
;       common blocks: @phtcs_init
;
; PROCEDURE:
;	PHTCS contains the following field definitions:
;
;		UNIT   = String corresponding to the 6 numbers identifying 
;			     the PHT CS (e.g. '123456' for PSTA123456.FITS) 
;		DIMS   = Actual dimension of the keywords corresponding to 
;			     the CSUNIT
;               All Compact Status Keywords CSGPXXXX as PSTAXXXX
;               All other Compact Status Keywords as in the archive 
;
; MODIFICATION HISTORY:
;       Wrtten by: Wai-Ming Tai (DIAS), July 1994
;	Oct 95 Version 3.5
;			
;-
; *********************************************************************
; *
; *********************************************************************
pro PHTCS_GET_REC, REC_NUM, RECORD
@phtcs
       ON_ERROR, 2
        HANDLE_VALUE, PHTCS(REC_NUM).HANDLE, PHTCST

	RECORD    = { UNIT: PHTCS(REC_NUM).UNIT,  $
                      DIMS: PHTCS(REC_NUM).DIMS,  $
                      UKST: PHTCST.UKST , $
                      UKEN: PHTCST.UKEN , $
		      IKST: PHTCST.IKST , $
                      IKEN: PHTCST.IKEN , $
                      UTST: PHTCST.UTST , $
                      UTEN: PHTCST.UTEN , $
		      SUBS: PHTCST.SUBS , $
                      OPFO: PHTCST.OPFO , $
                      F1TS: PHTCST.F1TS , $
                      F2TS: PHTCST.F2TS , $
                      F1PS: PHTCST.F1PS , $
                      F2PS: PHTCST.F2PS , $
		      C1PS: PHTCST.C1PS , $
                      C2PS: PHTCST.C2PS , $
                      C3PS: PHTCST.C3PS , $
                      CMOD: PHTCST.CMOD , $
                      CAMP: PHTCST.CAMP , $
                      CSTE: PHTCST.CSTE , $
		      CINC: PHTCST.CINC , $
                      CRES: PHTCST.CRES , $
                      DETA: PHTCST.DETA , $
                      DRS:  PHTCST.DRS  , $
                      MUX1: PHTCST.MUX1 , $
                      MUX2: PHTCST.MUX2 , $
		      XSTA: PHTCST.XSTA , $
                      D1OF: PHTCST.D1OF , $
                      D1GA: PHTCST.D1GA , $
                      D2OF: PHTCST.D2OF , $
                      D2GA: PHTCST.D2GA , $
                      FREQ: PHTCST.FREQ , $
		      NNDR: PHTCST.NNDR , $
                      NDR:  PHTCST.NDR  , $
                      INTT: PHTCST.INTT , $
                      MEAT: PHTCST.MEAT , $
                      MPC1: PHTCST.MPC1 , $
                      MPC2: PHTCST.MPC2 , $
		      MPC3: PHTCST.MPC3 , $
                      MET:  PHTCST.MET  }
      RETURN
END
