;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO PHTFILTER_PROP_INIT, filename=filename
;+
; NAME:
;	PHTFILTER_PROP_INIT
;
; PURPOSE:
;	Initialization of the common block FILTPROP for inclusion into 
;	routines. The reference wavelengths are read from the PFLUXCONV.FITS
;	calibration file. The airy disk diameters are hard-coded
;	The common block is defined in PHTFILTER_PROP and contains the main 
;	filter properties.
;
; CATEGORY:
;       PIA - initialisation
;
; CALLING SEQUENCE:
;	phtfilter_prop_init
;
; COMMON BLOCKS:
;	phtfilter_prop
;
; SIDE EFFECTS:
;	The values in the  FILTPROP common block are initialised
;
; COMMON BLOCK PARAMETERS:
;	filtprop: Structure containing central wavelengths and airy disks per
;		detector (filtprop.p1airyd, filtprop.p1cwl = arrays per filter 
;		arranged according to PHTFILTER)
;
; PROCEDURES USED:
;       ASTRO LIB: fxhread
;
;
; MODIFICATION HISTORY:
;	Written by: Ingolf Heinrichsen			Jan  1997
;		    (Split init and common definition)
;-

@phtfilter_prop

	ON_ERROR, 2                                          
			  
;Get the reference wavelengths from the PFLUXCONV CAL-G file
; open the file PFLUXCONV.FITS
;
        if keyword_set(filename) then file = filename else $
 		file=!CALG+'PFLUXCONV.FITS'
	OPENR, unit, file, /block, /GET_LUN 
	
; read header
;
	fxhread, unit, hdr

; close the CAL-G file and free the lun
;
	FREE_LUN, unit
	
; extract reference wavelengths parameters from header, 
; sort into correct sequence
;
	P1cwl = [fxpar(hdr,'CWP3P29'), $
		fxpar(hdr,'CWP3P6  '), $
		fxpar(hdr,'CWP4P85 '), $
		fxpar(hdr,'CWP7P3  '), $
		fxpar(hdr,'CWP7P7  '), $
		fxpar(hdr,'CWP10   '), $
		fxpar(hdr,'CWP11P3 '), $
		fxpar(hdr,'CWP12P8 '), $
		fxpar(hdr,'CWP16   '), $
		fxpar(hdr,'CWP11P5 ')]
		
	P2cwl = [fxpar(hdr,'CWP20   '), $
		fxpar(hdr,'CWP25   ')]

	P3cwl =	[fxpar(hdr,'CWP60   '), $
		fxpar(hdr,'CWP100  ') ]

	C1cwl = [fxpar(hdr,'CWC90   '), $
		fxpar(hdr,'CWC50   '), $
		fxpar(hdr,'CWC60   '), $
		fxpar(hdr,'CWC70   '), $
		fxpar(hdr,'CWC100  '), $
		fxpar(hdr,'CWC105  '), $
		fxpar(hdr,'CWC90   ')]
		
	C2cwl =	[fxpar(hdr,'CWC160  '), $
		fxpar(hdr,'CWC200  '), $
		fxpar(hdr,'CWC180  '), $
		fxpar(hdr,'CWC135  '), $
		fxpar(hdr,'CWC120  ') ]
		
; convert from metres into microns
;
	P1cwl = P1cwl*1e6
	P2cwl = P2cwl*1e6
	P3cwl = P3cwl*1e6
	C1cwl = C1cwl*1e6
	C2cwl = C2cwl*1e6
	
; fill the FILTPROP common structure, airy disks are hard-coded here
;
	FILTPROP={P1airyd:[2.8, 3.0, 4.1, 6.2, 6.4, 8.4, 9.5, 10.8, 13.8, 10.],$
		  P1cwl:P1cwl,$
		  P2airyd:[17.7, 20.], $
		  P2cwl:P2cwl, $
		  P3airyd:[50.3, 83.9], $
		  P3cwl:P3cwl, $
		  C1airyd:[75.5, 41.9, 50.3, 58.7, 83.9, 88.1, 75.5],$
		  C1cwl:C1cwl, $
		  C2airyd:[134., 168., 151., 113., 101.], $
		  C2cwl:C2cwl}
	
RETURN			
END

