;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PHTINTT_CORR_INIT
;
; PURPOSE:
;	Initialise a common block containing the reset interval correction
;	factors
;
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;       PHTINTT_CORR_INIT [,ERROR=error]
;
; INPUT:
;       (none)
;
; KEYWORD:
;	DATA: 'FITS' or none for FITS files, 'ASCII' for 'cresint.txt'
;	ERROR : 0 if OK, 1 if source file not found
;
; RESTRICTIONS:
;	FITS files with official names (eg 'PP1RESETI') or 'cresint.txt' must
;	reside in the !CALG directory, otherwise program ends with error=1
;
; PROCEDURES USED: 
;       Common Block(s) or @ procedure(s):
;        phtintt_corr       
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel  (ESA-SAI)		May 1997
;	V6.3
;	new column added (dS/dA0) (CG)
;	and reading from FITS file			September 1997
;	V6.5
;
;-
PRO phtintt_corr_init, error=error, data=data

COMMON phtintt_corr, phtintt_corr 

	IF not KEYWORD_SET(data) then data = 'FITS'
	
	IF data EQ 'FITS' THEN BEGIN

	 det = ''
	 intt = 0
	 dred = 0 
	 a0 = 0
	 a1 = 0
	 a0er = 0
	 a1er = 0

	 detlist = ['P1','P2','P3','C1','C2']
	 varlist = ['RESRI','RESDR','RESA0','RESA1','RESE0','RESE1']

	 datfits = !CALG + 'P' + detlist + 'RESETI.FITS'
	 
	 FOR ifile = 0,N_ELEMENTS(datfits)-1 DO BEGIN	  	
	   IF is_file_exist(datfits(ifile)) THEN BEGIN
	  	datele = 'P' + detlist(ifile) + varlist  
	  	FXBOPEN, unit, datfits(ifile), 1, hdr

	  	FXBREAD, unit, tintt , datele(0)
	  	det = [det, STRARR(N_ELEMENTS(tintt)) + detlist(ifile)]
	  	intt = [intt,tintt]
	  	fxbread, unit, tdred, datele(1)
	  	dred = [dred,tdred]
	  	fxbread,unit,ta0,datele(2)
	  	a0 = [a0,ta0]
	  	fxbread,unit,ta1,datele(3)
	  	a1 = [a1,ta1]
	  	fxbread,unit,ta0er,datele(4)
	  	a0er = [a0er,ta0er]
	  	fxbread,unit,ta1er,datele(5)
	  	a1er = [a1er,ta1er]
	  	FXBCLOSE, unit
	  	FREE_LUN, unit
	    ENDIF ELSE BEGIN
	     PRINT, 'File not found: ' + datfits(ifile) + ', returning ...'
	     RETURN
	    ENDELSE
	 ENDFOR	    

	 phtintt_corr={det:det(1:*),intt:intt(1:*),dred:dred(1:*),a0:a0(1:*),$
	 		a1:a1(1:*),a0er:a0er(1:*),a1er:a1er(1:*)}		      
	 error=0
	       
	ENDIF ELSE IF data EQ 'ASCII' THEN BEGIN   

	  IF is_file_exist(!CALG+'cresint.txt') THEN BEGIN
	    readcol, !CALG+'cresint.txt', det,a0,a1,a1er,ser,intt, dred, a0er, $
			      FORMAT=('A, F, F, F, F, X, I, I')

	    phtintt_corr={det:det,intt:intt,dred:dred,a0:a0,a1:a1,a0er:a0er,$
			a1er:a1er}		      
	    error=0
	  ENDIF ELSE error=1

	ENDIF ELSE error=1

	RETURN
	END
