;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PHTW2JY_INIT
;
; PURPOSE:
;	Initialize the common block PHTW2JY for inclusion into routines.
;	The common block PHTW2JY contains the conversion factors needed for
;	flux density and brightnes density extractions from in-band powers.
;
; CATEGORY:
;       PIA - initialization
;
; CALLING SEQUENCE:
;	phtw2jy_init
;
; COMMON BLOCK PARAMETERS:
;	W2JY_P:	Conversion factors (W->Jy) for P1, P2, P3 (per filter)
;	W2JY_C: Conversion factors (W->Jy) for C100, C200 (per filter)	
;	V2JY_S: Conversion factors for PHT-S (Amperes->Jy) (per PHT-S pixel)
;		(this are the calibrated factors) containing the A to 
;		Jy calibration.  
;	W2JY_S: Conversion factors for PHT-S (W->Jy)
;	W2MJY_S: Conversion factors for PHT-S (W->MJy/sr)
;	
;
; MODIFICATION HISTORY:
;	Written by: Carlos GABRIEL(ESA/VILSPA-SAI) 	April 1996
;	Bug for PHT-S extended sources fixed by new
;	calibration files fixed (CG)			March 1997	
;
;-

PRO phtw2jy_init
@phtw2jy	

	read_fluxconv
	read_specal
	  	
  	w2jy_s = FLTARR(128)
  	w2mjy_s = w2jy_s
  	
  	w2jy_s(0:7)   = 2.165e+10 
  	w2jy_s(8:15)  = 1.922e+10 
  	w2jy_s(16:23) = 1.745e+10 
  	w2jy_s(24:31) = 1.418e+10 
  	w2jy_s(32:39) = 1.446e+10 
  	w2jy_s(40:47) = 1.322e+10 
  	w2jy_s(48:55) = 1.183e+10 
  	w2jy_s(56:63) = 0.982e+10 

  	w2jy_s(64:71) = 2.217e+10 
  	w2jy_s(72:79) = 1.851e+10 
  	w2jy_s(80:87) = 1.494e+10 
  	w2jy_s(88:95) = 1.169e+10 
  	w2jy_s(96:103) = 0.841e+10 
  	w2jy_s(104:111) = 0.720e+10 
  	w2jy_s(112:119) = 0.720e+10 
  	w2jy_s(120:127) = 0.718e+10 
  	
;  	w2mjy_s(0:7)   = 2.721e+02 
;  	w2mjy_s(8:15)  = 2.422e+02 
;  	w2mjy_s(16:23) = 2.204e+02 
;  	w2mjy_s(24:31) = 1.795e+02 
;  	w2mjy_s(32:39) = 1.837e+02 
;  	w2mjy_s(40:47) = 1.681e+02 
;  	w2mjy_s(48:55) = 1.508e+02 
;  	w2mjy_s(56:63) = 1.254e+02 

;  	w2mjy_s(64:71) = 2.865e+02 
;  	w2mjy_s(72:79) = 2.401e+02 
;  	w2mjy_s(80:87) = 1.952e+02 
;  	w2mjy_s(88:95) = 1.537e+02 
;  	w2mjy_s(96:103) = 1.112e+02 
;  	w2mjy_s(104:111) = 0.961e+02 
;  	w2mjy_s(112:119) = 0.968e+02 
;  	w2mjy_s(120:127) = 0.970e+02 

	w2mjy_s = v2mjy_s / v2jy_s * w2jy_s

	w2jy_s = w2jy_s * 1.d-26

; To be consistent with other detectors: this is for the conversion W -> Jy  
	w2mjy_s = w2mjy_s * 1.d-32
	RETURN
	END
	
	
