;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA
;
; PURPOSE:
;	This is the "ISOPHOT Interactive Analysis" main program
;	to be called to start an Interactive Analysis session.
;	Menues lead you through the capabilities of the tool.
;	No other routines should be called directly from the command
;	line.
;
; CATEGORY:
;	PIA - graphics
;	
; CALLING SEQUENCE:
;	PIA
;	
; COMMON BLOCKS:
;	colour_indices
;	phterd
;
; PROCEDURES USED:
;	PIA LIB:
;		cs_init
;		erd_init
;		pia_aalevel
;		pia_buffil
;		pia_cal_crelin
;		pia_cal_darkcur
;		pia_cal_dietran
;		pia_cal_fcsill
;		pia_cal_fcspow
;		pia_cal_fpgc
;		pia_cal_ndrsel
;		pia_cal_ppsf
;		pia_cal_respons
;		pia_cal_swavl
;		pia_cal_vignet
;		pia_cal_colour_correction
;		pia_extfil
;		pia_fxtfil
;		pia_intfil
;		pia_prtdef
;		pia_set_sysvar
;		pia_view
;		scp_init
;		set_colours
;		spd_init
;		srd_init
;       INTERNAL:
;		pia_event
;
; MODIFICATION HISTORY:
; 	Written by:	D. Skaley (MPIK)		August 94
;       Modified (last) by:    CG			September 1997
;	Responsivity check added in calibration  JAc    November 1997
;	New (orb.pos.dep.) cal. menues added (CG)	February 1998
;	Delete buffers only after question (CG)		December 1999
;	Map simulator button added (CG)			March 2000
;	 OTF disabling (& enabling) in flag system (CG)	March 2000
;	V9.1	
;	Biweight customization added (CG)		May 2002
;	P32 tools added (CG+BS)				July 2002
;	V10.0
;-

; ****************************************************************************
;  Event handling routine for PIA top level menu
; ****************************************************************************

PRO pia_event, event
@phterd
@colour_indices

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue


	CASE uvalue OF

	'QUIT':	BEGIN
		WIDGET_CONTROL, event.top, /DESTROY
		END

	'CONTROLF': PIA_read_ext, GROUP=event.top

	'CONTROLB': PIA_man_mea, GROUP=event.top

	'P32TOOLS': PIA_erd2map 

	'XMTOOL': XMTOOL, GROUP=event.top

	'VIEW':	BEGIN
		pia_view, GROUP=event.top
		END

	'FXTF':	BEGIN
		pia_fxtfil, GROUP=event.top
		END

	'PROC':	BEGIN
		pia_buffil, GROUP=event.top
		END

	'AAPROC': BEGIN
		pia_aalevel, GROUP=event.top
		END

	'PIACOL':BEGIN
		  set_colours
		END

	'SYSVARS': BEGIN
	    old_calg = !CALG
	    old_print = !PIA_PRINTDIR
	    PIA_SET_PATHS, GROUP=event.top, /MODAL
	    IF !CALG NE old_calg THEN BEGIN
	       WIDGET_CONTROL, event.top, /HOURGLASS
	       reini = yes_no("Should all calibration data be reinitialized?")
	       IF reini THEN cal_init
	    ENDIF
	    IF !PIA_PRINTDIR NE old_print THEN pia_prtinit
	END 

	'SYSV_NVIEWS': pia_set_sysvar, 'NVIEWS', GROUP=event.top

	'UNCERT': PIA_DEF_NOWEIGHT
					
	'BIWEIGHT': PIA_DEF_BIWEIGHT
					
	'ERRBARS': PIA_DEF_ERRBARS
					
	'COORD': PIA_DEF_CORRCOOR
					
	'EXTFF': PIA_DEF_FFIELD
					
	'PLOTLIM': PIA_DEF_PLOT_LIMITS
					
	'DIS_OTF': BEGIN
		!OTFLOW = 99
		a = set_indsevere('SRD', 'NOTF', /delete, /copycom)
	END
	
	'ENA_OTF': BEGIN
		!OTFLOW = 1
		a = set_indsevere('SRD', 'NOTF', /update, /copycom)
	END

	'CPRI':	BEGIN		
		pia_prtdef, GROUP=event.top
		END

; Calibration Sequences:

	'REINIT': cal_init

	'C_FPGC': pia_cal_fpgc

	'C_DARK': BEGIN
		  pia_cal_darkcur
		  END

	'C_DARK_ORB': BEGIN
		  pia_cal_darkcur_orb
		  END
		  
	'C_FCSTAB': BEGIN
		  pia_cal_fcspow
		  END

	'C_RESPON': BEGIN
		  pia_cal_respons
		  END

	'C_RESPON_ORB': BEGIN
		  pia_cal_defresp_orb
		  END

	'C_ARESPON': BEGIN
		  pia_cal_actrespons
		  END

	'C_RESPCHK': BEGIN
		  pia_cal_respchk
		  END

	'C_LINEAR': BEGIN
		  pia_cal_crelin
		  END

	'C_RESPCHK': BEGIN
		  pia_cal_respchk
		  END

	'C_SWAVL': BEGIN
		  pia_cal_swavl
		  END

	'C_FCSILL': BEGIN
		  pia_cal_fcsill
		  END

	'C_FLATF': BEGIN
		  pia_cal_flatfield
		  END

	'C_PSF': BEGIN
		  pia_cal_ppsf
		  END

	'C_NDRSEL': BEGIN
		  pia_cal_ndrsel
		  END

	'C_VIGN': BEGIN
		  pia_cal_vignet
		  END

	'C_DIETR': BEGIN
		  pia_cal_dietran
		  END

	'C_CC': BEGIN
		  pia_cal_colour_correction
		  END

; AOT - Sequences:

	'A_GEN_P05P25': BEGIN
		 pia_genpro_top, genpr, /ABS_PHOT
		 FROM_SRD = 0
		 FROM_SCP = 0
		 INFO = 0
		 
		 IF genpr.gbegin EQ 1 THEN FROM_SRD=1
		 IF genpr.gbegin EQ 2 THEN FROM_SCP=1
		 IF genpr.info EQ 1 THEN INFO=1
		 
		 pia_proc_gen, /ABS_PHOT, FROM_SRD=from_srd, FROM_SCP=from_scp,$
		 	summ_info=info
		 END

	'A_GEN_SPARSE': BEGIN
		 pia_genpro_top, genpr, /ABS_PHOT
		 FROM_SRD = 0
		 FROM_SCP = 0
		 INFO = 0
		 IF genpr.gbegin EQ 1 THEN FROM_SRD=1
		 IF genpr.gbegin EQ 2 THEN FROM_SCP=1
		 IF genpr.info EQ 1 THEN INFO=1
		 
		 pia_proc_gen, /SPARSE_MAP, FROM_SRD=from_srd, $
		   FROM_SCP=from_scp, SUMM_INFO=info
		 END

	'A_GEN': BEGIN
		 pia_genpro_top, genpr
		 SRD = 0
		 SCP = 0
		 FROM_SRD = 0
		 FROM_SCP = 0
		 AUTO_RECO = 0
		 INFO = 0
		 IF genpr.gbegin EQ 1 THEN FROM_SRD=1
		 IF genpr.gbegin EQ 2 THEN FROM_SCP=1
		 IF genpr.gend EQ 0 THEN SRD=1 ELSE $
		 IF genpr.gend EQ 1 THEN SCP=1
		 IF genpr.auto_reco THEN auto_reco=1
		 IF genpr.info EQ 1 THEN INFO=1
		 
		 pia_proc_gen, FROM_SRD=from_srd, FROM_SCP=from_scp, $
		 	SRD=srd, SCP=scp, AUTO_REC=auto_reco, SUMM_INFO=info
		 END

        'A_GEN_SEP_RP': BEGIN
                 pia_proc_gen, /per_rpid
                 END

; BATCH - Sequences:
	'B_GEN_SEM': BEGIN
		 pia_proc_batch_manager_sm
		 END
; BATCH - Sequences:


; Show signal from orbits (partially or totally)
	'SHOORB': PIA_ANAL_SIG, GROUP=event.top

; Clear Space:

	'DEL_ERD': BEGIN 
		msg = 'Are you sure you want to delete ALL ERDs from buffer?'
		res = yes_no(msg)
		IF res EQ 1 THEN $
		 erd_init
	END	
			
	'DEL_SRD': BEGIN 
		msg = 'Are you sure you want to delete ALL SRDs from buffer?'
		res = yes_no(msg)
		IF res EQ 1 THEN $
			srd_init
	END

	'DEL_SMC': BEGIN 
		msg = 'Are you sure you want to delete ALL SMDs from buffer?'
		res = yes_no(msg)
		IF res EQ 1 THEN $
		  smc_init
	END

	'DEL_SCP': BEGIN 
		msg = 'Are you sure you want to delete ALL SCPs from buffer?'
		res = yes_no(msg)
		IF res EQ 1 THEN $
		  scp_init
	END

	'DEL_SPD': BEGIN 
		msg = 'Are you sure you want to delete ALL SPDs from buffer?'
		res = yes_no(msg)
		IF res EQ 1 THEN $
		  spd_init
	END

	'DEL_AAP': BEGIN 
		msg = 'Are you sure you want to delete ALL AAPs from buffer?'
		res = yes_no(msg)
		IF res EQ 1 THEN $
		  aap_init
	END

	'DEL_CS': BEGIN 
		msg = 'Are you sure you want to delete ALL CSs from buffer?'
		res = yes_no(msg)
		IF res EQ 1 THEN $
		  cs_init
	END

	'DEL_ALL': BEGIN
		msg = 'Are you sure you want to delete ALL DATA from buffer ???'
		res = yes_no(msg)
		IF res EQ 1 THEN BEGIN
		  	  	erd_init
	  			srd_init
;	  			smc_init
	  			scp_init
	  			spd_init
	  			aap_init
	  			cs_init
		ENDIF
	  
	END
	
	'MAPSIM': pia_mapsim

	'LOGO': BEGIN
	  TEXT = ['You are using the PHT-Interactive Analysis package, PIA',$
	  	'', $
'PIA is a joint development by the ', ' ',$
'         ESA Astrophysics Division ', ' ', $
'and the ', ' ',$
'         ISOPHOT Consortium ', $
' ',$
'with the collaboration of ', $
' ',$
'         The Infrared Processing and Analysis Center (IPAC) and ', $
' ',$
'         the Instituto de Astrofsica de Canarias (IAC). ', $
' ',$
'The PHT Consortium is led by the Max Planck Institute for Astronomy (MPIA), Heidelberg', $ 
' ',$
'Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and MPIA.',$
' ', $
' When publishing ISOPHOT Data reduced with this analysis package,',$
'please mention this in the acknowledgement.', '' , $
'No warranties for installation / support/ maintenance can be given.']

		PIA_DISP_PRINT_FILE, '',$ 
			TITLE="PHT Interactive Analysis (PIA)",$
			GROUP=event.top, TEXT=text
		END

		'HOMEPAGE': BEGIN
		 	WIDGET_CONTROL, event.top, /hourglass
			IF !VERSION.OS NE 'vms' THEN $
			 spawn, '$w3net http://isowww.estec.esa.nl/manuals/PHT/pia/ &' ELSE $
			 spawn, 'w3net http://isowww.estec.esa.nl/manuals/PHT/pia/',/nowait
			END
		
		'USERMAN': BEGIN
		 	WIDGET_CONTROL, event.top, /hourglass
			IF !VERSION.OS NE 'vms' THEN $
			 spawn, '$w3net $PIA_HTML/um/pia_um.html &' ELSE $
			 spawn, 'w3net /pia_dir/html/um/pia_um.html',/nowait
			END
		
		'USERM_H': BEGIN
			 WIDGET_CONTROL, event.top, /hourglass
			IF !VERSION.OS NE 'vms' THEN $
			 spawn, '$w3net $PIA_HTML/um/tour.html &' ELSE $
			 spawn, 'w3net /pia_dir/html/um/tour.html',/nowait
								
		END

		'USERM_W': BEGIN
		 	WIDGET_CONTROL, event.top, /hourglass
			IF !VERSION.OS NE 'vms' THEN $
			 spawn, '$w3net $PIA_HTML/um/main.html &' ELSE $
			 spawn, 'w3net /pia_dir/html/um/main.html',/nowait			
			
		END
		
		'IMPLEM': BEGIN
		 	WIDGET_CONTROL, event.top, /hourglass
			IF !VERSION.OS NE 'vms' THEN $
			 spawn, '$w3net $PIA_HTML/impl/impl.html &' ELSE $
			 spawn, 'w3net /pia_dir/html/impl/impl.html',/nowait			
		END

		'UPD_INFO': BEGIN
		    PIA_DISP_PRINT_FILE, !CALU + 'pia_mod_list.txt',$ 
			TITLE="PIA Updates Information",$
			GROUP=event.top
		 	
		END

		'PRINT_UM': BEGIN
		 	PIA_PRINT_UM
		END
		
	ELSE:	MESSAGE, /INFO, 'Function not yet implemented!'
	ENDCASE

	RETURN
END

; ****************************************************************************
;  PIA main program - definition of top level menu
; ****************************************************************************

PRO pia
COMMON pia_acknow, pia_acknow

on_error, 2
	IF XRegistered("pia") NE 0 THEN RETURN

	WIDGET_CONTROL, default_font="fixed"

	IF N_ELEMENTS(pia_acknow) EQ 0 THEN BEGIN
	  pia_welcome
	  pia_acknow = 1
	  !PROMPT = 'IDL/PIA>' 
	ENDIF

	pia_title   = "Interactive Scientific Analysis Tool for ISOPHOT"
	pia_version = "V10.0"
	defsysv, '!PIA_VERSION', pia_version

        export = '(e)'
        exp_vers = STRPOS(!PIA_VERSION,export)
;  Set-up widget hierarchy

	id_base = WIDGET_BASE( TITLE=pia_title+" - "+pia_version + $
		' - Top Window ', /COLUMN , XSIZE=700)

	DEFSYSV, '!pia_top_wid', id_base
	
	id_0 = WIDGET_BASE( id_base, /ROW )
	id_1 = WIDGET_BUTTON( id_0, VALUE='  Files  ', /MENU )
	id_2 = WIDGET_BUTTON( id_1, VALUE='Files Manager', $
		UVALUE='CONTROLF' )
; Calibration Sequences Widgets  
	id_2 = WIDGET_BUTTON( id_1, VALUE='Calibration Info', /MENU )
	
	id_3 = WIDGET_BUTTON( id_2, VALUE='RE-initialize calibration', $
				UVALUE='REINIT' )
;	id_3 = WIDGET_BUTTON( id_2, VALUE='Focal Plane Geometry', $
;				UVALUE='C_FPGC' )
;	IF exp_vers NE -1 THEN WIDGET_CONTROL, id_3, sensitive=0

	id_3 = WIDGET_BUTTON( id_2, VALUE='Dark Currents (obsolete)', UVALUE='C_DARK' )

	id_3 = WIDGET_BUTTON(id_2,VALUE='Orbital position dependent Dark Curr',$
	UVALUE='C_DARK_ORB' )

	id_3 = WIDGET_BUTTON( id_2, VALUE='FCS Calibration Curves ', $
				UVALUE='C_FCSTAB' )

	id_3 = WIDGET_BUTTON( id_2, VALUE='Default Responses (obsolete) ', $
				UVALUE='C_RESPON' )

	id_3 = WIDGET_BUTTON(id_2,VALUE='Def. Responses (orb. pos. dependent)', $
				UVALUE='C_RESPON_ORB' )

	id_3 = WIDGET_BUTTON( id_2, VALUE='Actual Responses ', $
				UVALUE='C_ARESPON' )

	id_3 = WIDGET_BUTTON( id_2, VALUE='Responsivity check ', $
				UVALUE='C_RESPCHK' )
	IF exp_vers NE -1 THEN WIDGET_CONTROL, id_3, sensitive=0

	id_3 = WIDGET_BUTTON( id_2, VALUE='Voltages Linearisation ', $
				UVALUE='C_LINEAR' )

	id_3 = WIDGET_BUTTON( id_2, VALUE='S-Central Wavelengths ', $
				UVALUE='C_SWAVL' )

	id_3 = WIDGET_BUTTON( id_2, VALUE='Vignetting ', $
				UVALUE='C_VIGN' )

	id_3 = WIDGET_BUTTON( id_2, VALUE='DIE Transfer ', $
				UVALUE='C_DIETR' )

	id_3 = WIDGET_BUTTON( id_2, VALUE='Filter2filter ("Ext.FF") ', $
				UVALUE='C_FLATF' )

	id_3 = WIDGET_BUTTON( id_2, VALUE='FCS illumination matrix ', $
				UVALUE='C_FCSILL' )

	id_3 = WIDGET_BUTTON( id_2, VALUE='Point Spread Function', $
			 UVALUE='C_PSF' )

	id_3 = WIDGET_BUTTON( id_2, VALUE='NDR general selection', $
			UVALUE='C_NDRSEL' )
	id_3 = WIDGET_BUTTON( id_2, VALUE='Colour Correction', $
			UVALUE='C_CC' )
	id_2 = WIDGET_BUTTON( id_1, VALUE='FileView', UVALUE='VIEW' )

	id_2 = WIDGET_BUTTON( id_1, VALUE='Quit', UVALUE='QUIT' )


	id_1 = WIDGET_BUTTON( id_0, VALUE='  Buffers  ', /MENU )
	id_2 = WIDGET_BUTTON( id_1, VALUE='Buffers Manager', $
		UVALUE='CONTROLB' )
	id_2 = WIDGET_BUTTON( id_1, VALUE='P32Tools', UVALUE='P32TOOLS' )
	id_2 = WIDGET_BUTTON( id_1, VALUE='Astrophysical Work', UVALUE='AAPROC' )
	id_2 = WIDGET_BUTTON( id_1, VALUE='Delete Buffers', /MENU )
	id_3 = WIDGET_BUTTON( id_2, VALUE='ERD Buffer ', UVALUE='DEL_ERD' )
	id_3 = WIDGET_BUTTON( id_2, VALUE='SRD Buffer ', UVALUE='DEL_SRD' )
;	id_3 = WIDGET_BUTTON( id_2, VALUE='SMC Buffer ', UVALUE='DEL_SMC' )
	id_3 = WIDGET_BUTTON( id_2, VALUE='SCP Buffer ', UVALUE='DEL_SCP' )
	id_3 = WIDGET_BUTTON( id_2, VALUE='SPD Buffer ', UVALUE='DEL_SPD' )
	id_3 = WIDGET_BUTTON( id_2, VALUE='AAP Buffer ', UVALUE='DEL_AAP' )
	id_3 = WIDGET_BUTTON( id_2, VALUE='CS Buffer ', UVALUE='DEL_CS' )
	id_3 = WIDGET_BUTTON( id_2, VALUE='Delete ALL !!', UVALUE='DEL_ALL' )

	id_1 = WIDGET_BUTTON( id_0, VALUE=' Sequences ', /MENU )

; AOT Sequences Widgets
	id_2 = WIDGET_BUTTON( id_1, VALUE='AOT/Batch processing', /MENU )
	id_3 = WIDGET_BUTTON( id_2, VALUE='General ', UVALUE ='A_GEN')
		
	id_3 = WIDGET_BUTTON( id_2, VALUE='-> ERD per RPid -> SCP', $
			UVALUE='A_GEN_SEP_RP' )
	id_3 = WIDGET_BUTTON( id_2, VALUE='Absolute Photometry (P05 / P25)', UVALUE='A_GEN_P05P25')
	id_3 = WIDGET_BUTTON( id_2, VALUE='Sparse Map (P17/18/19 / P37/38/39)', UVALUE='A_GEN_SPARSE')
	id_3 = WIDGET_BUTTON( id_2, VALUE='Serendipity ', UVALUE='B_GEN_SEM')
	id_2 = WIDGET_BUTTON( id_1, VALUE='Concatenate measurements', $
		UVALUE='SHOORB' )

	id_1 = WIDGET_BUTTON( id_0, VALUE=' Customize ', /MENU )
	id_2 = WIDGET_BUTTON( id_1, VALUE='Printer', UVALUE='CPRI' )
	id_2 = WIDGET_BUTTON( id_1, VALUE='PIA color table ', UVALUE='PIACOL' )
	id_2 = WIDGET_BUTTON( id_1, VALUE='Plots in main windows',$
			UVALUE='SYSV_NVIEWS' )
	id_2 = WIDGET_BUTTON( id_1, VALUE='PIA paths ', UVALUE='SYSVARS' )
	id_2 = WIDGET_BUTTON( id_1, VALUE='External Flatfield', UVALUE='EXTFF' )

	id_2 = WIDGET_BUTTON( id_1, VALUE='Error bars in Zoom&Print ', $
	    UVALUE='ERRBARS' )
	id_2 = WIDGET_BUTTON( id_1, VALUE='Weighting means ', UVALUE='UNCERT' )
	id_2 = WIDGET_BUTTON( id_1, VALUE='Biweight means ', UVALUE='BIWEIGHT' )
	id_2 = WIDGET_BUTTON( id_1, VALUE='Astron. coordinates ', UVALUE='COORD' )
	id_2 = WIDGET_BUTTON( id_1, VALUE='On-Target-Flag value ', /MENU)
	id_3 = WIDGET_BUTTON( id_2, VALUE='Disable ', UVAL='DIS_OTF') 
	id_3 = WIDGET_BUTTON( id_2, VALUE='Enable ', UVAL='ENA_OTF') 
	id_2 = WIDGET_BUTTON( id_1, VALUE='Limits for plots ', UVALUE='PLOTLIM')
;	id_2 = WIDGET_BUTTON( id_1, VALUE='Windows Manager', $
;		UVALUE='XMTOOL' )

	id_1 = WIDGET_BUTTON( id_0, VALUE=' Simulator ', UVALUE="MAPSIM" )

	id_1 = WIDGET_BUTTON( id_0, VALUE='  Quit  ', UVALUE='QUIT' )

	id_1 = WIDGET_LABEL( id_0, VALUE='        ' )
	id_1 = WIDGET_BUTTON( id_0, VALUE='    Help    ', /MENU )
	id_2 = WIDGET_BUTTON(id_1, VALUE='PIA Homepage', UVALUE='HOMEPAGE')
	id_2 = WIDGET_BUTTON(id_1, VALUE='User Manual', UVALUE='USERMAN')
	id_2 = WIDGET_BUTTON(id_1, VALUE='This Window', UVALUE='USERM_W')
	id_2 = WIDGET_BUTTON(id_1, VALUE='A PIA-Guided Tour', UVALUE='USERM_H')
	id_2 = WIDGET_BUTTON(id_1, VALUE='PIA development team', UVALUE='IMPLEM')
	id_2 = WIDGET_BUTTON(id_1, VALUE='About PIA', UVALUE='LOGO')
	id_2 = WIDGET_BUTTON(id_1, VALUE='Updates Info', UVALUE='UPD_INFO')
	id_2 = WIDGET_BUTTON(id_1, VALUE='Print User Manual', UVALUE='PRINT_UM')

;  Realize widget

	WIDGET_CONTROL, id_base, TLB_SET_XOFFSET=5,TLB_SET_YOFFSET=25,/REALIZE
	Xmanager,No_BLOCK=1, "pia", id_base

	RETURN
END
