;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIXEL_DET
;                
;PURPOSE:
; 	Returns the number of pixels  according to the detector, with the 
;	keyword ALLPX include resistor and open pixels
;                
; CATEGORY:
;       PIA - processing
;                
; CALLING SEQUENCE:
;       npix = PIXEL_DET(det, [/ALLPX])
;
; INPUT PARAMETERS:
;       det : name of the detector, a two character string [P1,P2,P3,C1,C2,SL]
;
; KEYWORDS:
;	ALLPX:   Including all pixels, resistor + open
;
; MODIFICATION HISTORY:
;       Written by: J.Acosta
;       Modified (last) by JA                      February 1997
;       V6.1
;	Added keywords IS_SPD and IS_AAP	Jacosta  	May 1998
;	V7.1
;-
FUNCTION PIXEL_DET,det, ALLPX = allpx, IS_SPD = is_spd, IS_AAP = is_aap

IF NOT KEYWORD_SET(ALLPX) THEN allpx = 0

new_det = strupcase(strtrim(det)) 

CASE 1 OF
 strmid(new_det,0,1) eq 'P': pix = 1
 new_det eq 'C1':  IF allpx THEN pix=11 ELSE pix = 9
 new_det eq 'C2':  IF allpx THEN pix=6 ELSE pix = 4
 strmid(new_det,0,1) eq 'S': IF allpx THEN pix=132 ELSE $  
                              IF KEYWORD_SET(IS_SPD) OR KEYWORD_SET(IS_AAP) THEN $
                                pix = 64 ELSE pix = 128
 ELSE: BEGIN
        print,'Not valid detector'
        pix=0
       END 
ENDCASE  
         
RETURN, pix
END    
 
