;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PROC_INT_RESP
; PURPOSE:
;	Interpolate two FCS measurements for using the interpolated responsivity
;	for a series of measurements to be power calibrated
; CATEGORY:
;	PIA - processing 
;                
; CALLING SEQUENCE:
;	PROC_INT_RESP, FCS1, FCS2, measlist
;
; INPUT PARAMETERS:
;	FCS1	: index within phtscp of first FCS measurement to be used
;	FCS2    : index within phtscp of second FCS measurement to be used
;
; OPTIONAL INPUT :
;	measlist: index list of measurements to be power calibrated within phtscp
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phtscp

;       PIA Procedure(s):
;               respons_interpol
;               pia_load_iscp
;               process_scp
;
; MODIFICATION HISTORY:
;	Written by: C. Gabriel (ESA-SAI)		July 1996

;-
PRO proc_int_resp, fcs1, fcs2, meas

@phtscp

	IF N_PARAMS() LT 3 THEN MESSAGE, $
	   'Syntax: PROC_INT_RESP, fcs1, fcs2, meas'
; create interpolation structure

	respons_interpol, fcs1, fcs2, resps

	IF N_ELEMENTS(meas) EQ 0 THEN measlist = INDGEN(fcs2-fcs1-1) + fcs1 + 1 $
				ELSE measlist = meas


	FOR i=0, N_ELEMENTS(measlist)-1 DO BEGIN

; load from phtscp into temporary array

		pia_load_iscp, phtscp(measlist(i)), tmpdata
		process_scp, tmpdata, tmpdata.hdr, 3, spdpos, $
				respint=resps

	ENDFOR

	RETURN
	END