;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO PROCESS_PIXEL, TMPDATA, IPIX, NDEG, STIME, SLOP, SLOPERR, SLFLAG,$
	 DIV_RAMP=DIV_RAMP 
;+
; NAME:
;	PROCESS_PIXEL
; PURPOSE:
;	Fit voltage ramps of chosen pixel data, taken into 
;	account diverse selections or flags plotting the resulting
;	ramps slopes with uncertainties
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	PROCESS_PIXEL, TMPDATA, IPIX, NDEG
;
; INPUT PARAMETERS:
;	TMPDATA	: Temporary ERD data structure
;	IPIX	: Pixel to be fitted
;	NDEG	: Degree of the polynomial to be fitted
;
; KEYWORD:
;	DIV_RAMP: For ramps subdivision
;
; OUTPUT PARAMETERS:
;	TIME	: Array containing slopes times
;	SLOP	: Array containing slopes
;	SLOPER	: Array containing slopes uncertainties
;	SLFLAG	: Array containing slopes flags (0:OK, 1:only two points used,
;						 2: bad)
;
;
; RESTRICTIONS:
;
; METHOD:
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phtacc
;		splitramp_par
;       PIA Procedure(s):
;               acc_flg
;               acc_volt
;               decode_pixf
;               fit_ramps
;
; MODIFICATION HISTORY:
;	Written by: C. Gabriel
;	Oct 95 Version 3.5
;	Call to fit_ramps changed (CG)			March 1996
;	Keyword DIV_RAMP added (CG)			May 1997
;	V6.3
;	Extended for using tmpdata.flag (CG)		November 1997
;	V6.6
;	Use of bitflag system + new more efficient 
;	  data reduction routines (JAcosta)		May 1999
;	Data reduction info added (CG)			May 1999
;	V7.4
;	Bug by splitting into maximal number fixed (CG) July 2000
;	V9.0
;	Bug by subdivision into 2 ramps fixed (CG)	July 2000
;	V9.1
;						
;-
; Needed common blocks :
@phtacc
@splitramp_par
;
	ON_ERROR, 2                                          
;
; Check the number of parameters
;
	IF N_PARAMS() LT 3 THEN MESSAGE, $
	 'Syntax: PROCESS_PIXEL, TMPDATA, PIX, NDEG, ' + $
	    '[TIME, SLOP, SLOPER, SLFLAG]'
; Decode the pixel flag word
	DECODE_PIXF, tmpdata.pixf, suspect, chopon, chops, dr, otf 

; Subdividing ramps
	IF KEYWORD_SET(div_ramp) THEN BEGIN
	   IF N_ELEMENTS(splitramp_par) EQ 0 THEN splitramp_par_init
	   nndr = tmpdata.nndr
	   IF splitramp_par.model EQ 0 THEN pseudoramp = splitramp_par.value $
	   ELSE IF splitramp_par.model EQ 1 THEN BEGIN
	      pseudoramp = ((nndr+1) / splitramp_par.value)
	      IF pseudoramp LT 2 THEN pseudoramp = 0
	      IF pseudoramp GT nndr THEN pseudoramp = 0
	   ENDIF ELSE pseudoramp = 0
	   DEFSYSV, '!subd_ramp', pseudoramp
	ENDIF  ELSE  DEFSYSV, '!subd_ramp', 0 


; Get index with the ramp ends.
   	  give_cs, tmpdata, cst, rec
          GET_RAMPEND, tmpdata.time, dr, tmpdata.tint, rampflag, rampend,  $ 
	     SUB_RAMP =  pseudoramp, datred=cst.drs(rec)		     
						   
; Get all severe flags individually per pixel
	  get_validflag, tmpdata.flag(ipix,*), 'ERD', redflag
	    
	CONP0 = tmpdata.CONP(ipix,*)
	 
	CONDIM = N_ELEMENTS(CONP0)
; Now fit ramps for chosen pixel 
        FIT_RAMPS, tmpdata.time, conp0, ndeg, redflag, rampend, dr,  $
	            TYLIN, TYSLOP, TYSLOPR, TYFLAG, TYTIME, TYRESI, TYNROS

; Output variables
	stime = TYTIME
	slop = TYSLOP
	sloperr = TYSLOPR
        slflag = TYFLAG

	RETURN
	END
