;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;      READ_ALLPSF
;
; PURPOSE:
;	Scan the directory containing all PSFs 
;	
; CATEGORY:
;       PIA - utilities
;
; CALLING SEQUENCE:
;       read_allpsf [,outfile] [,PSF_DIR =psf_dir] [,/VERBOSE]
;INPUT: 
;
;OUTPUT: 
;	outfile: name of file to write the date of perigee passage. If not
;	         specified then !F_ALLPERIGEE is used
;KEYWORDS: 
;	verbose: some information is giving about the files reading
;	PSF_DIR: repository directory containing Planned Skeleton Files (PSF) 
;
; PROCEDURES USED:
;       ASTRO LIB:
;	INTERNAL: 
;		read_psf_perigee		
;
; MODIFICATION HISTORY:
;       Written by:     Jose Acosta (PIDT - MPIA)       December 1997
;
;-
PRO read_allpsf, outfile, VERBOSE = verbose, PSF_DIR= psf_dir

IF NOT KEYWORD_SET(PSF_DIR) THEN PSF_DIR = '~phtcalib/psf/

print,'  Scanning  directory '+ PSF_DIR
spawn,'ls '+PSF_DIR+'*PSF',psf_name

slash = strpos(psf_name(0),'/psf/')+5
undersc = strpos(psf_name(0),'_')+1
rev = fix(strmid(psf_name,slash,4))
vers = fix(strmid(psf_name,undersc,2))

; check if PSF for a revolution is duplicated
uniq_rev = rev(UNIQ(rev,SORT(rev))) 

n_urev = N_ELEMENTS(uniq_rev)
psf_name_fin = strarr(n_urev)

; write a new array of psf_name avoiding duplicated files, in such cases selects
; the latest version one.
FOR i=0, n_urev-1 DO BEGIN
  ind_rep = WHERE(rev eq uniq_rev(i),nrep)
  IF nrep gt 1 THEN BEGIN
     maxrev = max(vers(ind_rep),indmax)
     psf_name_fin(i) = psf_name(ind_rep(indmax))
  ENDIF ELSE psf_name_fin(i) = psf_name(ind_rep(0))
ENDFOR     

IF n_elements(outfile) eq 0 THEN outfile = !F_ALLPERIGEE

openw, u_f, outfile, /get_lun

IF keyword_set(verbose) THEN print, 'Rev','Perigee','PSF_NAME',$ 
        format='(a4,2x,a25,2x,a11)'
;write rev. number, Perigee time, & PSF name into output file 

format='(a4,5(2x,a25),2x,a11)'  
   
FOR i=0, n_urev-1 DO BEGIN
   tperigee = read_psf_perigee(psf_name_fin(i),/OBS_WINDOW,OBS_OPEN1=oopen1,   $
         OBS_OPEN2=oopen2,OBS_CLOSE1=oclose1,OBS_CLOSE2=oclose2)
   IF KEYWORD_SET(verbose) THEN PRINT, strtrim(uniq_rev(i),2),tperigee, $
                 strmid(psf_name_fin(i), slash, 11),format='(a4,2x,a25,2x,a11)'
   printf, u_f, strtrim(uniq_rev(i),2),tperigee, oopen1, oclose1,   $ 
      oopen2, oclose2, strmid(psf_name_fin(i), slash, 11), format=format

ENDFOR

free_lun, u_f

RETURN
END   


  
