;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  pro read_asc_pfiltr, buffer, inputfile = inputfile

;+
; NAME:
;     READ_ASC_PFILTR
; PURPOSE:
;       Read a PHT PFILTR uplink file.
; CATEGORY:
;	PIA - I/O
; CALLING SEQUENCE:
;       READ_ASC_PFILTR, BUFFER, INPUTFILE = INPUTFILE 
;
; INPUT:
;
; OUTPUT:
;       BUFFER: a floating array of 11 X 14, where
;
; OPTIONAL INPUT:
;       INPUTFILE: string type for the input uplink file, 
;                  default is p_pfiltr.txt
;
; PROCEDURES USED:
;
; MODIFICATION HISTORY:
;       Written by: W. M. Tai
;	Oct 95 Version 3.5
;
;-
  on_error, 2


  if keyword_set(inputfile) then infile = inputfile else infile = 'p_pfiltr.txt'

; read in the input file and take out those lines begin with 'comment'
; and with '#', also trim off the leading and trailing spaces.

  openr, unit, infile, /get_lun
  line = ' '

; the first line is a dummy
  buf = strarr(1)

  while (not eof(unit)) do begin
    readf, unit, line 
    if strmid(line, 0, 7) ne 'COMMENT' then begin
     if strlen(strtrim(line, 2)) gt 0 then begin
       if strmid(line, 0, 1) ne '#' then buf = [buf, strtrim(line, 2)]
     end
    end
  end
  free_lun, unit

; we are interested in the value table itself
  end_table = where(strmid(buf, 0, 12) eq 'END_INST_TAB')

; the value 31 is the first 6 lines plus the 12 keys X 2 + 1
  value = buf(31: end_table(0) - 1)

; In case there are varying space delimiter between each value,
; we parse the value line one at a time to extract the individual
; value to a token_buf.

  tab = string(9b)

  pfiltr_value = [[strarr(11)]]

  for i = 0, 13 do begin
    line = value(i)

;   replace all the tab characters, just in case
    while strpos(line, tab) GE 0 do begin
      pos = strpos(line, tab)
      strput, line, ' ', pos
    endwhile

; the first element in the token_buf is a dummy
    token_buf = strarr(12)
    
    for j = 0, 10 do begin
      pos = strpos(line, ' ')
      token_buf(j) = strmid(line, 0, pos)
      len = strlen(line)
      line = strtrim(strmid(line, pos+1, len-pos-1), 1) 
    endfor
    token_buf(11) = line
    pfiltr_value = [[pfiltr_value] , [token_buf(1:11)]]
   endfor 

; Now we should have 15 elements in pfiltr_value where the first one is
; a dummy but the rest of it would correspond to the pixel number
   pfiltr_value = pfiltr_value(*, 1 : 14)

   buffer = float(pfiltr_value)

   return

end
