;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  pro read_asc_ppsf, buffer, inputfile = inputfile
;+
; NAME:
;     READ_ASC_PPSF
; PURPOSE:
;       Read a PHT PPSF uplink file.
; CATEGORY:
;	PIA - I/O
; CALLING SEQUENCE:
;       READ_ASC_PPSF, BUFFER, INPUTFILE = INPUTFILE 
;
; INPUT:
;
; OUTPUT:
;       BUFFER: float array for the PPSF table
;
; OPTIONAL INPUT:
;       INPUTFILE: string type for the input uplink file, 
;                  default is p_ppsf.txt
;
; PROCEDURES USED:
;
; MODIFICATION HISTORY:
;       Written by: W. M. Tai
;
;-
  on_error, 2


  if keyword_set(inputfile) then infile = inputfile else infile = 'p_ppsf.txt'

; read in the input file and take out those lines begin with 'comment'
; and with '#', also trim off the leading and trailing spaces.

  openr, unit, infile, /get_lun
  line = ' '

; the first line is a dummy
  buf = strarr(1)

  while (not eof(unit)) do begin
    readf, unit, line 
    if strmid(line, 0, 7) ne 'COMMENT' then begin
     if strlen(strtrim(line, 2)) gt 0 then begin
       if strmid(line, 0, 1) ne '#' then buf = [buf, strtrim(line, 2)]
     end
    end
  end
  free_lun, unit

; we are interested in the value table itself
  end_table = where(strmid(buf, 0, 12) eq 'END_INST_TAB')

; the value is the first 6 lines plus the nkeys X 2 + 1
; change the nkeys for different uplink files
  nkeys = 14
  begin_line = 7 + nkeys * 2
  value = buf(begin_line: end_table(0) - 1)
; note that we get rid of the first dummy line now

; In case there are varying space delimiter between each value,
; we parse the value line one at a time to extract the individual
; value to a token_buf.

  tab = string(9b)

; the first element in the ppsf_value is a dummy for the for loop
  ppsf_value = [[strarr(nkeys)]]

; nrows is the number of row in the table, change this for different
; table 

; change the nrows for different tables
  nrows = 14

; We only loop nkeys - 1, as the last token doesn't have any more blank
; space
    ind0 = nrows - 1
    ind = nkeys - 2

  for i = 0, ind0 do begin
    line = value(i)

;   replace all the tab characters, just in case
    while strpos(line, tab) GE 0 do begin
      pos = strpos(line, tab)
      strput, line, ' ', pos
    endwhile

    token_buf = strarr(nkeys)
    
; ind is calculated before the parental for loop.
    for j = 0, ind do begin
      pos = strpos(line, ' ')
      token_buf(j) = strmid(line, 0, pos)
      len = strlen(line)
      line = strtrim(strmid(line, pos+1, len-pos-1), 1) 
    endfor
    token_buf(nkeys - 1) = line
    ppsf_value = [[ppsf_value] , [token_buf]]
   endfor 

; Now we should have (nrows + 1) elements in ppsf_value where 
; the first one is
; a dummy but the rest of it would correspond to the pixel number
   ppsf_value = ppsf_value(*, 1 : nrows )

; change this to reflect the ouput format
  buffer = float(ppsf_value)

  return

end
