;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
;!                                                                             !
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
PRO READ_CHOPCOR
;+
; NAME:
;       READ_CHOPCOR
; PURPOSE:
;       Read the chopper correction factors from calg-G files and store 
;       into the COMMON phtchopcor
; CATEGORY:
;       PIA - I/O
;
; CALLING SEQUENCE:
;       READ_CHOPCOR
;
; INPUT PARAMETERS:
;       NONE
;
; OPTIONAL INPUT PARAMETERS:
;
; OUTPUT PARAMETERS:
;       NONE
;
; RESTRICTIONS:
;
; METHOD:
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               @phtchopcor
;       Astronomical Library:
;               fxread
;
; MODIFICATION HISTORY:
;       Written by: Jose Acosta                         January 1998
;       Version 7.0
;-
;
; Needed common blocks :
@phtchopcor

 ON_ERROR, 2
   
     ;define INCHOP_TIME: time spent per chopper plateau
     inchop_time = [1,2,4,8,16,32,64,128]
     NFREQ = N_ELEMENTS(inchop_time)
     
; xxchopcor are vectors of dimension [NPIX,NFREQ,2]
; should read the cal-G files
    FXREAD, !CALG + 'PPCHOPCOR.FITS', ppchopcor
    FXREAD, !CALG + 'PC1CHOPCOR.FITS', c1chopcor
    FXREAD, !CALG + 'PC2CHOPCOR.FITS', c2chopcor
    ; FXREAD, !CALG + 'PSCHOPP.FITS', slchopcor
    slchopcor = make_array(128,NFREQ,2,value=1)
    slchopcor(*,*,1)  = slchopcor(*,*,1)*0.
    
    c2p_pipe2ia, c2chopcor, c2chopcor_pia
       
CHOPCORR_STR = {inchop_time:inchop_time, p1corr:ppchopcor(0,*,*),     $
                 p2corr:ppchopcor(1,*,*), p3corr:ppchopcor(2,*,*),    $
                 c1corr:c1chopcor, c2corr:c2chopcor_pia, slcorr:slchopcor}

RETURN
END
 
