;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO READ_DARKORB
;+
; NAME:
;	READ_DARKORB
; PURPOSE:
;	Read the dark current depending on orbital position from calg-G files  
;       into the COMMON phtdarkorb
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;	READ_DARKORB
;
; INPUT PARAMETERS:
;	NONE
;
; OPTIONAL INPUT PARAMETERS:
;
; OUTPUT PARAMETERS:
;	NONE
;
; RESTRICTIONS:
;
; METHOD:
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               @phtdarkorb
;       PIA library:
;        	c2p_pipe2ia: changing order of C2 pixels 
;       Astronomical Library:
;               fxread
;
; MODIFICATION HISTORY:
;	Written by: Jose Acosta					November 1997
;	darkprorp and darkprom initialisation added (CG)	December 1997
;	Version 6.6
;	Time behaviour for SL included -> SLDARKTIME (JAc)	August 1998
;-
;
; Needed common blocks :
@phtdarkorb
	ON_ERROR, 2                                          

	FXREAD, !CALG+'PPDARK.FITS', ppdarkorb
	FXREAD, !CALG+'PC1DARK.FITS', c1darkorb
	FXREAD, !CALG+'PC2DARK.FITS', c2darkorb
	FXREAD, !CALG+'PSDARK.FITS', sldarkorb
	
	;change pixel ordering of C200 pixels from PIPELINE to PIA convention
	tmpdark = TRANSPOSE(c2darkorb,[1,0,2])
	c2p_pipe2ia, tmpdark, transdark
	c2darkorb = TRANSPOSE(transdark,[1,0,2])

	; construct the array with corresponding orbital position, 
	; the orbit will be divided into 100 bits
	NBITS = 100.
	ORBPOS_DARK = INDGEN(nbits) / nbits + 0.5 / nbits
	
	IF N_ELEMENTS(darkprorp) EQ 0 THEN darkprorp=0
	IF N_ELEMENTS(darkprom) EQ 0 THEN darkprom=0
	IF N_ELEMENTS(darkproaot) EQ 0 THEN darkproaot = 1
	
	;restore save file for the time dependency of SL dark current
	RESTORE, !CALSAVE +'SLDARKTIME.SAV'
	SLDARKTIME  = {TAU:tau, AMPL:a}
	
	
	DARKTDEP = 0
	

	RETURN
	END
