;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO READ_FCSILL, FILENAME
;+
; NAME:
;	READ_FCSILL
; PURPOSE:
;	Read the FCS illumination matrices from the FITS files into 
;       the COMMON phtillum
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;	READ_FCSILL[,FILENAME]
;
; INPUT PARAMETERS:
;	NONE
;
; OPTIONAL INPUT PARAMETERS:
;	FILENAME: An alternative file (or array of files) to be read, see
;		  restrictions !
;
; OUTPUT PARAMETERS:
;	NONE
;
; RESTRICTIONS:
;	FILENAME must be a valid (or an array of valid) PHT FCSILL fits file(s)
;			 AND
;		first character must be a P
;		2nd and 3rd characters must indicate the detector
;		('C1' for C100, 'P1' for P1, etc) 
;
; METHOD:
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phtillum
;       Astronomical Library:
;               fxread
;
; MODIFICATION HISTORY:
;	Written by: C. Gabriel - ESA/VILSPA-SAI
;	Modified by CG
;	Nov 96 Version 5.x
;	Change for C200 pixels SPD pipeline convention
;	New calibration version: primary FITS with a 4-dim table
;	 instead of binary table.
;	V6.0
;-
;
; Needed common blocks :
@phtillum

	ON_ERROR, 2                                          

; Take the user given file(s) or use the default ones

	IF KEYWORD_SET(filename) THEN file=filename ELSE BEGIN
		file='PC1ILLUM_01.FITS'
		file=[file,'PC2ILLUM_01.FITS']
	ENDELSE

	FOR I=0,N_ELEMENTS(file) - 1 DO BEGIN
		str = strmid(file(i),1,2)
		CASE str of 
			'C1': BEGIN
				fxread, !CALG+file(i), array
				c1ilcor = array(*,*,*,0)
				c1illun = array(*,*,*,1)
			      END
			'C2': BEGIN
				fxread, !CALG+file(i), array
				ilcor = array(*,*,*,0)
				illun = array(*,*,*,1)

; change from pipeline SPD convention
				c2p_pipe2ia, ilcor, c2ilcor
				c2p_pipe2ia, illun, c2illun
			      END
			ELSE: MESSAGE, /INFO, 'Not allowed string'
		ENDCASE
	ENDFOR
	RETURN
	END
