;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO READ_FCSPOW, FILENAME
;+
; NAME:
;	READ_FCSPOW
; PURPOSE:
;	Read the FCS power tables from the FITS files into 
;       the COMMON phtfcspow
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;	READ_FCSPOW[,FILENAME]
;
; INPUT PARAMETERS:
;	NONE
;
; OPTIONAL INPUT PARAMETERS:
;	FILENAME: An alternative file (or array of files) to be read, see
;		  restrictions !
;
; OUTPUT PARAMETERS:
;	NONE
;
; RESTRICTIONS:
;	FILENAME must be a valid (or an array of valid) PHT FCSPOW fits file(s)
;		located on the !CALG directory
;			 AND
;		2nd and 3rd characters must indicate the detector
;		('C1' for C100, 'P1' for P1, etc) 
;
; METHOD:
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phtfcs
;       Astronomical Library:
;               fxread
;
; MODIFICATION HISTORY:
;	Written by: C. Gabriel
;	Oct 95 Version 3.5
;	Reading also tables validity limits from hdr & putting them into @phtfcs
;	V7.0
;-
;
; Needed common blocks :
@phtfcs

	ON_ERROR, 2                                          

; Take the user given file(s) or use the default ones

	IF KEYWORD_SET(filename) THEN file=filename ELSE BEGIN
		file='PC1FCSPOW_02.FITS'
		file=[file,'PC2FCSPOW_02.FITS']
		file=[file,'PP1FCSPOW.FITS']
		file=[file,'PP2FCSPOW.FITS']
		file=[file,'PP3FCSPOW_02.FITS']
	ENDELSE

	FOR I=0,N_ELEMENTS(file) - 1 DO BEGIN
		str = strmid(file(i),1,2)
		CASE str of 
			'P1': BEGIN
				fxread, !CALG+file(i), p1fcspow
; read limits from header
				nfilt = N_ELEMENTS(p1fcspow(0,*,0,0))
				p1fcsp_lim = FLTARR(2,nfilt,2)
				p1fcsp_lim(0,*,*) = 0.
				p1fcsp_lim(1,*,*) = 99.
				
				openr, unit, !CALG+file(i), /block, /get_lun
				fxhread, unit, hdr
				values = FXPAR(hdr,'POWF1L*', count=count)
				IF count NE nfilt THEN BEGIN				
				  PRINT, STRING(7B), $
				    'Problem: P1 FCS1 POW low limits, old file?'
				ENDIF ELSE p1fcsp_lim(0,*,0) = values

				values = FXPAR(hdr,'POWF1U*', count=count)
				IF count NE nfilt THEN BEGIN				
				  PRINT, STRING(7B), $
				    'Problem: P1 FCS1 POW high limits, old file?'
				ENDIF ELSE p1fcsp_lim(1,*,0) = values

				values = FXPAR(hdr,'POWF2L*', count=count)
				IF count NE nfilt THEN BEGIN				
				  PRINT, STRING(7B), $
				    'Problem: P1 FCS2 POW low limits, old file?'
				ENDIF ELSE p1fcsp_lim(0,*,1) = values

				values = FXPAR(hdr,'POWF2U*', count=count)
				IF count NE nfilt THEN BEGIN				
				  PRINT, STRING(7B), $
				    'Problem: P1 FCS2 POW high limits, old file?'
				ENDIF ELSE p1fcsp_lim(1,*,1) = values
			END	
			'P2': BEGIN
				fxread, !CALG+file(i), p2fcspow
; read limits from header
				nfilt = N_ELEMENTS(p2fcspow(0,*,0,0))
				p2fcsp_lim = FLTARR(2,nfilt,2)
				p2fcsp_lim(0,*,*) = 0.
				p2fcsp_lim(1,*,*) = 99.
				
				openr, unit, !CALG+file(i), /block, /get_lun
				fxhread, unit, hdr
				values = FXPAR(hdr,'POWF1L*', count=count)
				IF count NE nfilt THEN BEGIN				   
				  PRINT, STRING(7B), $
				    'Problem: P2 FCS1 POW low limits, old file?'
				ENDIF ELSE p2fcsp_lim(0,*,0) = values

				values = FXPAR(hdr,'POWF1U*', count=count)
				IF count NE nfilt THEN BEGIN				  
				  PRINT, STRING(7B), $
				    'Problem: P2 FCS1 POW high limits, old file?'
				ENDIF ELSE p2fcsp_lim(1,*,0) = values

				values = FXPAR(hdr,'POWF2L*', count=count)
				IF count NE nfilt THEN BEGIN				
				  PRINT, STRING(7B), $
				    'Problem: P2 FCS2 POW low limits, old file?'
				ENDIF ELSE p2fcsp_lim(0,*,1) = values

				values = FXPAR(hdr,'POWF2U*', count=count)
				IF count NE nfilt THEN BEGIN				
				  PRINT, STRING(7B), $
				    'Problem: P2 FCS2 POW high limits, old file?'
				ENDIF ELSE p2fcsp_lim(1,*,1) = values
			END	
				
			'P3': BEGIN
				fxread, !CALG+file(i), p3fcspow
; read limits from header
				nfilt = N_ELEMENTS(p3fcspow(0,*,0,0))
				p3fcsp_lim = FLTARR(2,nfilt,2)
				p3fcsp_lim(0,*,*) = 0.
				p3fcsp_lim(1,*,*) = 99.
				
				openr, unit, !CALG+file(i), /block, /get_lun
				fxhread, unit, hdr
				values = FXPAR(hdr,'POWF1L*', count=count)
				IF count NE nfilt THEN BEGIN				
				  PRINT, STRING(7B), $
				    'Problem: P3 FCS1 POW low limits, old file?'
				ENDIF ELSE p3fcsp_lim(0,*,0) = values

				values = FXPAR(hdr,'POWF1U*', count=count)
				IF count NE nfilt THEN BEGIN				
				  PRINT, STRING(7B), $
				    'Problem: P3 FCS1 POW high limits, old file?'
				ENDIF ELSE p3fcsp_lim(1,*,0) = values

				values = FXPAR(hdr,'POWF2L*', count=count)
				IF count NE nfilt THEN BEGIN				
				  PRINT, STRING(7B), $
				    'Problem: P3 FCS2 POW low limits, old file?'
				ENDIF ELSE p3fcsp_lim(0,*,1) = values

				values = FXPAR(hdr,'POWF2U*', count=count)
				IF count NE nfilt THEN BEGIN				
				  PRINT, STRING(7B), $
				    'Problem: P3 FCS2 POW high limits, old file?'
				ENDIF ELSE p3fcsp_lim(1,*,1) = values
			END	
				
			'C1': BEGIN
				fxread, !CALG+file(i), c1fcspow
; read limits from header
				nfilt = N_ELEMENTS(c1fcspow(0,*,0,0))
				c1fcsp_lim = FLTARR(2,nfilt,2)
				c1fcsp_lim(0,*,*) = 0.
				c1fcsp_lim(1,*,*) = 99.
				
				openr, unit, !CALG+file(i), /block, /get_lun
				fxhread, unit, hdr
				values = FXPAR(hdr,'POWF1L*', count=count)
				IF count NE nfilt THEN BEGIN				
				  PRINT, STRING(7B), $
				    'Problem: C1 FCS1 POW low limits, old file?'
				ENDIF ELSE c1fcsp_lim(0,*,0) = values

				values = FXPAR(hdr,'POWF1U*', count=count)
				IF count NE nfilt THEN BEGIN				
				  PRINT, STRING(7B), $
				    'Problem: C1 FCS1 POW high limits, old file?'
				ENDIF ELSE c1fcsp_lim(1,*,0) = values

				values = FXPAR(hdr,'POWF2L*', count=count)
				IF count NE nfilt THEN BEGIN				
				  PRINT, STRING(7B), $
				    'Problem: C1 FCS2 POW low limits, old file?'
				ENDIF ELSE c1fcsp_lim(0,*,1) = values

				values = FXPAR(hdr,'POWF2U*', count=count)
				IF count NE nfilt THEN BEGIN				
				  PRINT, STRING(7B), $
				    'Problem: C1 FCS2 POW high limits, old file?'
				ENDIF ELSE c1fcsp_lim(1,*,1) = values
			END	
				
			'C2': BEGIN
				fxread, !CALG+file(i), c2fcspow
; read limits from header
				nfilt = N_ELEMENTS(c2fcspow(0,*,0,0))
				c2fcsp_lim = FLTARR(2,nfilt,2)
				c2fcsp_lim(0,*,*) = 0.
				c2fcsp_lim(1,*,*) = 99.
				
				openr, unit, !CALG+file(i), /block, /get_lun
				fxhread, unit, hdr
				values = FXPAR(hdr,'POWF1L*', count=count)
				IF count NE nfilt THEN BEGIN				
				  PRINT, STRING(7B), $
				    'Problem: C2 FCS1 POW low limits, old file?'
				ENDIF ELSE c2fcsp_lim(0,*,0) = values

				values = FXPAR(hdr,'POWF1U*', count=count)
				IF count NE nfilt THEN BEGIN				
				  PRINT, STRING(7B), $
				    'Problem: C2 FCS1 POW high limits, old file?'
				ENDIF ELSE c2fcsp_lim(1,*,0) = values

				values = FXPAR(hdr,'POWF2L*', count=count)
				IF count NE nfilt THEN BEGIN				
				  PRINT, STRING(7B), $
				    'Problem: C2 FCS2 POW low limits, old file?'
				ENDIF ELSE c2fcsp_lim(0,*,1) = values

				values = FXPAR(hdr,'POWF2U*', count=count)
				IF count NE nfilt THEN BEGIN				
				  PRINT, STRING(7B), $
				    'Problem: C2 FCS2 POW high limits, old file?'
				ENDIF ELSE c2fcsp_lim(1,*,1) = values
			END	
				
			ELSE: MESSAGE, /INFO, 'Not allowed string'
		ENDCASE
	    FREE_LUN, unit
	ENDFOR

	RETURN
	END
