;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO READ_FLATFIELD, FILENAME, C1ff=C1ff, C2ff=C2ff, Pff=Pff, $
		filter=filter
;+
; NAME:
;	READ_FLATFIELD
; PURPOSE:
;	Read the Flat Field Factors from the FITS files into 
;       the COMMON phtffield
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;	READ_FLATFIELD[,FILENAME]
;
; INPUT PARAMETERS:
;	NONE
;
; OPTIONAL INPUT PARAMETERS:
;	FILENAME: An alternative file (or array of files) to be read, see
;		  restrictions !
;
; OUTPUT PARAMETERS:
;	NONE
;
; KEYWORDS:
;	C1FF:	Flat field array for C100 data - 
;		   Full = FLTARR(9,7,2) except if FILTER set (s. FILTER)
;	C2FF:	Flat field array for C200 data - 
;		   Full = FLTARR(4,5,2) except if FILTER set (s. FILTER)
;	PFF:	Filter to filter corr array for P data - 
;		   Full = FLTARR(14,2) except if FILTER set (s. FILTER)
;	FILTER:	If set and corresponding to the nomenclature of C100/C200
;		filters (eg 'C1_50', 'C2_200') then C1FF/C2FF only for this 
;		filter (eg FLTARR(9,2) for C100)
;
; RESTRICTIONS:
;	FILENAME must be a valid (or an array of valid) PHT Flatfield (Filter
;	to filter) fits file(s)
;			 AND
;		first character must be a P
;		2nd and 3rd characters must indicate the detector
;		('PC1' for C100, 'PC2' for C200, 'PPF' for P) 
;
; METHOD:
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phtillum
;       Astronomical Library:
;               fxread
;
; MODIFICATION HISTORY:
;	Written by: C. Gabriel - ESA/VILSPA-SAI		May 1997
;	V6.3
;	Extended for filter to filter file PPFTOF	April 1999
;	V7.4
;-
;
; Needed common blocks :
@phtffield
@phtftof
@phtfilter

	ON_ERROR, 2                                          

; Take the user given file(s) or use the default ones

	IF KEYWORD_SET(filename) THEN file=filename ELSE BEGIN
		file='PC1FLAT.FITS'
		file=[file,'PC2FLAT.FITS','PPFTOF.FITS']
	ENDELSE

	c1fil='' & c2fil='' & pfil=''
	IF KEYWORD_SET(filter) THEN BEGIN
		IF N_ELEMENTS(c1filters) EQ 0 THEN phtfilter_init
		ind1 = WHERE(c1filters EQ filter,n1)
		ind2 = WHERE(c2filters EQ filter,n2)
		pfilters = [p1filters, p2filters, p3filters]
		ind3 = WHERE(pfilters EQ filter,n3)
		IF n1 GT 0 THEN c1fil=filter 
		IF n2 GT 0 THEN c2fil=filter
		If n3 GT 0 THEN pfil = filter
		IF (n1+n2+n3) EQ 0 THEN $
		   MESSAGE, /INFO, 'Wrong filter id given, returning'
		  
	ENDIF

	FOR I=0,N_ELEMENTS(file) - 1 DO BEGIN
		str = strmid(file(i),1,2)
		CASE str of 
			'PF': BEGIN
				fxread, !CALG+file(i), array
				ppftof = array(*,0)
				ppftofu = array(*,1)
				pff = array
				IF pfil NE '' THEN pff = $
				  reform(array(ind3,*))
			      END
			'C1': BEGIN
				fxread, !CALG+file(i), array
				c1flatf = array(*,*,0)
				c1flatu = array(*,*,1)
				c1ff = array
				IF c1fil NE '' THEN c1ff = $
				  reform(array(*,ind1,*))
			      END
			'C2': BEGIN
				fxread, !CALG+file(i), array
				flatf = array(*,*,0)
				flatu = array(*,*,1)
				c2ff = array

; change from pipeline SPD convention
				c2p_pipe2ia, flatf, c2flatf
				c2p_pipe2ia, flatu, c2flatu
				c2p_pipe2ia, c2ff, c2ff
				IF c2fil NE '' THEN c2ff = $
				  reform(c2ff(*,ind2,*))
			      END
			ELSE: MESSAGE, /INFO, 'Not allowed string'
		ENDCASE
	ENDFOR
	RETURN
	END
