;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO READ_FLUXCONV, FILENAME
;+
; NAME:
;	READ_FLUXCONV
; PURPOSE:
;	Read the Watts to Jy conversion factors from a FITS file into 
;       the COMMON phtw2jy
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;	READ_FLUXCONV
;
; INPUT PARAMETERS:
;	(none)
;
; OPTIONAL INPUT PARAMETERS:
;	FILENAME: The file to be read
;
; OUTPUT PARAMETERS:
;	NONE
;
; RESTRICTIONS:
;	FILENAME must be a valid PHT PFLUXCONV fits file
;
; METHOD:
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phtw2jy
;       Astronomical Library:
;               fxhread
;               fxpar
;
; MODIFICATION HISTORY:
;	Written by: C. Gabriel (ESA/VILSPA-SAI)		April 1996
;	Free_lun instead of close (CG)			May 1996
;-
;
; Needed common blocks :
@phtw2jy
	ON_ERROR, 2                                          

	IF KEYWORD_SET(filename) THEN file=filename ELSE $
			file=!CALG+'PFLUXCONV.FITS'

; open the file  (default='PFLUXCONV.FITS')
	OPENR, unit, file, /block, /GET_LUN 

; read header
	fxhread, unit, w2jhdr

; close the file 
	FREE_LUN, unit
	
; extract parameters
	w2jy_p = [fxpar(w2jhdr,'FCP3P29'), $
		fxpar(w2jhdr,'FCP3P6  '), $
		fxpar(w2jhdr,'FCP4P85 '), $
		fxpar(w2jhdr,'FCP7P3  '), $
		fxpar(w2jhdr,'FCP7P7  '), $
		fxpar(w2jhdr,'FCP10   '), $
		fxpar(w2jhdr,'FCP11P3 '), $
		fxpar(w2jhdr,'FCP12P8 '), $
		fxpar(w2jhdr,'FCP16   '), $
		fxpar(w2jhdr,'FCP11P5 '), $
		fxpar(w2jhdr,'FCP20   '), $
		fxpar(w2jhdr,'FCP25   '), $
		fxpar(w2jhdr,'FCP60   '), $
		fxpar(w2jhdr,'FCP100  ') ]
	w2jy_p = w2jy_p * 1.d-26
	
	w2jy_c = [0., fxpar(w2jhdr,'FCC90   '), $
		fxpar(w2jhdr,'FCC50   '), $
		fxpar(w2jhdr,'FCC60   '), $
		fxpar(w2jhdr,'FCC70   '), $
		fxpar(w2jhdr,'FCC100  '), $
		fxpar(w2jhdr,'FCC105  '), $
		fxpar(w2jhdr,'FCC90   '), $
		fxpar(w2jhdr,'FCC160  '), $
		fxpar(w2jhdr,'FCC200  '), $
		fxpar(w2jhdr,'FCC180  '), $
		fxpar(w2jhdr,'FCC135  '), $
		fxpar(w2jhdr,'FCC120  ') ]
	w2jy_c = w2jy_c * 1.d-26
	
	RETURN
	END
