;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       Read_footpr
;
; PURPOSE:
;	Read the calibration files P#FOOTPR  
;
; CATEGORY:
;       PIA - I/O
;
; CALLING SEQUENCE:
;       Read_footpr, det, fpr, fp_hdr
;
; INPUT:
;	DET:	Detector ('P2', 'C100', 'C1' ...)
;
; OUTPUT:
;	FPR:	The footprint data cube corresponding to DET
;	FP_HDR: The header of the footprint FITS file
;
; KEYWORD PARAMETERS:
;	ERROR: 0 if OK, 1 if failed
;
; COMMON BLOCKS:
;	(none)
;		
; PROCEDURES USED:
;	PIA LIB:
;		is_file_exist
;       ASTRO LIB:
;		fxread
;		
; MODIFICATION HISTORY:
;       Written by: C. Gabriel (ESA/VILSPA) 			July 1998
;	V7.2
;
;-
PRO read_footpr, det, fpr, fp_hdr, error=error

	ERROR = 0
	CASE STRUPCASE(STRMID(det,0,2)) of
	   'P2': file = !CALG + 'PP2FOOTP.FITS' 
	   'P3': file = !CALG + 'PP3FOOTP.FITS'
	   'C1': file = !CALG + 'PC1FOOTP.FITS'
	   'C2': file = !CALG + 'PC2FOOTP.FITS'
	   ELSE: BEGIN
	        PRINT, 'Not implemented case'
		ERROR = 1
		RETURN
	   END
	ENDCASE

	IF is_file_exist(file) NE -1 THEN BEGIN
		PRINT, 'Cannot find FOOTPRINT file ' + file + '. Returning'
		ERROR = 1
		RETURN
	ENDIF
	
	FXREAD, file, fpr, fp_hdr
	 	
	RETURN
	END
