;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO READ_IAAP, NAME, IPOS, PATH = PATH, ADMN=admn 
;+
; NAME:
;       READ_IAAP
; PURPOSE:
;	READ a PHTIAAP (Interactive Astronomical Application Data measurement) 
;	file into the dynamical structure PHTAAP  
; CATEGORY:
;	PIA - I/O
; CALLING SEQUENCE:
;       READ_IAAP, NAME [, IPOS] [, PATH = PATH] [, ADMN = ADMN]
;
; INPUT:
;       NAME 	: IAAP-savefile name
;
; OPTIONAL INPUT KEYWORD:
;	PATH    : path for the file
;
; OPTIONAL OUTPUT:
;	IPOS	: index within phtaap array
;
; OPTIONAL OUTPUT KEYWORD:
;	ADMN	: administration name (phtaap.admn)
;
;
; RESTRICTIONS:
;       NAME must correspond to a valid PHTIAAP file 
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phtaap
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel (ESA/SAI)		June 1996
;	central wavelength added (WMT)                  Nov 1996
;	IPOS added as output argument	(JAcosta)	April 1997	
;	Keyword admn added & filename in HDR (CG)	May 1997
;	V6.3
;-
;
@phtaap
@phtfilter_prop
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  READ_IAAP, NAME [, IPOS] [, PATH = PATH]'

;  check name for extension IAAP, name should not contain it!!
        ext_name = '.IAAP'
	trim_pos = strpos(name,ext_name)
	IF trim_pos ne -1 then tmpname = STRMID(name,0,trim_pos) $ 
	   ELSE tmpname = name

; create filename esp if path is set
	if keyword_set(PATH) then $
	  filename = PATH + TMPNAME + ext_name $
	else BEGIN
	  revers_name = STR_REVERSE(tmpname)
	  IF !version.os EQ "VMS" THEN $
	    ind = STRPOS(revers_name,']') ELSE $
	    ind = STRPOS(revers_name,'/') 
	  IF ind eq -1 THEN tmpname = revers_name ELSE $ 	    
	    tmpNAME = STRMID(revers_name,0,ind)
	  tmpname = STR_REVERSE(tmpname)
	  filename = name
	ENDELSE

;  Restore the save file

	RESTORE, FILENAME
	admn = phtiaap.admn
	hdr = phtiaap.hdr

; Put filename into header - If = official measname then put a 0
		  
	FXADDPAR, hdr, 'PIA_MNAM', tmpname, $
	 "Name chosen for measurement by PIA user", BEFORE='XTENSION'
		
; Check if old type
	res = FXPAR(hdr, 'PIA_NAAP', count=count)
	IF count EQ 0 THEN BEGIN
		gen_pap, phtiaap, pap
		phtiaap = pap
		gen_aap, phtiaap
		MESSAGE, /INFO, 'Old type AAP file converted to AAP2000'
		FXADDPAR, hdr, 'PIA_NAAP', 2, ' New type AAP: AAP2000 derived', $
		 BEFORE='XTENSION'
	ENDIF	
	
;  Fill the phtaap buffer
	fill_aap, phtiaap, hdr
	
;  Get the position within the PHTSCP structure 
        IPOS = N_elements(phtaap) - 1


        END
