;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO READ_ICLA, NAME, PATH = PATH, ADMN=admn 
;+
; NAME:
;       READ_ICLA
; PURPOSE:
;	READ a PHTICLA (Interactive Calibration A measurement) file 
;	into the dynamical structure PHTCLA  
; CATEGORY:
;	PIA - I/O
; CALLING SEQUENCE:
;       READ_ICLA, NAME, PATH = PATH
;
; INPUT:
;       NAME 	: CaL A-savefile name
;
; OPTIONAL INPUT:
;       PATH    : path for the file
;
; OPTIONAL OUTPUT KEYWORD:
;	ADMN	: administration name
;
; RESTRICTIONS:
;       NAME must correspond to a valid PHTICLA file 
;
; PROCEDURES USED: 
;       Common Block(s) or @ procedure(s):
;               adm
;               phtcla
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel
;	Oct 95 Version 3.5
;       optional path added (WMT)                       March 1996
;	Keyword admn added & filename in HDR (CG)	May 1997
;	V6.3
;-
;
@adm
@phtcla
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  READ_ICLA, NAME, [PATH = PATH]'

; create filename esp if path is set
	if keyword_set(PATH) then $
	  filename = PATH + NAME $
	else BEGIN
	  filename = NAME
	  IF !version.os EQ "VMS" THEN BEGIN
	    ind = STRPOS(filename,']') 
	    NAME = STRMID(filename,ind(0)+1,STRLEN(filename)-ind(0)-1)
	  ENDIF ELSE BEGIN
	    ind = STRPOS(filename,'/')
	    NAME = STRMID(filename, ind(max(ind))+1, $
	      STRLEN(filename)-ind(max(ind))+1)
	  ENDELSE
	ENDELSE

;  Restore the save file
	RESTORE, FILENAME
	admn = PHTICLA.admn
	hdr = phticla.hdr

; Put filename into header - If = official measname then put a 0

	name = STRMID(name,0,STRLEN(name)-5)
	IF name EQ PHTICLA.ADMN THEN $
	  name = 0 ELSE $
	  name = '"' + name + '"'
	FXADDPAR, hdr, 'PIA_MNAM', name, $
	 "Name chosen for measurement by PIA user", BEFORE='XTENSION'
		
; for giving back full filename
	NAME=FILENAME


;  Create the structures and the handles
        PHTCLAT = {PHTCLA_TYPE}
        PHTCLAT.HDR = HANDLE_CREATE()
        PHTCLAT.RPID = HANDLE_CREATE()
        PHTCLAT.QFLG = HANDLE_CREATE()
        PHTCLAT.QSTA = HANDLE_CREATE()
        PHTCLAT.STAT = HANDLE_CREATE()
        PHTCLAT.CPOS = HANDLE_CREATE()
        PHTCLAT.FCS1 = HANDLE_CREATE()
        PHTCLAT.FCS2 = HANDLE_CREATE()
        PHTCLAT.TEMP = HANDLE_CREATE()
        PHTCLAT.TIME = HANDLE_CREATE()
        PHTCLAT.BIAS = HANDLE_CREATE()
        PHTCLAT.PIXL = HANDLE_CREATE()
        PHTCLAT.PUNC = HANDLE_CREATE()

;  Fill the temporary CLA structure
        PHTCLAT.UNIT = PHTICLA.UNIT
        PHTCLAT.DET  = PHTICLA.DET
        PHTCLAT.ADMN = PHTICLA.ADMN
        PHTCLAT.ORDR = PHTICLA.ORDR
        PHTCLAT.DIMS = PHTICLA.DIMS
        PHTCLAT.DWEL = PHTICLA.DWEL

;  Fill the handles
        HANDLE_VALUE, PHTCLAT.HDR, hdr, /SET  
        HANDLE_VALUE, PHTCLAT.RPID, PHTICLA.RPID, /SET  
        HANDLE_VALUE, PHTCLAT.QFLG, PHTICLA.QFLG, /SET     
        HANDLE_VALUE, PHTCLAT.QSTA, PHTICLA.QSTA, /SET  
	HANDLE_VALUE, PHTCLAT.STAT, PHTICLA.STAT, /SET   
        HANDLE_VALUE, PHTCLAT.CPOS, PHTICLA.CPOS, /SET  
        HANDLE_VALUE, PHTCLAT.FCS1, PHTICLA.FCS1, /SET   
        HANDLE_VALUE, PHTCLAT.FCS2, PHTICLA.FCS2, /SET     
	HANDLE_VALUE, PHTCLAT.TEMP, PHTICLA.TEMP, /SET   
        HANDLE_VALUE, PHTCLAT.TIME, PHTICLA.TIME, /SET  
        HANDLE_VALUE, PHTCLAT.BIAS, PHTICLA.BIAS, /SET  
        HANDLE_VALUE, PHTCLAT.PIXL, PHTICLA.PIXL, /SET  
        HANDLE_VALUE, PHTCLAT.PUNC, PHTICLA.PUNC, /SET  

;  Update the PHTCLA structure using the temporary structure
        PHTCLA = [PHTCLA,PHTCLAT]

;  Does exist already an administration record for this measurement?
	       IDNAME = PHTICLA.ADMN
	       DETID = PHTICLA.DET
               ADMIND = WHERE(ADM.NAME EQ IDNAME, N)

;  Update the administration file using temporary structure
               IF (N EQ 1) THEN BEGIN
                ADM(ADMIND).PHTICLA = N_ELEMENTS(PHTCLA) - 1
                IF (DETID EQ 'SS') THEN BEGIN
                  STRPUT, IDNAME, 'L', 1
                  ADMIND2 = WHERE(ADM.NAME EQ IDNAME, N)
                  IF (N EQ 1) THEN $
                        ADM(ADMIND2).PHTICLA = N_ELEMENTS(PHTCLA) - 1 $
                   ELSE IF (N EQ 0) THEN BEGIN
                        ADMT = {ADM_TYPE}
                        ADMT.NAME = IDNAME
                        CLAPOS = N_ELEMENTS(PHTCLA) - 1
                        ADMT.PHTICLA = CLAPOS
                        ADM = [ADM, ADMT]
                  ENDIF ELSE PRINT, 'READ_CLA: Several identical ADM-records'
                ENDIF
               ENDIF ELSE IF (N EQ 0) THEN BEGIN
                   ADMT = {ADM_TYPE}
                   ADMT.NAME = IDNAME
                   CLAPOS = N_ELEMENTS(PHTCLA) - 1
                   ADMT.PHTICLA = CLAPOS
                   ADM = [ADM, ADMT]
                IF (DETID EQ 'SS') THEN BEGIN
                  STRPUT, IDNAME, 'L', 1
                  ADMIND2 = WHERE(ADM.NAME EQ IDNAME, N)
                  IF (N EQ 1) THEN $
                        ADM(ADMIND2).PHTICLA = N_ELEMENTS(PHTCLA) - 1 $
                   ELSE IF (N EQ 0) THEN BEGIN
                        ADMT = {ADM_TYPE}
                        ADMT.NAME = IDNAME
                        CLAPOS = N_ELEMENTS(PHTCLA) - 1
                        ADMT.PHTICLA = CLAPOS
                        ADM = [ADM, ADMT]
                  ENDIF ELSE PRINT, 'READ_CLA: Several identical ADM-records'
                ENDIF
               ENDIF ELSE PRINT, 'READ_CLA: Several identical ADM-records'
        RETURN
        END
