;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO READ_ICS, NAME, PATH = PATH 
;+
; NAME:
;       READ_ICS
; PURPOSE:
;	READ a PHTICS (Interactive Compact Status Data) file 
;	into the dynamical structure PHTCS 
; CATEGORY:
;	PIA - I/O
; CALLING SEQUENCE:
;       READ_ICS, NAME, PATH = PATH
;
; INPUT:
;       NAME 	: CS-savefile name
;
; OPT. INPUT:
;	PATH    : path for the file
;
; RESTRICTIONS:
;       NAME must be a valid PHTICS file 
;
; PROCEDURES USED: 
;       Common Block(s) or @ procedure(s):
;               phtcs
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel (ESA/VILSPA-SAI)		December 1995
;	optional path added (WMT)		        March 1996
;
;-
;
@phtcs
;
        ON_ERROR, 2
	on_ioerror, print_error
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  READ_ICS, NAME, [PATH = PATH]'

	if keyword_set(path) then $
	  filename = path + name $
	else filename = name
	junk = FINDFILE(filename, COUNT=count)
	IF count EQ 0 THEN BEGIN
		MESSAGE, /info, 'Internal CS not found, returning + continuing'
		RETURN
	ENDIF ELSE BEGIN

;  Restore the save file
	RESTORE, FILENAME

	ind = WHERE(PHTCS.UNIT EQ PHTICS.UNIT, count)
	IF count GT 0 THEN BEGIN
		MESSAGE, /INFO, 'Compact Status file already present'
		RETURN
	ENDIF

;  Create the structures and the handles
        PHTCST = {PHTCS_TYPE}
        PHTCST.HANDLE = HANDLE_CREATE()

;  Fill the temporary ERD structure
        PHTCST.UNIT = PHTICS.UNIT
        PHTCST.DIMS = PHTICS.DIMS

;  Fill the handles
        HANDLE_VALUE, PHTCST.HANDLE, PHTICS.HANDLE, /SET  

;  Update the PHTCS structure using the temporary structure
        PHTCS = [PHTCS,PHTCST]

	ENDELSE
        RETURN
print_error:
	msg = 'File: ' + NAME + ' Not Found!'
	return
        END
