;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
pro read_idb_def,header,idb,idb_ar_table,idb_ar_image

;+
; NAME:
;       read_idb_def
; PURPOSE:
;       Read data from pht_fm.idb_def data base
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;       read_idb_def,header,idb,idb_ar_table,idb_ar_image
;
; INPUT PARAMETERS:
;       NONE
;
; OUTPUT PARAMETERS:
;       idb         :database array
;       idb_ar_table and idb_ar_image with informations about 
;              action routines
;       header      :header of idb_def file
;
; RESTRICTIONS:
;       NONE
; 
; METHOD:
;       Store data used for all kinds of idb entries in the first
;       17 elements of the idb array, element number 18 contains
;       an pointer on a struct of 5 pointers on the 5 posible
;       entries: index status analog1 analog2 analog3
;       A zero means, that no data of this type is used for
;       this entry        
;
; PROCEDURES USED:
;       Astronomical Library:
;               boost_array
;       Other Procedure(s):
;               pht_fm.idb_def
;
; MODIFICATION HISTORY:
;       Written by: Andreas Karch
;	Modified by: C Gabriel
;	Oct 95 Version 3.5
;	Free_lun instead of close (CG)		May 1996
;-

idb=''
dummy=''
form_index=strarr(4)
form_status=strarr(17)
form_analog1=strarr(7)
form_analog2=strarr(32)
form_analog3=strarr(16,4)
help_analog3=strarr(4,16)
a_bottom=0
idb_ar_table=''
idb_ar_image=''

; struct for input
struct={idb_pool_form,index:0,status:0,analog1:0,analog2:0,analog3:0}

openr,unit,!CALG+'pht_fm.idb_def', /get_lun

; read header
 ;  header(0) = Version
 ;  header(1) = Nr of Entries
 ;  header(2) = Instrument

header = intarr(3)
readf,unit,dummy,format='(78x,i3)'
 header(0)=dummy
readf,unit,dummy,dummz,format='(15x,i3,12x,i1)'
 header(1)=dummy
 header(2)=dummz

; read idb_def in array idb
;  0: de_number  1: de_name  2: de_type  3: subcom_flag  4: mode_flag  5: monitor
;  6: max_slots  7: decomp  8: conv  9: limsel  10: limit  11: memver  12: qlagen 
;  13: extr_source 14: extr_ar  15: location  16: offset  17: length  
;  18: handle with corresponding struct

; loop through entries

for z=0,header(1)-1 do begin

form='(/,1x,a3,9x,a12,9x,a3,8x,a1,6x,a1,9x,a1,/,14x,a3,8x,a1,6x,a1,8x,a1,9x,a1,8x,a1,8x,a1,/'
form=form+'14x,a5,6x,a31,/,15x,a5,8x,a5,8x,a3)'

help=strarr(18)
junk=strarr(19)
readf,unit,help,format=form
junk(0:17)=help

; idb(18,z) contains a pointer on the struct of type {idb_pool_form} with the information
;  about the DE number z

junk(18)=handle_create()
help=junk

a={idb_pool_form,0,0,0,0,0}

; index form
; handle_value,help(18)   .index contains pointer on form_index array
; form_index:  0: subcom_index  1: subcom_mask  2: mode_index  3: mode_mask

 if help(3) ne ' ' or help(4) ne ' '  then begin
  readf,unit,form_index,format='(12x,a12,6x,a4,6x,a12,6x,a4)
  a.index=handle_create(value=form_index)
 endif

; status form if conversion is selected
; handle_value(18)  .status contains pointer on form_status array
; form_status:  0: conv_ar  1-16: conv_tab(1-16)

 if help(2) eq 'STS' and help(8) ne ' ' then begin
  readf,unit,form_status,format='(13x,a31,10x,/,6x,8(1x,a8),/,6x,8(1x,a8))'
  a.status=handle_create(value=form_status)
 endif

; analog1 form whenever analog
; handle_value(18) .analog1 contains pointer on form_analog1
; form_analog1:  0: conv_ar  1: limsel_ar  2: limitch_ar  3: conv_index
;                      4: limsel_index  5: limitch_index  6: unit                   

 if help(2) eq 'ANA'  then begin
  form='(13x,a31,/,15x,a31,/,16x,a31,/,16x,a12,14x,a12,15x,a12,6x,4a1)' 
  readf,unit,form_analog1,format=form
  a.analog1=handle_create(value=form_analog1)
 endif

; analog2 form whenever analog and conversion needed
; handle_value(18) .analog2 contains pointer on form_analog2
; form_analog2:   0-31: c_tab(1-32) 

 if help(2) eq 'ANA' and help(8) ne ' ' then begin
  readf,unit,form_analog2,format='(7(10x,4(1x,a10),/),10x,4(1x,a10))
  
  ; the analog conversion tables must be prepared for the interpolation
  ; that is done at conversion (isn't needed for our purposes)
  
  ;  form_analog2=trans_fill_ctab(form_analog2) 

 a.analog2=handle_create(value=form_analog2)
 endif

; analog3 form whenever analog and limits selected
; handle_value(18) .analog3 contains pointer on form_analog3
; form_analog3:   (0-15,0-3) : limit (1-16,1-4)

 if help(2) eq 'ANA' and  (help(9) ne ' ' or help(10) ne ' ' ) then begin
  readf,unit,help_analog3,format='(15(10x,4(1x,a10),/),10x,4(1x,a10))'
  
  ;the 16 sets of 4 limits come from the formatted input in the form of an 
  ;(4,16) array, but should be in an (16,4) array so the folowing translation
  ;has to be done
    for l=0,3 do begin
     form_analog3(*,l)=help_analog3(l,*)
    endfor

 a.analog3=handle_create(value=form_analog3)
 endif

; add phot data to idb array

if help(15) ge 628 and help(15) le 692 then begin
 if z eq 0 then idb=help
 if z ne 0 then boost_array,idb,help
endif

handle_value,help(18),a,/set

endfor

; read AR table

readf,unit,a_bottom,idb_ar_image,format='(18x,i3,7x,a)'

if a_bottom gt 0 then begin
 idb_ar_table=strarr(a_bottom)
 for i=1,a_bottom do begin
  readf,unit,dummy,format='(1x,a31)'
  idb_ar_table(i)=dummy
 endfor
endif

FREE_LUN,unit

end
