;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO READ_IERD, NAME, PATH = PATH, ADMN = ADMN 
;+
; NAME:
;       READ_IERD
; PURPOSE:
;	READ a PHTIERD (Interactive Edited Raw Data measurement) file 
;	into the dynamical structure PHTERD  
; CATEGORY:
;	PIA - I/O
; CALLING SEQUENCE:
;       READ_IERD, NAME [,PATH = PATH] [, ADMN = ADMN]
;
; INPUT:
;       NAME 	: ERD-savefile name
; OPTIONAL INPUT:
;	PATH    : path for the file
;
; OUTPUT KEYWORD:
;	ADMN    : administration name (phterd.admn)
;
;
; RESTRICTIONS:
;       NAME must be a valid PHTIERD file 
;
; PROCEDURES USED: 
;       Common Block(s) or @ procedure(s):
;               adm
;               phterd
;       PIA Procedure(s):
;               read_erd
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel
;	Oct 95 Version 3.5
;       optional path added (WMT)                       March 1996
;	Keyword admn added & filename in HDR (CG)	May 1997
;	V6.3
;-
;
;@adm
@phterd
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  READ_IERD, NAME [, IPOS] [,PATH = PATH] [, ADMN = ADMN]'

;  check name for extension ISRD, name should not contain it!!
        ext_name = '.IERD'
	trim_pos = strpos(name,ext_name)
	IF trim_pos ne -1 then tmpname = STRMID(name,0,trim_pos) $ 
	  ELSE tmpname = name 

; create filename esp if path is set
	if keyword_set(PATH) then $
	  filename = PATH + TMPNAME + ext_name $
	else BEGIN
	  revers_name = STR_REVERSE(tmpNAME)
	  IF !version.os EQ "VMS" THEN $
	    ind = STRPOS(revers_name,']') ELSE $
	    ind = STRPOS(revers_name,'/') 
	  IF ind eq -1 THEN tmpname = revers_name ELSE $ 	    
	    tmpname = STRMID(revers_name,0,ind)
	  tmpname = STR_REVERSE(tmpname)
	  filename = name
	ENDELSE

;  Restore the save file
	RESTORE, FILENAME
	ADMN = phtierd.admn
	hdr = phtierd.hdr

; Put filename into header - If = official measname then put a 0

	FXADDPAR, hdr, 'PIA_MNAM', tmpname, $
	 "Name chosen for measurement by PIA user", BEFORE='XTENSION'
		

;  Create the structures and the handles
;  Fill the phtspd buffer
        fill_erd, phtierd, hdr
       
;  Get the position within the PHTERD structure 
	IPOS = N_ELEMENTS(phterd) - 1

; not used anymore, leave just in case 
;;  Does exist already an administration record for this measurement?
;	       IDNAME = PHTIERD.ADMN
;	       DETID = PHTIERD.DET
;               ADMIND = WHERE(ADM.NAME EQ IDNAME, N)
;
;;  Update the administration file using temporary structure
;               IF (N EQ 1) THEN BEGIN
;                ADM(ADMIND).PHTIERD = N_ELEMENTS(PHTERD) - 1
;                IF (DETID EQ 'SS') THEN BEGIN
;                  STRPUT, IDNAME, 'L', 1
;                  ADMIND2 = WHERE(ADM.NAME EQ IDNAME, N)
;                  IF (N EQ 1) THEN $
;                        ADM(ADMIND2).PHTIERD = N_ELEMENTS(PHTERD) - 1 $
;                   ELSE IF (N EQ 0) THEN BEGIN
;                        ADMT = {ADM_TYPE}
;                        ADMT.NAME = IDNAME
;                        ERDPOS = N_ELEMENTS(PHTERD) - 1
;                        ADMT.PHTIERD = ERDPOS
;                        ADM = [ADM, ADMT]
;                  ENDIF ELSE PRINT, 'READ_ERD: Several identical ADM-records'
;                ENDIF
;               ENDIF ELSE IF (N EQ 0) THEN BEGIN
;                   ADMT = {ADM_TYPE}
;                   ADMT.NAME = IDNAME
;                   ERDPOS = N_ELEMENTS(PHTERD) - 1
;                   ADMT.PHTIERD = ERDPOS
;                   ADM = [ADM, ADMT]
;                IF (DETID EQ 'SS') THEN BEGIN
;                  STRPUT, IDNAME, 'L', 1
;                  ADMIND2 = WHERE(ADM.NAME EQ IDNAME, N)
;                  IF (N EQ 1) THEN $
;                        ADM(ADMIND2).PHTIERD = N_ELEMENTS(PHTERD) - 1 $
;                   ELSE IF (N EQ 0) THEN BEGIN
;                        ADMT = {ADM_TYPE}
;                        ADMT.NAME = IDNAME
;                        ERDPOS = N_ELEMENTS(PHTERD) - 1
;                        ADMT.PHTIERD = ERDPOS
;                        ADM = [ADM, ADMT]
;                  ENDIF ELSE PRINT, 'READ_IERD: Several identical ADM-records'
;                ENDIF
;               ENDIF ELSE PRINT, 'READ_IERD: Several identical ADM-records'
        RETURN
        END
