;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO READ_ISCP, NAME, IPOS, PATH = PATH, ADMN = ADMN 
;+
; NAME:
;       READ_ISCP
; PURPOSE:
;	READ a PHTISCP (Interactive Signal per Chopper Plateau) file 
;	into the dynamical structure PHTSCP  
; CATEGORY:
;	PIA - I/O
; CALLING SEQUENCE:
;       READ_ISCP, NAME [, IPOS] [, PATH = PATH] [, ADMN = ADMN]
;
; INPUT:
;       NAME 	: SCP-savefile name
; OPTIONAL INPUT:
;	PATH    : path for the file
;
; OPTIONAL OUTPUT:
;	IPOS	: index within phtscp array
;
; OUTPUT KEYWORD:
;	ADMN    : administration name (phtscp.admn)
;
; RESTRICTIONS:
;       NAME must be a valid PHTISCP file 
;
; PROCEDURES USED: 
;       Common Block(s) or @ procedure(s):
;               adm
;               phtscp
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel (ESA/ESTEC-SAI)
;	Oct 95 Version 3.5
;	Structure extension: ARSI, ANDR and AVSD
;       add optional path (WMT)                        March 1996
;	IPOS added as output argument	(JAcosta)	April 1997	
;	Keyword admn added & filename in HDR (CG)	May 1997
;       Simplified way of asigning name and saving (JA) May 1997
;	V6.3
;-
;
;@adm
@phtscp
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  READ_ISCP, NAME [, IPOS] [, PATH = PATH] [, ADMN = ADMN]'

;  check name for extension ISCP, name should not contain it!!
        ext_name = '.ISCP'
	trim_pos = strpos(name,ext_name)
	IF trim_pos ne -1 then tmpname = STRMID(name,0,trim_pos) $ 
	   ELSE tmpname = name


; create filename esp if path is set
	if keyword_set(PATH) then $
	  filename = PATH + TMPNAME + ext_name $
	else BEGIN
	  revers_name = STR_REVERSE(tmpname)
	  IF !version.os EQ "VMS" THEN $
	    ind = STRPOS(revers_name,']') ELSE $
	    ind = STRPOS(revers_name,'/') 
	  IF ind eq -1 THEN tmpname = revers_name ELSE $ 	    
	    tmpNAME = STRMID(revers_name,0,ind)
	  tmpname = STR_REVERSE(tmpname)
	  filename = name
	ENDELSE


;  Restore the save file
	RESTORE, FILENAME
	admn = PHTISCP.ADMN
	hdr = phtiscp.hdr

; Put filename into header - If = official measname then put a 0

	FXADDPAR, hdr, 'PIA_MNAM', tmpname, $
	 "Name chosen for measurement by PIA user", BEFORE='XTENSION'
		

;  Fill the phtscp buffer
 	fill_scp, phtiscp, hdr

;  Get the position within the PHTSCP structure 
	IPOS = N_elements(phtscp) - 1 

;  Does exist already an administration record for this measurement?
	       IDNAME = PHTISCP.ADMN
	       DETID = PHTISCP.DET

; not used anymore, leave just in case 
;;  Update the administration file using temporary structure
;               ADMIND = WHERE(ADM.NAME EQ IDNAME, N)
;               IF (N EQ 1) THEN BEGIN
;                ADM(ADMIND).PHTSCP = N_ELEMENTS(PHTSCP) - 1
;                IF (DETID EQ 'SS') THEN BEGIN
;                  STRPUT, IDNAME, 'L', 1
;                  ADMIND2 = WHERE(ADM.NAME EQ IDNAME, N)
;                  IF (N EQ 1) THEN $
;                        ADM(ADMIND2).PHTSCP = N_ELEMENTS(PHTSCP) - 1 $
;                   ELSE IF (N EQ 0) THEN BEGIN
;                        ADMT = {ADM_TYPE}
;                        ADMT.NAME = IDNAME
;                        SCPPOS = N_ELEMENTS(PHTSCP) - 1
;                        ADMT.PHTSCP = SCPPOS
;                        ADM = [ADM, ADMT]
;                  ENDIF ELSE PRINT, 'READ_ISCP: Several identical ADM-records'
;                ENDIF
;               ENDIF ELSE IF (N EQ 0) THEN BEGIN
;                   ADMT = {ADM_TYPE}
;                   ADMT.NAME = IDNAME
;                   SCPPOS = N_ELEMENTS(PHTSCP) - 1
;                   ADMT.PHTSCP = SCPPOS
;                   ADM = [ADM, ADMT]
;                IF (DETID EQ 'SS') THEN BEGIN
;                  STRPUT, IDNAME, 'L', 1
;                  ADMIND2 = WHERE(ADM.NAME EQ IDNAME, N)
;                  IF (N EQ 1) THEN $
;                        ADM(ADMIND2).PHTSCP = N_ELEMENTS(PHTSCP) - 1 $
;                   ELSE IF (N EQ 0) THEN BEGIN
;                        ADMT = {ADM_TYPE}
;                        ADMT.NAME = IDNAME
;                        SCPPOS = N_ELEMENTS(PHTSCP) - 1
;                        ADMT.PHTSCP = SCPPOS
;                        ADM = [ADM, ADMT]
;                  ENDIF ELSE PRINT, 'READ_ISCP: Several identical ADM-records'
;                ENDIF
;               ENDIF ELSE PRINT, 'READ_ISCP: Several identical ADM-records'

        RETURN
        END
