;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO READ_ISPD, NAME, IPOS, PATH = PATH, ADMN = ADMN  
;+
; NAME:
;       READ_ISPD
; PURPOSE:
;	READ a PHTISPD (Interactive Standard Processed Data measurement) file 
;	into the dynamical structure PHTSPD  
; CATEGORY:
;	PIA - I/O
; CALLING SEQUENCE:
;       READ_ISPD, NAME [, IPOS] [, PATH = PATH] [, ADMN = ADMN]
;
; INPUT:
;       NAME 	: ISPD-savefile name
;
; OPTIONAL INPUT:
;	PATH    : path for the file
;
; OPTIONAL OUTPUT:
;	IPOS	: index within phtspd array
;
; OUTPUT KEYWORD:
;	ADMN    : administration name (phtscp.admn)
;
; RESTRICTIONS:
;       NAME must correspond to a valid PHTISPD file 
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               adm
;               phtspd
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel
;	Oct 95 Version 3.5
;	RA, DEC bug fixed + missed keywords (CG)        December 1995
;       optional path added (WMT)                       March 1996
;	Keyword admn added & filename in HDR (CG)	May 1997
;	V6.3
;-
;
;@adm
@phtspd
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  READ_ISPD, NAME [, IPOS] [, PATH = PATH] [, ADMN = ADMN]'

;  check name for extension ISPD, name should not contain it!!
        ext_name = '.ISPD'
	trim_pos = strpos(name,ext_name)
	IF trim_pos ne -1 then tmpname = STRMID(name,0,trim_pos) $ 
	   ELSE tmpname = name

; create filename esp if path is set
	if keyword_set(PATH) then $
	  filename = PATH + TMPNAME + ext_name $
	else BEGIN
	  revers_name = STR_REVERSE(tmpname)
	  IF !version.os EQ "VMS" THEN $
	    ind = STRPOS(revers_name,']') ELSE $
	    ind = STRPOS(revers_name,'/') 
	  IF ind eq -1 THEN tmpname = revers_name ELSE $ 	    
	    tmpNAME = STRMID(revers_name,0,ind)
	  tmpname = STR_REVERSE(tmpname)
	  filename = name
	ENDELSE

;  Restore the save file
	RESTORE, FILENAME
	admn = PHTISPD.ADMN
	hdr = phtispd.hdr

; Put filename into header - If = official measname then put a 0

	FXADDPAR, hdr, 'PIA_MNAM', tmpname, $
	 "Name chosen for measurement by PIA user", BEFORE='XTENSION'
		

;  Create the structures and the handles
;  Fill the phtspd buffer
        fill_spd, phtispd, hdr
       
;  Get the position within the PHTSCP structure 
	IPOS = N_ELEMENTS(phtspd) - 1

; not used anymore, leave just in case 
;;  Does exist already an administration record for this measurement?
;	       IDNAME = PHTISPD.ADMN
;              ADMIND = WHERE(ADM.NAME EQ IDNAME, N)
;;  Update the administration file using temporary structure
;              IF (N EQ 1) THEN $
;                ADM(ADMIND).PHTISPD = N_ELEMENTS(PHTSPD) - 1 $
;               ELSE IF (N EQ 0) THEN BEGIN
;                ADMT = {ADM_TYPE}
;                ADMT.NAME = IDNAME
;                ADMT.PHTISPD = N_ELEMENTS(PHTSPD) - 1
;                ADM = [ADM, ADMT]
;              ENDIF ELSE PRINT, 'READ_SPD: Several identical ADM-records'
	RETURN
        END
