;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO READ_MAP, FILENAME, HEADER, BUFFER, PATH = PATH
;+
; NAME:
;       READ_MAP
; PURPOSE:
;       Read a PHT-AAR (Auto Analysis Result) file 
; CATEGORY:
;       PIA - I/O
; CALLING SEQUENCE:
;       READ_MAP, NAME, HEADER, BUFFER, [ PATH = PATH ]
;
; INPUT:
;       NAME    : Name of AAR FITS file to be read
;
; OPT. INPUT:
;       PATH    : optional path for the file
;
; OPT. OUTPUTS:
;       HEADER  : String array containing the FITS binary table extension
;                 header
; RESTRICTIONS:
;       File must be a valid PHT AAR FITS file
;	Except PHT Photometric Image
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               adm
;               phtcs
;               phtaar
;       Astronomical Library:
;               sxpar
; MODIFICATION HISTORY:
;       Written by: Wai-Ming Tai (DIAS)		Apr, 1996
;
;-

@phtaar
;
  ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 3 THEN MESSAGE, $
          'Syntax:  READ_MAP, NAME, HEADER, BUFFER, [PATH = PATH]'

; create filename esp if path is set
        if keyword_set(PATH) then $
          filename = PATH + FILENAME $
        else filename = !FITDIR + FILENAME
; read in the map
	fxread, filename, buffer, header
	tmpaar = {phtaar_type}
	filetype = sxpar( header, 'FILENAME')
	admn = filetype
	meaname = strmid(filetype, 4, 8)
	filetype = strmid(filetype, 0, 4)
	tmpaar.admn = strmid(admn, 0, 2) + '00' + strmid(admn, 4, 8)
	tmpaar.type = filetype
	tmpaar.hdr = handle_create()
	handle_value, tmpaar.hdr, header, /set
	tmpaar.data = handle_create()
	handle_value, tmpaar.data, buffer, /set
	phtaar = [ phtaar, tmpaar ]
END
