;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO READ_OMEGA, filename
;+
; NAME:
;	READ_OMEGA
;
; PURPOSE:
;	This procedure initialises the phtomega and the phtapert common block
;
; CALLING SEQUENCE:
;	READ_OMEGA
;
; INPUTS:
;	None
;
; OPTIONAL INPUT PARAMETERS:
;	FILENAME: An alternative file (or array of files) to be read, see
;		  restrictions !
;
; OUTPUTS:
;	None
;
; RESTRICTIONS:
;	FILENAME must be a valid (or an array of valid) PPOMEGA,
;	PC1OMEGA or PC2OMEGA fits file(s)
;		located on the !CALG directory
;
; COMMON BLOCKS:
;       None
;
; SIDE EFFECTS:
;	The variables in the phtapert and phtomega common block are initialised
;
; PROCEDURES USED:
;	read_ppomega
;       read_pc1omega
;       read_pc2omega
;
; MODIFICATION HISTORY:
;	Written by: Ingolf Heinrichsen
;	Jan 98 Version 1.0
;	V7.0
;-

        ON_ERROR, 2             ; Return to calling procedure

; Take the user given file(s) or use the default ones

        IF KEYWORD_SET(filename) THEN file=filename ELSE BEGIN
            file='PPOMEGA.FITS'
            file=[file,'PC1OMEGA.FITS']
            file=[file,'PC2OMEGA.FITS']
        ENDELSE

        FOR I=0,N_ELEMENTS(file) - 1 DO BEGIN
            str = strmid(file(i),1,2)
            CASE str of 
                'PO': read_ppomega
                'C1': read_pc1omega
                'C2': read_pc2omega
                ELSE: MESSAGE, /INFO, 'Not allowed string'
            ENDCASE
        ENDFOR
        RETURN    
    END
