;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO READ_PC1OMEGA
;+
; NAME:
;	READ_PC1OMEGA
;
; PURPOSE:
;	This procedure initialises the phtomega and the phtapert
;	common block from the PC1OMEGA.FITS CAL-G file
;
; CALLING SEQUENCE:
;	READ_PC1OMEGA
;
; INPUTS:
;	None
;
; OUTPUTS:
;	None
;
; COMMON BLOCKS:
;       None
;
; SIDE EFFECTS:
;	The variables in the phtapert and phtomega common block are
;	initialised with the PHT-C100 information.
;
; PROCEDURES USED:
;       fxbopen, fxbread, fxpar
;
; MODIFICATION HISTORY:
;	Written by: Ingolf Heinrichsen
;	Jan 98 Version 1.0
;	V7.0
;       Free_lun unit after 1st open call (CG)          Jul 99
;       V8.0
;-
@phtomega
@phtapert

        ON_ERROR, 2             ; Return to calling procedure


; open CAL-G file, should be there !

        openr, unit, !CALG+'PC1OMEGA.FITS', /block, /get_lun
        fxhread, unit, hdr
	free_lun, unit
	
        fxbopen, unit, !CALG+'PC1OMEGA.FITS', 1, ehdr

; read the header information into phtapert common block

        C1_DIAMY=[fxpar(hdr,'DIAMY'), $
                  fxpar(hdr,'DIAMYU')]
        C1_DIAMZ=[fxpar(hdr,'DIAMZ'), $
                  fxpar(hdr,'DIAMZU')]
        C1_AREA=[fxpar(hdr,'AREA1'),$
                 fxpar(hdr,'AREAU1')]

; now read the file contents into the phtomega common block

        fxbread, unit, PC1OMOFY, 'PC1OMOFY'
        fxbread, unit, PC1OMOYU, 'PC1OMOYU'
        fxbread, unit, PC1OMOFZ, 'PC1OMOFZ'
        fxbread, unit, PC1OMOZU, 'PC1OMOZU'
        fxbread, unit, PC1OMDAY, 'PC1OMDAY'
        fxbread, unit, PC1OMDYU, 'PC1OMDYU'
        fxbread, unit, PC1OMDAZ, 'PC1OMDAZ'
        fxbread, unit, PC1OMDZU, 'PC1OMDZU'
        fxbread, unit, PC1OMOME, 'PC1OMOME'
        fxbread, unit, PC1OMOMU, 'PC1OMOMU'

        C1OFFY=fltarr(9,7,2)
        C1OFFZ=fltarr(9,7,2)
        C1SIZEY = fltarr(9,7,2)   
        C1SIZEZ = fltarr(9,7,2)
        C1OM=fltarr(9,7,2) 
        
        for i=0, 6 do begin
            for j=0, 8 do begin
                C1OFFY(j,i,0)=PC1OMOFY(9*i+j)
                C1OFFY(j,i,1)=PC1OMOYU(9*i+j)
                C1OFFZ(j,i,0)=PC1OMOFZ(9*i+j)
                C1OFFZ(j,i,1)=PC1OMOZU(9*i+j)
                C1SIZEY(j,i,0)=PC1OMDAY(9*i+j)
                C1SIZEY(j,i,1)=PC1OMDYU(9*i+j)
                C1SIZEZ(j,i,0)=PC1OMDAZ(9*i+j)
                C1SIZEZ(j,i,1)=PC1OMDZU(9*i+j)
                C1OM(j,i,0)=PC1OMOME(9*i+j) * 1.E-7
                C1OM(j,i,1)=PC1OMOMU(9*i+j) * 1.E-7
             endfor
        endfor

; close the CAL-G file
        free_lun, unit
        RETURN    
    END




