;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO READ_PC2OMEGA
;+
; NAME:
;	READ_PC2OMEGA
;
; PURPOSE:
;	This procedure initialises the phtomega and the phtapert
;	common block from the PC2OMEGA.FITS CAL-G file
;
; CALLING SEQUENCE:
;	READ_PC2OMEGA
;
; INPUTS:
;	None
;
; OUTPUTS:
;	None
;
; COMMON BLOCKS:
;       None
;
; SIDE EFFECTS:
;	The variables in the phtapert and phtomega common block are
;	initialised with the PHT-C200 information.
;
; PROCEDURES USED:
;       fxbopen, fxbread, fxpar
;       C2P_PIPE2IA
;
; MODIFICATION HISTORY:
;	Written by: Ingolf Heinrichsen
;	Jan 98 Version 1.0
;	V7.0
;	Free_lun unit after 1st open call (CG)		Jul 99
;	V8.0
;-
@phtomega
@phtapert

        ON_ERROR, 2             ; Return to calling procedure


; open CAL-G file, should be there !

        openr, unit, !CALG+'PC2OMEGA.FITS', /block, /get_lun
        fxhread, unit, hdr
	free_lun, unit	

        fxbopen, unit, !CALG+'PC2OMEGA.FITS', 1, ehdr

; read the header information into phtapert common block

        C2_DIAMY=[fxpar(hdr,'DIAMY'), $
                  fxpar(hdr,'DIAMYU')]
        C2_DIAMZ=[fxpar(hdr,'DIAMZ'), $
                  fxpar(hdr,'DIAMZU')]
        C2_AREA=[fxpar(hdr,'AREA1'),$
                 fxpar(hdr,'AREAU1')]

; now read the file contents into the phtomega common block

        fxbread, unit, PC2OMOFY, 'PC2OMOFY'
        fxbread, unit, PC2OMOYU, 'PC2OMOYU'
        fxbread, unit, PC2OMOFZ, 'PC2OMOFZ'
        fxbread, unit, PC2OMOZU, 'PC2OMOZU'
        fxbread, unit, PC2OMDAY, 'PC2OMDAY'
        fxbread, unit, PC2OMDYU, 'PC2OMDYU'
        fxbread, unit, PC2OMDAZ, 'PC2OMDAZ'
        fxbread, unit, PC2OMDZU, 'PC2OMDZU'
        fxbread, unit, PC2OMOME, 'PC2OMOME'
        fxbread, unit, PC2OMOMU, 'PC2OMOMU'

        C2OFFY=fltarr(4,5,2)
        C2OFFZ=fltarr(4,5,2)
        C2SIZEY = fltarr(4,5,2)   
        C2SIZEZ = fltarr(4,5,2)
        C2OM=fltarr(4,5,2) 
        
        for i=0, 4 do begin
            for j=0, 3 do begin
                C2OFFY(j,i,0)=PC2OMOFY(4*i+j)
                C2OFFY(j,i,1)=PC2OMOYU(4*i+j)
                C2OFFZ(j,i,0)=PC2OMOFZ(4*i+j)
                C2OFFZ(j,i,1)=PC2OMOZU(4*i+j)
                C2SIZEY(j,i,0)=PC2OMDAY(4*i+j)
                C2SIZEY(j,i,1)=PC2OMDYU(4*i+j)
                C2SIZEZ(j,i,0)=PC2OMDAZ(4*i+j)
                C2SIZEZ(j,i,1)=PC2OMDZU(4*i+j)
                C2OM(j,i,0)=PC2OMOME(4*i+j) * 1.E-7
                C2OM(j,i,1)=PC2OMOMU(4*i+j) * 1.E-7
            endfor
        endfor

; turn the pixel order to conform to PIA convention

        C2P_PIPE2IA, C2OFFY, Iaarr
        C2OFFY=Iaarr
        C2P_PIPE2IA, C2OFFZ, Iaarr
        C2OFFZ=Iaarr
        C2P_PIPE2IA, C2SIZEY, Iaarr
        C2SIZEY=Iaarr
        C2P_PIPE2IA, C2SIZEZ, Iaarr
        C2SIZEZ=Iaarr
        C2P_PIPE2IA, C2OM, Iaarr
        C2OM=Iaarr


; close the CAL-G file
        free_lun, unit
        RETURN    
    END




