;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
pro read_phthk, tdtnum,hkdat,timestep,header

;+
; NAME:
;       read_phthk
; PURPOSE:
;       Read data from GEHK?.FITS file in arrays hkdat and timestep
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;       read_phthk, tdtnum,hkdat,timestep,header
;
; INPUT PARAMETERS:
;       tdtnum      : tdt number of fits file (as a string,
;                     e.g. '00310203'
;
; OUTPUT PARAMETERS:
;       hkdat       :array containing the fits data
;       timestep(x) :time for each measurement
;       header      :header of fits file
;
; RESTRICTIONS:
;       NONE
; 
; METHOD:
;       fxbread idl procedure, MERGEHDR       
;
; PROCEDURES USED:
;       PIA Procedure(s):
;               mergehdr
;       Astronomical Library:
;               fxbclose
;               fxbopen
;               fxbread
;               fxhread
;
; MODIFICATION HISTORY:
;       Written by: Andreas Karch 
;	Oct 95 Version 3.5
;	
;-


;read fits-file - change -> shape4
 filename=!FITDIR+'GEHK'+tdtnum+'.FITS'
 OPENR, UNIT, filename, /BLOCK, /GET_LUN
 FXHREAD, UNIT, PHDR
 CLOSE, UNIT
 fxbopen,unit,filename,1,eheader
 MERGEHDR, PHDR, eheader , header
 fxbread,unit,hkdat,'GEHKFR8'
 fxbread,unit,timestep,'GEPRTKEY'
 fxbclose,unit


;reduce hk-dat to required phot data
 index=indgen(67)+150
 hkdat=hkdat(index,*)

;make long array from byte array
 hkdat=long(hkdat)

;hkdat 0-65 contains the data, hkdat 66 the tdtnum
 hkdat(66,*)=handle_create(value=tdtnum)

end
