;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO READ_PPOMEGA
;+
; NAME:
;	READ_PPOMEGA
;
; PURPOSE:
;	This procedure initialises the phtomega and the phtapert
;	common block from the PPOMEGA.FITS CAL-G file
;
; CALLING SEQUENCE:
;	READ_PPOMEGA
;
; INPUTS:
;	None
;
; OUTPUTS:
;	None
;
; COMMON BLOCKS:
;       None
;
; SIDE EFFECTS:
;	The variables in the phtapert and phtomega common block are
;	initialised with the PHT-P information.
;
; PROCEDURES USED:
;       fxbopen, fxbread, fxpar
;
; MODIFICATION HISTORY:
;	Written by: Ingolf Heinrichsen
;	Jan 98 Version 1.0
;	V7.0
;	Free_lun unit after 1st open call (CG)		Jul 99
;	V8.0
;-
@phtomega
@phtapert

        ON_ERROR, 2             ; Return to calling procedure


	
; open CAL-G file, should be there !

        openr, unit, !CALG+'PPOMEGA.FITS', /block, /get_lun
        fxhread, unit, hdr
        free_lun, unit	

        fxbopen, unit, !CALG+'PPOMEGA.FITS', 1, ehdr

; read the header information into phtapert common block

        P_DIAMY=[[fxpar(hdr,'DIAMY1'),$
                  fxpar(hdr,'DIAMY2'),$
                  fxpar(hdr,'DIAMY3'),$
                  fxpar(hdr,'DIAMY4'),$
                  fxpar(hdr,'DIAMY5'),$
                  fxpar(hdr,'DIAMY6'),$
                  fxpar(hdr,'DIAMY7'),$
                  fxpar(hdr,'DIAMY8'),$
                  fxpar(hdr,'DIAMY9'),$
                  fxpar(hdr,'DIAMY10'),$
                  fxpar(hdr,'DIAMY11'),$
                  fxpar(hdr,'DIAMY12'),$
                  fxpar(hdr,'DIAMY13'),$
                  fxpar(hdr,'DIAMY14')],$
                 [fxpar(hdr,'DIAMYU1'),$
                  fxpar(hdr,'DIAMYU2'),$
                  fxpar(hdr,'DIAMYU3'),$
                  fxpar(hdr,'DIAMYU4'),$
                  fxpar(hdr,'DIAMYU5'),$
                  fxpar(hdr,'DIAMYU6'),$
                  fxpar(hdr,'DIAMYU7'),$
                  fxpar(hdr,'DIAMYU8'),$
                  fxpar(hdr,'DIAMYU9'),$
                  fxpar(hdr,'DIAMYU10'),$
                  fxpar(hdr,'DIAMYU11'),$
                  fxpar(hdr,'DIAMYU12'),$
                  fxpar(hdr,'DIAMYU13'),$
                  fxpar(hdr,'DIAMYU14')]]

        P_DIAMZ=[[fxpar(hdr,'DIAMZ1'),$
                  fxpar(hdr,'DIAMZ2'),$
                  fxpar(hdr,'DIAMZ3'),$
                  fxpar(hdr,'DIAMZ4'),$
                  fxpar(hdr,'DIAMZ5'),$
                  fxpar(hdr,'DIAMZ6'),$
                  fxpar(hdr,'DIAMZ7'),$
                  fxpar(hdr,'DIAMZ8'),$
                  fxpar(hdr,'DIAMZ9'),$
                  fxpar(hdr,'DIAMZ10'),$
                  fxpar(hdr,'DIAMZ11'),$
                  fxpar(hdr,'DIAMZ12'),$
                  fxpar(hdr,'DIAMZ13'),$
                  fxpar(hdr,'DIAMZ14')],$
                 [fxpar(hdr,'DIAMZU1'),$
                  fxpar(hdr,'DIAMZU2'),$
                  fxpar(hdr,'DIAMZU3'),$
                  fxpar(hdr,'DIAMZU4'),$
                  fxpar(hdr,'DIAMZU5'),$
                  fxpar(hdr,'DIAMZU6'),$
                  fxpar(hdr,'DIAMZU7'),$
                  fxpar(hdr,'DIAMZU8'),$
                  fxpar(hdr,'DIAMZU9'),$
                  fxpar(hdr,'DIAMZU10'),$
                  fxpar(hdr,'DIAMZU11'),$
                  fxpar(hdr,'DIAMZU12'),$
                  fxpar(hdr,'DIAMZU13'),$
                  fxpar(hdr,'DIAMZU14')]]

        P_AREA=[[fxpar(hdr,'AREA1'),$
                 fxpar(hdr,'AREA2'),$
                 fxpar(hdr,'AREA3'),$
                 fxpar(hdr,'AREA4'),$
                 fxpar(hdr,'AREA5'),$
                 fxpar(hdr,'AREA6'),$
                 fxpar(hdr,'AREA7'),$
                 fxpar(hdr,'AREA8'),$
                 fxpar(hdr,'AREA9'),$
                 fxpar(hdr,'AREA10'),$
                 fxpar(hdr,'AREA11'),$
                 fxpar(hdr,'AREA12'),$
                 fxpar(hdr,'AREA13'),$
                 fxpar(hdr,'AREA14')],$
                [fxpar(hdr,'AREAU1'),$
                 fxpar(hdr,'AREAU2'),$
                 fxpar(hdr,'AREAU3'),$
                 fxpar(hdr,'AREAU4'),$
                 fxpar(hdr,'AREAU5'),$
                 fxpar(hdr,'AREAU6'),$
                 fxpar(hdr,'AREAU7'),$
                 fxpar(hdr,'AREAU8'),$
                 fxpar(hdr,'AREAU9'),$
                 fxpar(hdr,'AREAU10'),$
                 fxpar(hdr,'AREAU11'),$
                 fxpar(hdr,'AREAU12'),$
                 fxpar(hdr,'AREAU13'),$
                 fxpar(hdr,'AREAU14')]]

; Shape of each PHT-P aperture (c = circular, r = rectangular)
        P_Shape = 'ccccrcccccccrc'

; now read the file contents into the phtomega common block

        fxbread, unit, PPOMDASY, 'PPOMDASY'
        fxbread, unit, PPOMDAYU, 'PPOMDAYU'
        fxbread, unit, PPOMDASZ, 'PPOMDASZ'
        fxbread, unit, PPOMDAZU, 'PPOMDAZU'
        fxbread, unit, PPOMOMEG, 'PPOMOMEG'
        fxbread, unit, PPOMOMUN, 'PPOMOMUN'


        PSIZEY=fltarr(14,14,2)
        PSIZEZ=fltarr(14,14,2)
        POM=fltarr(14,14,2)

        for i=0, 13 do begin
            for j=0, 13 do begin
; we change the order here to have same position for filter as C dets.
                PSIZEY(j,i,0)=PPOMDASY(14*i+j)
                PSIZEY(j,i,1)=PPOMDAYU(14*i+j)
                PSIZEZ(j,i,0)=PPOMDASZ(14*i+j)
                PSIZEZ(j,i,1)=PPOMDAZU(14*i+j)
                POM(j,i,0)=PPOMOMEG(14*i+j)*1.e-7
                POM(j,i,1)=PPOMOMUN(14*i+j)*1.e-7
            endfor
        endfor

; close the CAL-G file
        free_lun, unit
        RETURN    
    END




