;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       READ_PSF_PERIGEE
;
; PURPOSE:
;	Read a PSF file returning the perigee pass time 
;
; CATEGORY:
;       PIA - I/O
;
; CALLING SEQUENCE:
;       read_asc_orbit, psffile, perigee_time
;
; INPUT:
;       psffile: A PSF ascii type file
;
; OUTPUT:
;	perigee_time: The time quoted in psffile as perigee time (in 
;		'date_conv' floating format) 
;
; COMMON BLOCKS:
;
; PROCEDURES USED:
;       ASTRO LIB:
;		date_conv
;
; MODIFICATION HISTORY:
;       Written by: J. Acosta  (IAC/ESA)                September 1996
;			
;-

FUNCTION read_psf_perigee, psffile, OBS_WINDOW= obs_window, $
    OBS_OPEN1 = obs_open1, OBS_OPEN2 = obs_open2, OBS_CLOSE1 = obs_close1, $
    OBS_CLOSE2 = obs_close2 

  on_error, 2

  	OPENR, unit, psffile, /GET_LUN
  	line = ' '
	buf = STRARR(1)
	fin = 0
	fin_obs = 0 
  	WHILE (not eof(unit)) AND fin NE 1 DO BEGIN
    		readf, unit, line
    		line_start = STRMID(line, 0, 30) 
    		IF strpos(line_start,'PSF_START') GT 0 THEN BEGIN
    		    per_time = STRMID(line_start, 0, 11)
    		    IF KEYWORD_SET(OBS_WINDOW) THEN BEGIN
    		      WHILE (not eof(unit)) AND fin_obs NE 1 DO BEGIN
    		        readf, unit, line
    		        line_start = STRMID(line,0,30)
    		        line_med = STRMID(line,46,10)
    		        is_open = STRPOS(line_start,'OBS_OPEN')
    		        is_close = STRPOS(line_start,'OBS_CLOSE')
    		        is_before = STRPOS(line_med,'01')
    		        is_after = STRPOS(line_med,'02')
    		        CASE 1 OF 
    		          (is_open GT 0) AND (is_before GT 0): $
    		               obs1op_tk = STRMID(line_start,0,11)
    		          (is_close GT 0) AND (is_before GT 0): $
    		               obs1cl_tk = STRMID(line_start,0,11)
    		          (is_open GT 0) AND (is_after GT 0): $
    		               obs2op_tk = STRMID(line_start,0,11)
    		          (is_close GT 0) AND (is_after GT 0): BEGIN
    		               obs2cl_tk = STRMID(line_start,0,11)
    		               fin_obs = 1
    		              END
    		           ELSE: 
    		        ENDCASE     
    		      ENDWHILE 
    		    ENDIF
    		    fin=1
    		ENDIF
  	END
  	FREE_LUN, unit
  	
	;PERIGEE TIME
  	date = [FLOAT(STRMID(per_time, 0,2)),FLOAT(STRMID(per_time, 2,3)), $
  	        FLOAT(STRMID(per_time, 5,2)),FLOAT(STRMID(per_time, 7,2)), $
  	        FLOAT(STRMID(per_time, 9,2))]
  	
  	perigee_time = date_conv(date,'STRING')

	IF KEYWORD_SET(OBS_WINDOW) THEN BEGIN 
	
	; OBS_OPEN 1
  	date = [FLOAT(STRMID(obs1op_tk, 0,2)),FLOAT(STRMID(obs1op_tk, 2,3)), $
  	        FLOAT(STRMID(obs1op_tk, 5,2)),FLOAT(STRMID(obs1op_tk, 7,2)), $
  	        FLOAT(STRMID(obs1op_tk, 9,2))]
  	        
  	obs_open1 = date_conv(date,'STRING')
  	       
	; OBS_OPEN 2
  	date = [FLOAT(STRMID(obs2op_tk, 0,2)),FLOAT(STRMID(obs2op_tk, 2,3)), $
  	        FLOAT(STRMID(obs2op_tk, 5,2)),FLOAT(STRMID(obs2op_tk, 7,2)), $
  	        FLOAT(STRMID(obs2op_tk, 9,2))]
  	        
  	obs_open2 = date_conv(date,'STRING')
  	       
	; OBS_CLOSE 1
  	date = [FLOAT(STRMID(obs1cl_tk, 0,2)),FLOAT(STRMID(obs1cl_tk, 2,3)), $
  	        FLOAT(STRMID(obs1cl_tk, 5,2)),FLOAT(STRMID(obs1cl_tk, 7,2)), $
  	        FLOAT(STRMID(obs1cl_tk, 9,2))]
  	        
  	obs_close1 = date_conv(date,'STRING')
  	       
	; OBS_CLOSE 2
  	date = [FLOAT(STRMID(obs2cl_tk, 0,2)),FLOAT(STRMID(obs2cl_tk, 2,3)), $
  	        FLOAT(STRMID(obs2cl_tk, 5,2)),FLOAT(STRMID(obs2cl_tk, 7,2)), $
  	        FLOAT(STRMID(obs2cl_tk, 9,2))]
  	        
  	obs_close2 = date_conv(date,'STRING')
  	
  	ENDIF       
  	
  	RETURN, perigee_time
  	END
  	
  	

