;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO READ_RESP, FILENAME
;+
; NAME:
;	READ_RESP
; PURPOSE:
;	Read the default PHT responsivities from a FITS file into 
;       the COMMON phtresdef
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;	READ_RESP
;
; INPUT PARAMETERS:
;	NONE
;
; OPTIONAL INPUT PARAMETERS:
;	FILENAME: The file to be read
;
; OUTPUT PARAMETERS:
;	NONE
;
; RESTRICTIONS:
;	FILENAME must be a valid PHT responsivity fits file
;
; METHOD:
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phtresdef
;       Astronomical Library:
;               fxhread
;               fxpar
;
; MODIFICATION HISTORY:
;	Written by: C. Gabriel
;	Oct 95 Version 3.5
;	assign uncertainty to responsivity until a value can be read from
;	FITS file                            		J. Acosta (Jun-96)
;	Changed to pipeline SPD C200 pixel order - CG		December 1996
;	V5.5
;-
;
; Needed common blocks :
@phtresdef
	ON_ERROR, 2                                          

	IF KEYWORD_SET(filename) THEN file=filename ELSE $
			file=!CALG+'PRESPONSE.FITS'

; open the file  (default='presponse.fits')
	OPENR, unit, file, /block, /GET_LUN 

; read header
	fxhread, unit, reshdr

; close the file 
	FREE_LUN, unit
	
; extract parameters
	p1resp = fxpar(reshdr, 'P1RESP')
	p2resp = fxpar(reshdr, 'P2RESP')
	p3resp = fxpar(reshdr, 'P3RESP')
	
	c1resp = fxpar(reshdr, 'C1RESP*')

	c2resp_p = fxpar(reshdr, 'C2RESP*')
; Change to SPD pipeline pixel order
	c2p_pipe2ia, c2resp_p, c2resp

	; provisionary set the uncertainty to a certain percentage
	percent = 0.00
	p1resu = p1resp * percent
	p2resu = p2resp * percent
	p3resu = p3resp * percent

	c1resu = c1resp * percent
	c2resu = c2resp * percent	

;        slresp = fxpar(reshdr, 'SRESP*')

; do not rotate S responsivities ( from < to > lambda ) They seem to be right
;	slresp = ROTATE(slresp, 2)

	RETURN
	END
