;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO READ_RESPORB, filename=filename
;+
; NAME:
;	READ_RESPORB
; PURPOSE:
;	Read the responsivity depending on orbital position from calg-G files  
;       into the COMMON phtresporb
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;	READ_RESPORB
;
; INPUT PARAMETERS:
;	NONE
;
; OPTIONAL INPUT PARAMETERS:
;
; OUTPUT PARAMETERS:
;	NONE
;
; KEYWORDS:
;     filename:       Array of filenames to be used as input. If not set, 
;                     the default is: [PPRESP_02,PC1RESP_02,PC2RESP_02],
;                     FITS files residing on !FITDIR.
;
; RESTRICTIONS:
;
; METHOD:
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               @phtresporb
;       PIA library:
;        	c2p_pipe2ia: changing order of C2 pixels 
;       Astronomical Library:
;               fxread
;
; MODIFICATION HISTORY:
;	Written by: Carlos GABRIEL (ESA/VILSPA-SAI)		January 1998
;	V7.0
;	Bug for case of NO keyword filename fixed (CG)		April 1998
;	V7.1
;-
;
; Needed common blocks :
@phtresporb
	ON_ERROR, 2                                          

	IF KEYWORD_SET(filename) THEN file=filename ELSE BEGIN
	   file = 'PPRESP_02.FITS'
	   file = [file,'PC1RESP_02.FITS']
	   file = [file,'PC2RESP_02.FITS']
	ENDELSE
	
	FOR i=0,N_ELEMENTS(file)-1 DO BEGIN   
	
	   str = strmid(file(i),0,3)
	   
	   CASE str of 
	      'PPR': BEGIN
	        FXREAD, !CALG + file(i),ppresporb
	      END
	      
	      'PC1': BEGIN
	          FXREAD, !CALG + file(i),c1resporb
	      END

	      'PC2': BEGIN
	          FXREAD, !CALG + file(i),c2resporb
	;change pixel ordering of C200 pixels from PIPELINE to PIA convention
		  tmpresp = TRANSPOSE(c2resporb,[1,0,2])
		  c2p_pipe2ia, tmpresp, transresp
		  c2resporb = TRANSPOSE(transresp,[1,0,2])
	      END

	      ELSE: MESSAGE, /INFO, 'Not allowed filename'
	    ENDCASE
	ENDFOR
	
	; construct the array with corresponding orbital position, 
	; the orbit will be divided into 100 bits
	NBITS = 100.
	ORBPOS_RESP = INDGEN(nbits) / nbits + 0.5 / nbits
	
	IF N_ELEMENTS(respprorp) EQ 0 THEN respprorp=0
	IF N_ELEMENTS(respprom) EQ 0 THEN respprom=0
	IF N_ELEMENTS(respproaot) EQ 0 THEN respproaot=0

	RETURN
	END
