;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  PRO read_scp, name, path = path
;+
; NAME:
;       READ_SCP
; PURPOSE:
;	READ a PHTSCP (Interactive Signal per Chopper Plateau) fits file 
;	into the dynamical structure PHTSCP  
; CATEGORY:
;	PIA - I/O
; CALLING SEQUENCE:
;       READ_SCP, NAME
;
; INPUT:
;       NAME 	: SCP-fitsfile name
;
; OPT. INPUT:
;	PATH    : path for the file
;
; RESTRICTIONS:
;       NAME must be a valid PHTSCP fits file 
;
; PROCEDURES USED: 
;       Common Block(s) or @ procedure(s):
;               adm
;               phtscp
;       PIA Procedure(s):
;               mergehdr
;       Astronomical Library:
;               fxpar
;
; MODIFICATION HISTORY:
;       Written by: W M Tai (adapted from C Gabriel in read_iscp.pro)
;	optional path added
;	add three new fields to the phtscpt, (arsi, andr and avsd) 
;	change rpid to byte array
;							(WMT)  Mar 96
;	Oct 95 Version 3.5
;	mod to use read_fits_header.pro                 (WMT)  Jan 97
;
;-
;
@adm
@phtscp
;
  ON_ERROR, 2


; create filename esp if path is set
  if keyword_set(PATH) then $
    filename = PATH + NAME $
  else filename = !FITDIR + NAME

; read Compact status file
  csname = 'PSTA' + STRMID(name,4,8) + '.FITS'
  IF NOT keyword_set(PATH) then $
   read_cs, csname  ELSE BEGIN
    read_cs, csname, path=path, status=status
    IF (status) THEN BEGIN
      PRINT, 'Trying now to read CS from FITDIR ...'
      read_cs, csname
    ENDIF
   ENDELSE 
;
; read in the fits header and pass the current file pointer to cur_ptr
;
  read_fits_header, filename, hdr, stat, cur_ptr = cur_ptr

; Extract the detector ID
id = strmid(name, 0, 2)
CASE ID OF

'C1': BEGIN
; C100
  BUF_TYPE = { time: 0.0, $
	       aver: fltarr(11), $
	       avun: fltarr(11),$
	       medi: fltarr(11),$
	       q1me: fltarr(11),$
	       q3me: fltarr(11),$
	       flag: intarr(11),$
	       chop: 0.0, $
	       step: 0, $
	       fcsn: 0, $
	       temp: 0.0, $
	       fcs1: 0.0, $
	       fcs2: 0.0, $
	       tkey: 0.0, $
	       rpid: bytarr(2), $
               arsi: fltarr(11), $
               andr: fltarr(11), $
               avsd: fltarr(11) }         

      END
'C2': BEGIN
; C200 
  BUF_TYPE = { time: 0.0, $
	       aver: fltarr(6), $
	       avun: fltarr(6),$
	       medi: fltarr(6),$
	       q1me: fltarr(6),$
	       q3me: fltarr(6),$
	       flag: intarr(6),$
	       chop: 0.0, $
	       step: 0, $
	       fcsn: 0, $
	       temp: 0.0, $
	       fcs1: 0.0, $
	       fcs2: 0.0, $
	       tkey: 0.0, $
	       rpid: bytarr(2), $
               arsi: fltarr(6), $
               andr: fltarr(6), $
               avsd: fltarr(6) }           
      END
'SL': BEGIN
; S
  BUF_TYPE = { time: 0.0, $
	       aver: fltarr(132), $
	       avun: fltarr(132),$
	       medi: fltarr(132),$
	       q1me: fltarr(132),$
	       q3me: fltarr(132),$
	       flag: intarr(132),$
	       chop: 0.0, $
	       step: 0, $
	       fcsn: 0, $
	       temp: 0.0, $
	       fcs1: 0.0, $
	       fcs2: 0.0, $
	       tkey: 0.0, $
	       rpid: bytarr(2), $
               arsi: fltarr(132), $
               andr: fltarr(132), $
               avsd: fltarr(132) }
      END
ELSE:
ENDCASE

IF STRMID(ID, 0, 1) EQ 'P' THEN BEGIN
; P
  BUF_TYPE = { time: 0.0, $
	       aver: fltarr(1), $
	       avun: fltarr(1),$
	       medi: fltarr(1),$
	       q1me: fltarr(1),$
	       q3me: fltarr(1),$
	       flag: intarr(1),$
	       chop: 0.0, $
	       step: 0, $
	       fcsn: 0, $
	       temp: 0.0, $
	       fcs1: 0.0, $
	       fcs2: 0.0, $
	       tkey: 0.0, $
	       rpid: bytarr(2), $
               arsi: fltarr(1), $
               andr: fltarr(1), $
               avsd: fltarr(1) }
ENDIF

;  Create the structures and the handles
        PHTSCPT = {PHTSCP_TYPE}
        PHTSCPT.HDR = HANDLE_CREATE()
        PHTSCPT.TIME = HANDLE_CREATE()
        PHTSCPT.AVER = HANDLE_CREATE()
        PHTSCPT.AVUN = HANDLE_CREATE()
        PHTSCPT.MEDI = HANDLE_CREATE()
        PHTSCPT.Q1ME = HANDLE_CREATE()
        PHTSCPT.Q3ME = HANDLE_CREATE()
        PHTSCPT.FLAG = HANDLE_CREATE()
        PHTSCPT.CHOP = HANDLE_CREATE()
        PHTSCPT.STEP = HANDLE_CREATE()
        PHTSCPT.FCSN = HANDLE_CREATE()
        PHTSCPT.TEMP = HANDLE_CREATE()
        PHTSCPT.FCS1 = HANDLE_CREATE()
        PHTSCPT.FCS2 = HANDLE_CREATE()
        PHTSCPT.TKEY = HANDLE_CREATE()
        PHTSCPT.RPID = HANDLE_CREATE()
        PHTSCPT.ARSI = HANDLE_CREATE()
        PHTSCPT.ANDR = HANDLE_CREATE()
        PHTSCPT.AVSD = HANDLE_CREATE()

  tmpdate = fxpar(hdr, 'SCP_DATE')
  tmptime = fxpar(hdr, 'SCP_TIME')
  phtscpt.unit = tmpdate + ' ' + tmptime
  phtscpt.det  = fxpar(hdr, 'SCP_DET')
  phtscpt.ordr = fxpar(hdr, 'SCP_ORDR')
  phtscpt.dims = fxpar(hdr, 'SCP_DIMS')
  res = strpos(name, '_')
  phtscpt.admn = strmid(name, 0, res)
  buf = replicate(buf_type, phtscpt.dims)
;
; start to read in the binary data
; we use the current file pointer position from read_fits_header
; to move the newly opened file pointer position to the begining
; of the binary data
;
  OPENR, UNIT, FILENAME, /BLOCK, /GET_LUN
  point_lun, unit, cur_ptr
  readu, unit, buf

  IF STRMID(ID, 0, 1) EQ 'P' THEN BEGIN
    taver = fltarr(1, phtscpt.dims)
    tavun = taver
    tmedi = taver
    tq1me = taver
    tq3me = taver
    tarsi = taver
    tandr = taver
    tavsd = taver
    tflag = intarr(1, phtscpt.dims)

    taver(0,*) = buf.aver
    tavun(0,*) = buf.avun
    tmedi(0,*) = buf.medi
    tq1me(0,*) = buf.q1me
    tq3me(0,*) = buf.q3me
    tarsi(0,*) = buf.arsi
    tandr(0,*) = buf.andr
    tavsd(0,*) = buf.avsd
    tflag(0,*) = buf.flag
  endif else begin
    taver = buf.aver
    tavun = buf.avun
    tmedi = buf.medi
    tq1me = buf.q1me
    tq3me = buf.q3me
    tarsi = buf.arsi
    tandr = buf.andr
    tavsd = buf.avsd
    tflag = buf.flag
  endelse

  ttime = buf.time
  tchop = buf.chop
  tstep = buf.step
  tfcsn = buf.fcsn
  ttemp = buf.temp
  tfcs1 = buf.fcs1
  tfcs2 = buf.fcs2
  ttkey = buf.tkey
  trpid = buf.rpid

  byteorder, ttime, /xdrtof
  byteorder, taver, /xdrtof
  byteorder, tavun, /xdrtof
  byteorder, tmedi, /xdrtof
  byteorder, tq1me, /xdrtof
  byteorder, tq3me, /xdrtof
  byteorder, tflag, /ntohs 
  byteorder, tchop, /xdrtof
  byteorder, tstep, /ntohs 
  byteorder, tfcsn, /ntohs 
  byteorder, ttemp, /xdrtof
  byteorder, tfcs1, /xdrtof
  byteorder, tfcs2, /xdrtof
  byteorder, ttkey, /xdrtof
  byteorder, tarsi, /xdrtof
  byteorder, tandr, /xdrtof
  byteorder, tavsd, /xdrtof
;  byteorder, trpid, /xdrtof
  
free_lun, unit

;  Fill the handles
        HANDLE_VALUE, PHTSCPT.HDR, HDR, /SET  
        HANDLE_VALUE, PHTSCPT.TIME, TTIME, /SET     
        HANDLE_VALUE, PHTSCPT.AVER, TAVER, /SET     
        HANDLE_VALUE, PHTSCPT.AVUN, TAVUN, /SET     
        HANDLE_VALUE, PHTSCPT.MEDI, TMEDI, /SET     
        HANDLE_VALUE, PHTSCPT.Q1ME, TQ1ME, /SET     
        HANDLE_VALUE, PHTSCPT.Q3ME, TQ3ME, /SET     
        HANDLE_VALUE, PHTSCPT.FLAG, TFLAG, /SET  
        HANDLE_VALUE, PHTSCPT.CHOP, TCHOP, /SET   
        HANDLE_VALUE, PHTSCPT.STEP, TSTEP, /SET   
        HANDLE_VALUE, PHTSCPT.FCSN, TFCSN, /SET   
        HANDLE_VALUE, PHTSCPT.TEMP, TTEMP, /SET   
        HANDLE_VALUE, PHTSCPT.FCS1, TFCS1, /SET   
        HANDLE_VALUE, PHTSCPT.FCS2, TFCS2, /SET   
        HANDLE_VALUE, PHTSCPT.TKEY, TTKEY, /SET   
        HANDLE_VALUE, PHTSCPT.RPID, TRPID, /SET   
        HANDLE_VALUE, PHTSCPT.ARSI, TARSI, /SET   
        HANDLE_VALUE, PHTSCPT.ANDR, TANDR, /SET   
        HANDLE_VALUE, PHTSCPT.AVSD, TAVSD, /SET   

;  Update the PHTSCP structure using the temporary structure
;  Below is copied from CG's read_iscp.pro, WMT, Feb 95
        PHTSCP = [PHTSCP,PHTSCPT]

;  Does exist already an administration record for this measurement?
	       IDNAME = PHTSCPT.ADMN
	       DETID = PHTSCPT.DET
               ADMIND = WHERE(ADM.NAME EQ IDNAME, N)

;  Update the administration file using temporary structure
               IF (N EQ 1) THEN BEGIN
                ADM(ADMIND).PHTSCP = N_ELEMENTS(PHTSCP) - 1
                IF (DETID EQ 'SS') THEN BEGIN
                  STRPUT, IDNAME, 'L', 1
                  ADMIND2 = WHERE(ADM.NAME EQ IDNAME, N)
                  IF (N EQ 1) THEN $
                        ADM(ADMIND2).PHTSCP = N_ELEMENTS(PHTSCP) - 1 $
                   ELSE IF (N EQ 0) THEN BEGIN
                        ADMT = {ADM_TYPE}
                        ADMT.NAME = IDNAME
                        SCPPOS = N_ELEMENTS(PHTSCP) - 1
                        ADMT.PHTSCP = SCPPOS
                        ADM = [ADM, ADMT]
                  ENDIF ELSE PRINT, 'READ_SCP: Several identical ADM-records'
                ENDIF
               ENDIF ELSE IF (N EQ 0) THEN BEGIN
                   ADMT = {ADM_TYPE}
                   ADMT.NAME = IDNAME
                   SCPPOS = N_ELEMENTS(PHTSCP) - 1
                   ADMT.PHTSCP = SCPPOS
                   ADM = [ADM, ADMT]
                IF (DETID EQ 'SS') THEN BEGIN
                  STRPUT, IDNAME, 'L', 1
                  ADMIND2 = WHERE(ADM.NAME EQ IDNAME, N)
                  IF (N EQ 1) THEN $
                        ADM(ADMIND2).PHTSCP = N_ELEMENTS(PHTSCP) - 1 $
                   ELSE IF (N EQ 0) THEN BEGIN
                        ADMT = {ADM_TYPE}
                        ADMT.NAME = IDNAME
                        SCPPOS = N_ELEMENTS(PHTSCP) - 1
                        ADMT.PHTSCP = SCPPOS
                        ADM = [ADM, ADMT]
                  ENDIF ELSE PRINT, 'READ_SCP: Several identical ADM-records'
                ENDIF
               ENDIF ELSE PRINT, 'READ_SCP: Several identical ADM-records'

  RETURN
END




