;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO READ_selndr, FILENAME
;+
; NAME:
;	READ_SELNDR
; PURPOSE:
;	Read the Pipeline non-destructive read-outs selection criteria 
;	from a FITS file into COMMON phtselndr
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;	READ_SELNDR[,FILENAME]
;
; INPUT PARAMETERS:
;	NONE
;
; OPTIONAL INPUT PARAMETERS:
;	FILENAME: An alternative file to be read, see
;		  restrictions !
;
; OUTPUT PARAMETERS:
;	NONE
;
; RESTRICTIONS:
;	FILENAME must be a valid PHT SELNDR fits file(s)
;		located on the !FITDIR directory
;
; METHOD:
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phtselndr
;       Astronomical Library:
;               fxbclose
;               fxbopen
;               fxbread
;
; MODIFICATION HISTORY:
;	Written by: C. Gabriel
;	Oct 95 Version 3.5
;-
;
; Needed common blocks :
@phtselndr

	ON_ERROR, 2                                          

; Take the user given file(s) or use the default ones

	IF KEYWORD_SET(filename) THEN file=filename ELSE $
		file='PSELNDR.FITS'

	FXBOPEN, unit, !CALG+file, 1
	FXBREAD, unit, pp1sndr, 'PP1SNDR'
	FXBREAD, unit, pp2sndr, 'PP2SNDR'
	FXBREAD, unit, pp3sndr, 'PP3SNDR'
	FXBREAD, unit, pc1sndr, 'PC1SNDR'
	FXBREAD, unit, pc2sndr, 'PC2SNDR'
	FXBREAD, unit, psssndr, 'PSSSNDR'
	FXBREAD, unit, pslsndr, 'PSLSNDR'
 
        FXBCLOSE, unit
	RETURN
	END
