;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO READ_SPECAL, FILENAME, ATABLE = atable
;+
; NAME:
;	READ_SPECAL
; PURPOSE:
;	Read the Volts/s to Jy conversion factors from a FITS file into 
;       the COMMON phtw2jy
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;	READ_SPECAL
;
; INPUT PARAMETERS:
;	(none)
;
; OPTIONAL INPUT PARAMETERS:
;	FILENAME: The file to be read
;
; OUTPUT PARAMETERS:
;	NONE
;
; RESTRICTIONS:
;	FILENAME must be a valid PHT PSPECAL fits file
;
; METHOD:
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phtw2jy
;       Astronomical Library:
;               fxhread
;               fxpar
;
; MODIFICATION HISTORY:
;	Written by: C. Gabriel (ESA/VILSPA-SAI)		April 1996
;	Last change by CG - New calfile 		January 1997
;       keyword ATABLE added to read an ASCII table 
;					    (JAcosta)   May 1997
;	V6.3
;-
;
; Needed common blocks :
@phtw2jy
@phtslwavlen
@phtcap
	ON_ERROR, 2                                          


        IF KEYWORD_SET(ATABLE) then read_fits = 0 ELSE read_fits = 1

        IF read_fits EQ 0 AND NOT KEYWORD_SET(filename) THEN $
            MESSAGE, 'Filename for the table should be specified ',/INFO

	IF KEYWORD_SET(filename) THEN file=filename ELSE $
			file=!CALG+'PSPECAL.FITS'


CASE 1 OF

read_fits: BEGIN   ; read spectral response function from CALG formatted file
        ; open the file  (default='PSPECAL.FITS')
	FXBOPEN, unit, file, 1, hdr
	
        ; read lambda's
	FXBREAD, unit, slwavelen, 'PSPELAMB'
	FXBREAD, unit, slwavel_unc, 'PSPELUNC'
	slwavelen = slwavelen * 1.E06
	slwavel_unc = slwavel_unc * 1.E06
	
	
        ; read spectral response 
	FXBREAD, unit, v2j, 'PSPESRFP'
	FXBREAD, unit, v2j_unc, 'PSPESRUP'
	FXBREAD, unit, v2mj, 'PSPESRFE'
	FXBREAD, unit, v2mj_unc, 'PSPESRUE'

	FXBCLOSE, unit
	FREE_LUN, unit
	
	END
	
ELSE: BEGIN      ;read from an ASCII table containing 4 columns: 
	         ; pixel, wavelength, v2j, v2j_unc
	readcol,filename, pix, tmpwave, tmpv2j, tmpv2j_unc,  $ 
	   format = 'I,F,F,F',/silent 
        ;define remaining variables, 
        ; not change wavelength (assumed to be correct) 
        IF N_ELEMENTS(tmpwave) NE 128 THEN $ 
          MESSAGE, 'Format is not correct ',/INFO
	IF N_ELEMENTS(v2mj) EQ 128 THEN corr_m = v2mj/v2j  $ 
	     ELSE corr_m = 0.01354    ; if not defined set nominal aperture
 
	v2j = tmpv2j
	v2j_unc = tmpv2j_unc
	v2mj = tmpv2j * corr_m
	v2mj_unc = tmpv2j_unc * corr_m

	END
	
ENDCASE
	 
; 
;

; extract parameters -> v2jy_s is in A/Jy (since it is afterwards
; converted into a R = [A/W] as for the other detectors, here we 
; must multiply by the capacitances in order to get them converted
	v2jy_s = v2j * 0.
	v2jyunc_s = v2j * 0.
	v2mjy_s = v2mj * 0.
	v2mjyunc_s = v2mj * 0.
	IF N_ELEMENTS(sscap) EQ 0 THEN phtcap_init
	v2jy_s(0:63) = v2j(0:63) * sscap
	v2jy_s(64:127) = v2j(64:127) * slcap
	v2mjy_s(0:63) = v2mj(0:63) * sscap
	v2mjy_s(64:127) = v2mj(64:127) * slcap
	
	v2jyunc_s(0:63) = v2j_unc(0:63) * sscap
	v2jyunc_s(64:127) = v2j_unc(64:127) * slcap
	v2mjyunc_s(0:63) = v2mj_unc(0:63) * sscap
	v2mjyunc_s(64:127) = v2mj_unc(64:127) * slcap
	
 	
	RETURN
	END
