;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO READ_SPECAL_CHOP, FILENAME, TABLE = table, PATH =path
;+
; NAME:
;       READ_SPECAL_CHOP
; PURPOSE:
;       Read the Volts/s to Jy conversion factors and first order correction
;	for SL chopped measurement from a FITS file into the COMMON phtslchopp. 
; CATEGORY:
;       PIA - I/O
;
; CALLING SEQUENCE:
;       READ_SPECAL_CHOP
;
; INPUT PARAMETERS:
;       (none)
;
; OPTIONAL INPUT PARAMETERS:
;       FILENAME: The file to be read
;       PATH: The directory to find the file to be read
;	TABLE: To read a savefile instead of cal-G file
;
; OUTPUT PARAMETERS:
;       NONE
;
; RESTRICTIONS:
;       FILENAME must be a valid PHT PSPECAL fits file
;
; METHOD:
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phtslchopp
;       Astronomical Library:
;               fxhread
;               fxpar
;
; MODIFICATION HISTORY:
;       Written by: J. Acosta (IAC)         			Feb. 1999
;       V7.3
;	Upgrade (CG)						Jul. 1999
;	V7.9
;-
;
; Needed common blocks :
@phtslchopp
        
ON_ERROR, 2                                          

SL_CHOP_SPRF = {avg:FLTARR(128), unc:FLTARR(128), a0:FLTARR(128), $ 
     a0_unc:FLTARR(128), a1:FLTARR(128), a1_unc:FLTARR(128),      $
     min_sig:FLTARR(128),max_sig:FLTARR(128)}

IF NOT KEYWORD_SET(TABLE) THEN  BEGIN  ; read from CALG file

     FXBOPEN, unit, !CALG + 'PSPECAL.FITS', 1, FHDR
     FXBREAD, unit, data, 'PSPECRFP'
     sl_chop_sprf.avg = data
     FXBREAD, unit, data, 'PSPECRUP'
     sl_chop_sprf.unc = data
     FXBREAD, unit, data, 'PSPECCC0'
     sl_chop_sprf.a0 = data
     FXBREAD, unit, data, 'PSPECCC1'
     sl_chop_sprf.a1 = data
     FXBREAD, unit, data, 'PSPECUC0'
     sl_chop_sprf.a0_unc = data
     FXBREAD, unit, data, 'PSPECUC1'
     sl_chop_sprf.a1_unc = data
; reads limits from table - not yet in FITS file
     restore, !CALSAVE+'SLCHOP_SPRF.SAV'
     sl_chop_sprf.min_sig = min_sig
     sl_chop_sprf.max_sig = max_sig

ENDIF ELSE BEGIN ; reads from SAVEFILE

     IF N_ELEMENTS(filename) EQ 0 THEN $
    	  filename ='SLCHOP_SPRF.SAV'
     IF N_ELEMENTS(path) EQ 0 THEN path = !CALSAVE	  
     restore,path+filename
     sl_chop_sprf.avg = sprf_avg
     sl_chop_sprf.unc = sprf_unc
     sl_chop_sprf.a0 = corr_1st(*,0)
     sl_chop_sprf.a1 = corr_1st(*,1)
     sl_chop_sprf.a0_unc = ucorr_1st(*,0)
     sl_chop_sprf.a1_unc = ucorr_1st(*,1)
     sl_chop_sprf.min_sig = min_sig
     sl_chop_sprf.max_sig = max_sig
ENDELSE 


RETURN
END
