;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	READHDR
;
; PURPOSE:
;	Read in a FITS header (primary or extended).
;	The internal file pointer must be positioned at the beginning of
;	the header which shall be read in. For the primary header this is
;	the beginning of the file, for the extended header this is
;	the position of the next FITS record (2880 bytes) just after the
;	primary header.
;
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;	READHDR, lun, header
;
; INPUTS:
;	lun :	The logical unit number of the FITS file, which
;		has been opened already.
;
; KEYWORD PARAMETERS:
;	NOEND :		Set this keyword to strip the 'END' card (the last
;			non-blank card) from the header.
;
;	ERROR :		Returns and error code:
;			0 = no error
;			1 = an error occured when reading the file
;
; OUTPUTS:
;	header :	The header (primary or extended, depending on the
;			initial position of the file pointer).
;
; SIDE EFFECTS:
;	The FITS file remains open, the file pointer points to the beginning
;	of the next FITS record after the header.
; PROCEDURES USED:
;	
; MODIFICATION HISTORY:
;	Written by: D. Skaley
;	Oct 95 Version 3.5
;-


PRO READHDR, lun, header, NOEND=noend, ERROR=error

	fits_record = bytarr( 80, 36, /NOZERO )
	header = [ '' ]
	endfound = 0
	REPEAT BEGIN
		ON_IOERROR, badfile
		READU, lun, fits_record
		header_block = STRING( fits_record )
		last = (WHERE(STRMID(header_block,0,8) EQ 'END     ',n))(0)
		IF n EQ 0 THEN BEGIN
			header = [ header, header_block ]
		ENDIF ELSE BEGIN
			IF KEYWORD_SET(noend) THEN last = last-1
			IF last GE 0 THEN header=[header,header_block(0:last)]
			endfound = 1
		ENDELSE
	ENDREP UNTIL endfound
	header = header(1:*)

	error = 0
	RETURN
badfile:
	error = 1
	RETURN

	END
