;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	REBUILD_RAMPS
;
; PURPOSE:
;	reconstruct a ramp which is affected by glitches. It looks for the
;	median of unaffected readout differences and use that to 
;       reconstruct the readout jumps. It works only for an individual ramp. 
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;    newramp = REBUILD_RAMPS (time, ramp, indok, indreb)
;
; INPUTS:
;	time	: Vector containing the independent variable [t]  (same size)
;	ramp	: Vector containing the individual readouts
;	indok	: Index containing the good readouts
;	indreb  : Index containing the readouts to rebuild 
;
; OUTPUTS:
;	newramp : Array containing the repaired readouts
;
; KEYWORD INPUT:
;
; RESTRICTIONS:
;	time, ramp and redflag must have the same number of elements
;
; PROCEDURES USED:
;	None
;
; MODIFICATION HISTORY:
;	Written by:	Jose Acosta 				      May 1999	
;	V7.4
;-
FUNCTION rebuild_ramps, time, ramp, ind_val, ind_noval, VERBOSE =verbose

newramp = ramp

 nele = N_ELEMENTS(time)
 diff_indiv = ramp(1:nele-1) - ramp(0:nele-2)
 ;ind_val = WHERE(redflag EQ 0,nval)
 nval = N_ELEMENTS(ind_val)
 nnoval = N_ELEMENTS(ind_noval)   
 ;ind_noval = WHERE(redflag GT 0, nnoval)  
 
 IF nval EQ 0 THEN BEGIN
    IF KEYWORD_SET(VERBOSE) THEN $ 
        print,'WARNING: Ramp can not be reconstructed: No valid readouts'
    GOTO, ENDREBUILD
 ENDIF 
 
 IF nval GT 1 AND nnoval GT 0 THEN BEGIN 
   IF nval GT 10 THEN diff_median = MEDIAN(diff_indiv(ind_val(1:*)-1))  $
     ELSE diff_median = AVG(diff_indiv(ind_val(1:*)-1))
   FOR i=0, nnoval-1 DO  $
      newramp(ind_noval(i):*) = newramp(ind_noval(i):*) - $ 
        diff_indiv(ind_noval(i)-1) + diff_median
 ENDIF

ENDREBUILD:

RETURN, newramp 
END
