;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

PRO rpid_check, rpid, flag, VERBOSE=verbose

; NAME:
;	rpid_check
;       
; PURPOSE:
;	This procedure assigns rpid values to rpid=[0b,0b]
;
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	rpid_check
;
; INPUTS:
;	rpid:	An array or RPID values: rpid=BYTARR(2,n) n=number of signals
;	flag:	An array of flag values: flag=INTARR(m,n) m=number of pixels
;		
;
; KEYWORD PARAMETERS:
;	VERBOSE:       for getting messages
;
; OUTPUTS:
;	None
;
; MODIFICATION HISTORY:
;	Written By:	Carlos GABRIEL (ESA-VILSPA/SAI)
;	V7.0
;	Bug for only first point not defined fixed (CG)		February 1998
;	V7.1
;-

   indsus =  WHERE(rpid(0,*) EQ 0B AND rpid(1,*) EQ 0B, nsus)

   IF nsus EQ N_ELEMENTS(rpid(0,*)) THEN BEGIN
      rpid = rpid + 1B
      IF KEYWORD_SET(VERBOSE) THEN BEGIN
         PRINT, 'Check RPID=[0,0]'
         PRINT, ' All RPIDs set to [1,1] - They were all undefined'
      ENDIF   
    RETURN
   ENDIF

   IF nsus GT 0 THEN BEGIN
		
      ncor =  0
      nncor =  0
      IF indsus(0) EQ 0 THEN BEGIN
         rpid(*,0) =  [1B,1B]
         IF nsus GT 1 THEN $
          indsus =  indsus(1:*)
         ncor =  ncor + 1
	 nsus = nsus -1
      ENDIF

      FOR i=0,nsus-1 DO BEGIN
         indok=WHERE(rpid(0,0:indsus(i)) NE 0B AND $
                     rpid(1,0:indsus(i)) NE 0B,ok)
         IF ok GT 0 THEN BEGIN
            rpid(*,indsus(i)) = rpid(*,max(indok)) 
            ncor =  ncor+1
         ENDIF ELSE BEGIN
            flag(*,indsus(i)) = 16
            nncor =  nncor + 1
         ENDELSE
         
      ENDFOR
      IF KEYWORD_SET(VERBOSE) THEN BEGIN
         PRINT, 'Check RPID=[0,0]'
         IF ncor GT 0 THEN $
         PRINT, ' ' + STRTRIM(ncor,2) + ' corrected RPID'
         IF nncor GT 0 THEN $
         PRINT, ' ' + STRTRIM(nncor,2) + ' could not be corrected'
       ENDIF   
    ENDIF

RETURN
END
