;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO SCP_INIT, index=index 
;+
; NAME:
;       scp_init
; PURPOSE:
;       Initializes the structure PHTSCP defining the contents as
;	a template structure PHTSCP_TYPE. It can be used for clearing
;	the whole SCP structure, in case this should show as necessary. 
; CATEGORY:
;	PIA - initialization
;
; CALLING SEQUENCE:
;       SCP_INIT
;
; INPUT PARAMETERS:
;	None       
;
; OUTPUT PARAMETERS: 
;	None
;
; KEYWORDS:
;	Index:	If set, only those will be deleted from buffer
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phtscp
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel
;	Oct 95 Version 3.5
;	Free handles added (CG)			January 1996
;	use scp_fist_handle and scp_last_handle (WMT) May 1996
;	Keyword index for clearing set of records added (CG+JA)	May 1997
;	V6.3
;-

@phtscp

	nelbuf = N_ELEMENTS(phtscp)
	IF nelbuf EQ 1 THEN RETURN

	flag = intarr(nelbuf)
	
	IF NOT KEYWORD_SET(index) THEN index = indgen(nelbuf-1)+1

	flag(index) = 1
		
	nele = N_ELEMENTS(index)

	IF nele GE 1 THEN $
	   FOR I = 0, nele - 1 DO $
		FOR ihan = scp_first_handle, scp_last_handle DO $
		  HANDLE_FREE, phtscp(index(i)).(ihan)

	ind = WHERE(flag EQ 0)
	phtscp = phtscp(ind)
	

END

