;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	SEP_RP
;
; PURPOSE:
;	Separate an ERD measurement into pieces per RPID
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	SEP_RP, tmperd
;
; INPUT PARAMETERS:
;	tmperd	: temporary (real) ERD structure
;
; OUTPUT PARAMETERS:
;	(none)
;
; RESTRICTIONS:
;	tmperd must be a temporary real structure
;
; SIDE EFFECTS:
;	phterd buffer increase by (rasterpoints * rasterlines) measurements 
;
; METHOD:
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phterd
;
; MODIFICATION HISTORY:
;	Written by: C. Gabriel (ESA/VILSPA - SAI)		1996
;	Bug for last raster point fixed (CG)			June 1997
;	V6.4
;	Change accordingly to new keyword in ERD structure
;	 phterd.flag (CG)					February 1998
;	V7.1
;	Bug fixed: temperature 2-dim for SL (CG)		August 1999
;	V8.0
;-
PRO sep_rp, tmperd

@phterd

	
	nrasty = max(tmperd.rpid(0,*)) 
	nrastz = max(tmperd.rpid(1,*))

	FOR iz=1,nrastz DO $
	  FOR iy=1,nrasty DO BEGIN 
	  
	  	indices = WHERE(tmperd.rpid(0,*) EQ iy AND $
	  			tmperd.rpid(1,*) EQ iz, n)
	  	IF n GT 0 THEN BEGIN
	         PHTERDT = {PHTERD_TYPE}        
	         PHTERDT.HDR  = HANDLE_CREATE()
	         PHTERDT.RAWP = HANDLE_CREATE()
                 PHTERDT.CONP = HANDLE_CREATE()
                 PHTERDT.FITV = HANDLE_CREATE()
                 PHTERDT.TIME = HANDLE_CREATE()
                 PHTERDT.PIXF = HANDLE_CREATE()
                 PHTERDT.CHOP = HANDLE_CREATE()
                 PHTERDT.STEP = HANDLE_CREATE()
                 PHTERDT.FCSN = HANDLE_CREATE()
                 PHTERDT.TEMP = HANDLE_CREATE()
                 PHTERDT.FCS1 = HANDLE_CREATE()
                 PHTERDT.FCS2 = HANDLE_CREATE()
                 PHTERDT.TKEY = HANDLE_CREATE()
                 PHTERDT.RPID = HANDLE_CREATE()
                 PHTERDT.FLAG = HANDLE_CREATE()
	  	
                 PHTERDT.UNIT = tmperd.unit          
                 PHTERDT.DET  = tmperd.det
		 PHTERDT.ADMN = tmperd.admn + '_y'+STRTRIM(STRING(iy),2)+ $
		   				'_z'+STRTRIM(STRING(iz),2)
		 PHTERDT.ORDR = tmperd.ORDR
                 PHTERDT.DIMS = n
		 PHTERDT.TINT = tmperd.tint
		 PHTERDT.NNDR = tmperd.nndr
		 PHTERDT.RCHP = tmperd.rchp
		   
		 HANDLE_VALUE, phterdt.hdr, tmperd.hdr, /set
		 HANDLE_VALUE, phterdt.rawp, tmperd.rawp(*,indices), /set
		 HANDLE_VALUE, phterdt.conp, tmperd.conp(*,indices), /set
		 HANDLE_VALUE, phterdt.time, tmperd.time(indices), /set
		 HANDLE_VALUE, phterdt.pixf, tmperd.pixf(indices), /set
		 HANDLE_VALUE, phterdt.chop, tmperd.chop(indices), /set
		 HANDLE_VALUE, phterdt.step, tmperd.step(indices), /set
		 HANDLE_VALUE, phterdt.fcsn, tmperd.fcsn(indices), /set
		 IF tmperd.det EQ 'SL' THEN $
		  HANDLE_VALUE, phterdt.temp, tmperd.temp(*,indices), /set ELSE $
		  HANDLE_VALUE, phterdt.temp, tmperd.temp(indices), /set
		 
		 HANDLE_VALUE, phterdt.fcs1, tmperd.fcs1(indices), /set
		 HANDLE_VALUE, phterdt.fcs2, tmperd.fcs2(indices), /set
		 HANDLE_VALUE, phterdt.tkey, tmperd.tkey(indices), /set
		 HANDLE_VALUE, phterdt.rpid, tmperd.rpid(*,indices), /set
		 HANDLE_VALUE, phterdt.flag, tmperd.flag(*,indices), /set
		   
		    
	  	 phterd = [phterd, phterdt]
	  	ENDIF
	 ENDFOR
	 
RETURN
END
	  	
		
	
