;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	SEP_RP_CHOP
;
; PURPOSE:
;	Separate an array per raster point and chopper position computing
;	  the corresponding weighted means und uncertainties
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	SEP_RP_CHOP, flux, flunc, rpid, step, flout, flounc, flpos
;
; INPUTS:
;	flux: 	a 2 dimensional array (eg mnpw(9,1200)
;	flunc:	the corresponding uncertainty array
;	rpid:	the raster point id array (eg rpid(2,1200))
;	step:	the chopper step array (PIA convention!)
;
; KEYWORD PARAMETERS:
;	(none)
;
; OUTPUTS:
;	flout:	the "flux" array averaged per raster point and chopper pos.
;	flounc:	the corresponding uncertainty array
;	flpos:	a string array with one entry per rpid/chpos combination
;
; PROCEDURES USED:
;	PIA Procedure(s):
;		weight_mean
;
; COMMON BLOCKS:
;	(none)
;
; MODIFICATION HISTORY:
;	Written by: 	C. Gabriel, ESA/VILSPA		July 1996
;-

PRO sep_rp_chop, flux, flunc, rpid, step, flout, flounc, flpos

	get_rastersteps, rpid, raststeps
	ipos = -1L	
	npix = N_ELEMENTS(flux(*,0))
	ntot = max(raststeps) * max(step)
	flout = fltarr(npix, ntot)
	flounc = flout
	flpos = STRARR(ntot)

	FOR IRAST=1, max(raststeps) DO BEGIN
	
	   ind = WHERE(raststeps EQ irast, nr)
		
	   FOR ICHOP=1, max(step) DO BEGIN
		
	   	ipos = ipos + 1
		indch = WHERE(step(ind) EQ ichop, nc)
		
		IF nc GT 0 THEN BEGIN
		
		   FOR Ipix = 0, npix-1 DO BEGIN
			weight_mean, flux(ipix,ind(indch)), $
				flunc(ipix,ind(indch)), mean, stdev, sig
			flout(ipix,ipos) = mean
			flounc(ipix,ipos) = stdev
		   ENDFOR
		   
		ENDIF ELSE BEGIN
			flout(*,ipos) = 0.
			flounc(*,ipos) = 0.
		ENDELSE
		
		
		flpos(ipos)= 'RPID: '+STRTRIM(STRING(FIX(RPID(0,ind(0)))),2) +$
			' '+STRTRIM(STRING(FIX(RPID(1,ind(0)))),2) +$
			     '    CH.step: ' +STRTRIM(STRING(step(ichop)),2)
			     
	    ENDFOR
	    
	 ENDFOR
	 
	 RETURN
	 END
		
		
