;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO DER_SMCHDR, SRDHDR, SMCHDR, USRMSG = USRMSG
;+
; NAME:
;       DER_SMCHDR
; PURPOSE:
;	Derive a SMC Header file, adding to the SRD header (SRDHDR) 
;	keywords indicating signal selection criteriae for SMC derivation.
;
; CALLING SEQUENCE:
;       DER_SMCHDR, srdhdr, smchdr
;
; INPUT:
;       SRDHDR 	: SRD-header
;
; OUTPUT:
;       SMCHDR 	: SMC-header
;
; COMMON BLOCKS:
;	phtacc
;
; RESTRICTIONS:
;
; PROCEDURES USED: 
;
; MODIFICATION HISTORY:
;       Written by P. Merluzzi            		June 1995
;	SMDHDR -> SMCHDR	                   (SB, 19/07/96)
;       New SMC structure, new header keywords     (SB, 28/01/97)
;
;-
;
@phtacc
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 2 THEN MESSAGE, $
         'Syntax:  DER_SMCHDR, SRDHDR, SMCHDR'

        LINE = 'NMEAS   =                    1' +$
         ' / Number of measurements'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [JUNK]

        LINE = 'FILTERID=                    0' +$
         ' / Filter ID (CHW2 position)'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]

        LINE = 'POLID   =                    0' +$
         ' / Polarizer ID (CHW1 position)'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]

        LINE = 'SELTRS1 =                    0' +$
         ' / Selected TRS for FCS1'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]

        LINE = 'SELTRS2 =                    0' +$
         ' / Selected TRS for FCS2'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]

        LINE = 'SELPOW1 =                    0' +$
         ' / Selected power for FCS1'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]

        LINE = 'SELPOW2 =                    0' +$
         ' / Selected power for FCS2'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]

        LINE = 'CALFILT =                    0' +$
         ' / Filter used for cal (CHW position)'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]

        LINE = 'CALPOL  =                    0' +$
         ' / Polarizer used for cal (CHW position)'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]

        LINE = 'CALTYPE =                    0' +$
         ' / Photometric calibration type'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]

        LINE = 'RESPP1  =                    0' +$
         ' / Responsivity (A/W) used for pixel 1'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]

        LINE = 'RESPP2  =                    0' +$
         ' / Responsivity (A/W) used for pixel 2'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]

        LINE = 'RESPP3  =                    0' +$
         ' / Responsivity (A/W) used for pixel 3'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]

        LINE = 'RESPP4  =                    0' +$
         ' / Responsivity (A/W) used for pixel 4'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]

        LINE = 'RUNCP1  =                    0' +$
         ' / Responsivity uncertainty pixel 1'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]

        LINE = 'RUNCP2  =                    0' +$
         ' / Responsivity uncertainty pixel 2'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]

        LINE = 'RUNCP3  =                    0' +$
         ' / Responsivity uncertainty pixel 3'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]

        LINE = 'RUNCP4  =                    0' +$
         ' / Responsivity uncertainty pixel 4'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]

        LINE = 'PRSM_WND=                    0' +$
         ' / low velocity parts of slew discarded'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]

        LINE = 'PRSM_VEL=                    0' +$
         ' / SM parameter SMP_VEL'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]

        LINE = 'PRSM_STY=                    0' +$
         ' / sensitivity equalized (1=from fluxes, 2=from backgr.)'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]

        LINE = 'PRSM_SY1=                  1.0' +$
         ' / sensitivity factor (pixel 1)'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]
        
        LINE = 'PRSM_SY2=                  1.0' +$
         ' / sensitivity factor (pixel 2)'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]
        
        LINE = 'PRSM_SY3=                  1.0' +$
         ' / sensitivity factor (pixel 3)'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]
        
        LINE = 'PRSM_SY4=                  1.0' +$
         ' / sensitivity factor (pixel 4)'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]

        LINE = 'PRSM_BCK=                    0' +$
         ' / background & noise computed'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]

        LINE = 'PRSM_BIT=                    0' +$
         ' / number of background iterations'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]

        LINE = 'PRSM_GN1=                  0.0' +$
         ' / global noise (MJy/sr, pixel 1)'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]
        
        LINE = 'PRSM_GN2=                  0.0' +$
         ' / global noise (MJy/sr, pixel 2)'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]
        
        LINE = 'PRSM_GN3=                  0.0' +$
         ' / global noise (MJy/sr, pixel 3)'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]
        
        LINE = 'PRSM_GN4=                  0.0' +$
         ' / global noise (MJy/sr, pixel 4)'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]
        
        LINE = 'PRSM_DEG=                    0' +$
         ' / deglitching performed'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]

        LINE = 'PRSM_SGL=                    0' +$
         ' / SM parameter SMP_SNRGL'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]

        LINE = 'PRSM_SPL=                    0' +$
         ' / SM parameter SMP_SNRPGL'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]

        LINE = 'PRSM_PRC=                    0' +$
         ' / 1=simple proc.  2=advanced proc.'
        junk = string(replicate(32b, 80))
        strput, junk, line, 0
        TMPHDR = [TMPHDR,JUNK]

        keyword = strmid(srdhdr, 0, 8)
        xtension = where(keyword eq 'XTENSION')
        hdrlen = n_elements(srdhdr)
        smchdr = [ srdhdr( 0: xtension(0) - 1), tmphdr, $
                   srdhdr( xtension(0) : hdrlen - 1)]

        COMMENT = WHERE(KEYWORD EQ 'COMMENT ')
        posi = STRPOS(SMCHDR(COMMENT(0)),'Signal')
        IF posi NE -1 THEN BEGIN 
           tmpline = SMCHDR(COMMENT(0))
           STRPUT, tmpline, 'Surface brightness data', posi
           SMCHDR(COMMENT(0)) = tmpline
        ENDIF

        RETURN
        END
