;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO FILL_SMC, tmp, newheader, REPLACE=replace 
;+
; NAME:
;       FILL_SMC
;
; PURPOSE:
;	FILLS a temporary structure into the dynamical structure PHTSMC  
;
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;       FILL_SMC, tmp [,newheader] [,REPLACE=replace]
;
; INPUT:
;       tmp 	: SMC like temporary structure
;
; OPTIONAL INPUT:
;	newheader:  New header to be change into the structure
;
; KEYWORD:
;	REPLACE : IF set (different to 0) put structure into this PHTSMC position
;
; RESTRICTIONS:
;       tmp must be a valid phtsmc like temporary structure
;
; PROCEDURES USED: 
;       Common Block(s) or @ procedure(s):
;               phtsmc
;
; MODIFICATION HISTORY:
;       Written by: S. Bogun  (MPIA)		June 97
;
;-
;
@adm
@phtsmc
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  FILL_SMC, tmp [,newhdr] [,REPLACE=replace]'

;  Create the structures and the handles
	PHTSMCT = {PHTSMC_TYPE}
        PHTSMCT.HDR = HANDLE_CREATE()
        PHTSMCT.TKEY = HANDLE_CREATE()
        PHTSMCT.TIME = HANDLE_CREATE()
        PHTSMCT.FLX = HANDLE_CREATE()
        PHTSMCT.FLXU = HANDLE_CREATE()
        PHTSMCT.BACK = HANDLE_CREATE()
        PHTSMCT.NOIS = HANDLE_CREATE()
        PHTSMCT.FLAG = HANDLE_CREATE()
        PHTSMCT.SMFL = HANDLE_CREATE()
        PHTSMCT.RA = HANDLE_CREATE() 
        PHTSMCT.RAU = HANDLE_CREATE()
        PHTSMCT.DEC = HANDLE_CREATE()
        PHTSMCT.DECU = HANDLE_CREATE() 
        PHTSMCT.ROLL = HANDLE_CREATE()
        PHTSMCT.ROLU = HANDLE_CREATE()

;  Fill the temporary SMC structure
        PHTSMCT.UNIT = tmp.UNIT
        PHTSMCT.DET  = tmp.DET
        PHTSMCT.ADMN = tmp.ADMN
        PHTSMCT.ORDR = tmp.ORDR
        PHTSMCT.DIMS = tmp.DIMS

                           
;  Fill the handles
	IF N_PARAMS() LT 2 THEN HDR = tmp.hdr $ 
	  ELSE  HDR= newheader
        HANDLE_VALUE, PHTSMCT.HDR, HDR, /SET 
        HANDLE_VALUE, PHTSMCT.HDR, tmp.HDR, /SET
        HANDLE_VALUE, PHTSMCT.TKEY, tmp.TKEY, /SET
        HANDLE_VALUE, PHTSMCT.TIME, tmp.TIME, /SET
        HANDLE_VALUE, PHTSMCT.FLX, tmp.FLX, /SET
        HANDLE_VALUE, PHTSMCT.FLXU, tmp.FLXU, /SET
        HANDLE_VALUE, PHTSMCT.BACK, tmp.BACK, /SET
        HANDLE_VALUE, PHTSMCT.NOIS, tmp.NOIS, /SET
        HANDLE_VALUE, PHTSMCT.FLAG, tmp.FLAG, /SET
        HANDLE_VALUE, PHTSMCT.SMFL, tmp.SMFL, /SET
        HANDLE_VALUE, PHTSMCT.RA, tmp.RA, /SET
        HANDLE_VALUE, PHTSMCT.RAU, tmp.RAU, /SET
        HANDLE_VALUE, PHTSMCT.DEC, tmp.DEC, /SET
        HANDLE_VALUE, PHTSMCT.DECU, tmp.DECU, /SET
        HANDLE_VALUE, PHTSMCT.ROLL, tmp.ROLL, /SET
        HANDLE_VALUE, PHTSMCT.ROLU, tmp.ROLU, /SET

;  Update the PHTSMC structure using the temporary structure
	IF KEYWORD_SET(REPLACE) THEN BEGIN
		IF N_ELEMENTS(phtsmc) LE replace THEN $
		  MESSAGE, /INFO, 'Non-existing position, returning' ELSE $
		  phtsmc(replace) = phtsmct 
	ENDIF ELSE $
          PHTSMC = [PHTSMC,PHTSMCT]

        RETURN
        END
