;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_GENCHO_SM
;
; PURPOSE:
;	Menu for general choices within an automatic PIA procedure.
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	PIA_gencho_sm
;
; INPUTS:
;	
; KEYWORD PARAMETERS:
;	GROUP
;		The group leader of the widget hirarchy
;	
; OUTPUTS:
;	none
;	
; SIDE EFFECTS:
;	several variables are defined in two common blocks, which drive
;	the automatic measurements processing	
;	
; PROCEDURES USED:
;	INTERNAL: 
;		pia_gencho_sm_event
;
; COMMON BLOCKS:
;	pia_gencho_sm_cmn	for internal use
;	gencho_sm_cmn	for returning several variables
;	pia_gencho_sm_wid 	for internal use
;	
; MODIFICATION HISTORY:
;       Written by: 	Stefan Bogun (MPIA)			July 1996
;	adapted from PIA_GENCHO written by Carlos Gabriel
;	modified:     new design for PSE (SB)			January 1997
;	              usage of subdivided ramps (SB)		June 1997
;	              flatfielding (SB)		                August 1997
;                     Completely new design according to SESAME-V4.0 (SB)
;                                                               December 1997
;	Reset Interval Correction setting added (CG)		April 1998
;	V7.1
;	Modal defined as prescribed by IDL >= 5.0 (CG)		February 1999
;	V7.3.1
;-

; ****************************************************************************
;  Event handling routine for PIA general choices menu
; ****************************************************************************

PRO pia_gencho_sm_event, event


@gencho_sm

   COMMON pia_gencho_sm_cmn, filesel, erdsel, calset, ramp, f_ramp, $
    linear, deglit2, flat, darkc, deglit, drft, f_linear, f_deglit2, f_flat, $
    f_darkc, f_deglit, f_drft, savisrd, savismc, savsmc, backrep, resint

   COMMON pia_gencho_sm_wid, contset, conterd, contferd, contcor, contfcor, $
    contsav, calbase

   WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

   CASE uvalue OF

      'ACCEPT': BEGIN
         gen_file = filesel
         gen_erd = erdsel
         gen_cal = calset
         gen_ramp = ramp
         gen_f_ramp = f_ramp
         gen_lin = linear
         gen_deg2 = deglit2
         gen_flat = flat
         gen_dar = darkc
         gen_deg = deglit
         gen_drf = drft
         gen_f_lin = f_linear
         gen_f_deg2 = f_deglit2
         gen_f_flat = f_flat
         gen_f_dar = f_darkc
         gen_f_deg = f_deglit
         gen_f_drf = f_drft
         gen_isrd = savisrd
         gen_ismc = savismc
         gen_smc = savsmc
         gen_rep = backrep
	 gen_resint = resint
	 
         IF gen_file EQ 0 THEN $
          gen_filt = 'P2E*.FITS' $
         ELSE IF gen_file EQ 1 THEN $
          gen_filt = 'C2*.ISRD' $
         ELSE IF gen_file EQ 2 THEN $
          gen_filt = 'C2*.ISMC'

         gen_stop = 0
         WIDGET_CONTROL, event.top, /DESTROY
      END

      'CANCEL': BEGIN

         gen_stop = 1
         WIDGET_CONTROL, event.top, /DESTROY

      END

      'FILESEL': BEGIN 	
         CASE event.value OF
            0: BEGIN
               filesel = 0

               WIDGET_CONTROL, contset(0), SENSITIVE = 1
               WIDGET_CONTROL, contset(1), SENSITIVE = 0
               WIDGET_CONTROL, conterd, SENSITIVE = 1
               WIDGET_CONTROL, contferd, SENSITIVE = 1
               WIDGET_CONTROL, contcor(0), SENSITIVE = 1
               WIDGET_CONTROL, contcor(1), SENSITIVE = 1
               WIDGET_CONTROL, contcor(2), SENSITIVE = 1
               WIDGET_CONTROL, contcor(3), SENSITIVE = 1
               WIDGET_CONTROL, contcor(4), SENSITIVE = 1
               WIDGET_CONTROL, contcor(5), SENSITIVE = 1
               WIDGET_CONTROL, contcor(6), SENSITIVE = 1
               WIDGET_CONTROL, contfcor(0), SENSITIVE = 1
               WIDGET_CONTROL, contfcor(1), SENSITIVE = 1
               WIDGET_CONTROL, contfcor(2), SENSITIVE = 1
               WIDGET_CONTROL, contfcor(3), SENSITIVE = 1
               WIDGET_CONTROL, contfcor(4), SENSITIVE = 1
               WIDGET_CONTROL, contfcor(5), SENSITIVE = 1
               WIDGET_CONTROL, contsav(0), SENSITIVE = 1
               WIDGET_CONTROL, calbase, SENSITIVE = 1   
            END

            1: BEGIN
               filesel = 1

               WIDGET_CONTROL, contset(0), SENSITIVE = 0   
               WIDGET_CONTROL, contset(1), SENSITIVE = 0
               WIDGET_CONTROL, conterd, SENSITIVE = 0
               WIDGET_CONTROL, contferd, SENSITIVE = 0
               WIDGET_CONTROL, contcor(0), SENSITIVE = 0   
               WIDGET_CONTROL, contcor(1), SENSITIVE = 0   
               WIDGET_CONTROL, contcor(2), SENSITIVE = 1
               WIDGET_CONTROL, contcor(3), SENSITIVE = 1
               WIDGET_CONTROL, contcor(4), SENSITIVE = 1
               WIDGET_CONTROL, contcor(5), SENSITIVE = 1
               WIDGET_CONTROL, contcor(6), SENSITIVE = 1
               WIDGET_CONTROL, contfcor(0), SENSITIVE = 0  
               WIDGET_CONTROL, contfcor(1), SENSITIVE = 0  
               WIDGET_CONTROL, contfcor(2), SENSITIVE = 1  
               WIDGET_CONTROL, contfcor(3), SENSITIVE = 1  
               WIDGET_CONTROL, contfcor(4), SENSITIVE = 1  
               WIDGET_CONTROL, contfcor(5), SENSITIVE = 1  
               WIDGET_CONTROL, contsav(0), SENSITIVE = 0
               WIDGET_CONTROL, calbase, SENSITIVE = 1   
            END
            
            2: BEGIN
               filesel = 2

               WIDGET_CONTROL, contset(0), SENSITIVE = 0   
               WIDGET_CONTROL, contset(1), SENSITIVE = 1
               WIDGET_CONTROL, conterd, SENSITIVE = 0
               WIDGET_CONTROL, contferd, SENSITIVE = 0
               WIDGET_CONTROL, contcor(0), SENSITIVE = 0   
               WIDGET_CONTROL, contcor(1), SENSITIVE = 0   
               WIDGET_CONTROL, contcor(2), SENSITIVE = 0
               WIDGET_CONTROL, contcor(3), SENSITIVE = 0
               WIDGET_CONTROL, contcor(4), SENSITIVE = 0
               WIDGET_CONTROL, contcor(5), SENSITIVE = 0
               WIDGET_CONTROL, contcor(6), SENSITIVE = 0
               WIDGET_CONTROL, contfcor(0), SENSITIVE = 0  
               WIDGET_CONTROL, contfcor(1), SENSITIVE = 0  
               WIDGET_CONTROL, contfcor(2), SENSITIVE = 0  
               WIDGET_CONTROL, contfcor(3), SENSITIVE = 0  
               WIDGET_CONTROL, contfcor(4), SENSITIVE = 0  
               WIDGET_CONTROL, contfcor(5), SENSITIVE = 0  
               WIDGET_CONTROL, contsav(0), SENSITIVE = 0
               WIDGET_CONTROL, calbase, SENSITIVE = 0   
            END
            
         ENDCASE
      END

      'SAVEFIL': BEGIN
         CASE event.value OF
            
            0: savisrd = event.select
            
            1: savismc = event.select
            
            2: savsmc = event.select
            
         ENDCASE
      END

      'SELECS': BEGIN
         CASE event.value OF
            
            0: erdsel = event.select
            
            1: backrep = event.select
            
         ENDCASE
      END

      'CALIB': BEGIN 	
         CASE event.value OF
            0: BEGIN
               calset = 0

               WIDGET_CONTROL, contferd, SENSITIVE = 0
               WIDGET_CONTROL, contfcor(0), SENSITIVE = 0
               WIDGET_CONTROL, contfcor(1), SENSITIVE = 0
               WIDGET_CONTROL, contfcor(2), SENSITIVE = 0
               WIDGET_CONTROL, contfcor(3), SENSITIVE = 0
               WIDGET_CONTROL, contfcor(4), SENSITIVE = 0
               WIDGET_CONTROL, contfcor(5), SENSITIVE = 0
            END

            1: BEGIN
               calset = 1

               WIDGET_CONTROL, contferd, SENSITIVE = 1
               WIDGET_CONTROL, contfcor(0), SENSITIVE = 1
               WIDGET_CONTROL, contfcor(1), SENSITIVE = 1
               WIDGET_CONTROL, contfcor(2), SENSITIVE = 1
               WIDGET_CONTROL, contfcor(3), SENSITIVE = 1
               WIDGET_CONTROL, contfcor(4), SENSITIVE = 1
               WIDGET_CONTROL, contfcor(5), SENSITIVE = 1
            END
            
            2: BEGIN
               calset = 2

               WIDGET_CONTROL, contferd, SENSITIVE = 1
               WIDGET_CONTROL, contfcor(0), SENSITIVE = 1
               WIDGET_CONTROL, contfcor(1), SENSITIVE = 1
               WIDGET_CONTROL, contfcor(2), SENSITIVE = 1
               WIDGET_CONTROL, contfcor(3), SENSITIVE = 1
               WIDGET_CONTROL, contfcor(4), SENSITIVE = 1
               WIDGET_CONTROL, contfcor(5), SENSITIVE = 1
            END
            
         ENDCASE
      END

      'RAMPP': ramp = event.value

      'F_RAMPP': f_ramp = event.value

      'CORRECS': BEGIN
         CASE event.value OF
            
            0: linear = event.select
            
            1: deglit2 = event.select

            2: flat = event.select
            
            3: darkc = event.select
            
            4: deglit = event.select
            
            5: drft = event.select
            
            6: resint = event.select
          ENDCASE
      END

      'F_CORRECS': BEGIN
         CASE event.value OF
            
            0: f_linear = event.select
            
            1: f_deglit2 = event.select

            2: f_flat = event.select
            
            3: f_darkc = event.select
            
            4: f_deglit = event.select
            
            5: f_drft = event.select
            
         ENDCASE
      END

      ELSE:

   ENDCASE
   RETURN
END

; ****************************************************************************
;  PIA GENCHO_SM - menu definition procedure
; ****************************************************************************

PRO pia_gencho_sm, GROUP=group

; Definitions common to all instances
@gencho_sm

   COMMON pia_gencho_sm_cmn, filesel, erdsel, calset, ramp, f_ramp, $
    linear, deglit2, flat, darkc, deglit, drft, f_linear, f_deglit2, f_flat, $
    f_darkc, f_deglit, f_drft, savisrd, savismc, savsmc, backrep, resint

   COMMON pia_gencho_sm_wid, contset, conterd, contferd, contcor, contfcor, $
    contsav, calbase

   IF N_ELEMENTS(gen_file) EQ 0 THEN filesel = 0 ELSE filesel = gen_file
   IF N_ELEMENTS(gen_erd) EQ 0 THEN erdsel = 0 ELSE erdsel = gen_erd
   IF N_ELEMENTS(gen_cal) EQ 0 THEN calset = 0 ELSE calset = gen_cal
   IF N_ELEMENTS(gen_ramp) EQ 0 THEN ramp = 0 ELSE ramp = gen_ramp
   IF N_ELEMENTS(gen_f_ramp) EQ 0 THEN f_ramp = 0 ELSE f_ramp = gen_f_ramp
   IF N_ELEMENTS(gen_lin) EQ 0 THEN linear = 0 ELSE linear = gen_lin
   IF N_ELEMENTS(gen_deg2) EQ 0 THEN deglit2 = 0 ELSE deglit2 = gen_deg2
   IF N_ELEMENTS(gen_flat) EQ 0 THEN flat = 0 ELSE flat = gen_flat
   IF N_ELEMENTS(gen_dar) EQ 0 THEN darkc = 0 ELSE darkc = gen_dar
   IF N_ELEMENTS(gen_deg) EQ 0 THEN deglit = 0 ELSE deglit = gen_deg
   IF N_ELEMENTS(gen_drf) EQ 0 THEN drft = 0 ELSE drft = gen_drf
   IF N_ELEMENTS(gen_f_lin) EQ 0 THEN f_linear = 0 ELSE f_linear = gen_f_lin
   IF N_ELEMENTS(gen_f_deg2) EQ 0 THEN f_deglit2 = 0 ELSE f_deglit2 = gen_f_deg2
   IF N_ELEMENTS(gen_f_flat) EQ 0 THEN f_flat = 0 ELSE f_flat = gen_f_flat
   IF N_ELEMENTS(gen_f_dar) EQ 0 THEN f_darkc = 0 ELSE f_darkc = gen_f_dar
   IF N_ELEMENTS(gen_f_deg) EQ 0 THEN f_deglit = 0 ELSE f_deglit = gen_f_deg
   IF N_ELEMENTS(gen_f_drf) EQ 0 THEN f_drft = 0 ELSE f_drft = gen_f_drf
   IF N_ELEMENTS(gen_isrd) EQ 0 THEN savisrd = 0 ELSE savisrd = gen_isrd
   IF N_ELEMENTS(gen_ismc) EQ 0 THEN savismc = 0 ELSE savismc = gen_ismc
   IF N_ELEMENTS(gen_smc) EQ 0 THEN savsmc = 0 ELSE savsmc = gen_smc
   IF N_ELEMENTS(gen_rep) EQ 0 THEN backrep = 0 ELSE backrep = gen_rep
   IF N_ELEMENTS(gen_resint) EQ 0 THEN resint = 0 ELSE resint = gen_resint


   IF not KEYWORD_SET(group) THEN group = !pia_top_wid

   gchbase = WIDGET_BASE(TITLE = 'PIA procedure SeM selection menu', $ 
                         /COLUMN, /modal, group=group)

   filebase = WIDGET_BASE(gchbase, /ROW)

   stdbut = cw_bgroup(filebase, LABEL_TOP = 'Input to be used', $
                      /EXCLUSIVE, /FRAME, $
                      SET_VALUE = filesel, $
                      UVALUE = 'FILESEL', $
                      ["ERD FITS files", $
                       "SRD Internal files", $
                       "SMC Internal files" ])

   stdbut = cw_bgroup(filebase, LABEL_TOP = 'Saving into files', $
                      /NONEXCLUSIVE, /FRAME, $
                      SET_VALUE = [savisrd,savismc,savsmc], $
                      UVALUE = 'SAVEFIL', IDS = contsav, $
                      ["Save SRD measurements to IDL files", $
                       "Save SMC measurements to IDL files", $
                       "Save SMC measurements to FITS files" ])

   setbase = WIDGET_BASE(gchbase, /ROW)
   
   stdbut = cw_bgroup(setbase, LABEL_TOP = 'Settings', $
                      /NONEXCLUSIVE, /FRAME, $
                      SET_VALUE = [erdsel,backrep], $
                      UVALUE = 'SELECS', IDS = contset, $
                      ["Selection decision desired for ERD",$
                       "Reprocess background"])

   calbase = cw_bgroup(setbase, LABEL_TOP = 'Calibration', $
                       /EXCLUSIVE, /FRAME, $
                       SET_VALUE = calset, $
                       UVALUE = 'CALIB', IDS = contcal, $
                       ["Default responsivities (orbital pos. dep.)", $
                        "Responsivities from FCS", $
                        "Responsivities from orbit" ])

   erdbase = WIDGET_BASE(gchbase, /ROW)

   conterd = cw_bgroup(erdbase, LABEL_TOP = 'ramp processing of sky meas.', $
                      /EXCLUSIVE, /FRAME, $
                      SET_VALUE = ramp, $
                      UVALUE = 'RAMPP', $
                      ["Use whole ramps", $
                       "Use pairs of readouts        "])
 
   contferd = cw_bgroup(erdbase, LABEL_TOP = 'ramp processing of FCS meas.', $
                      /EXCLUSIVE, /FRAME, $
                      SET_VALUE = f_ramp, $
                      UVALUE = 'F_RAMPP', $
                      ["Use whole ramps", $
                       "Use pairs of readouts        "])
    
   corbase = WIDGET_BASE(gchbase, /ROW)

   skycor = cw_bgroup(corbase, LABEL_TOP = 'Corrections for sky meas.', $
                      /NONEXCLUSIVE, /FRAME, $
                      SET_VALUE = $
                       [linear,deglit2,flat,darkc,deglit,drft,resint], $
                      UVALUE = 'CORRECS', IDS = contcor, $
                      ["Ramps Linearization (ERD)", $
                       "Ramps Deglitching (ERD)", $
                       "Statistical flatfielding (SRD)", $
                       "Dark Current Subtraction (SRD)", $
                       "Signals Deglitching (SRD)", $
                       "Drifts recognition (SRD) ", $
                       "Reset Interval Corr.(SRD-also FCS)"])

   fcscor = cw_bgroup(corbase, LABEL_TOP = 'Corrections for FCS meas.', $
                      /NONEXCLUSIVE, /FRAME, $
                      SET_VALUE = [f_linear,f_deglit2,f_flat,f_darkc,f_deglit,$
                                   f_drft], $
                      UVALUE = 'F_CORRECS', IDS = contfcor, $
                      ["Ramps Linearization (ERD)", $
                       "Ramps Deglitching (ERD)", $
                       "Statistical flatfielding (SRD)", $
                       "Dark Current Subtraction (SRD)", $
                       "Signals Deglitching (SRD)", $
                       "Drifts recognition (SRD) " ])
   
   control = WIDGET_BASE(gchbase,/ROW)

   junk = WIDGET_LABEL(control, VALUE = '                          ')
   accept = WIDGET_BUTTON(control, VALUE = '  OK  ', $
                          /FRAME, UVALUE = 'ACCEPT')
   junk = WIDGET_LABEL(control, VALUE = '                          ')
   cancel = WIDGET_BUTTON(control, VALUE = '  Cancel  ', $
                          /FRAME, UVALUE = 'CANCEL')

   WIDGET_CONTROL, gchbase, /REALIZE, TLB_SET_XOFFSET=450

   IF filesel GE 1 THEN BEGIN
      WIDGET_CONTROL, conterd, SENSITIVE = 0
      WIDGET_CONTROL, contferd, SENSITIVE = 0
      WIDGET_CONTROL, contset(0), SENSITIVE = 0
      WIDGET_CONTROL, contcor(0), SENSITIVE = 0
      WIDGET_CONTROL, contcor(1), SENSITIVE = 0
      WIDGET_CONTROL, contfcor(0), SENSITIVE = 0
      WIDGET_CONTROL, contfcor(1), SENSITIVE = 0
      WIDGET_CONTROL, contsav(0), SENSITIVE = 0
   ENDIF

   IF filesel EQ 2 THEN BEGIN
      WIDGET_CONTROL, contcor(2), SENSITIVE = 0
      WIDGET_CONTROL, contcor(3), SENSITIVE = 0
      WIDGET_CONTROL, contcor(4), SENSITIVE = 0
      WIDGET_CONTROL, contcor(5), SENSITIVE = 0
      WIDGET_CONTROL, contfcor(2), SENSITIVE = 0
      WIDGET_CONTROL, contfcor(3), SENSITIVE = 0
      WIDGET_CONTROL, contfcor(4), SENSITIVE = 0
      WIDGET_CONTROL, contfcor(5), SENSITIVE = 0
      WIDGET_CONTROL, contset(1), SENSITIVE = 1
   ENDIF $
   ELSE BEGIN
      WIDGET_CONTROL, contset(1), SENSITIVE = 0
   ENDELSE

; Resposivities from orbit not yet available
   WIDGET_CONTROL, contcal(2), SENSITIVE = 0

   XManager, /NO_BLOCK, "pia_gencho_sm", gchbase, GROUP=group
   
   RETURN

END
