;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_PROC_BATCH_MANAGER_SM
;
; PURPOSE:
;       Menu and procedure within the PIA to get automatically
;       a sequence of steps to be performed, without major interaction
;	for Serendipity measurements.
;       Data reduction from ERD up to SMC level and point source extraction, 
;	including calibration.
;	This menu is on top of PIA_PROC_BATCH_SM and loop over several files
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       PIA_PROC_BATCH_MANAGER_SM
;
; INPUTS:
;
; KEYWORD PARAMETERS:
;
; OUTPUTS:
;	none
;
;
; COMMON BLOCKS:
;	phterd:		ERD dynamical structure
;	phtsrd:		SRD dynamical structure
;	phtsmc:		SMC dynamical structure
;       gencho_sm_cmn   for returning several variables
;       phtacc		for selection criteria
;	batch_sm_wid:   widget information
;
; PROCEDURES USED:
;	PIA Procedure(s):
;	Internal:
;		pia_proc_batch_manager_sm_event
;
; MODIFICATION HISTORY:
;       Written by: 	Stefan Bogun (MPIA)			July 1996
;	adapted from PIA_PROC_BATCH_MANAGER written by Carlos Gabriel
;
;	cleaning all buffers (SB, October 1996)
;	also cleaning IIPH buffer (SB, November 1996)
;	correct handling of CANCEL button  (SB, November 1996)
;	processing window remains the same (SB, November 1996)
;	changing path in file selectors works now (SB, December 1996)
;	reading files from !XDRDIR rather than !INTDIR (SB, February 1997)
;       slight corrections due to changed parameters (SB, December 1997)
;-
PRO pia_proc_batch_manager_sm_event, event

 	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

        CASE UVALUE OF
        
        	'QUIT': WIDGET_CONTROL, event.top, /destroy
		ELSE:
		
	ENDCASE

	RETURN
	END

PRO PIA_PROC_BATCH_MANAGER_SM
@gencho_sm
@phterd
@phtsrd
@phtsmc
@phtacc
COMMON batch_sm_wid, proc_base, proc_text1

        base = WIDGET_BASE(TITLE='PIA Batch Manager for Serendipity', /COLUMN)

	quit = WIDGET_BUTTON(base, VALUE=" QUIT ", UVALUE="QUIT")
        text1 = WIDGET_TEXT(base, XSIZE=60, YSIZE=30, /SCROLL, XOFFSET=10, $
			YOFFSET=50, VALUE=['Starting BATCH processing',' '])

        WIDGET_CONTROL, base, /REALIZE

        WIDGET_CONTROL, base, /hourglass


	pia_gencho_sm

        IF gen_stop THEN BEGIN
           WIDGET_CONTROL, base, /destroy
           RETURN
        ENDIF

        IF N_ELEMENTS(gen_erd) EQ 0 THEN gen_erd = 0

;
; ERD Selection criteria 
; 
	IF gen_file EQ 0 THEN BEGIN
	   drnacc = sm_drnacc
	   ndr1nac = sm_ndr1nac
	   nselndr = sm_nselndr
	
	   IF (gen_erd) THEN pia_rodisc, nndr = -1

	   sm_drnacc = drnacc
	   sm_ndr1nac = ndr1nac
	   sm_nselndr = nselndr
	ENDIF

; Serendipity parameter settings

	IF N_ELEMENTS(gen_file) EQ 0 THEN gen_file=0
	
	IF gen_file EQ 0 THEN BEGIN
; starting from ERD
	  oldpath = !FITDIR
	  fillist = pia_pickfile(/multi, filter=gen_filt, path=!FITDIR, $
	     get_path=newpath)
	  !FITDIR = newpath

          IF fillist(0) EQ '' THEN BEGIN
                MESSAGE, /INFO, $
		  ' No Data selected, BATCH Sequence stopped'
        	WIDGET_CONTROL, base, /destroy
                RETURN
          ENDIF
		
          proc_base = WIDGET_BASE(TITLE='Serendipity batch processing messages', $
          /COLUMN, XOFFSET=300)

          proc_text1 = WIDGET_TEXT(proc_base, XSIZE=60, YSIZE=30, /SCROLL, XOFFSET=60, $
	  YOFFSET=50)

          WIDGET_CONTROL, proc_base, /REALIZE
          WIDGET_CONTROL, proc_base, /hourglass

	  FOR I=0, N_ELEMENTS(fillist)-1 DO BEGIN 
	  
        	filename = STRUPCASE(STRTRIM(fillist(i),2))
        	filename = strmid(filename,(STRPOS(filename,'.FITS') - 12), 17)

        	WIDGET_CONTROL, text1, SET_VALUE='Reading ERD '+filename, $
			/append
		WIDGET_CONTROL, base, /hourglass
          	
		read_erd, filename,hdr,ilunr

; Compute first measurement on the ERD level
		firsterd = ilunr(0)

;
; Compute last measurement to be used
; 
		lasterd = max(ilunr)	    
;
; Compute all measurements to be processed to SMC (FCS to SCP)
;

	  	meas = indgen(lasterd-firsterd+1) + firsterd

        	WIDGET_CONTROL, text1, $
        	 SET_VALUE='Processing measurements from '+filename, $
			/append
		WIDGET_CONTROL, base, /hourglass

        	WIDGET_CONTROL, text1, $
        	 SET_VALUE=['Another window will inform you ---> ',' '], $
			/append
		WIDGET_CONTROL, base, /hourglass

		PIA_PROC_BATCH_SM, meas

        	WIDGET_CONTROL, text1, $
        	 SET_VALUE='Now cleaning all buffers ', $
			/append
		WIDGET_CONTROL, base, /hourglass
		
		erd_init
		srd_init
		scp_init
		smc_init
		cs_init
		iiph_init

		CLOSE, /ALL

	    ENDFOR		
	    WIDGET_CONTROL, proc_base, /destroy
	    !FITDIR = oldpath
	    
	ENDIF $
	  
	ELSE IF gen_file EQ 1 THEN BEGIN
; starting from SRD	

          oldpath = !XDRDIR
          fillist = pia_pickfile(/multi, filter=gen_filt, path=!XDRDIR, $
             get_path=newpath)
          !XDRDIR = newpath

          IF fillist(0) EQ '' THEN BEGIN
                MESSAGE, /INFO, $
		  ' No Data selected, BATCH Sequence stopped'
        	WIDGET_CONTROL, base, /destroy
                RETURN
          ENDIF
		
          proc_base = WIDGET_BASE(TITLE='Serendipity batch processing messages', $
          /COLUMN, XOFFSET=300)

          proc_text1 = WIDGET_TEXT(proc_base, XSIZE=60, YSIZE=30, /SCROLL, XOFFSET=60, $
	  YOFFSET=50)

          WIDGET_CONTROL, proc_base, /REALIZE
          WIDGET_CONTROL, proc_base, /hourglass

	  FOR I=0, N_ELEMENTS(fillist)-1 DO BEGIN 
	  
        	filename = STRUPCASE(STRTRIM(fillist(i),2))
        	filename = strmid(filename,(STRPOS(filename,'.ISRD') - 12), 17)

        	WIDGET_CONTROL, text1, SET_VALUE='Reading ISRD '+filename, $
			/append
		WIDGET_CONTROL, base, /hourglass
          	
		read_isrd, filename, path=!XDRDIR
		srdnam = strmid(filename,0,12)
		ilunr = WHERE(phtsrd.admn EQ srdnam)
		ilunr = ilunr(0)
		isrdnum = strmid(phtsrd(ilunr).admn,4,8)
		icsname = 'CS' + isrdnum + '.ICS'
		read_ics, icsname, path=!XDRDIR

        	WIDGET_CONTROL, text1, $
        	 SET_VALUE='Processing measurements from '+filename, $
			/append
		WIDGET_CONTROL, base, /hourglass

        	WIDGET_CONTROL, text1, $
        	 SET_VALUE=['Another window will inform you ---> ',' '], $
			/append
		WIDGET_CONTROL, base, /hourglass

		PIA_PROC_BATCH_SM, ilunr

        	WIDGET_CONTROL, text1, $
        	 SET_VALUE='Now cleaning all buffers ', $
			/append
		WIDGET_CONTROL, base, /hourglass

		
                srd_init
                scp_init
                smc_init
                cs_init
		iiph_init

		CLOSE, /ALL

	    ENDFOR		
	    WIDGET_CONTROL, proc_base, /destroy
	    !XDRDIR = oldpath
	    
	ENDIF $
	  
	ELSE IF gen_file EQ 2 THEN BEGIN
; starting from SMC	
          oldpath = !XDRDIR
          fillist = pia_pickfile(/multi, filter=gen_filt, path=!XDRDIR, $
             get_path=newpath)
          !XDRDIR = newpath

          IF fillist(0) EQ '' THEN BEGIN
                MESSAGE, /INFO, $
		  ' No Data selected, BATCH Sequence stopped'
        	WIDGET_CONTROL, base, /destroy
                RETURN
          ENDIF
		
          proc_base = WIDGET_BASE(TITLE='Serendipity batch processing messages', $
          /COLUMN, XOFFSET=300)

          proc_text1 = WIDGET_TEXT(proc_base, XSIZE=60, YSIZE=30, /SCROLL, XOFFSET=60, $
	  YOFFSET=50)

          WIDGET_CONTROL, proc_base, /REALIZE
          WIDGET_CONTROL, proc_base, /hourglass

	  FOR I=0, N_ELEMENTS(fillist)-1 DO BEGIN 
	  
        	filename = STRUPCASE(STRTRIM(fillist(i),2))
        	filename = strmid(filename,(STRPOS(filename,'.ISMC') - 12), 17)

        	WIDGET_CONTROL, text1, SET_VALUE='Reading ISMC '+filename, $
			/append
		WIDGET_CONTROL, base, /hourglass
          	
		read_ismc, filename, path=!XDRDIR
		smcnam = strmid(filename,0,12)
		ilunr = WHERE(phtsmc.admn EQ smcnam)
		ilunr = ilunr(0)

        	WIDGET_CONTROL, text1, $
        	 SET_VALUE='Processing measurements from '+filename, $
			/append
		WIDGET_CONTROL, base, /hourglass

        	WIDGET_CONTROL, text1, $
        	 SET_VALUE=['Another window will inform you ---> ',' '], $
			/append
		WIDGET_CONTROL, base, /hourglass

		PIA_PROC_BATCH_SM, ilunr

        	WIDGET_CONTROL, text1, $
        	 SET_VALUE='Now cleaning SMC buffer ', $
			/append
		WIDGET_CONTROL, base, /hourglass

		
                smc_init

		CLOSE, /ALL

	    ENDFOR		
	    WIDGET_CONTROL, proc_base, /destroy
	    !XDRDIR = oldpath
	    
	ENDIF

	
	XMANAGER, /NO_BLOCK, "PIA_PROC_BATCH_MANAGER_SM", base, GROUP=group
	
	RETURN
	END
