




 FUNCTION PIA_SM_MED, A
;+
; NAME
;	 MED
; PURPOSE
;	Compute the median of an array, which may be of even length.
;
; CALLING SEQUENCE:
; 	MID_VALUE = PIA_SM_MED(A)
;
; OUTPUTS
; 	The median of array A
; REVISION HISTORY:
;	H.T. Freudenreich, ?/89
;-
ON_ERROR,2
NUM = N_ELEMENTS(A)
IF NUM MOD 2 EQ 0 THEN BEGIN  ; even # points. Can't call MEDIAN.
   B = A   &  B = B( SORT(B) )  &  I0  = (NUM-1)/2  & MED =.5*(B(I0)+B(I0+1))
ENDIF ELSE MED=MEDIAN(A)
RETURN, MED
END











Function  PIA_SM_LastEl,  Array
;~~~~~~~~~~~~~~~~~~~~~~~
;
; returns last Element of Array
;
Return, Array (N_Elements (Array)-1)
End


Function  PIA_SM_LstEl,  Array
;~~~~~~~~~~~~~~~~~~~~~~
;
; returns last Element of Array
;
Return, Array (N_Elements (Array)-1)
End


Function   PIA_SM_Len,  Array
;~~~~~~~~~~~~~~~~~~~~~

; returns total length of array

Return, N_Elements (Array)
End












FUNCTION  PIA_SM_ROBUST_SIGMA,Y, ZERO=REF
;
;+
; NAME:
;	ROBUST_SIGMA
;
; PURPOSE:
;	Calculate a resistant estimate of the dispersion of a distribution.
;	For an uncontaminated distribution, this is identical to the standard
;	deviation.
;
; CALLING SEQUENCE:
;	result = ROBUST_SIGMA( Y, [ /ZERO ] )
;
; INPUT:
;	Y = Vector of quantity for which the dispersion is to be calculated
; OPTIONAL INPUT KEYWORD:
;	ZERO - if set, the dispersion is calculated w.r.t. 0.0 rather than the
;		central value of the vector. If Y is a vector of residuals, this
;		should be set.
;
; OUTPUT:
;	ROBUST_SIGMA returns the dispersion. In case of failure, returns
;	value of -1.0
;
; SUBROUTINE CALLS:
;	MED, which calculates the median
;
; PROCEDURE:
;	Use the median absolute deviation as the initial estimate, then weight
;	points using Tukey's Biweight. See, for example, "Understanding Robust
;	and Exploratory Data Analysis," by Hoaglin, Mosteller and Tukey, John
;	Wiley & Sons, 1983.
;
; REVSION HISTORY:
;	H. Freudenreich, STX, 8/90
;
;-

EPS = 1.0E-20
IF KEYWORD_SET(REF) THEN Y0=0. ELSE Y0  = PIA_SM_MED(Y)
; First, the median absolute deviation about the median:
MAD = PIA_SM_MED( ABS(Y-Y0) )/.6745
; If the MAD=0, try the MEAN absolute deviation:
IF MAD LT EPS THEN MAD=AVG( ABS(Y-Y0) )/.80
IF MAD LT EPS THEN BEGIN
   SIGGMA=0.
   RETURN,SIGGMA
ENDIF
; Now the biweighted value:
U   = (Y-Y0)/(6.*MAD)
UU  = U*U
Q   = WHERE(UU LE 1.0, COUNT)
IF COUNT LT 3 THEN BEGIN
   PRINT,'ROBUST_SIGMA: This distribution is TOO WEIRD! Returning -1'
   SIGGMA = -1.
   RETURN,SIGGMA
ENDIF
NUMERATOR = TOTAL( (Y(Q)-Y0)^2 * (1-UU(Q))^4 )
N     = N_ELEMENTS(Y)
DEN1  = TOTAL( (1.-UU(Q))*(1.-5.*UU(Q)) )
SIGGMA = N*NUMERATOR/(DEN1*(DEN1-1.))
IF SIGGMA GT 0. THEN SIGGMA = SQRT(SIGGMA) ELSE SIGGMA=0.

RETURN,SIGGMA
END














FUNCTION PIA_SM_ROB_CHECKFIT,Y, YFIT, EPS, DEL, SIG, FRACDEV, NGOOD,W,B,$
                      BISQUARE_LIMIT=BLIM
;+
; NAME:
;	ROB_CHECKFIT
; PURPOSE:
;	Used by ROBUST_... routines to determine the quality of a fit and to
;	return biweights.
; CALLING SEQUENCE:
;	status = ROB_CHECKFIT( Y, YFIT, EPS, DEL, SIG, FRACDEV, NGOOD, W, B
;				BISQUARE_LIMIT = )
; INPUT:
;	Y     = the data
;	YFIT  = the fit to the data
;	EPS   = the "too small" limit
;	DEL   = the "close enough" for the fractional median abs. deviations
; RETURNS:
;	Integer status. if =1, the fit is considered to have converged
;
; OUTPUTS:
;	SIG   = robust standard deviation analog
;	FRACDEV = the fractional median absolute deviation of the residuals
;	NGOOD   = the number of input point given non-zero weight in the
;		calculation
;	W     = the bisquare weights of Y
;	B     = residuals scaled by sigma
;
; OPTIONAL INPUT KEYWORD:
;	BISQUARE_LIMIT = allows changing the bisquare weight limit from
;			default 6.0
; REVISION HISTORY:
;	Written, H.T. Freudenreich, HSTX, 1/94
;-

  ISTAT = 0

  IF KEYWORD_SET(BLIM) THEN BFAC=BLIM ELSE BFAC=6.

  DEV = Y-YFIT

  SIG=PIA_SM_ROBUST_SIGMA(DEV,/ZERO)
; If the standard deviation = 0 then we're done:
  IF SIG LT EPS THEN GOTO,DONE

  IF DEL GT 0. THEN BEGIN
   ; If the fraction std. deviation ~ machine precision, we're done:
     Q=WHERE( ABS(YFIT) GT EPS, COUNT )
     IF COUNT LT 3 THEN FRACDEV=0. ELSE FRACDEV = PIA_SM_MED( ABS( DEV(Q)/YFIT(Q) ) )
     IF FRACDEV LT DEL THEN GOTO,DONE
  ENDIF

  ISTAT = 1

; Calculate the (bi)weights:
  B = ABS(DEV)/(BFAC*SIG)
  S = WHERE( B GT 1.0,COUNT )  &  IF COUNT GT 0 THEN B(S) = 1.
  NGOOD = N_ELEMENTS(Y)-COUNT

  W=(1.-B^2)
  W=W/TOTAL(W)
DONE:
RETURN, ISTAT
END








FUNCTION PIA_SM_ROBUST_POLY_FIT,X,Y,NDEG,YFIT,SIG, NUMIT=THIS_MANY
;+
; NAME:
;	ROBUST_POLY_FIT
;
; PURPOSE:
;	An outlier-resistant polynomial fit.
;
; CALLING SEQUENCE:
;	COEFF = ROBUST_POLY_FIT(X,Y,NDEGREE  ,[ YFIT,SIG, NUMIT =] )
;
; INPUTS:
;	X = Independent variable vector, floating-point or double-precision
;	Y = Dependent variable vector
;
; OUTPUTS:
;	Function result = coefficient vector, length NDEGREE+1.
;	IF COEFF=0.0, NO FIT! If N_ELEMENTS(COEFF) > degree+1, the fit is poor
;	(in this case the last element of COEFF=0.)
;	Either floating point or double precision.
;
; OPTIONAL OUTPUT PARAMETERS:
;	YFIT = Vector of calculated y's
;	SIG  = the "standard deviation" of the residuals
;
; RESTRICTIONS:
;	Large values of NDEGREE should be avoided. This routine works best
;	when the number of points >> NDEGREE.
;
; PROCEDURE:
;	For the initial estimate, the data is sorted by X and broken into
;	NDEGREE+2 sets. The X,Y medians of each set are fitted to a polynomial
;	 via POLY_FIT.   Bisquare ("Tukey's Biweight") weights are then
;	calculated, using a limit  of 6 outlier-resistant standard deviations.
;	The fit is repeated iteratively until the robust standard deviation of
;	the residuals changes by less than .03xSQRT(.5/(N-1)).
;
; REVISION HISTORY
;	Written, H. Freudenreich, STX, 8/90. Revised 4/91.
;	2/94 -- changed convergence criterion
;-

ON_ERROR,2

EPS   = 1.0E-20
DEL   = 5.0E-07
DEGMAX= 6

IF N_ELEMENTS(THIS_MANY) GT 0 THEN ITMAX=THIS_MANY ELSE ITMAX=25

BADFIT=0

NPTS = N_ELEMENTS(X)
MINPTS=NDEG+1
IF (NPTS/4*4) EQ NPTS THEN NEED2 = 1 ELSE NEED2 = 0
N3 = 3*NPTS/4  &  N1 = NPTS/4

; If convenient, move X and Y to their centers of gravity:
IF NDEG LT DEGMAX THEN BEGIN
   X0=TOTAL(X)/NPTS  &  Y0=TOTAL(Y)/NPTS
   U=X-X0            &  V=Y-Y0
ENDIF ELSE BEGIN
   U=X               &  V=Y
ENDELSE

; The initial estimate.

; Choose an odd number of segments:
NUM_SEG = NDEG+2
IF (NUM_SEG/2*2) EQ NUM_SEG THEN NUM_SEG =NUM_SEG+1
MIN_PTS = NUM_SEG*3
IF NPTS LT 10000 THEN BEGIN ;MIN_PTS THEN BEGIN
;  Settle for least-squares:
   LSQFIT = 1
   CC = POLY_FIT( U, V, NDEG, YFIT )
ENDIF ELSE BEGIN
;  Break up the data into segments:
   LSQFIT = 0
   Q = SORT(U)
   U = U(Q)  &  V = V(Q)
   N_PER_SEG = INTARR(NUM_SEG)
   N_PER_SEG(*) = NPTS/NUM_SEG

;  Put the leftover points in the middle segment:
   N_LEFT = NPTS - N_PER_SEG(0)*NUM_SEG
   N_PER_SEG(NUM_SEG/2) = N_PER_SEG(NUM_SEG/2) + N_LEFT
   R = FLTARR(NUM_SEG)  &  S = FLTARR(NUM_SEG)
   R(0)=PIA_SM_MED( U(0:N_PER_SEG(0)-1) ) & S(0)=PIA_SM_MED( V(0:N_PER_SEG(0)-1) )
   I2 = N_PER_SEG(0)-1
   FOR I=1,NUM_SEG-1 DO BEGIN
     I1 = I2 + 1
     I2 = I1 + N_PER_SEG(I) - 1
     R(I) = PIA_SM_MED( U(I1:I2) )     &  S(I) = PIA_SM_MED( V(I1:I2) )
   ENDFOR
;  Now fit:
   CC = POLY_FIT( R,S, NDEG )
   YFIT = POLY(U,CC)
ENDELSE

ISTAT=PIA_SM_ROB_CHECKFIT(V,YFIT,EPS,DEL,  SIG,FRACDEV,NGOOD,W,S)
IF ISTAT EQ 0 THEN GOTO,AFTERFIT

IF NGOOD LT MINPTS THEN BEGIN
   IF LSQFIT EQ 0 THEN BEGIN
      ;  Try a least-squares:
      CC = POLY_FIT( U, V, NDEG, YFIT )
      ISTAT=PIA_SM_ROB_CHECKFIT(V,YFIT,EPS,DEL,  SIG,FRACDEV,NGOOD,W,S)
      IF ISTAT EQ 0 THEN GOTO,AFTERFIT
      NGOOD = NPTS-COUNT
   ENDIF
   IF NGOOD LT MINPTS THEN BEGIN
      PRINT,'ROBUST_POLY_FIT: No Fit Possible!'
      RETURN,0.
   ENDIF
ENDIF

; Now iterate until the solution converges:
CLOSE_ENOUGH = .03*SQRT(.5/(NPTS-1)) > DEL
DIFF= 1.0E10
SIG_1= (100.*SIG) < 1.0E20
NIT = 0
WHILE( (DIFF GT CLOSE_ENOUGH) AND (NIT LT ITMAX) ) DO BEGIN
  NIT=NIT+1
  SIG_2=SIG_1
  SIG_1=SIG
  CC= POLYFITW( U, V, W, NDEG, YFIT )
  ISTAT=PIA_SM_ROB_CHECKFIT(V,YFIT,EPS,DEL,  SIG,FRACDEV,NGOOD,W,S)
  IF ISTAT EQ 0 THEN GOTO,AFTERFIT
  IF NGOOD LT MINPTS THEN BEGIN
     PRINT,'ROBUST_POLY_FIT: Questionable Fit!'
     BADFIT=1
     GOTO,AFTERFIT
  ENDIF
  DIFF = (ABS(SIG_1-SIG)/SIG) < (ABS(SIG_2-SIG)/SIG)
ENDWHILE

;IF NIT GE ITMAX THEN PRINT,'ROBUST_POLY_FIT: Did not converge in',ITMAX,$
;' iterations!'

AFTERFIT:
CC=REFORM(CC)

IF NDEG LT DEGMAX THEN BEGIN
CASE NDEG OF
 1: CC(0) = CC(0)-CC(1)*X0 + Y0
 2: BEGIN
   CC(0) = CC(0)-CC(1)*X0+CC(2)*X0^2 + Y0
   CC(1) = CC(1)-2.*CC(2)*X0
    END
 3: BEGIN
   CC(0) = CC(0)-CC(1)*X0+CC(2)*X0^2-CC(3)*X0^3 + Y0
   CC(1) = CC(1)-2.*CC(2)*X0+3.*CC(3)*X0^2
   CC(2) = CC(2)-3.*CC(3)*X0
    END
 4: BEGIN
   CC(0) = CC(0)-   CC(1)*X0+CC(2)*X0^2-CC(3)*X0^3+CC(4)*X0^4+ Y0
   CC(1) = CC(1)-2.*CC(2)*X0+3.*CC(3)*X0^2-4.*CC(4)*X0^3
   CC(2) = CC(2)-3.*CC(3)*X0+6.*CC(4)*X0^2
   CC(3) = CC(3)-4.*CC(4)*X0
    END
 5: BEGIN
   CC(0) = CC(0)-  CC(1)*X0+CC(2)*X0^2-CC(3)*X0^3+CC(4)*X0^4-CC(5)*X0^5+ Y0
   CC(1) = CC(1)-2.*CC(2)*X0+ 3.*CC(3)*X0^2- 4.*CC(4)*X0^3+5.*CC(5)*X0^4
   CC(2) = CC(2)-3.*CC(3)*X0+ 6.*CC(4)*X0^2-10.*CC(5)*X0^3
   CC(3) = CC(3)-4.*CC(4)*X0+10.*CC(5)*X0^2
   CC(4) = CC(4)-5.*CC(5)*X0
    END
 ENDCASE
ENDIF

; Calculate the fit at points X:
IF( N_PARAMS(0) GT 3 )THEN YFIT=POLY(X,CC)

IF BADFIT EQ 1 THEN CC=[CC,0.]

RETURN,CC
END









FUNCTION  PIA_SM_ROBUST_LINEFIT,XIN,YIN,YFIT,SIG,SS, NUMIT=THIS_MANY, BISECT=TYPE, $
                         Bisquare_Limit=Bisquare_Limit, $
                         Close_Factor=Close_Factor
;+
; NAME:
;	ROBUST_LINEFIT
;
; PURPOSE:
;	An outlier-resistant two-variable linear regression. Either Y on X
;	or, for the case in which there is no true independent variable, the
;	bisecting line of Y vs X and X vs Y is calculated. No knowledge of
;	the errors of the input points is assumed.
;
; CALLING SEQUENCE:
;	COEFF = ROBUST_LINEFIT( X, Y, YFIT, SIG, COEF_SIG, [ BISECT = ,
;			BiSquare_Limit = , Close_factor = , NumIT = ] )
;
; INPUTS:
;	X = Independent variable vector, floating-point or double-precision
;	Y = Dependent variable vector
;
; OUTPUTS:
;	Function result = coefficient vector.
;	If = 0.0 (scalar), no fit was possible.
;	If vector has more than 2 elements (the last=0) then the fit is dubious.
;
; OPTIONAL OUTPUT PARAMETERS:
;	YFIT = Vector of calculated y's
;	SIG  = The "standard deviation" of the fit's residuals. If BISECTOR
;		is set, this will be smaller by ~ sqrt(2).
;	COEF_SIG  = The estimated standard deviations of the coefficients. If
;		BISECTOR is set, however, this becomes the vector of fit
;		residuals measured orthogonal to the line.
;
; OPTIONAL INPUT KEYWORDS:
;	NUMIT = the number of iterations allowed. Default = 25
;	BISECT  if set, the bisector of the "Y vs X" and "X vs Y" fits is
;		determined.  The distance PERPENDICULAR to this line is used
;		in calculating weights. This is better when the uncertainties
;		in X and Y are comparable, so there is no true independent
;		variable.  Bisquare_Limit  Limit used for calculation of
;		bisquare weights. In units of outlier-resistant standard
;		deviations. Default: 6.
;		Smaller limit ==>more resistant, less efficient
; Close_Factor  - Factor used to determine when the calculation has converged.
;		Convergence if the computed standard deviation changes by less
;		than Close_Factor * ( uncertainty of the std dev of a normal
;		distribution ). Default: 0.03.
; SUBROUTINE CALLS:
;	MED, to calculate the median
;	ROB_CHECKFIT
;	ROBUST_SIGMA, to calculate a robust analog to the std. deviation
;
; PROCEDURE:
;	For the initial estimate, the data is sorted by X and broken into 2
;	groups. A line is fitted to the x and y medians of each group.
;	Bisquare ("Tukey's Biweight") weights are then calculated, using the
;	a limit of 6 outlier-resistant standard deviations.
;	This is done iteratively until the standard deviation changes by less
;	than CLOSE_ENOUGH = CLOSE_FACTOR * {uncertainty of the standard
;		deviation of a normal distribution}
;
; REVISION HISTORY:
;	Written, H. Freudenreich, STX, 4/91.
;	4/13/93 to return more realistic SS's HF
;	2/94 --more error-checking, changed convergence criterion HF
;	5/94 --added BISECT option. HF.
;       8/94 --added Close_Factor and Bisquare_Limit options  Jack Saba.
;-

;;ON_ERROR,2

IF N_ELEMENTS(THIS_MANY) GT 0 THEN ITMAX=THIS_MANY ELSE ITMAX=25

IF ( NOT KEYWORD_SET ( Close_Factor   ) ) THEN Close_Factor = 0.03

DEL = 5.0E-07
EPS = 1.0E-20

N=N_ELEMENTS(XIN)

; First, shift X and Y to their centers of gravity:
X0=TOTAL(XIN)/N  &  Y0=TOTAL(YIN)/N
X = XIN-X0       &  Y = YIN-Y0

CC=FLTARR(2)
SS=FLTARR(2)
SIG=0.
YFIT=YIN
BADFIT=0
NGOOD=N

; Make sure the independent variables are not all the same.
XRANGE=MAX(X)-MIN(X)
AVEX= (TOTAL(ABS(X))/N) > EPS
IF (XRANGE LT EPS) OR (XRANGE/AVEX LT DEL) THEN BEGIN
   PRINT,'ROBUST_LINEFIT: Independent variables the same. No fit possible.'
   RETURN,0.
ENDIF

; First guess:
LSQ=0
YP=Y
IF N GT 5 THEN BEGIN
;  We divide the data into 2 groups and fit a line to their X and Y medians.
   S=SORT(X) &  U=X(S)  &  V=Y(S)
   NHALF=N/2-1
   X1=PIA_SM_MED(U(0:NHALF)) & X2=PIA_SM_MED(U(NHALF+1:N-1))
   Y1=PIA_SM_MED(V(0:NHALF)) & Y2=PIA_SM_MED(V(NHALF+1:N-1))
   IF ABS(X2-X1) LT EPS THEN BEGIN
;     The X medians are too close. Select the end-points instead.
      X1=U(0)  &  X2=U(N-1)
      Y1=V(0)  &  Y2=V(N-1)
   ENDIF
   CC(1)=(Y2-Y1)/(X2-X1)  & CC(0)=Y1-CC(1)*X1
   YFIT=CC(0)+CC(1)*X
   ISTAT=PIA_SM_ROB_CHECKFIT(YP,YFIT,EPS,DEL,  SIG,FRACDEV,NGOOD,W,S)
   IF NGOOD LT 2 THEN LSQ=1
ENDIF
IF (LSQ EQ 1) OR (N LT 6) THEN BEGIN  ; Try a least-squares fit
   SX=TOTAL(X) & SY=TOTAL(Y) & SXY=TOTAL(X*Y) & SXX=TOTAL(X*X)
   D=SXX-SX*SX
   IF ABS(D) LT EPS THEN BEGIN
      PRINT,'ROBUST_LINEFIT: No fit possible.'
      RETURN,0.
   ENDIF
   YSLOP=(SXY-SX*SY)/D      &   YYINT=(SXX*SY-SX*SXY)/D

   IF KEYWORD_SET(TYPE) THEN BEGIN
;     Get the X vs Y line.
      SYY=TOTAL(Y*Y)
      D=SYY-SY*SY
      IF ABS(D) LT EPS THEN BEGIN
         PRINT,'ROBUST_LINEFIT: No fit possible.'
         RETURN,0.
      ENDIF
      TSLOP=(SXY-SY*SX)/D   &   TYINT=(SYY*SX-SY*SXY)/D
;     Now invert it to get the form Y=a+bX:
      IF ABS(TSLOP) LT EPS THEN BEGIN
         PRINT,'ROBUST_LINEFIT: No fit possible.'
         RETURN,0.
      ENDIF
      XSLOP=1./TSLOP       &   XYINT=-TYINT/TSLOP
;     Now calculate the equation of the bisector of the 2 lines:
      IF YSLOP GT XSLOP THEN BEGIN
         A1=YYINT  &  B1=YSLOP  &  R1=SQRT(1.+YSLOP^2)
         A2=XYINT  &  B2=XSLOP  &  R2=SQRT(1.+XSLOP^2)
      ENDIF ELSE BEGIN
         A2=YYINT  &  B2=YSLOP  &  R2=SQRT(1.+YSLOP^2)
         A1=XYINT  &  B1=XSLOP  &  R1=SQRT(1.+XSLOP^2)
      ENDELSE
      YINT=(R1*A2+R2*A1)/(R1+R2)
      SLOP=(R1*B2+R2*B1)/(R1+R2)
;     Now find the orthogonal distance to the line. Convert to normal
;     coordinates.
      R=SQRT(1.+SLOP^2)  & IF YINT GT 0. THEN R=-R
      U1=SLOP/R  & U2=-1./R  &  U3=YINT/R
      YP=U1*X+U2*Y+U3  ; = orthog. distance to line
      YFIT=FLTARR(N) & YFIT(*)=0. ; to fool ROB_CHECKFIT
      SS=YP
   ENDIF ELSE BEGIN
      SLOP=YSLOP               &   YINT=YYINT
      YFIT = YINT+SLOP*X
   ENDELSE
   CC=[YINT,SLOP]
   ISTAT=PIA_SM_ROB_CHECKFIT(YP,YFIT,EPS,DEL,  SIG,FRACDEV,NGOOD,W,S)
ENDIF

IF ISTAT EQ 0 THEN GOTO,AFTERFIT

IF NGOOD LT 2 THEN BEGIN
   PRINT,'ROBUST_LINEFIT: Data Dangerously Weird. Fit Questionable.'
   BADFIT=1
   GOTO,AFTERFIT
ENDIF

; Now iterate until the solution converges:
SIG_1= (100.*SIG) < 1.0E20
CLOSE_ENOUGH = Close_Factor * SQRT(.5/(N-1)) > DEL
DIFF= 1.0E20
NIT = 0
WHILE( (DIFF GT CLOSE_ENOUGH) AND (NIT LT ITMAX) ) DO BEGIN
  NIT=NIT+1
  SIG_2=SIG_1
  SIG_1=SIG
  SX=TOTAL(W*X) & SY=TOTAL(W*Y) & SXY=TOTAL(W*X*Y) & SXX=TOTAL(W*X*X)
  D=SXX-SX*SX
  IF ABS(D) LT EPS THEN BEGIN
     PRINT,'ROBUST_LINEFIT: No fit possible.'
     RETURN,0.
  ENDIF
  YSLOP=(SXY-SX*SY)/D      &   YYINT=(SXX*SY-SX*SXY)/D
  SLOP=YSLOP               &   YINT=YYINT
  IF KEYWORD_SET(TYPE) THEN BEGIN
;    Get the X vs Y line.
     SYY=TOTAL(W*Y*Y)
     D=SYY-SY*SY
     IF ABS(D) LT EPS THEN BEGIN
        PRINT,'ROBUST_LINEFIT: No fit possible.'
        RETURN,0.
     ENDIF
     TSLOP=(SXY-SY*SX)/D   &   TYINT=(SYY*SX-SY*SXY)/D
;    Now invert it to get the form Y=a+bX:
     IF ABS(TSLOP) LT EPS THEN BEGIN
        PRINT,'ROBUST_LINEFIT: No fit possible.'
        RETURN,0.
     ENDIF
     XSLOP=1./TSLOP       &   XYINT=-TYINT/TSLOP
;    Now calculate the equation of the bisector of the 2 lines:
     IF YSLOP GT XSLOP THEN BEGIN
        A1=YYINT  &  B1=YSLOP  &  R1=SQRT(1.+YSLOP^2)
        A2=XYINT  &  B2=XSLOP  &  R2=SQRT(1.+XSLOP^2)
     ENDIF ELSE BEGIN
        A2=YYINT  &  B2=YSLOP  &  R2=SQRT(1.+YSLOP^2)
        A1=XYINT  &  B1=XSLOP  &  R1=SQRT(1.+XSLOP^2)
     ENDELSE
     YINT=(R1*A2+R2*A1)/(R1+R2)
     SLOP=(R1*B2+R2*B1)/(R1+R2)
     R=SQRT(1.+SLOP^2)  & IF YINT GT 0. THEN R=-R
     U1=SLOP/R  & U2=-1./R  &  U3=YINT/R
     YP=U1*X+U2*Y+U3  ; = orthog distance to line
     YFIT=FLTARR(N) & YFIT(*)=0.
     SS=YP
  ENDIF ELSE BEGIN
     YFIT = YINT+SLOP*X
  ENDELSE
  CC=[YINT,SLOP]
  ISTAT=PIA_SM_ROB_CHECKFIT(YP,YFIT,EPS,DEL,  SIG,FRACDEV,NGOOD,W,S, $
                     Bisquare_Limit=Bisquare_Limit )

  IF ISTAT EQ 0 THEN GOTO,AFTERFIT
  IF NGOOD LT 2 THEN BEGIN
     PRINT,'ROBUST_LINEFIT: Data Dangerously Weird. Fit Questionable.'
     BADFIT=1
     GOTO,AFTERFIT
  ENDIF
  DIFF = (ABS(SIG_1-SIG)/SIG) < (ABS(SIG_2-SIG)/SIG)
ENDWHILE

AFTERFIT:
; Untranslate the coefficients
CC(0) = CC(0)+Y0-CC(1)*X0

IF N_PARAMS(0) GT 2 THEN YFIT = CC(0) + CC(1)*XIN
IF KEYWORD_SET(BISECT) THEN RETURN,CC

IF (N_PARAMS(0) GT 3) AND (SIG GT EPS) AND (NGOOD GT 2) THEN BEGIN
   ; Here we use an empirical formula to approximate the standard deviations
   ; of the coefficients. They are usually accurate to ~ 25%.
   SX2=TOTAL(W*X*X)
   UU=S*S
   DEV=YIN-YFIT
   Y0=TOTAL( W*DEV )
   Q=WHERE(UU LE 1.0,COUNT)
   DEN1 = ABS(TOTAL( (1.-UU(Q))*(1.-5.*UU(Q)) ))
   SIG=PIA_SM_ROBUST_SIGMA(DEV,/ZERO)
   ; Now empirically derived estimates of the uncertainties:
   SS(0)=SIG/SQRT(DEN1)/1.105
   SS(1)=SS(0)/SQRT(SX2)
   ; Take the X shift into account:
   SS(0)=SQRT(SS(0)^2+X0*SS(1)^2)
ENDIF

IF BADFIT EQ 1 THEN CC=[CC,0.]

RETURN,CC
END







FUNCTION  PIA_SM_BIWEIGHT_MEAN,Y,SIGMA, WEIGHTs
;
;+
; NAME:
;	BIWEIGHT_MEAN
;
; PURPOSE:
;	Calculate the center and dispersion (like mean and sigma) of a
;	distribution using bisquare weighting.
;
; CALLING SEQUENCE:
;	Mean = BIWEIGHT_MEAN( Vector, [ Sigma, Weights ] )
;
; INPUTS:
;	Vector = Distribution in vector form
;
; OUTPUT:
;	Mean - The location of the center.
;
; OPTIONAL OUTPUT ARGUMENTS:
;
;	Sigma = An outlier-resistant measure of the dispersion about the
;	center, analogous to the standard deviation. The half-width of the 95%
;	confidence interval = |STUDENT_T( .95, .7*(N-1) )*SIGMA/SQRT(N)|,
;	where N = number of points.
;
;	Weights = The weights applied to the data in the last iteration.
;
;SUBROUTINE CALLS:
;	MED, which calculates a median
;
; REVISION HISTORY
;	Written,  H. Freudenreich, STX, 12/89
;	Modified 2/94, H.T.F.: use a biweighted standard deviation rather than
;		median absolute deviation.
;	Modified 2/94, H.T.F.: use the fractional change in SIGMA as the
;		convergence criterion rather than the change in center/SIGMA.
;-

  ON_ERROR,2
  maxit = 20 ; Allow 20 iterations
  eps = 1.0e-24

  n = n_elements(y)
  close_enough =.03*sqrt(.5/(n-1)) ; compare to fractional change in width

  diff = 1.0e30
  itnum = 0

; As an initial estimate of the center, use the median:
  y0=pia_sm_med(y)

; Calculate the weights:
  dev = y-y0
  sigma = pia_sm_robust_sigma( dev )

  if sigma lt EPS then begin
;    The median is IT. Do we need the weights?
     if n_elements(weights) gt 0 then begin
;       Flag any value away from the median:
        limit=3.*sigma
        q=where( abs(dev) gt limit, count )
        weights=fltarr(n)
        weights(*)=1.
        if count gt 0 then weights(q)=0.
     endif
     diff = 0. ; (skip rest of routine)
  endif

; Repeat:
  while( (diff gt close_enough) and (itnum lt maxit) )do begin
    itnum = itnum + 1
    uu = ( (y-y0)/(6.*sigma) )^2
    q=where(uu gt 1.,count) & if count gt 0 then uu(q)=1.
    weights=(1.-uu)^2       & weights=weights/total(weights)
    y0 = total( weights*y )
    dev = y-y0
    prev_sigma = sigma      & sigma = pia_sm_robust_sigma( dev,/zero )
    if sigma gt eps then diff=abs(prev_sigma-sigma)/prev_sigma else diff=0.
  endwhile

return,y0
end












FUNCTION PIA_SM_LOWESS,X,Y,WINDOW,NDEG, NOISE
;
;+
; NAME:
;	LOWESS
;
; PURPOSE:
;	Robust smoothing of 1D data. A non-parametric way of drawing a smooth
;	curve to represent data. (For 2D (map) data, use LOESS.)
;
; CALLING SEQUENCE:
;	YSmooth = LOWESS( X, Y, Window, NDeg, Noise )
;
; INPUT ARGUMENTS:
;	X = X values
;	Y = Y values, to be smoothed
;	WINDOW = width of smoothing window
;	NDEG   = degree of polynomial to be used within the window (1 or 2
;		recommended)
;
; OUTPUT:
;	Ysmooth - LOWESS returns the vector of smoothed Y values
;
; OPTIONAL OUTPUT ARGUMENT:
;	Noise = the robust std. deviation w.r.t. the fit, at each point
;
; NOTE:
;	This routine uses a least-squares fit within a moving window. The fit
;	is weighted by statistical weights and weights that are a function of
;	distance from the center of the window. This is a "local weighted
;	polynomial regression smoother" (Cleveland 1979, Journal of the Amer.
;	Statistical Association, 74, 829-836).
;	A polynomial of degree NDEG+1 is fitted directly to the first and last
;	WINDOW/2 points.
;
;	This routine is fairly slow.
;
; SUBROUTINES CALLED:
;	ROBUST_LINEFIT
;	ROBUST_POLY_FIT
;	ROB_CHECKFIT
;	ROBUST_SIGMA
;	POLYFITW
;	MED
;
; REVISION HISTORY:
;	Written,  H.T. Freudenreich, HSTX, 1/8/93
;	H.T. Freudenreich, 2/94 Return sigma rather than slope
;-

ON_ERROR,2

EPS = 1.0E-20

ITMAX = 3

M=WINDOW/2
N=N_ELEMENTS(X)

IF N_PARAMS() GT 4 THEN BEGIN
   WANT_NOISE=1
   NOISE=FLTARR(N)
ENDIF ELSE WANT_NOISE=0

Z=Y

FOR I=M,N-M-1 DO BEGIN
  WIDENED=0

  FITIT:
  U=X(I-M:I+M) - X(I)
  V=Y(I-M:I+M)

; If V is constant, do nothing:
  IF MAX(V) EQ MIN(V) THEN BEGIN
     Z(I)=V(0)
     IF WANT_NOISE EQ 1 THEN NOISE(I)=0.
     GOTO,NEXT
  ENDIF

; First, a robust fit. Allowing more than 3 iterations is usually a waste
; of time.
  IF NDEG EQ 1 THEN CC=PIA_SM_ROBUST_LINEFIT(  U,V,     YFIT, NUMIT=ITMAX )  ELSE $
                    CC=PIA_SM_ROBUST_POLY_FIT( U,V,NDEG,YFIT, NUMIT=ITMAX )
; If no fit possible...
  NCOEF=N_ELEMENTS(CC)
  IF NCOEF NE (NDEG+1) THEN BEGIN
     IF (I GT M) AND (I LT (N-M-1)) THEN BEGIN
;       Widen the window temporarily and try again.
        WINDOW=WINDOW+2 & M=M+1
        PRINT,'LOWESS: Expanding window by 2 points to try again'
        WIDENED = 1
        GOTO,FITIT
     ENDIF ELSE BEGIN
        Z(I) = PIA_SM_MED(V)
        IF WANT_NOISE EQ 1 THEN NOISE(I)=PIA_SM_ROBUST_SIGMA(V-Z(I),/ZERO)
        PRINT,'LOWESS: Taking Y median instead of fit'
        GOTO,NEXT
     ENDELSE
  ENDIF

; Now calculate the biweights from the residuals:
  R = V-YFIT
  SIG = PIA_SM_ROBUST_SIGMA(R,/ZERO)
  IF WANT_NOISE EQ 1 THEN NOISE(I)=SIG
  IF SIG LT eps THEN SIG=TOTAL(ABS(R))/.8/N_ELEMENTS(R)
  IF SIG LT eps THEN BEGIN
     W=FLTARR(WINDOW)
     W(*)=1.0  ; equal weights
  ENDIF ELSE BEGIN
     R = ( R/(6.*SIG) )^2
     Q = WHERE(R GT 1.,COUNT) & IF COUNT GT 0 THEN R(Q)=1.
     W =(1.-R)^2
  ENDELSE

; Now multiply by the "distance" weights:
  DEL = .5*( U(1)-U(0)+U(M)-U(M-1) )
  D = DEL+MAX([U(WINDOW-1)-U(M),U(M)-U(0)]) ;=max distance of any point from Xi
  WD= ( 1.- ( ABS( ( U-U(M) )/D ) )^3 )^3

  W = W*WD
  W = W/TOTAL(W)

; Now a weighted polynomial fit:
  CC=POLYFITW(U,V,W,NDEG,YFIT)

  Z(I) = CC(0)
  IF WIDENED EQ 1 THEN BEGIN
     WINDOW=WINDOW-2 & M=M-1
     WIDENED=0
  ENDIF

  NEXT:
ENDFOR

; Now take care of the end points! Fit a polynomial of degree NDEG to them.

I1=WINDOW-1
FITSTART:
U=X(0:I1)  &  V=Z(0:I1)
CC=PIA_SM_ROBUST_POLY_FIT( U,V,NDEG,YFIT,SIG )
IF N_ELEMENTS(CC) NE (NDEG+1) THEN BEGIN
   I1=I1+1
   GOTO,FITSTART
ENDIF
Z(0:M-1) = YFIT(0:M-1)
IF WANT_NOISE EQ 1 THEN NOISE(0:M-1)=SIG

I1=N-WINDOW
FITEND:
U=X(I1:N-1)  &  V=Z(I1:N-1)
CC=PIA_SM_ROBUST_POLY_FIT( U,V,NDEG,YFIT,SIG )
IF N_ELEMENTS(CC) NE (NDEG+1) THEN BEGIN
   I1=I1-1
   GOTO,FITEND
ENDIF
IEND=N_ELEMENTS(YFIT)
Z(N-M:N-1)=YFIT(IEND-M:IEND-1)
IF WANT_NOISE EQ 1 THEN NOISE(N-M:N-1)=SIG

RETURN,Z
END











PRO    PIA_SM_BackFilter,  Data, BackData, DiffData, NoiseData, FinalSigma, $
                              Debug=Debug, Plot=Plot, _EXTRA=EXTRA
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~



NData =  N_Elements (Data)

XVecAll = FIndGen (NData)


InternalDebug = 0
If (Keyword_set (Debug))  $
   then begin
      InternalDebug = 1
   endif


If ((Keyword_set (Debug)) OR  (InternalDebug EQ 1))  $
   then begin
      print, ' <pia_sm_BackFilter>  ... wavelet filtering  '
   endif


If (Keyword_set (Plot))  $
   then begin
      PIA_SM_WMR_Filtering , Data , WaveData , NoiseData, FinalSigma,            $
                      Thresh=3. , NoIter=10 , Notrans=8 , InitSigma=4. ,  $
                      /robustsigma , /PLOT
   ENDIF ELSE BEGIN
      PIA_SM_WMR_Filtering , Data , WaveData , NoiseData, FinalSigma,            $
                      Thresh=3. , NoIter=10 , Notrans=8 , InitSigma=4. , /robustsigma
   endelse


If (Keyword_set (Plot))  $
   then begin
      plot, Data, /ystyle, /xstyle , psym=10
      oplot, WaveData, psym=0
   endif

If ((Keyword_set (Debug)) OR  (InternalDebug EQ 1))  $
   then begin
      print, ' <pia_sm_BackFilter>  ... noise = ' , FinalSigma
   endif



If ((Keyword_set (Debug)) OR  (InternalDebug EQ 1))  $
   then begin
      print, ' <pia_sm_BackFilter>  ... morphological filtering first time '
   endif

;;PIA_SM_Morph_1D_Process,  Data ,  MorphDataPositiv , 11 , 5  , 1.0 , /gauss , /open
;;PIA_SM_Morph_1D_Process,  Data ,  MorphDataPositiv ,  19 , 9 , 5.0 , /gauss , /open
PIA_SM_Morph_1D_Process,  Data ,  MorphDataPositiv ,  23 , 9 , 5.0 , /gauss , /open


If ((Keyword_set (Debug)) OR  (InternalDebug EQ 1))  $
   then begin
      print, ' <pia_sm_BackFilter>  ... lowess first time '
   endif

WindowWidth = 50
IF (NData LT WindowWidth) THEN  WindowWidth =  Long (NData / 2)
BackDataPositiv =  PIA_SM_LowEss (XVecAll , MorphdataPositiv , WindowWidth , 2)


If ((Keyword_set (Debug)) OR  (InternalDebug EQ 1))  $
   then begin
      print, ' <pia_sm_BackFilter>  ... morphological filtering on inverted data '
   endif

;;PIA_SM_Morph_1D_Process,  -Data ,  MorphDataNegativ , 11 , 5  , 1.0 , /gauss , /open
;;PIA_SM_Morph_1D_Process,  -Data ,  MorphDataNegativ , 19 , 9  , 5.0 , /gauss , /closing
PIA_SM_Morph_1D_Process,  -Data ,  MorphDataNegativ , 23 , 9  , 5.0 , /gauss , /closing


If ((Keyword_set (Debug)) OR  (InternalDebug EQ 1))  $
   then begin
      print, ' <pia_sm_BackFilter>  ... lowess on inverted data '
   endif


WindowWidth = 50
IF (NData LT WindowWidth) THEN  WindowWidth =  Long (NData / 2)
BackDataNegativ =  PIA_SM_LowEss (XVecAll , MorphdataNegativ , WindowWidth , 2)


BackDataMean = 0.5 * (BackDataPositiv - BackDataNegativ)


If ((Keyword_set (Debug)) OR  (InternalDebug EQ 1))  $
   then begin
      print, ' <pia_sm_BackFilter>  ... final smoothing '
   endif

FilterSize = 51  <  NData
PIA_SM_Filter ,   BackDataMean , BackData ,  Params=[FilterSize , 2] , /savgol, /PaddMirror

Diffdata =  Data(*) - BackData(*)

If ((Keyword_set (Debug)) OR  (InternalDebug EQ 1))  $
   then begin
      print, ' <pia_sm_BackFilter>  ... final wavelet filtering  '
   endif


InitSigma =  FinalSigma
If (Keyword_set (Plot))  $
   then begin
      PIA_SM_WMR_Filtering , DiffData , WaveData2 , NoiseData, FinalSigma,              $
                      Thresh=3. , NoIter=10 , Notrans=8 , InitSigma=InitSigma,  $
                      /robustsigma , /plot
   ENDIF ELSE BEGIN
      PIA_SM_WMR_Filtering , DiffData , WaveData2 , NoiseData, FinalSigma,              $
                      Thresh=3. , NoIter=10 , Notrans=8 , InitSigma=InitSigma, /robustsigma
   endelse


If ((Keyword_set (Debug)) OR  (InternalDebug EQ 1))  $
   then begin
      print, ' <pia_sm_BackFilter>  ... final noise = ' , FinalSigma
   endif

HighThresh =  3.0 * FinalSigma
PIA_SM_1D_OutlierRazor,  Diffdata, OutputVals, NOutVals,   $
      		         Mask_Outliers, HighThresh=HighThresh , /absolute


XVec =  Where (Mask_Outliers LT 1)
YVec =  OutputVals
FitPara =  PIA_SM_ROBUST_POLY_FIT (XVec , YVec , 4 , YFit)

XVec = FIndGen (N_Elements(Diffdata))
YFit = Poly (Xvec , Fitpara)

BackData =  BackData(*) + YFit(*)





;;;;-----------------------------------------------------------



If ((Keyword_set (Debug)) OR  (InternalDebug EQ 1))  $
   then begin
      print, ' <pia_sm_BackFilter>  ... wavelet filtering on difference '
   endif


Diffdata = Data (*) - BackData (*)

InitSigma =  FinalSigma
PIA_SM_WMR_Filtering ,   Diffdata , WaveDiff , NoiseDiff , FinalSigma ,     $
                         Thresh=3. , NoIter=10 , Notrans=8 ,                $
                         InitSigma=InitSigma, /robustsigma

PIA_SM_OutlierInterval,  WaveDiff , SourceMask ,                                   $
                         StartWindows , EndWindows, NWindows ,                     $
                         HighCut=3.*FinalSigma , LowCut=0.5*FinalSigma , Extend=3


XAll = FindGen (NData)

;XCutted =  Where (SourceMask LE 0 , NCutted)
;IF ( (NWindows GT 0) AND (NCutted GT 0) AND (N_Elements(XCutted) GT 3) )   $
;   THEN BEGIN
;      YCutted =  BackData (XCutted)
;
;Xinterpol =  FindGen (N_Elements (XCutted))
;YInterpol =  Data (XCutted)
;
;
;If ((Keyword_set (Debug)) OR  (InternalDebug EQ 1))  $
;   then begin
;      print, ' <pia_sm_BackFilter>  ... lowess and interpolation on cutted data '
;   endif
;
;WindowWidth = 30
;IF (NCutted LT WindowWidth) THEN  WindowWidth =  Long (N_Elements (XCutted)/2)
;
;BackSmoothCutted  =  PIA_SM_LowEss(Xinterpol , YInterpol , WindowWidth , 2)
;
;PIA_SM_Monipol,   XCutted , BackSmoothCutted , XAll , BackData

XCutted =  Where (SourceMask LE 0 , NCutted)
IF ( (NWindows GT 0) AND (NCutted GT 0) AND (N_Elements(XCutted) GT 3) )   $
   THEN BEGIN
      YCutted =  BackData (XCutted)


      If ((Keyword_set (Debug)) OR  (InternalDebug EQ 1))  $
         then begin
            print, ' <pia_sm_BackFilter>  ... interpolation on cutted data '
         endif

      PIA_SM_Monipol,   XCutted , YCutted , XAll , BackData
   ENDIF


;;;;-----------------------------------------------------------



If (Keyword_set (Plot))  $
   then begin
      plot, Data, /ystyle, /xstyle , psym=10 , title='Data / Background'
      oplot, BackData , psym=0 , color=4
   endif



Return
END


















PRO    OK_PIA_SM_BackFilter,  Data, BackData, DiffData, NoiseData, FinalSigma, $
                              Debug=Debug, Plot=Plot, _EXTRA=EXTRA
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~



NData =  N_Elements (Data)

XVecAll = FIndGen (NData)


InternalDebug = 0
If (Keyword_set (Debug))  $
   then begin
      InternalDebug = 1
   endif


If ((Keyword_set (Debug)) OR  (InternalDebug EQ 1))  $
   then begin
      print, ' <pia_sm_BackFilter>  ... wavelet filtering  '
   endif


If (Keyword_set (Plot))  $
   then begin
      PIA_SM_WMR_Filtering , Data , WaveData , NoiseData, FinalSigma,            $
                      Thresh=3. , NoIter=10 , Notrans=8 , InitSigma=4. ,  $
                      /robustsigma , /PLOT
   ENDIF ELSE BEGIN
      PIA_SM_WMR_Filtering , Data , WaveData , NoiseData, FinalSigma,            $
                      Thresh=3. , NoIter=10 , Notrans=8 , InitSigma=4. , /robustsigma
   endelse


If (Keyword_set (Plot))  $
   then begin
      plot, Data, /ystyle, /xstyle , psym=10
      oplot, WaveData, psym=0
   endif

If ((Keyword_set (Debug)) OR  (InternalDebug EQ 1))  $
   then begin
      print, ' <pia_sm_BackFilter>  ... noise = ' , FinalSigma
   endif



If ((Keyword_set (Debug)) OR  (InternalDebug EQ 1))  $
   then begin
      print, ' <pia_sm_BackFilter>  ... morphological filtering first time '
   endif

;;PIA_SM_Morph_1D_Process,  Data ,  MorphDataPositiv , 11 , 5  , 1.0 , /gauss , /open
;;PIA_SM_Morph_1D_Process,  Data ,  MorphDataPositiv ,  19 , 9 , 5.0 , /gauss , /open
PIA_SM_Morph_1D_Process,  Data ,  MorphDataPositiv ,  23 , 9 , 5.0 , /gauss , /open


If ((Keyword_set (Debug)) OR  (InternalDebug EQ 1))  $
   then begin
      print, ' <pia_sm_BackFilter>  ... lowess first time '
   endif

WindowWidth = 50
IF (NData LT WindowWidth) THEN  WindowWidth =  Long (NData / 2)
BackDataPositiv =  PIA_SM_LowEss (XVecAll , MorphdataPositiv , WindowWidth , 2)


If ((Keyword_set (Debug)) OR  (InternalDebug EQ 1))  $
   then begin
      print, ' <pia_sm_BackFilter>  ... morphological filtering on inverted data '
   endif

;;PIA_SM_Morph_1D_Process,  -Data ,  MorphDataNegativ , 11 , 5  , 1.0 , /gauss , /open
;;PIA_SM_Morph_1D_Process,  -Data ,  MorphDataNegativ , 19 , 9  , 5.0 , /gauss , /closing
PIA_SM_Morph_1D_Process,  -Data ,  MorphDataNegativ , 23 , 9  , 5.0 , /gauss , /closing


If ((Keyword_set (Debug)) OR  (InternalDebug EQ 1))  $
   then begin
      print, ' <pia_sm_BackFilter>  ... lowess on inverted data '
   endif


WindowWidth = 50
IF (NData LT WindowWidth) THEN  WindowWidth =  Long (NData / 2)
BackDataNegativ =  PIA_SM_LowEss (XVecAll , MorphdataNegativ , WindowWidth , 2)


BackDataMean = 0.5 * (BackDataPositiv - BackDataNegativ)


If ((Keyword_set (Debug)) OR  (InternalDebug EQ 1))  $
   then begin
      print, ' <pia_sm_BackFilter>  ... final smoothing '
   endif

FilterSize = 51  <  NData
PIA_SM_Filter ,   BackDataMean , BackData ,  Params=[FilterSize , 2] , /savgol, /PaddMirror

Diffdata =  Data(*) - BackData(*)

If ((Keyword_set (Debug)) OR  (InternalDebug EQ 1))  $
   then begin
      print, ' <pia_sm_BackFilter>  ... final wavelet filtering  '
   endif


InitSigma =  FinalSigma
If (Keyword_set (Plot))  $
   then begin
      PIA_SM_WMR_Filtering , DiffData , WaveData2 , NoiseData, FinalSigma,              $
                      Thresh=3. , NoIter=10 , Notrans=8 , InitSigma=InitSigma,  $
                      /robustsigma , /plot
   ENDIF ELSE BEGIN
      PIA_SM_WMR_Filtering , DiffData , WaveData2 , NoiseData, FinalSigma,              $
                      Thresh=3. , NoIter=10 , Notrans=8 , InitSigma=InitSigma, /robustsigma
   endelse


If ((Keyword_set (Debug)) OR  (InternalDebug EQ 1))  $
   then begin
      print, ' <pia_sm_BackFilter>  ... final noise = ' , FinalSigma
   endif

HighThresh =  3.0 * FinalSigma
PIA_SM_1D_OutlierRazor,  Diffdata, OutputVals, NOutVals,   $
      		         Mask_Outliers, HighThresh=HighThresh , /absolute


XVec =  Where (Mask_Outliers LT 1)
YVec =  OutputVals
FitPara =  PIA_SM_ROBUST_POLY_FIT (XVec , YVec , 4 , YFit)

XVec = FIndGen (N_Elements(Diffdata))
YFit = Poly (Xvec , Fitpara)

BackData =  BackData(*) + YFit(*)


If (Keyword_set (Plot))  $
   then begin
      plot, Data, /ystyle, /xstyle , psym=10 , title='Data / Background'
      oplot, BackData , psym=0 , color=4
   endif


Return
END











PRO    PIA_SM_BackNoiseMask_2,  Data, NoiseData, BackData, FinalSigma, $
                              Debug=Debug, Plot=Plot, _EXTRA=EXTRA
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~



NData =  N_Elements (Data)

XVecAll = FIndGen (NData)


InternalDebug = 0
If (Keyword_set (Debug))  $
   then begin
      InternalDebug = 1
   endif


If ((Keyword_set (Debug)) OR  (InternalDebug EQ 1))  $
   then begin
      print, ' <pia_sm_backnoise>  ... filtering first time '
   endif


If (Keyword_set (Plot))  $
   then begin
      PIA_SM_WMR_Filtering , Data, WaveData, NoiseData, FinalSigma, Thresh=3.,   $
                      NoIter=10 , Notrans=8 , InitSigma=4. , /plot
   ENDIF ELSE BEGIN
      PIA_SM_WMR_Filtering , Data, WaveData, NoiseData, FinalSigma, Thresh=3.,   $
                      NoIter=10 , Notrans=8 , InitSigma=4.
   endelse


If (Keyword_set (Plot))  $
   then begin
      plot, Data, /ystyle, /xstyle , psym=2
      oplot, WaveData, psym=0
   endif

If ((Keyword_set (Debug)) OR  (InternalDebug EQ 1))  $
   then begin
      print, ' <pia_sm_backnoise>  ... noise = ' , FinalSigma
   endif


PIA_SM_Morph_1D_Process,  Data ,  MorphData , 11 , 5  , 1.0 , /gauss , /open


PeakData =   Data - MorphData

Plot, PeakData

LowThresh  =   0.75 * FinalSigma
HighThresh =  3.0 * FinalSigma


If (Keyword_set (Plot))  $
   then begin
      PIA_SM_1D_OutlierRazor,   PeakData , CuttedPeakData , NOutVals, OutlierMask,  $
                          LowThresh=LowThresh,  HighThresh=HighThresh, $
                          /POSITIVEONLY , /PLOT , /CUTVALUE
   ENDIF ELSE BEGIN
      PIA_SM_1D_OutlierRazor,   PeakData , CuttedPeakData , NOutVals, OutlierMask,  $
                          LowThresh=LowThresh,  HighThresh=HighThresh, $
                          /POSITIVEONLY , /CUTVALUE
   endelse


GoodMask = abs (1 - OutlierMask (*))

GoodPointIndex =  Where (GoodMask (*) GT 0 , NGoodpoints)

PIA_SM_PropIndicsToWinds,   GoodPointIndex, StartWindows, EndWindows, NWindows

NoInterPoints =  -1
FOR i = 0 , NWindows-1 , 1  DO BEGIN


   IF ((EndWindows(i) - StartWindows(i) + 1) EQ 1)  $
      THEN BEGIN
         NoInterPoints = NoInterPoints + 1

         j = StartWindows(i)

         xmean = float (j)
         ymean = WaveData(j)

         IF (NoInterPoints EQ 0)  $
            THEN BEGIN
               xvec =  [xmean]
               yvec =  [ymean]
            ENDIF ELSE BEGIN
               xvec =  [xvec , xmean]
               yvec =  [yvec , ymean]
            ENDELSE
      ENDIF

   IF ((EndWindows(i) - StartWindows(i) + 1) EQ 2)  $
      THEN BEGIN
         NoInterPoints = NoInterPoints + 1

         j = StartWindows(i)

         xmean = float (j + (j+1)) / 2.0
         ymean = (WaveData(j) + WaveData(j+1)) / 2.0

         IF (NoInterPoints EQ 0)  $
            THEN BEGIN
               xvec =  [xmean]
               yvec =  [ymean]
            ENDIF ELSE BEGIN
               xvec =  [xvec , xmean]
               yvec =  [yvec , ymean]
            ENDELSE
      ENDIF


   IF ((EndWindows(i) - StartWindows(i) + 1) GE 3)  $
      THEN BEGIN

         FOR  j =  StartWindows(i)+1 , EndWindows(i)-1 , 1  DO BEGIN

            NoInterPoints = NoInterPoints + 1

            xmean = float ((j-1) + j + (j+1)) / 3.0
            ymean = (WaveData(j-1) + WaveData(j) + WaveData(j+1)) / 3.0

            IF (NoInterPoints EQ 0)  $
               THEN BEGIN
                  xvec =  [xmean]
                  yvec =  [ymean]
               ENDIF ELSE BEGIN
                  xvec =  [xvec , xmean]
                  yvec =  [yvec , ymean]
               ENDELSE

         ENDFOR

      ENDIF

ENDFOR

pia_sm_monipol,     XVec, YVec, XVecAll, YInterpol


BackData =  YInterpol

Return
END





; +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
; +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++








Function   PIA_SM_ReverseVector,  Vector
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

NData        = N_Elements (Vector)
LstDataInd   = NData - 1
Result       = FltArr (NData)

For i = 0 , LstDataInd do begin
   k = LstDataInd - i
   Result (k) = Vector (i)
EndFor

Return, Result
End








Pro   PIA_SM_CleanVectorEnd , Data , BadMask , CleanedData ,   $
                              UseGood=UseGood
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

CleanedData = Data(*)

NGood = 7
If (N_Elements (UseGood) gt 0) then  NGood = UseGood

ReverseData    = PIA_SM_ReverseVector (Data)
ReverseBadMask = PIA_SM_ReverseVector (BadMask)

PIA_SM_CleanVectorStart , ReverseData , ReverseBadMask ,     $
                          ReverseCleanedData , UseGood=NGood

CleanedData = PIA_SM_ReverseVector (ReverseCleanedData)

Return
End










Pro   PIA_SM_CleanVectorStart , Data , BadMask , CleanedData ,   $
                                UseGood=UseGood
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


;  Replace first few array elements marked as bad (BadMask > 0)
;  by a linear regression using the first "UseGood" data values
;  marked as good (BadMask =< 0)


CleanedData = Data(*)

NGood = 5
If (N_Elements (UseGood) gt 0) then  NGood = UseGood

NData = N_Elements (Data)

If (BadMask(0) gt 0)  $
   then begin
      NUsable = 0
      For  i = 0 , NData-1  do begin
         If (BadMask(i) le 0)  $
            then begin
               If (NUsable le 0)  $
                  then begin
                     GoodIndex = [i]
                     NUsable = NUsable + 1
                  endif else begin
                     GoodIndex = [GoodIndex(*) , i]
                     NUsable = NUsable + 1
                  endelse
            endif
         If (NUsable gt NGood)  then   Goto,  LOOPEND

      EndFor

LOOPEND:

      XVec = GoodIndex (*)
      YVec = Data (GoodIndex)

      FitPara =  PIA_SM_ROBUST_LINEFIT (XVec , YVec)

      XVec = FindGen (GoodIndex(N_Elements(GoodIndex)-1))
      YReplace = FitPara(0) + (FitPara(1)*XVec(*))

      For  i = 0 , GoodIndex(N_Elements(GoodIndex)-1)-1  do begin
         If (BadMask(i) gt 0)  $
            then begin
               CleanedData (i) = YReplace (i)
            endif
      EndFor
   endif


Return
End











Pro  PIA_SM_ConvSMFlagsMask,   SM_Flags, WeightMask, Bad=Bad, Good=Good
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

;
; /* include Serendipity Dynamical Structure /*

@phtsm


; /* get size of data */

Dimen    = Size (SM_Flags)
NoPixels = Dimen (1)
NoData   = Dimen (2)

; /* get the differe

WeightMask       = IntArr (NoPixels , NoData)
IF (Keyword_set (Good)) $
   THEN BEGIN
      MaskValue        =  0
      WeightMask (*,*) =  abs (1 - MaskValue)
   ENDIF

IF (Keyword_set (Bad)) $
   THEN BEGIN
      MaskValue        =  1
      WeightMask (*,*) =  abs (1 - MaskValue)
   ENDIF


; /* get the different flags separately */

PIA1Flags     = SM_Flags (*,*)  AND  flg_pia_1
PIA2Flags     = SM_Flags (*,*)  AND  flg_pia_2
GlitchFlags   = SM_Flags (*,*)  AND  flg_glitch
PSESrcFlags   = SM_Flags (*,*)  AND  flg_source
PSCandFlags   = SM_Flags (*,*)  AND  flg_srccand

LowSpeedFlags = SM_Flags (*,*)  AND  flg_speed

For i = 0 , NoPixels-1  do begin
;;   PIA1Index    = Where (PIA1Flags(i,*)    eq  flg_pia_1,   NoPIA1)
   PIA2Index      = Where (PIA2Flags(i,*)      eq  flg_pia_2,   NoPIA2)
   GlitchIndex    = Where (GlitchFlags(i,*)    eq  flg_glitch,  NoGlitch)
   PSCandIndex    = Where (PSESrcFlags(i,*)    eq  flg_srccand, NoPSCand)
   PSESrcIndex    = Where (PSESrcFlags(i,*)    eq  flg_source,  NoPSESrc)

   LowSpeedIndex  = Where (LowSpeedFlags(i,*)  eq  flg_speed,   NoLowSpeed)


;;   If (NoPIA1   gt 0)    then  FitFlagMask (i,PIA1Index)   = 0
   If (NoPIA2   gt 0)      then  WeightMask (i,PIA2Index)   = MaskValue
   If (NoGlitch gt 0)      then  WeightMask (i,GlitchIndex) = MaskValue
   If (NoPSCand gt 0)      then  WeightMask (i,PSCandIndex) = MaskValue
   If (NoPSESrc gt 0)      then  WeightMask (i,PSESrcIndex) = MaskValue

   If (NoLowSpeed gt 0)    then  WeightMask (i,LowSpeedIndex)  = MaskValue
EndFor

Return
END










function   PIA_SM_RandomIndexVec,   IndexStart, IndexEnd,  NVals,   $
                                    Sort=Sort, Debug=Debug, _EXTRA=EXTRA
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

RandomVec = RandomU (Seed , NVals)

IndexVec = IntArr (NVals)
IndexVec (*) = long ((abs (float (IndexEnd - IndexStart)) * RandomVec (*)) + 0.5)   $
                    + abs (IndexStart)

IF (Keyword_Set (Sort))  THEN  IndexVec (*) = IndexVec (sort (IndexVec (*)))

if (keyword_set (debug))  $
   then begin
      print , ' <RandomIndexVec> , IndexStart/End = ' , IndexStart, IndexEnd
      print , ' <RandomIndexVec> , IndexVec       = ' , IndexVec (*)
   endif

Return, IndexVec (*)
End










PRO      PIA_SM_MeanSigma,    Data, Ave, Sdev
;----------------------------------------

;
; compute mean and sigma of array
;

Ave  = 0.0
Var  = 0.0
Sdev = 0.0

Nelem = Float (N_Elements (Data))

Ave   = Total (Data) / Nelem

s     = Data (*) - Ave

If (Nelem  gt  1.0)  Then  $
   Var = ( Total (s(*) ^ 2)  -  ((Total (s) ^ 2) / Nelem) ) / (Nelem - 1.0)

Sdev  = sqrt (Var)

Return
End








PRO PIA_SM_RESISTANT_MEAN,Y,CUT,MEAN,SIGMA,NUM_REJ
;+
; NAME:
;	RESISTANT_MEAN
;
; PURPOSE:
;	An outlier-resistant determination of the mean and its standard
;	deviation.  It trims away outliers using the median and the median
;	absolute deviation.
;
; CALLING SEQUENCE:
;	RESISTANT_MEAN,VECTOR,SIGMA_CUT, MEAN,SIGMA,NUM_REJECTED
;
; INPUT ARGUMENT:
;	VECTOR    = Vector to average
;	SIGMA_CUT = Data more than this number of standard deviations from the
;		median is ignored. Suggested values: 2.0 and up.
;
; OUTPUT ARGUMENT:
;	MEAN  = the mean
;	SIGMA = the standard deviation of the mean
;	NUM_REJECTED = the number of points trimmed
;
; SUBROUTINE CALLS:
;	MED, which calculates a median
;
; REVISION HISTORY:
;	Written, H. Freudenreich, STX, 1989; Second iteration added 5/91.
;-

ON_ERROR,2

NPTS    = N_ELEMENTS(Y)
YMED    = PIA_SM_MED(Y)
ABSDEV  = ABS(Y-YMED)
MEDABSDEV = PIA_SM_MED( ABSDEV )/.6745
IF MEDABSDEV LT 1.0E-24 THEN MEDABSDEV = AVG(ABSDEV)/.8

CUTOFF    = CUT*MEDABSDEV

GOODPTS = Y( WHERE( ABSDEV LE CUTOFF ) )
MEAN    = AVG( GOODPTS )
NUM_GOOD = N_ELEMENTS( GOODPTS )
SIGMA   = SQRT( TOTAL((GOODPTS-MEAN)^2)/NUM_GOOD )
NUM_REJ = NPTS - NUM_GOOD

; Compensate SIGMA for truncation (formula by HF):
SC=CUT
IF SC LT 1.75 THEN SC=1.75
IF SIGMA LE 3.4 THEN SIGMA=SIGMA/(.18553+.505246*SC-.0784189*SC*SC)

CUTOFF = CUT*SIGMA

GOODPTS = Y( WHERE( ABSDEV LE CUTOFF ) )
MEAN    = AVG( GOODPTS )
NUM_GOOD = N_ELEMENTS( GOODPTS )
SIGMA   = SQRT( TOTAL((GOODPTS-MEAN)^2)/NUM_GOOD )
NUM_REJ = NPTS - NUM_GOOD

SC=CUT
IF SC LT 1.75 THEN SC=1.75
IF SIGMA LE 3.4 THEN SIGMA=SIGMA/(.18553+.505246*SC-.0784189*SC*SC)

; Now the standard deviation of the mean:
SIGMA = SIGMA/SQRT(NPTS-1.)

RETURN
END







;=============================================================================
;=============================================================================


pro   pia_sm_locate,   xx, x, j
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

IndexVec = Where (x ge xx)
j = Indexvec (N_Elements (IndexVec)-1)

return
end




function   pia_sm_sign,   value,  signedval
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

result = abs (value)
if  (signedval lt 0.0)  then  result = -1.0 * result

return, result
end



pro  pia_sm_setup_monipol,     x, y, a, b, c, d
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

; monotone interpolation, setup subroutine

n = n_elements (x)
nm1 = n - 1
nm2 = n - 2
nm3 = n - 3

a = fltarr (nm1)
b = fltarr (nm1)
c = fltarr (nm1)
d = fltarr (nm1)

h = fltarr (nm1)
s = fltarr (nm1)
p = fltarr (n)
yderiv = fltarr (n)


h = x(1:nm1) - x(0:nm2)
s = (y(1:nm1) - y(0:nm2)) / h

p (0) = s (0) * ( 1.0 + (h (0) / (h (0) + h (1))) )  -            $
        s (1) * ( h (0) / (h (0) + h (1)) )

P (1:nm2) = ( (s(0:nm3) * h(1:nm2)) + (s(1:nm2) * h(0:nm3)) )  /  $
            (h (0:nm3) + h (1:nm2))

p (nm1) = s (nm2) * ( 1.0 + (h (nm2) / (h (nm2) + h (nm3))) )  -   $
          s (nm3) * ( h (nm2) / (h (nm2) + h (nm3)) )

yderiv (0) = p (0)
if ((p(0)*s(0)) le 0.0)               then  yderiv (0) = 0.0
if (abs (p(0)) gt (2.0 * abs (s(0)))) then  yderiv (0) = 2.0 * s(0)

for  i = 1 , nm2  do begin
   im1 = i - 1
   yderiv(i) = (pia_sm_sign (1.0,s(im1)) + pia_sm_sign (1.0,s(i)))  *   $
                min ([abs(s(im1)) , abs(s(i)) , 0.5*abs(p(i))])
endfor

yderiv (nm1) = p (nm1)
if ((p(nm1)*s(nm2)) le 0.0)              then  yderiv (nm1) = 0.0
if (abs(p(nm1)) gt (2.0 * abs(s(nm2))))  then  yderiv (nm1) = 2.0 * s(nm2)

a (0:nm2) = (yderiv(0:nm2) + yderiv(1:nm1) - (2.0 * s(0:nm2)))  /  $
            (h (0:nm2) * h (0:nm2))

b (0:nm2) = ((3.0 * s (0:nm2)) - (2.0 * yderiv (0:nm2)) - yderiv (1:nm1)) / h (0:nm2)

c (0:nm2) = yderiv (0:nm2)

d (0:nm2) = y (0:nm2)

return
end






pro    pia_sm_do_monipol,        x , y , a , b , c , d , xnew , f
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

; monotone interpolation, evaluate subroutine

n_newx =  n_elements (xnew)
funvalue = fltarr (n_newx)

n      = n_elements (x)
npara  = n_elements (a)

for i = 0 , n_newx-1  do begin
   xdeter = xnew (i)

   if (xdeter lt x(0))    then  xdeter = x(0)
   if (xdeter gt x(n-1))  then  xdeter = x(n-1)

   pia_sm_locate,   x, xdeter, ind
   if (ind gt (npara-1))  then  ind = npara-1

   dx = xdeter - x (ind)

   funvalue (i)  = (a(ind) * (dx ^ 3.0))  +  (b(ind) * (dx ^ 2.0))  +        $
                   (c(ind) * dx)          +   d(ind)

endfor

if (n_newx eq 1)  $
   then f = funvalue (0)     $
   else f = funvalue (*)

return
end









Pro    pia_sm_monipol,        x , y , xnew , ynew
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

pia_sm_setup_monipol,     x , y , a , b , c , d
pia_sm_do_monipol,        x , y , a , b , c , d , xnew , ynew

return
end







;================================================================================
;================================================================================




Function   PIA_SM_LinTrans,  StartIndep, EndIndep, StartDepen, EndDepen, NewIndep
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

If (NewIndep lt StartIndep)  then  Return, StartDepen

If (NewIndep gt EndIndep)    then  Return, EndDepen

Result = ( (NewIndep - StartIndep) / (EndIndep - StartIndep) *         $
           (EndDepen - StartDepen) )     +     StartDepen

Return, Result
End







;================================================================================
;================================================================================


function pia_sm_poly_smooth, data, width, DEGREE=degree, NLEFT=nl, NRIGHT=nr,  $
				DERIV_ORDER=order, COEFFICIENTS=filter_coef
;+
; NAME:
;	POLY_SMOOTH
;
; PURPOSE:
;	Reduce noise in 1-D data (e.g. time-series, spectrum)
;	but retain dynamic range of variations in the data by
;	applying a least squares smoothing polynomial filter,
;
;	also called the Savitzky-Golay smoothing filter, cf. Numerical
;	Recipes (Press et al. 1992, Sec.14.8)
;
;	The low-pass filter coefficients are computed by effectively
;	least-squares fitting a polynomial in moving window,
;	centered on each data point, so the new value will be the
;	zero-th coefficient of the polynomial. Approximate first derivates
;	of the data can be computed by using first degree coefficient of
;	each polynomial, and so on. The filter coefficients for a specified
;	polynomial degree and window width are computed independent of any
;	data, and stored in a common block. The filter is then convolved
;	with the data array to result in smoothed data with reduced noise,
;	but retaining higher order variations (better than SMOOTH).
;
; CATEGORY:
;       Array
;
; CALLING SEQUENCE:
;
;	spectrum = poly_smooth( data, [ width, DEGREE = , NLEFT = , NRIGHT =
;					DERIV_ORDER = ,COEFF = ]
;
; INPUTS:
;	data = 1-D array, such as a spectrum or time-series.
;
;	width = total number of data points to use in filter convolution,
;		(default = 5, using 2 past and 2 future data points),
;		must be larger than DEGREE of polynomials, and a guideline is
;		make WIDTH between 1 and 2 times the FWHM of desired features.
;
; KEYWORDS:
;
;	DEGREE = degree of polynomials to use in designing the filter
;		via least squares fits, (default DEGREE = 2), and
;		the higher degrees will preserve sharper features.
;
;	NLEFT = # of past data points to use in filter convolution,
;		excluding current point, overrides width parameter,
;		so that width = NLEFT + NRIGHT + 1.  (default = NRIGHT)
;
;	NRIGHT = # of future data points to use (default = NLEFT).
;
;	DERIV_ORDER = order of derivative desired (default = 0, no derivative).
;
;	COEFFICIENTS = optional output of the filter coefficients applied,
;		but they are all stored in common block for reuse, anyway.
; RESULTS:
;	Function returns the data convolved with polynomial filter coefs.
;
; EXAMPLE:
;
;	Given a wavelength - flux spectrum (w,f), apply a 31 point quadratic
;	smoothing filter and plot
;
;	IDL> plot, w, poly_smooth(f,31)
; COMMON BLOCKS:
;	common poly_smooth, degc, nlc, nrc, coefs, ordermax
;
; PROCEDURE:
;	As described in Numerical Recipies, 2nd edition sec.14.8,
;	Savitsky-Golay filter.
;	Matrix of normal eqs. is formed by starting with small terms
;	and then adding progressively larger terms (powers).
;	The filter coefficients of up to derivative ordermax are stored
;	in common, until the specifications change, then recompute coefficients.
;	Coefficients are stored in convolution order, zero lag in the middle.
; MODIFICATION HISTORY:
;	Written, Frank Varosi NASA/GSFC 1993.
;-
	if N_params() LT 1 then begin
		print,'Syntax - smoothdata = ' + $
			'poly_smooth( data , width, [ DEGREE = , NLEFT = '
	print,f='(35x,A)', 'NRIGHT = , DERIV_ORDER =, COEFFICIENT = ]'
	return, -1
	endif

  common poly_smooth, degc, nlc, nrc, coefs, ordermax

	if N_elements( degree ) NE 1 then degree = 2
	if N_elements( order ) NE 1 then order = 0
	order = ( order < (degree-1) ) > 0

	if N_elements( width ) EQ 1 then begin
		width = fix( width ) > 3
		if (N_elements(nr) NE 1) AND (N_elements(nl) NE 1) then begin
			nl = width/2
			nr = width - nl -1
		   endif
	   endif

	if N_elements( nr ) NE 1 then begin
		if N_elements( nl ) EQ 1 then  nr = nl  else  nr = 2
	   endif

	if N_elements( nl ) NE 1 then begin
		if N_elements( nr ) EQ 1 then  nl = nr  else  nl = 2
	   endif

	if N_elements( coefs ) LE 1 then begin
		degc = 0
		nlc = 0
		nrc = 0
		ordermax = 3
	   endif

	if (degree NE degc) OR (nl NE nlc) OR (nr NE nrc) OR $
						(order GT ordermax) then begin
		degree = degree > 2
		ordermax = ( ordermax < 3 ) > order
		nj = degree+1
		nl = nl > 0
		nr = nr > 0
		nrl = nr + nl + 1

		if (nrl LE degree) then begin
			message,"# of points in filter must be > degree",/INFO
			return, data
		   endif

		ATA = fltarr( nj, nj )
		ATA(0,0) = 1
		iaj = indgen( nj ) # replicate( 1, nj )
		iaj = iaj + transpose( iaj )
		m1_iaj = (-1)^iaj

		for k = 1, nr>nl do begin
		    k_iaj = float( k )^iaj
		    CASE 1 OF
			( k LE nr<nl ):	ATA = ATA + ( k_iaj + k_iaj*m1_iaj )
			( k LE nr ):	ATA = ATA + k_iaj
			( k LE nl ):	ATA = ATA + k_iaj * m1_iaj
		     ENDCASE
		  endfor

		LUdcmp, ATA, LUindex

		Bmat = fltarr( nj, degree<(ordermax+1) )
		B = fltarr( nj )

		for m = 0, (degree-1)<ordermax do begin
			B(*) = 0
			B(m) = 1
			LUbksb, ATA, LUindex, B
			Bmat(0,m) = B
		  endfor

		kvec = [0]
		if (nl GT 0) then kvec = [ rotate( -indgen( nl )-1, 2 ), kvec ]
		if (nr GT 0) then kvec = [ kvec, indgen( nr )+1 ]
		Kmat = fltarr( nrl, nj )
		Kmat(*,0) = 1
		for m = 1,degree do Kmat(0,m) = Kmat(*,m-1) * kvec

		coefs = Kmat # Bmat
		degc = degree
		nlc = nl
		nrc = nr

		if (nr GT nl) then begin
			sc = size( coefs )
			coefs = [  fltarr( nr-nl, sc(2) ),  coefs ]
		  endif else if (nl GT nr) then begin
			sc = size( coefs )
			coefs = [ coefs,  fltarr( nl-nr, sc(2) )  ]
		   endif
	   endif

	filter_coef = coefs(*,order)

return, convol( data, filter_coef )
end



;================================================================================
;================================================================================






PRO  PIA_SM_1D_OutlierRazor,   InputVals, OutputVals, NOutVals, OutlierMask,      $
                               LowThresh=LowThresh, HighThresh=HighThresh,        $
                               POSITIVEONLY=POSITIVEONLY, CUTVALUE=CUTVALUE,      $
                               DEBUG=DEBUG, PLOT=PLOT,                            $
                              _EXTRA=EXTRA
;----------------------------------------------------------------------------------

;
;
;
;

InternalDebug = 0          ;  1  =  on !


Sigma_Low_Thresh     = 0.75
If (Keyword_set (LowThresh))  then  Sigma_Low_Thresh = LowThresh

Sigma_High_Thresh    = 2.5
If (Keyword_set (HighThresh))  then  Sigma_High_Thresh = HighThresh

Sigma_ScndGuess_Mean = 3.0

MinDataPoints        = 4



NInVals         = N_Elements (InputVals)
OutlierMask     = IntArr (NInVals)
OutlierMask (*) = 0


if  (KEYWORD_SET (DEBUG))  or  (InternalDebug eq 1)  then begin
   print , ' '
   print , ' ****************************************************** '
   print , ' *     Debug - Output  Routine    <outlierrazor1D>    * '
   print , ' ****************************************************** '
   print , ' '
   print , ' <outlierrazor1D> , NInVals   = ' , NInVals
;   print , ' <outlierrazor1D> , InputVals = ' , InputVals
endif


; /* .. wrong parameter ! */

If (NInvals  eq  0)  $                 ; ... no input at all !
   then begin
     print , ' ==> ERROR in OutlierRazor1D : No Data passed !! '

     OutputVals  = FltArr (1)
     OutputVals  = 0.0
     NOutVals    = 0
     return
   endif



; /* .. too few data points */

If (NInvals  lt  MinDataPoints)  $            ; ... do essentially nothing
   then begin
     print , ' ==> ERROR in OutlierRazor1D : too few data points available !! '

     OutputVals = InputVals
     NOutVals = N_Elements (InputVals)
     return
   endif



; /* so far, so good : prepare first guess of mean, sigma */

if (NOT  KEYWORD_SET (CUTVALUE))  $
   then begin
      InitMean  =  PIA_SM_BiWeight_Mean (InputVals, InitSigma, InitWeights)
      if (KEYWORD_SET (POSITIVEONLY))  $
         then begin
            FewOutliers = InputVals (WHERE (    (Inputvals - InitMean)  lt  (abs(Sigma_ScndGuess_Mean * InitSigma))))
         endif else begin
            FewOutliers = InputVals (WHERE (abs (Inputvals - InitMean)  lt  (abs(Sigma_ScndGuess_Mean * InitSigma))))
         endelse
   endif

if (KEYWORD_SET (CUTVALUE))  $
   then begin
      BelowCutIndex = WHERE (Inputvals lt HighThresh , NBelowCut)
      If (NBelowCut gt 0)  $
         then begin
            FewOutliers = InputVals (BelowCutIndex)
         endif else begin
            print , ' ==> ERROR in OutlierRazor1D : Nothing below HighThresh !! '

            OutputVals = InputVals
            NOutVals = N_Elements (InputVals)
            return
         endelse
   endif



if  (KEYWORD_SET (DEBUG))  or  (InternalDebug eq 1)  then begin
   print , ' <outlierrazor1D> , InitMean  = ' , InitMean
   print , ' <outlierrazor1D> , InitSigma = ' , InitSigma
;   print , ' <outlierrazor1D> , FewOutliers = ' , FewOutliers
   print , ' <outlierrazor1D> , Elements (FewOutliers) = ' , N_elements (FewOutliers)
endif



If (N_Elements (FewOutliers)  le  2)  then  FewOutliers = InputVals



; /* Indexarrays with low and high thresh outliers */

if (NOT  KEYWORD_SET (CUTVALUE))  $
   then begin
      RevisedMean =  PIA_SM_BiWeight_Mean (FewOutliers, RevisedSigma, RevisedWeights)
      if (KEYWORD_SET (POSITIVEONLY))  $
         then begin
            Index_Low_Sigma  = WHERE (    (InputVals-RevisedMean) gt (abs(Sigma_Low_Thresh*RevisedSigma)))
            Index_High_Sigma = WHERE (    (InputVals-RevisedMean) gt (abs(Sigma_High_Thresh*RevisedSigma)))
         endif else begin
            Index_Low_Sigma  = WHERE (abs (InputVals-RevisedMean) gt (abs(Sigma_Low_Thresh*RevisedSigma)))
            Index_High_Sigma = WHERE (abs (InputVals-RevisedMean) gt (abs(Sigma_High_Thresh*RevisedSigma)))
         endelse
   ENDIF

if (KEYWORD_SET (CUTVALUE))  $
   then begin
      Index_Low_Sigma  = (WHERE (InputVals gt HighThresh))
      Index_High_Sigma = (WHERE (InputVals gt HighThresh))
   endif

if  (KEYWORD_SET (DEBUG))  or  (InternalDebug eq 1)  then begin
   print , ' <outlierrazor1D> , RevisedMean = ' , RevisedMean
   print , ' <outlierrazor1D> , RevisedSigma = ' , RevisedSigma
   print , ' <outlierrazor1D> , NLowIndex = ' , N_Elements (Index_Low_Sigma)
   print , ' <outlierrazor1D> , NHighIndex = ' , N_Elements (Index_High_Sigma)

;   print , ' <outlierrazor1D> , Index_Low_Sigma = ' , Index_Low_Sigma
;   print , ' <outlierrazor1D> , Index_High_Sigma = ' , Index_High_Sigma
;   print , ' <outlierrazor1D> , Fluke = ' , abs ((FewOutliers-RevisedMean) / RevisedSigma)
endif


; /* no high sigma outliers */

if ((N_Elements (Index_High_Sigma) eq  1)  and  (Index_High_Sigma (0) eq  -1)) $
   then begin
     print , ' ==> ERROR in OutlierRazor1D : No HighSigma Outliers !! '

     OutputVals = InputVals
     NOutVals = N_Elements (InputVals)
     return
   endif


; /* prepare the detection and extension of outliers */

NoiseFlagVec = IntArr (NInVals)
NoiseFlagVec (*) = 0

ExtSpikeFlagVec1 = IntArr (NInVals)
ExtSpikeFlagVec1 (*) = 0

ExtSpikeFlagVec2 = IntArr (NInVals)
ExtSpikeFlagVec2 (*) = 0

if  (KEYWORD_SET (DEBUG))  or  (InternalDebug eq 1)  then begin
   SpikeFlagVec1 = IntArr (NInVals)
   SpikeFlagVec1 (*) = 0

   SpikeFlagVec2 = IntArr (NInVals)
   SpikeFlagVec2 (*) = 0

   SpikeFlagVec1 (Index_High_Sigma) = 1
   SpikeFlagVec2 (Index_High_Sigma) = 1
endif


; /* reach for the chainsaw :                                              */
; /*       look for low-thresh outliers adjacent to high_thresh outliers  */


NoiseFlagVec (Index_Low_Sigma)  = 1

ExtSpikeFlagVec1 (Index_High_Sigma) = 1

ExtSpikeFlagVec2 (Index_High_Sigma) = 1

For  k  =  1 , (NInVals - 1) do begin

   i = k

   ii = (NInVals - 2)  - k + 1

   If ( (NoiseFlagVec  (i)       gt  0)  and  $
        (ExtSpikeFlagVec1 (i-1)  gt  0) )  then  $
      ExtSpikeFlagVec1 (i) = 1

   If ( (NoiseFlagVec  (ii)       gt  0)  and  $
        (ExtSpikeFlagVec2 (ii+1)  gt  0) )  then  $
      ExtSpikeFlagVec2 (ii) = 1

Endfor


; /* Index of good and bad data points */

NotBadFlagVec = WHERE ((ExtSpikeFlagVec1  eq  0)   and   (ExtSpikeFlagVec2  eq  0))
BadFlagVec    = WHERE ((ExtSpikeFlagVec1  gt  0)   or    (ExtSpikeFlagVec2  gt  0))


; /* no good data points found */

if ((N_Elements (NotBadFlagVec)  eq  1)  and  (NotBadFlagVec (0) eq  -1)) $
   then begin
     print , ' ==> ERROR in OutlierRazor1D : Only outliers found  !! '

     OutputVals      = FltArr (1)
     OutputVals  (0) = 0.0
     NOutVals        = 0
     return
   endif


;if  (KEYWORD_SET (DEBUG))  or  (InternalDebug eq 1)  then begin
;   print , ' <outlierrazor1D> , i, Noise(i), Spike1(i), Spike2(i), ExtSpike1(i), ExtSpike2(i)'
;   For  i = 0 , NInvals-1   do begin
;      print , i , Noiseflagvec (i) , SpikeFlagVec1 (i) , SpikeFlagVec2 (i) , ExtSpikeFlagVec1 (i) , ExtSpikeFlagVec2 (i)
;   Endfor
;   print , ' <outlierrazor1D> , N_Elements (NotBadFlagVec) = ' , N_Elements (NotBadFlagVec)
;   print , ' <outlierrazor1D> , NotBadFlagVec = ' , NotBadFlagVec
;   print , ' <outlierrazor1D> , N_Elements (BadFlagVec)    = ' , N_Elements (BadFlagVec)
;   print , ' <outlierrazor1D> , BadFlagVec = ' , BadFlagVec
;   print , ' '
;endif


; /* ... the final result  !! */

OutputVals = InputVals (NotBadFlagVec)

NOutVals = N_Elements (OutputVals)

OutlierMask (BadFlagVec) = 1


; /* ... very short result : replace outliers by median instead !! */

if (n_elements (OutputVals)  lt  MinDataPoints) $
   then  begin
      print , ' ==> ERROR in OutlierRazor1D : Cutted Result too short  !! '

      Replace_Value = PIA_SM_Med (OutputVals)
      OutputVals = InputVals
      OutputVals (BadFlagVec) = Replace_Value
      NOutVals = N_Elements (OutputVals)
      OutlierMask (BadFlagVec) = 1
   endif



if  (KEYWORD_SET (DEBUG))  or  (InternalDebug eq 1)  then begin
;   print , ' <outlierrazor1D> , OutputVals = ' , OutputVals
   print , ' <outlierrazor1D> , NOutVals = ' , NoutVals
endif


; /* plot for checking purposes */

if  KEYWORD_SET (PLOT) $
   then begin
      Replace_Value = PIA_SM_Med (OutputVals)

      YPlotAll = InputVals
      YPlotNew = InputVals
      YPlotNew (BadFlagVec) = Replace_Value

;      if  (KEYWORD_SET (DEBUG))  or  (InternalDebug eq 1)  $
;         then begin
;            print , ' <outlierrazor1D> , YPlotAll = ' , YPlotAll
;            print , ' <outlierrazor1D> , YPlotNew  = ' , YPlotNew
;         endif

;;      PLOT, YPlotAll, PSYM=10, yrange=[-0.03,+0.045], xrange=[-2,NInvals+1], /xstyle, /ystyle
;      PLOT, YPlotAll, PSYM=10, xrange=[-2,NInvals+1], /xstyle, /ystyle
;      OPLOT, YPlotNew-0.02, PSYM=10, color=5

;      wait, 1


;     set_plot, 'ps'
;      device,file='idl.ps'

;;      PLOT, YPlotAll, PSYM=10, xrange=[-2,NInvals+1], /xstyle, yrange=[-5,70], /ystyle
      PLOT, YPlotAll, PSYM=10, xrange=[-2,NInvals+1], /xstyle, /ystyle
      OPLOT, YPlotNew, PSYM=10, color=5

;      device,/close
;     set_plot, 'x'
;      spawn, 'lpr -Pphtprint  idl.ps'

;;      cursor, xxaa , yyaa
;      wait, 10

;     set_plot, 'ps'
;      device,file='idl.ps'

;;      PLOT, YPlotAll, PSYM=10, xrange=[2200,2750], /xstyle,yrange=[-5,60], /ystyle
;      PLOT, YPlotAll, PSYM=10, xrange=[2200,2750], /xstyle, /ystyle
;      OPLOT, YPlotNew, PSYM=10, color=5

;      device,/close
;      set_plot, 'x'
;      spawn, 'lpr -Pphtprint  idl.ps'

   endif

if  (KEYWORD_SET (DEBUG))  or  (InternalDebug eq 1)  then begin
   print , ' <outlierrazor1D> , ... leaving '
   print , ' '
endif


Return
end





;================================================================================
;================================================================================





Pro  PIA_SM_RandBackEstim,  Data,  GoodMask,  Background,                $
                        RandShift=RandShift,                         $
                        Unknown=Unknown, Ave3=Ave3,                  $
                        NoRandSamples=NoRandSamples,                 $
                        Plot=Plot, Debug=Debug, _EXTRA=EXTRA
;---------------------------------------------------------------------


;
; determine smooth background by intelligent guessing
; regions devoid of objects
;
;
;
;

KappaCut = 3.0

LeftShift  = 11
RightShift = 9

NData = N_Elements (Data)
NGoodData = N_Elements (Data(Where (GoodMask(*) GT 0)))

If ( (Keyword_Set (Unknown)) or   $
     ((not Keyword_Set (Unknown)) and (not Keyword_Set (Ave3))) )   $
   then begin
      GenerateNoRandSamples = 10
      GenerateNoRandSamples = 40
      PercentDataUsed = PIA_SM_LinTrans  (50. , 800. , 30. , 10. , Float(NData))

      LeftShift  = 11
      RightShift = 9

      If (NGoodData le 10)  $
         then begin
            PercentDataUsed = 100.
            LeftShift  = 1
            RightShift = 1
         endif

      If ((NGoodData gt 10)  AND (NGoodData le 30))  $
         then begin
            PercentDataUsed = 90.
            LeftShift  = 1
            RightShift = 1
         endif

      If ((NGoodData gt 30)  AND (NGoodData le 50))  $
         then begin
            PercentDataUsed = 70.
            LeftShift  = 2
            RightShift = 2
         endif

      If ((NGoodData gt 50)  AND (NGoodData lt 100))  $
         then begin
            LeftShift  = 5
            RightShift = 5
         endif
   endif

If (Keyword_Set (Ave3))  $
   then begin
      GenerateNoRandSamples = 10
      GenerateNoRandSamples = 15
      PercentDataUsed = 13.0

      LeftShift  = 11
      RightShift = 9

      If (NGoodData le 10)                            then  PercentDataUsed =  100.
      If ((NGoodData gt 10)  AND (NGoodData le 30))   then  PercentDataUsed =   80.
      If ((NGoodData gt 30)  AND (NGoodData lt 50))   then  PercentDataUsed =   60.

   endif

If (Keyword_Set (NoRandSamples))  then   GenerateNoRandSamples = NoRandSamples
NRandPoints    = Long (Float (NData) * PercentDataUsed / 100.0)  +  1

BackfitAttempt = FltArr  (NData , GenerateNoRandSamples)
Background     = FltArr (NData)

If (Keyword_set (Debug))  $
   then begin
      print, ' <pia_sm_background> NData = ' , NData
      print, ' <pia_sm_background> NRandPoints = ' , NRandPoints
      print, ' <pia_sm_background> GenerateNoRandSamples = ' , GenerateNoRandSamples
      print, ' <pia_sm_background> PercentDataUsed = ' , PercentDataUsed
   endif


XVecAll = FIndGen (NData)

For  k = 0 , GenerateNoRandSamples-1    do begin

   If (Keyword_set (Debug))  $
      then begin
         print, ' ... creating random background no ' , k
      endif

   IndVecCentre =  PIA_SM_RandomIndexVec (1 , NData-2 , NRandPoints , /Sort)

   If (Keyword_set (RandShift))  $
      then begin
         IndVecLeftShift  =  PIA_SM_RandomIndexVec (0 , LeftShift , NRandPoints)
         IndVecRightShift =  PIA_SM_RandomIndexVec (0 , RightShift , NRandPoints)
         IndVecLeft  = IndVecCentre - IndVecLeftShift
         IndVecRight = IndVecCentre + IndVecRightShift
      endif else begin
         IndVecLeft  = IndVecCentre - LeftShift
         IndVecRight = IndVecCentre + RightShift
      endelse

   if (min (IndVecLeft) lt 0)  $
      then begin
         IndVecLeft (Where (IndVecLeft lt 0)) = IndVecLeft (Where (IndVecLeft lt 0)) + NData
         IndVecLeft = IndVecLeft (sort (IndVecLeft))
      endif

   if (max (IndVecRight) gt (NData-1))  $
      then begin
         IndVecRight (Where (IndVecRight gt (NData-1))) = IndVecRight (Where (IndVecRight gt (NData-1))) - NData
         IndVecRight = IndVecRight (sort (IndVecRight))
      endif



   IndVec = [0 , IndVecCentre , NData-1]
   IndVec = IndVec (sort (IndVec(*)))
   IndVec = IndVec (uniq (IndVec(*)))

;;   IndVec = IndVec (Where (GoodMask(IndVec) gt 0))
   DummyIndex = Where (GoodMask(IndVec) gt 0 , NUsable)
   If (NUsable gt 5)  $
      then  IndVec = IndVec(DummyIndex)

   If ( (Keyword_Set (Unknown)) or   $
        ((not Keyword_Set (Unknown)) and (not Keyword_Set (Ave3))) )  $
      then begin
          XVec = Float (IndVec (*))
          YVec = Data  (IndVec (*))
      endif

   If (Keyword_Set (Ave3))  $
      then begin
         IndVecP1  = IndVec + 1
         IndInd =  Where (IndVecP1 gt (NData-1) , NIndInd)
         IF (NIndInd GT 0)  THEN  IndVecP1 (IndInd) = NData - 1

         IndVecM1  = IndVec - 1
         IndInd =  Where (IndVecM1 lt 0 , NIndInd)
         IF (NIndInd GT 0)  THEN  IndVecM1 (IndInd) = 0

         WeightVec   = GoodMask (IndVec) + GoodMask (IndVecP1) + GoodMask (IndVecM1)
         Data3Points = ( (Data (IndVec)   * GoodMask (IndVec))    +           $
                         (Data (IndVecP1) * GoodMask (IndVecP1))  +           $
                         (Data (IndVecM1) * GoodMask (IndVecM1)) )

         XVec = Float (IndVec)
         XVec = XVec (Where (WeightVec gt 0))
         YVec = Data3Points (Where (WeightVec gt 0)) / WeightVec (Where (WeightVec gt 0))
      endif

   pia_sm_monipol,     XVec, YVec, XVecAll, YInterpolCentre



   IndVec = [0 , IndVecLeft , NData-1]
   IndVec = IndVec (sort (IndVec(*)))
   IndVec = IndVec (uniq (IndVec(*)))

;;   IndVec = IndVec (Where (GoodMask(IndVec) gt 0))
   DummyIndex = Where (GoodMask(IndVec) gt 0 , NUsable)
   If (NUsable gt 5)   $
      then  IndVec = IndVec(DummyIndex)

   If ( (Keyword_Set (Unknown)) or   $
        ((not Keyword_Set (Unknown)) and (not Keyword_Set (Ave3))) )  $
      then begin
         XVec = Float (IndVec (*))
         YVec = Data  (IndVec (*))
      endif

   If (Keyword_Set (Ave3))  $
      then begin
         IndVecP1  = IndVec + 1
         IndInd =  Where (IndVecP1 gt (NData-1) , NIndInd)
         IF (NIndInd GT 0)  THEN  IndVecP1 (IndInd) = NData - 1

         IndVecM1  = IndVec - 1
         IndInd =  Where (IndVecM1 lt 0 , NIndInd)
         IF (NIndInd GT 0)  THEN  IndVecM1 (IndInd) = 0

         WeightVec   = GoodMask (IndVec) + GoodMask (IndVecP1) + GoodMask (IndVecM1)
         Data3Points = ( (Data (IndVec)   * GoodMask (IndVec))    +           $
                         (Data (IndVecP1) * GoodMask (IndVecP1))  +           $
                         (Data (IndVecM1) * GoodMask (IndVecM1)) )

         XVec = Float (IndVec)
         XVec = XVec (Where (WeightVec gt 0))
         YVec = Data3Points (Where (WeightVec gt 0)) / WeightVec (Where (WeightVec gt 0))
      endif

   pia_sm_monipol,     XVec, YVec, XVecAll, YInterpolLeft




   IndVec = [0 , IndVecRight , NData-1]
   IndVec = IndVec (sort (IndVec(*)))
   IndVec = IndVec (uniq (IndVec(*)))

;;   IndVec = IndVec (Where (GoodMask(IndVec) gt 0))
   DummyIndex = Where (GoodMask(IndVec) gt 0 , NUsable)
   If (NUsable gt 5)  $
      then  IndVec = IndVec(DummyIndex)


   If ( (Keyword_Set (Unknown)) or   $
        ((not Keyword_Set (Unknown)) and (not Keyword_Set (Ave3))) )  $
      then begin
         XVec = Float (IndVec (*))
         YVec = Data  (IndVec (*))
       endif

   If (Keyword_Set (Ave3))  $
      then begin
         IndVecP1  = IndVec + 1
         IndInd =  Where (IndVecP1 gt (NData-1) , NIndInd)
         IF (NIndInd GT 0)  THEN  IndVecP1 (IndInd) = NData - 1

         IndVecM1  = IndVec - 1
         IndInd =  Where (IndVecM1 lt 0 , NIndInd)
         IF (NIndInd GT 0)  THEN  IndVecM1 (IndInd) = 0

         WeightVec   = GoodMask (IndVec) + GoodMask (IndVecP1) + GoodMask (IndVecM1)
         Data3Points = ( (Data (IndVec)   * GoodMask (IndVec))    +           $
                         (Data (IndVecP1) * GoodMask (IndVecP1))  +           $
                         (Data (IndVecM1) * GoodMask (IndVecM1)) )

         XVec = Float (IndVec)
         XVec = XVec (Where (WeightVec gt 0))
         YVec = Data3Points (Where (WeightVec gt 0)) / WeightVec (Where (WeightVec gt 0))
      endif

   pia_sm_monipol,     XVec, YVec, XVecAll, YInterpolRight




   For  i = 0 , (NData - 1 )   do begin
;      tmpvec = [YInterpolCentre (i) ,YInterpolLeft (i) , YInterpolRight (i)]
;      tmpvec (*) = tmpvec (sort (tmpvec(*)))
;      BackfitAttempt (i , k) = 0.5 * (tmpvec (0) + tmpvec (1))

      If ( (Keyword_Set (Unknown)) or   $
           ((not Keyword_Set (Unknown)) and (not Keyword_Set (Ave3))) )  $
         then begin
            BackfitAttempt (i , k) = min ([YInterpolCentre (i) ,  $
                                           YInterpolLeft (i) ,   $
                                           YInterpolRight (i)])
         endif

      If (Keyword_Set (Ave3))  $
         then begin
            tmpvec = [YInterpolCentre (i) ,YInterpolLeft (i) , YInterpolRight (i)]
            tmpvec (*) = tmpvec (sort (tmpvec(*)))
            BackfitAttempt (i , k) = 0.5 * (tmpvec (0) + tmpvec (1))

;            BackfitAttempt (i , k) = (YInterpolCentre (i)   +    $
;                                      YInterpolLeft (i)     +    $
;                                      YInterpolRight (i)) / 3.0

         endif

   EndFor

   If (Keyword_set (Plot))  $
      then begin
         plot, xvecall , data , /ystyle,/xstyle, psym=10
         oplot, XVecall, BackfitAttempt (*,k), color=6 , psym=10
         wait, 1
      endif
EndFor

For  i = 0 , NData-1  do begin
   PIA_SM_Resistant_Mean, BackfitAttempt (i,*), KappaCut, Mean, Sigma, No_reject
   Background (i) = Mean
EndFor

If (Keyword_set (Plot))  $
   then begin
      plot, xvecall , Data , /ystyle, /xstyle , psym=10 , yr=[-10 , max(data)]
      oplot, xvecall, Background, color=4 , psym=10
      oplot, xvecall, Data-Background, color=2 , psym=10
      wait,  1
   endif

Return
End





;===========================================================================
;===========================================================================








Pro   PIA_SM_NewBackground,  Data,  InMask, PartitionFlags, FitFrom, FitUntil, $
                          Background, Noise, FinalSigma,                       $
                          FilterMorph=FilterMorph, Debug=Debug, Plot=Plot,     $
                          _EXTRA=EXTRA
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


;;
;;   latest version using wavelet smoothing  etc.
;;


;+
; NAME:
;        Pia_SM_Background
;
; PURPOSE:
;        Routine for Modeling of Background, taking care of various switches
;        and loops over all detector pixels
;
;
; CATEGORY:
;        ISOPHOT, PIA, Serendipity Survey
;
; CALLING SEQUENCE:
;        PIA_SM_Background     Data, InMask, Background, OutlierMask,   $
;                      OnlySecond=OnlySecond, PolySmooth=PolySmooth,    $
;                      Debug=Debug, Plot=Plot, _EXTRA=EXTRA
; INPUTS:
;
;
; KEYWORD PARAMETERS:
;
; OUTPUTS:
;
; COMMON BLOCKS:
;
; PROCEDURES USED:
;
; NOTES:
;
; REVISION HISTORY:
;
;-

print, ' <PIA_SM_Background> ... newbackground called '

MaxGapWidth =  0

InternalDebug = 0
If (Keyword_set (Debug))  $
   then begin
      InternalDebug = 1
   endif


; /* Initialization */

Dimen    = Size (Data)
NoPixels = Dimen (1)
NoData   = Dimen (2)

Background        = FltArr (NoPixels , NoData)
Background  (*,*) =  0.0

Noise             = FltArr (NoPixels , NoData)
Noise (*,*)       =  0.0

FinalSigma     =  FltArr (NoPixels)
FinalSigma (*) =  0.0


; /* Loop over all detector pixels */

For i = 0 , NoPixels-1  do begin

   If (InternalDebug eq 1)  $
      then begin
         print, ' <PIA_SM_Background> ... starting first estimation, pixel',i
      endif

   UsePartMask = Transpose(PartitionFlags (i, FitFrom(i):FitUntil(i)))

   PropertyIndexVec = Where (UsePartMask le 0)
   PIA_SM_PropIndicsToWinds, PropertyIndexVec, StartWindows, EndWindows, NWindows

   PartStart = [0]
   PartEnd   = [FitUntil(i) - FitFrom(i)]
   NParts = 1

   If (NWindows  gt  0)  $
      then begin
         For l = 0 , NWindows-1 , 1  do begin
            If ((EndWindows (l) - StartWindows (l) + 1)  gt  MaxGapWidth)  $
               then begin
                  PartStart = [PartStart , EndWindows (l)+1]
                  PartEnd   = [PartEnd   , StartWindows (l)-1]
                  NParts = NParts + 1
               endif
         EndFor
         PartStart = PartStart (Sort (PartStart))
         PartEnd   = PartEnd   (Sort (PartEnd))
      endif

   PartStart = PartStart (*)  +  FitFrom(i)
   PartEnd   = PartEnd (*)    +  FitFrom(i)


   If (InternalDebug eq 1)  $
      then begin
         print, ' <PIA_SM_Background> ... no of parts to fit = ' , NParts
      endif


   ; /* Loop over all parts of the data */

   For l = 0 , NParts-1 , 1  do begin

      NoUseData = PartEnd (l) - PartStart (l) + 1
      Offset = PartStart (l)

      UseData = Transpose(Data  (i, PartStart(l):PartEnd(l)))
      UseMask = Transpose(InMask (i, PartStart(l):PartEnd(l)))

      IndUnflagData = Where (UseMask(*) gt 0  ,  NoUnflagData) + Offset

      If (InternalDebug eq 1) $
         then begin
            print, ' <PIA_SM_Background>  Part = ' , l
            print, ' <PIA_SM_Background> NoUseData = ' , NoUseData
;            print, ' <PIA_SM_Background> IndUnflagData = ' , IndUnflagData
;      	    print, ' <PIA_SM_Background> UnflagData = ' , Transpose(Data (i,IndUnflagData))
         endif

     If (NoUnflagData eq 1)  $
         then begin
      	    If (InternalDebug eq 1)  $
      	       then begin
      		  print, ' <PIA_SM_Background> ... only 1 useful data point in this part '
      	       endif

            Background (i,IndUnflagData) = Data (i,IndUnflagData)
         endif

      If ((NoUnflagData ge 2)  AND (NoUnflagData le 6))  $
         then begin
      	    If (InternalDebug eq 1)  $
      	       then begin
      		  print, ' <PIA_SM_Background> ... few useful data point in this part '
      		  print, ' <PIA_SM_Background>     polynomial of order 1 fitted '
      	       endif

      	    XVec = Float (IndUnflagData (*))
      	    YVec = Data (i,IndUnflagData)

      	    FitPara =  PIA_SM_ROBUST_LINEFIT (XVec , YVec)

      	    XVec = FIndGen (NoUseData) + Offset
      	    YFit = Poly (Xvec , Fitpara)

            Background (i,PartStart(l):PartEnd(l)) = YFit (*)
         endif

      If ((NoUnflagData gt 6)  AND (NoUnflagData le 20))  $
         then begin
      	    If (InternalDebug eq 1)  $
      	       then begin
      		  print, ' <PIA_SM_Background> ... a few more useful data point in this part '
      		  print, ' <PIA_SM_Background>     polynomial of order 2 fitted '
      	       endif

      	    XVec = Float (IndUnflagData (*))
      	    YVec = Data (i,IndUnflagData)

            LstElem = N_Elements (YVec) - 1
            YVec (0) = 0.5 * (YVec (1) + YVec (2))
            YVec (LstElem) = 0.5 * (YVec (LstElem-1) + YVec (LstElem-2))

      	    FitPara =  PIA_SM_ROBUST_POLY_FIT (XVec , YVec , 2 , YFit)

      	    XVec = FIndGen (NoUseData) + Offset
      	    YFit = Poly (Xvec , Fitpara)

            Background (i,PartStart(l):PartEnd(l)) = YFit (*)
         endif

      If ((NoUnflagData gt 20) AND (NoUnflagData le 30))  $
         then begin
      	    If (InternalDebug eq 1)  $
      	       then begin
      		  print, ' <PIA_SM_Background> ... even more useful data point in this part '
      		  print, ' <PIA_SM_Background>     polynomial of order 4 fitted '
      	       endif

      	    XVec = Float (IndUnflagData (*))
      	    YVec = Data (i,IndUnflagData)

            LstElem = N_Elements (YVec) - 1
            YVec (0) = 0.5 * (YVec (1) + YVec (2))
            YVec (LstElem) = 0.5 * (YVec (LstElem-1) + YVec (LstElem-2))

      	    FitPara =  PIA_SM_ROBUST_POLY_FIT (XVec , YVec , 4 , YFit)

      	    XVec = FIndGen (NoUseData) + Offset
      	    YFit = Poly (Xvec , Fitpara)

            Background (i,PartStart(l):PartEnd(l)) = YFit (*)
         endif


      If (NoUnflagData gt 30) $
         then begin

      	    If (InternalDebug eq 1)  $
      	       then begin
      		  print, ' <PIA_SM_Background> ... enough data points for standard background '
      		  print, ' <PIA_SM_Background>     first estimation running, pixel',i , ' part' , l+1
      	       endif

            IF (Keyword_Set (FilterMorph))  $
               THEN BEGIN
                  PIA_SM_Morph_1D_Process,   UseData , UseDataMorph , 3 , 0.1 , /Gauss, /Opening
                  UseData =  UseDataMorph(*)
               Endif

            PIA_SM_BackFilter,  UseData, BackData, Difference,   $
                                   NoiseData, SigmaNoiseFinal
;;                                   NoiseData, SigmaNoiseFinal , /DEBUG

            Background (i,PartStart(l):PartEnd(l)) = BackData (*)
            Noise (i,PartStart(l):PartEnd(l))      = NoiseData (*)
            FinalSigma (i)                         =  SigmaNoiseFinal

            If (Keyword_set (Plot))  $
               then begin
                        plot,  UseData (*) , psym=0, /xstyle,/ystyle, title='first background'
                        oplot, Background (i,PartStart(l):PartEnd(l)), color=3
                        oplot, UseData (*)-Background (i,PartStart(l):PartEnd(l)), color=5
                        wait, 1
               endif

         ENDIF

   ENDFOR  ; all Parts

ENDFOR  ; All Detector Pixels


return
end











;===========================================================================
;===========================================================================






Pro   PIA_SM_Background,  Data,  InMask, PartitionFlags, FitFrom, FitUntil, $
                          Background, OutlierMask,                          $
                          WindowWidth=WindowWidth, Quick=Quick,             $
                          OnlySecond=OnlySecond, PolySmooth=PolySmooth,     $
                          FilterMorph=FilterMorph,                          $
                          Debug=Debug, Plot=Plot,                           $
                          MATHERR=MATHERR,                                  $
                          _EXTRA=EXTRA
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


;+
; NAME:
;        Pia_SM_Background
;
; PURPOSE:
;        Routine for Modeling of Background, taking care of various switches
;        and loops over all detector pixels
;
;
; CATEGORY:
;        ISOPHOT, PIA, Serendipity Survey
;
; CALLING SEQUENCE:
;        PIA_SM_Background     Data, InMask, Background, OutlierMask,   $
;                      OnlySecond=OnlySecond, PolySmooth=PolySmooth,    $
;                      Debug=Debug, Plot=Plot, _EXTRA=EXTRA
; INPUTS:
;
;
; KEYWORD PARAMETERS:
;
; OUTPUTS:
;
; COMMON BLOCKS:
;
; PROCEDURES USED:
;
; NOTES:
;
; REVISION HISTORY:
;        Ver 1.0     M. Stickel, MPIA/IDC    December 1996
;                    ... written
;        Ver 1.1     M. Stickel, MPIA/IDC    January 1997
;                    2 - step -algorithm with keywords
;        Ver 1.2     M. Stickel, MPIA/IDC    January 1997
;                    quick mode : interpolate and poly_smooth
;
;-


MaxGapWidth =  5

InternalDebug = 0
If (Keyword_set (Debug))  $
   then begin
      InternalDebug = 1
   endif

If (Keyword_set (MATHERR))  $
   then begin
      NeedErrorChecking = check_math (trap=1)
   endif

; /* Initialization */

Dimen    = Size (Data)
NoPixels = Dimen (1)
NoData   = Dimen (2)

Background        = FltArr (NoPixels , NoData)
Background  (*,*) =  0.0

OutlierMask     = IntArr (NoPixels , NoData)
OutlierMask (*) =  0



IF (Keyword_Set (ONLYSECOND))  $
   THEN BEGIN
      GoodMask =  InMask (*,*)
      GOTO,  ONLYSECONDSTEP
   ENDIF



;  ------- first step ----------



; /* Loop over all detector pixels */

For i = 0 , NoPixels-1  do begin

   If (InternalDebug eq 1)  $
      then begin
         print, ' <PIA_SM_Background> ... starting first estimation, pixel',i
      endif

   UsePartMask = Transpose(PartitionFlags (i, FitFrom(i):FitUntil(i)))

   PropertyIndexVec = Where (UsePartMask le 0)
   PIA_SM_PropIndicsToWinds, PropertyIndexVec, StartWindows, EndWindows, NWindows

   PartStart = [0]
   PartEnd   = [FitUntil(i) - FitFrom(i)]
   NParts = 1

   If (NWindows  gt  0)  $
      then begin
         For l = 0 , NWindows-1 , 1  do begin
            If ((EndWindows (l) - StartWindows (l) + 1)  gt  MaxGapWidth)  $
               then begin
                  PartStart = [PartStart , EndWindows (l)+1]
                  PartEnd   = [PartEnd   , StartWindows (l)-1]
                  NParts = NParts + 1
               endif
         EndFor
         PartStart = PartStart (Sort (PartStart))
         PartEnd   = PartEnd   (Sort (PartEnd))
      endif

   PartStart = PartStart (*)  +  FitFrom(i)
   PartEnd   = PartEnd (*)    +  FitFrom(i)

   ; /* Loop over all parts of the data */

   For l = 0 , NParts-1 , 1  do begin

      NoUseData = PartEnd (l) - PartStart (l) + 1
      Offset = PartStart (l)

      UseData = Transpose(Data  (i, PartStart(l):PartEnd(l)))
      UseMask = Transpose(InMask (i, PartStart(l):PartEnd(l)))

      IndUnflagData = Where (UseMask(*) gt 0  ,  NoUnflagData) + Offset

      If (InternalDebug eq 1) $
         then begin
            print, ' <PIA_SM_Background>  Part = ' , l+1
            print, ' <PIA_SM_Background> NoUseData = ' , NoUseData
;            print, ' <PIA_SM_Background> IndUnflagData = ' , IndUnflagData
;      	    print, ' <PIA_SM_Background> UnflagData = ' , Transpose(Data (i,IndUnflagData))
         endif

     If (NoUnflagData eq 1)  $
         then begin
      	    If (InternalDebug eq 1)  $
      	       then begin
      		  print, ' <PIA_SM_Background> ... only 1 useful data point in this part '
      	       endif

            Background (i,IndUnflagData) = Data (i,IndUnflagData)
         endif

      If ((NoUnflagData ge 2)  AND (NoUnflagData le 6))  $
         then begin
      	    If (InternalDebug eq 1)  $
      	       then begin
      		  print, ' <PIA_SM_Background> ... few useful data point in this part '
      		  print, ' <PIA_SM_Background>     polynomial of order 1 fitted '
      	       endif

      	    XVec = Float (IndUnflagData (*))
      	    YVec = Data (i,IndUnflagData)

      	    FitPara =  PIA_SM_ROBUST_LINEFIT (XVec , YVec)

      	    XVec = FIndGen (NoUseData) + Offset
      	    YFit = Poly (Xvec , Fitpara)

            Background (i,PartStart(l):PartEnd(l)) = YFit (*)
         endif

      If ((NoUnflagData gt 6)  AND (NoUnflagData le 20))  $
         then begin
      	    If (InternalDebug eq 1)  $
      	       then begin
      		  print, ' <PIA_SM_Background> ... a few more useful data point in this part '
      		  print, ' <PIA_SM_Background>     polynomial of order 2 fitted '
      	       endif

      	    XVec = Float (IndUnflagData (*))
      	    YVec = Data (i,IndUnflagData)

            LstElem = N_Elements (YVec) - 1
            YVec (0) = 0.5 * (YVec (1) + YVec (2))
            YVec (LstElem) = 0.5 * (YVec (LstElem-1) + YVec (LstElem-2))

      	    FitPara =  PIA_SM_ROBUST_POLY_FIT (XVec , YVec , 2 , YFit)

      	    XVec = FIndGen (NoUseData) + Offset
      	    YFit = Poly (Xvec , Fitpara)

            Background (i,PartStart(l):PartEnd(l)) = YFit (*)
         endif

      If ((NoUnflagData gt 20) AND (NoUnflagData le 30))  $
         then begin
      	    If (InternalDebug eq 1)  $
      	       then begin
      		  print, ' <PIA_SM_Background> ... even more useful data point in this part '
      		  print, ' <PIA_SM_Background>     polynomial of order 4 fitted '
      	       endif

      	    XVec = Float (IndUnflagData (*))
      	    YVec = Data (i,IndUnflagData)

            LstElem = N_Elements (YVec) - 1
            YVec (0) = 0.5 * (YVec (1) + YVec (2))
            YVec (LstElem) = 0.5 * (YVec (LstElem-1) + YVec (LstElem-2))

      	    FitPara =  PIA_SM_ROBUST_POLY_FIT (XVec , YVec , 4 , YFit)

      	    XVec = FIndGen (NoUseData) + Offset
      	    YFit = Poly (Xvec , Fitpara)

            Background (i,PartStart(l):PartEnd(l)) = YFit (*)
         endif


      If (NoUnflagData gt 30) $
         then begin

      	    If (InternalDebug eq 1)  $
      	       then begin
      		  print, ' <PIA_SM_Background> ... enough data points for standard background '
      		  print, ' <PIA_SM_Background>     first estimation running, pixel',i , ' part' , l
      	       endif

         ;  /* No good mask is available : We make our own first background guess */

            If ((not Keyword_Set (OnlySecond))  and  (not Keyword_Set (Quick)))  $
               then begin

         ;        /* first background guess using the random-data-points-interpolator */

                  If (not Keyword_Set (PolySmooth))  $
                     then BEGIN
                        LstElem = N_Elements (UseData) - 1
                        UseData (0) = 0.5 * (UseData (1) + UseData (2))
                        UseData (LstElem) = 0.5 * (UseData (LstElem-1) + UseData (LstElem-2))

                        IF (Keyword_Set (FilterMorph))  $
                           THEN BEGIN
                              PIA_SM_Morph_1D_Process,   UseData , UseDataMorph , 3 , 0.1 , /Gauss, /Opening
                              UseData =  UseDataMorph(*)
                           Endif

      			PIA_SM_RandBackEstim,  UseData (*), UseMask(*),    $
      	 				     First_Background, /Single
      	 ;;;				   First_Background, /Single,   /plot,  /debug
      			Difference = UseData (*) - First_Background (*)
                     endif

         ;        /* first background guess using Savitzky-Golay - Filter*/

                  If (Keyword_Set (PolySmooth))  $
                     then BEGIN
                        LstElem = N_Elements (UseData) - 1
                        UseData (0) = 0.5 * (UseData (1) + UseData (2))
                        UseData (LstElem) = 0.5 * (UseData (LstElem-1) + UseData (LstElem-2))

                        IF (Keyword_Set (FilterMorph))  $
                           THEN BEGIN
                              PIA_SM_Morph_1D_Process,   UseData , UseDataMorph , 3 , 0.1 , /Gauss, /Opening
                              UseData =  UseDataMorph(*)
                           Endif

      			Width = 41
      			If (NoUseData lt 50)  then  Width = 11
      			TMPData = DblArr (NoUseData+Width+Width)

      			TMPData (Width:(NoUseData-1)+Width) = UseData(*)
      			TMPData (0:Width-1) = UseData(0)
      			TMPData (NoData:NoUseData+Width-1) = UseData(NoUseData-1)

      			First_Background = pia_sm_poly_smooth  (TMPData , Width , degree=4)

      			Difference = UseData (*) - First_Background (Width:NoUseData-1+Width)

      			First_Background = First_Background (Width:NoUseData-1+Width)
                     endif

;                  If (Keyword_set (Plot)  ne  0)  $
;                     then begin
;                        plot,  UseData (*) , psym=0, /xstyle,/ystyle, title='first background'
;                        oplot, First_Background(*) , color=3
;                        wait, 3
;         ;               cursor, x , y
;                     endif


                  If (InternalDebug eq 1)  $
                     then begin
                        print, ' <PIA_SM_Background> ... cutting outliers '
                     endif



         ;        /* using first background guess an outlier mask is created ... */

     		  If (NoUnflagData  gt  50)   $
                     then begin
                        PIA_SM_1D_OutlierRazor,  Difference, OutputVals, NOutVals,   $
      			                         Mask_Outliers
                     ENDIF ELSE BEGIN
      			PIA_SM_1D_OutlierRazor,  Difference, OutputVals, NOutVals,   $
      						 Mask_Outliers, HighThresh=5.
      		     ENDELSE

      		  If (NOutVals lt 10)  $
      		     then begin
      			PIA_SM_1D_OutlierRazor,  Difference, OutputVals, NOutVals,   $
      						 Mask_Outliers, HighThresh=5.
      		     ENDIF

                  If (N_Elements (Mask_Outliers) gt 0)  $
                     then begin
                        OutlierMask (i,PartStart(l):PartEnd(l)) = Mask_Outliers(*)
                     endif
               endif

          endif



      If (Keyword_set (Plot))  $
	 then begin
		  ymax = max (UseData(*) , ymin)
		  plot,  UseData (*) , psym=0, /xstyle,/ystyle, yrange=[ymin,ymax], title='first background'
		  oplot, Background (i,PartStart(l):PartEnd(l)), color=3
		  oplot, UseData (*)-Background (i,PartStart(l):PartEnd(l)), color=5
		  wait, 1
	 endif

   ENDFOR  ; all Parts

ENDFOR  ; All Detector Pixels




;  ------- merge outliers of all 4 pixels with incomng mask ----------

If (InternalDebug eq 1)  $
   then begin
      print, ' <PIA_SM_Background> ... merging masks '
   ENDIF



CumuOutlierMask =  IntArr (Nodata)
For i = 0 , NoPixels-1  do begin
   IndexOutlier =  Where (OutlierMask(i,*) GT 0 , NOutlier)
   IF (NOutlier GT 0)  $
      THEN BEGIN
         CumuOutlierMask (IndexOutlier) =  1
      endif
EndFor

IndexCumuOutlier =  Where (CumuOutlierMask(*) GT 0 , NCumuOutlier)
GoodMask =  InMask (*,*)
IF (NCumuOutlier GT 0)  $
   THEN BEGIN
      For i = 0 , NoPixels-1  do begin
         GoodMask (i , IndexCumuOutlier) = 0
      EndFor
   endif



ONLYSECONDSTEP:



;  ------- second step ----------




For i = 0 , NoPixels-1  do begin

   If (InternalDebug eq 1)  $
      then begin
         print, ' <PIA_SM_Background> ... starting second estimation, pixel',i
      ENDIF

   UsePartMask = Transpose(PartitionFlags (i, FitFrom(i):FitUntil(i)))

   PropertyIndexVec = Where (UsePartMask le 0)
   PIA_SM_PropIndicsToWinds, PropertyIndexVec, StartWindows, EndWindows, NWindows

   PartStart = [0]
   PartEnd   = [FitUntil(i) - FitFrom(i)]
   NParts = 1

   If (NWindows  gt  0)  $
      then begin
         For l = 0 , NWindows-1 , 1  do begin
            If ((EndWindows (l) - StartWindows (l) + 1)  gt  MaxGapWidth)  $
               then begin
                  PartStart = [PartStart , EndWindows (l)+1]
                  PartEnd   = [PartEnd   , StartWindows (l)-1]
                  NParts = NParts + 1
               endif
         EndFor
         PartStart = PartStart (Sort (PartStart))
         PartEnd   = PartEnd   (Sort (PartEnd))
      endif

   PartStart = PartStart (*)  +  FitFrom(i)
   PartEnd   = PartEnd (*)    +  FitFrom(i)


   ; /* Loop over all parts of the data */

   For l = 0 , NParts-1 , 1  do begin

      NoUseData = PartEnd (l) - PartStart (l) + 1
      Offset = PartStart (l)

      UseData = Transpose(Data  (i, PartStart(l):PartEnd(l)))
      UseMask = Transpose(GoodMask (i, PartStart(l):PartEnd(l)))

      IndUnflagData = Where (UseMask(*) gt 0  ,  NoUnflagData) + Offset

      If (InternalDebug eq 1) $
         then begin
            print, ' <PIA_SM_Background>  Part = ' , l+1
            print, ' <PIA_SM_Background> NoUseData = ' , NoUseData
;            print, ' <PIA_SM_Background> IndUnflagData = ' , IndUnflagData
;      	    print, ' <PIA_SM_Background> UnflagData = ' , Transpose(Data (i,IndUnflagData))
         endif

     If (NoUnflagData eq 1)  $
         then begin
      	    If (InternalDebug eq 1)  $
      	       then begin
      		  print, ' <PIA_SM_Background> ... only 1 useful data point in this part '
      	       endif

            Background (i,IndUnflagData) = Data (i,IndUnflagData)
         endif

      If ((NoUnflagData ge 2)  AND (NoUnflagData le 6))  $
         then begin
      	    If (InternalDebug eq 1)  $
      	       then begin
      		  print, ' <PIA_SM_Background> ... few useful data point in this part '
      		  print, ' <PIA_SM_Background>     polynomial of order 1 fitted '
      	       endif

      	    XVec = Float (IndUnflagData (*))
      	    YVec = Data (i,IndUnflagData)

      	    FitPara =  PIA_SM_ROBUST_LINEFIT (XVec , YVec)

      	    XVec = FIndGen (NoUseData) + Offset
      	    YFit = Poly (Xvec , Fitpara)

            Background (i,PartStart(l):PartEnd(l)) = YFit (*)
         endif

      If ((NoUnflagData gt 6)  AND (NoUnflagData le 20))  $
         then begin
      	    If (InternalDebug eq 1)  $
      	       then begin
      		  print, ' <PIA_SM_Background> ... a few more useful data point in this part '
      		  print, ' <PIA_SM_Background>     polynomial of order 2 fitted '
      	       endif

      	    XVec = Float (IndUnflagData (*))
      	    YVec = Data (i,IndUnflagData)

            LstElem = N_Elements (YVec) - 1
            YVec (0) = 0.5 * (YVec (1) + YVec (2))
            YVec (LstElem) = 0.5 * (YVec (LstElem-1) + YVec (LstElem-2))

      	    FitPara =  PIA_SM_ROBUST_POLY_FIT (XVec , YVec , 2 , YFit)

      	    XVec = FIndGen (NoUseData) + Offset
      	    YFit = Poly (Xvec , Fitpara)

            Background (i,PartStart(l):PartEnd(l)) = YFit (*)
         endif

      If ((NoUnflagData gt 20) AND (NoUnflagData le 30))  $
         then begin
      	    If (InternalDebug eq 1)  $
      	       then begin
      		  print, ' <PIA_SM_Background> ... even more useful data point in this part '
      		  print, ' <PIA_SM_Background>     polynomial of order 4 fitted '
      	       endif

      	    XVec = Float (IndUnflagData (*))
      	    YVec = Data (i,IndUnflagData)

            LstElem = N_Elements (YVec) - 1
            YVec (0) = 0.5 * (YVec (1) + YVec (2))
            YVec (LstElem) = 0.5 * (YVec (LstElem-1) + YVec (LstElem-2))

      	    FitPara =  PIA_SM_ROBUST_POLY_FIT (XVec , YVec , 4 , YFit)

      	    XVec = FIndGen (NoUseData) + Offset
      	    YFit = Poly (Xvec , Fitpara)

            Background (i,PartStart(l):PartEnd(l)) = YFit (*)
         endif



      If (NoUnflagData gt 30) $
         then begin

      	    If (InternalDebug eq 1)  $
      	       then begin
      		  print, ' <PIA_SM_Background> ... enough data points for standard background '
      		  print, ' <PIA_SM_Background>     second estimation running, pixel',i , ' part' , l+1
      	       endif

         ;  /* The second version of the background : either slow  ........  */

            If (not  Keyword_Set (Quick))  $
               then BEGIN

                   IF (Keyword_Set (FilterMorph))  $
                      THEN BEGIN
                         PIA_SM_Morph_1D_Process,   UseData , UseDataMorph , 3 , 0.1 , /Gauss, /Opening
                         UseData =  UseDataMorph(*)
                      Endif

                   PIA_SM_RandBackEstim,  UseData (*), UseMask (*),    $
      	 		              Second_Background, /Ave3, /RandShift
      		;;;	              Second_Background, /Ave3, /RandShift, /debug, /plot

                   Background (i,PartStart(l):PartEnd(l)) = Second_Background (*)
               endif

         ;  /* ........................... or fast ! */

            If (Keyword_Set (Quick))  $
               then begin
                  BadIndex  = Where (UseMask(*) le 0, NoBad)
                  GoodIndex = Where (UseMask(*) gt 0, NoGood)
                  GoodData  =  UseData (*)

                  XVec = Float (GoodIndex (*))
                  YVec = GoodData (*)

                  If (NoBad gt 0)  $
                     then begin
                        XVecFind = Float (BadIndex)
                        pia_sm_monipol,     XVec, YVec, XVecFind, YInterpol
                     endif

                  YVec =  UseData (*)

                  If (NoBad gt 0)  $
                     then begin
                        YVec (BadIndex) = YInterpol
                     endif

                  If (N_Elements (WindowWidth) gt 0)  $
                     then begin
                        Width = WindowWidth
                     endif else begin
                        Width = 41
                     endelse
                  TMPData = FltArr (NoData+Width+Width)

                  TMPData (Width:(NoData-1)+Width) = YVec (*)
                  TMPData (0:Width-1)              = YVec (0)
                  TMPData (NoData:NoData+Width-1)  = YVec (NoData-1)

                  Second_Background = pia_sm_poly_smooth  (TMPData , Width , degree=4)

                  Second_Background = Second_Background (Width:NoData-1+Width)

                  Background (i,PartStart(l):PartEnd(l)) = Second_Background (*)

               endif
          endif



      ;  /* Put second version into Return-Parameter */


      If (Keyword_set (Plot))  $
	 then begin
		  ymax = max (UseData(*) , ymin)
		  plot,  UseData (*) , psym=0, /xstyle,/ystyle, yrange=[ymin,ymax], title='second background'
		  oplot, Background (i,PartStart(l):PartEnd(l)), color=3
		  oplot, UseData (*)-Background (i,PartStart(l):PartEnd(l)), color=5
		  wait, 1
	 endif

   EndFor

EndFor

If (Keyword_set (MATHERR))  $
   then begin
      NeedErrorChecking = check_math (trap=0)
   endif


return
end












;============================================================================
;============================================================================






PRO   PIA_SM_Noise,    Data,  Mask, GlobalStatistics, SlewNoise,       $
                       NoMask=NoMask, Debug=Debug, _EXTRA=EXTRA
;------------------------------------------------------------------------------

;  /* Debugging needed ?  */

InternalDebug = 0
If (Keyword_set (Debug))  $
   then begin
      InternalDebug = 1
   endif

;  /* Get Size of Data Array */

Dimen = Size (Data)
NoPixels = Dimen (1)
NoDataPoints = Dimen(2)

SlewNoise =  FltArr (NoPixels , NoDataPoints)
SlewNoise (*,*) =  0.0

GlobalStatistics = FltArr (NoPixels , 2)
GlobalStatistics (* , *) = 0.0


If (InternalDebug eq 1)  $
   then begin
      print, ' <PIA_SM_Noise> NoPixels = ', NoPixels
   endif

;  /* Loop over all Detector pixels */

For i = 0 , NoPixels-1  do begin

;   /* Anything to exclude ? */

   If ( (Keyword_set (NoMask))   or  (N_elements (Mask) eq 0) )   $
      then begin
         UseData = Transpose (Data (i,*))
      endif else begin
         UseIndex = Where (Mask (i,*) gt 0 , NUseful)
         IF (Nuseful GT 0)  THEN  UseData  = Transpose (Data (i , UseIndex))
      endelse

   NData = Float (N_Elements (UseData))
   If (NData LE 0)  $
      then begin
         print, ' <PIA_SM_Noise> ==> ERROR: No data to compute noise ! '
         print, ' <PIA_SM_Noise> ... returning '
         Return
      ENDIF

   If (InternalDebug eq 1)  $
      then begin
         print, ' <PIA_SM_Noise> PixelIndex i = ', i
         print, ' <PIA_SM_Noise> NData   = ', NData
;         print, ' <PIA_SM_Noise> UseData = ', UseData
      endif

   InitSigma =  PIA_SM_ROBUST_SIGMA (UseData)

   PIA_SM_WMR_Filtering , UseData, WaveData, NoiseData, FinalSigma, Thresh=3.,     $
                   NoIter=10, Notrans=8, InitSigma=InitSigma,               $
                   /robustsigma

   Mean     = Total (NoiseData(*)) / NData

   If (InternalDebug eq 1)  $
      then begin
         print, ' <PIA_SM_Noise> Index i = ', i
         print, ' <PIA_SM_Noise> Mean    = ', Mean
         print, ' <PIA_SM_Noise> StdDev  = ', FinalSigma
      endif

;   /* Save it */

   GlobalStatistics (i , 0) = Mean
   GlobalStatistics (i , 1) = FinalSigma

   If ( (Keyword_set (NoMask))   or  (N_elements (Mask) eq 0) )   $
      then begin
         SlewNoise (i,*) =  NoiseData (*)
      endif else begin
         SlewNoise (i,UseIndex) =  NoiseData (*)
      endelse

EndFor

If (InternalDebug eq 1)  $
   then begin
      print, ' <PIA_SM_Noise> MeanVals = ', GLobalStatistics (* , 0)
      print, ' <PIA_SM_Noise> StdDevs  = ', GLobalStatistics (* , 1)
   endif

; /* Well done ... */


Return
End














Function    PIA_SM_Sensitivity,   Data, Mask,                            $
                                  NoMask=NoMask, Standard=Standard,      $
                                  Debug=Debug, _EXTRA=EXTRA
;-------------------------------------------------------------------------



InternalDebug = 0
If (Keyword_set (Debug))  $
   then begin
      InternalDebug = 1
   endif


StandardSensitivities =  [0.65 , 1.475, 1.2 , 1.2]  ; from minisurvey distributions
If (Keyword_set (Standard))  $
   then begin
      ScaleFactors = StandardSensitivities (*)
      Return , ScaleFactors
   endif


Dimen            = Size (Data)
NoPixels         = Dimen (1)
ScaleFactors     = FltArr (NoPixels)
ScaleFactors (*) =  1.0

If (InternalDebug  eq  1)  $
   then begin
      print, ' <PIA_SM_Sensitivity> NoPixels = ', NoPixels
   endif

For i = 0 , NoPixels-1  do begin
   If ( (Keyword_set (NoMask))   or  (N_elements (Mask) eq 0) )  $
      then begin
         UseData = Transpose (Data (i,*))
      endif else begin
         UseIndex = Where (Mask (i,*) gt 0 , NUseful)
         IF (Nuseful GT 0)  THEN  UseData  = Transpose (Data (i , UseIndex))
      endelse

   NData = Float (N_Elements (UseData))
   If (NData LE 0)  $
      then begin
         print, ' <PIA_SM_Sensitivity> ==> ERROR: No data to compute '
         print, '                      sensitivities of pixel ' , i
         print, ' <PIA_SM_Sensitivity> ... returning '
         Return , ScaleFactors
      endif

   ScaleFactors (i) = Total (UseData (*)) / NData

   If (InternalDebug eq 1)  $
      then begin
         print, ' <PIA_SM_Sensitivity> Index i = ', i
         print, ' <PIA_SM_Sensitivity> NData   = ', NData
         print, ' <PIA_SM_Sensitivity> UseData = ', UseData
      endif
EndFor

MeanScaleFactor  = Total (ScaleFactors (*)) / Float (NoPixels)
ScaleFactors (*) = MeanScaleFactor / ScaleFactors (*)

If (InternalDebug eq 1)  $
   then begin
      print, ' <PIA_SM_Sensitivity> ScaleFactors    = ', ScaleFactors (*)
      print, ' <PIA_SM_Sensitivity> MeanScaleFactor = ', MeanScaleFactor
   endif

Return, ScaleFactors
End










