;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	PIA_SM_DIS2SMC
;
; PURPOSE:
;	Menu for PIA SMC Data display.
;	This is a fourth level menu in the PIA hierarchy.
;
;	This routine should only be called by the PIA Display Data routine
;	and should not be called directly from the command line.
;
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;	PIA_SM_DIS2SMC, GROUP=group, DATA=data, NV=nv, REDRAW=redraw
;	
; KEYWORD PARAMETERS:
;	GROUP:	The group leader of the widget hirarchy
;       DATA:   An element of the PHTSMC dynamical structure
;       NV:     Number of Views (1 <= NV <= 4)
;       REDRAW: To redraw same data
;	
; COMMON BLOCKS:
;	adm
;	colour_indices
;	phtacc
;	phtcs
;	phtsm
;	phtsmc
;	dsp2smc_cmn (internal)
;	pia_dsp2ch5_cmn (internal)
;	dsp2smc_widg (internal)
;	pia_dspchz_cmn (internal)
;	dispcust_cmn (internal)
;	smc2text (internal)
;	pia_sm_widget_info (internal)
;
; RESTRICTIONS:
;       DATA must be a valid element of PHTSMC dynamical structure
;		
; PROCEDURES USED:
;	PIA LIB:
;		decode_admn
;		get_convwh
;		get_pht_hk
;		pia_dis2smc
;		pia_disp_cs
;		pia_disp_hdr
;		pia_dispcust
;		pia_sm_load_ismc
;		pia_multmeas
;		pia_oplot
;		pia_pixchoice
;		pia_plot
;		pia_pubplot
;		pia_showstr
;		pia_sigdisc
;		pia_sm_write_ismc
;               pia_sm_psework_create
;               pia_sm_psework_init
;               pia_sm_psework_to_phtismc
;         	pia_xplot
;		pickmeas
;		write_smc
;		xdisp_hk
;       ASTRO LIB:
;		avg
;		fxpar
;		sigma
;		precess
;		euler
;       INTERNAL:
;		pixbut2event5
;		view2event5
;		average2nonch5
;		average2event5
;		median2nonch5
;		median2event5
;		zoom2event5
;		zoom2fourier5
;		zoom2sync5
;		zoomn2sync5
;		zoom2it5
;		pia_reset2view5
;		pia_dsmc2_event
;	OTHER:
;		sphdist
;		deriv
;
; MODIFICATION HISTORY:
;       Written by: S. Bogun, MPIA, August 1996 
;		    based on PIA_DIS2SRD written by C. Gabriel
;	Modified:
;	  usage of tmpdata.flag modified (discarded == 2) (SB, October 1996)
;	  warning messages when too many samples are discarded
;							  (SB, October 1996)
;	  SM flags now variables			  (SB, November 1996)
;	  updated according to new PHTSMC structure, new working structure
;							  (SB, December 1996)
;         IF flag THEN ... changed to IF flag NE 0 THEN ..(SB, January 1997)
;	  new ISMC structure, work structure, point source
;            structure, new processing sequence for ISMC  (SB, January 1997)
;         generation of PSE working structure exernal now (SB, February 1997)
;-

; *********************************************************************
; *
; *********************************************************************
PRO pixbut2event5, event

   COMMON pia_dsp2smc_cmn, tmpdata, point_sources, lgal, bgal, dst, view, $
    viewsize, nviews, viewoptions, viewbut_ctrl, overid 
   COMMON pia_dsp2ch5_cmn, pixcho, pixop, pixres, psymch, pixcount
   COMMON dsp2smc_widg, pixbut, wndcont, aficont, fpscont, epscont, winhtcont, $
    winbtcont, winbpcont, deglcont

   WIDGET_CONTROL, event.id, GET_UVALUE = new_pixbut

   ind = WHERE(pixcho EQ new_pixbut(0))
   ind = ind(0)

   IF ind LT 0 OR ind GE nviews THEN BEGIN

      pixcount = pixcount+1
      IF pixcount GE nviews THEN pixcount = 0

      old_pixcho = pixcho(pixcount)
      pixcho(pixcount) = new_pixbut(0)

      view(pixcount).viewtype = 0
      pia_reset2view5, pixcount, view(pixcount).controlid

      txtval = STRTRIM(STRING(pixcount+1),2)
      WIDGET_CONTROL, pixbut(old_pixcho), $
       SET_VALUE = ' '
      WIDGET_CONTROL, pixbut(pixcho(pixcount)), $
       SET_VALUE = txtval
   ENDIF
END

; *********************************************************************
; *
; *********************************************************************
PRO view2event5, event

   COMMON pia_dsp2smc_cmn, tmpdata, point_sources, lgal, bgal, dst, view, $
    viewsize, nviews, viewoptions, viewbut_ctrl, overid 
   COMMON pia_dsp2ch5_cmn, pixcho, pixop, pixres, psymch, pixcount

   viewindexid = WIDGET_INFO(event.id, /PARENT)
   WIDGET_CONTROL, viewindexid, GET_UVALUE = viewindex
   WIDGET_CONTROL, event.id, GET_UVALUE = setting
   setting = setting(0)

   IF (view(viewindex(0)).viewtype NE setting) THEN BEGIN
      view(viewindex(0)).viewtype = setting
      pia_reset2view5, viewindex, viewindexid
   ENDIF
END

; *********************************************************************
; *
; *********************************************************************
PRO average2nonch5, event

   COMMON pia_dsp2smc_cmn, tmpdata, point_sources, lgal, bgal, dst, view, $
    viewsize, nviews, viewoptions, viewbut_ctrl, overid 
   COMMON pia_dsp2ch5_cmn, pixcho, pixop, pixres, psymch, pixcount

   WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
   WIDGET_CONTROL, event.top, /HOURGLASS

   average2event5, windowindex

END

; *********************************************************************
; *
; *********************************************************************
PRO average2event5, windowindex

   COMMON pia_dsp2smc_cmn, tmpdata, point_sources, lgal, bgal, dst, view, $
    viewsize, nviews, viewoptions, viewbut_ctrl, overid 
   COMMON pia_dsp2ch5_cmn, pixcho, pixop, pixres, psymch, pixcount
   COMMON sm2_acc, wnd_set, back_set, degl_set, htr_set, afi_set, prc_set
@phtsm

   wtype = view(windowindex).viewtype 

   ytitle = viewoptions(wtype).viewylab

   notacc = 0
   notac1 = 0
   notac2 = 0

   CASE wtype OF

      0: BEGIN
         pixch = pixcho(windowindex)
         data = tmpdata.flx(pixch,*) * tmpdata.sens(pixch)
         unc = tmpdata.flxu(pixch,*) * tmpdata.sens(pixch)
         str = 'Surface Brightness Averages Pixel '+ $
          STRTRIM(STRING(pixch),2)
         IF degl_set NE 0 THEN $
          indnacc = WHERE(tmpdata.smfl(pixch,*) AND flg_glitch, notacc)
         indnac1 = WHERE(tmpdata.flag(pixch,*) AND 2B, notac1)
         IF wnd_set NE 0 THEN $
          indnac2 = WHERE(tmpdata.smfl(pixch,*) AND flg_speed, notac2)
      END
      
      1: BEGIN
         pixch = pixcho(windowindex)
         data = tmpdata.flx(pixch,*) * tmpdata.sens(pixch)
         unc = tmpdata.flxu(pixch,*) * tmpdata.sens(pixch)
         str = 'Surface Brightness Averages Pixel '+ $
          STRTRIM(STRING(pixch),2)
         IF degl_set NE 0 THEN $
          indnacc = WHERE(tmpdata.smfl(pixch,*) AND flg_glitch, notacc)
         indnac1 = WHERE(tmpdata.flag(pixch,*) AND 2B, notac1)
         IF wnd_set NE 0 THEN $
          indnac2 = WHERE(tmpdata.smfl(pixch,*) AND flg_speed, notac2)
      END
      
      2: BEGIN
         pixch = pixcho(windowindex)
         data = tmpdata.smfl(pixch,*)
         unc = 0
         str = 'SeM Flag Averages Pixel '+STRTRIM(STRING(pixch),2)
      END
      3: BEGIN
         data = tmpdata.tkey
         unc = 0
         str = 'Time Key Averages'
      END
      4: BEGIN
         data = tmpdata.ra
         unc = tmpdata.rau
         str = 'Right Ascension Averages'
      END
      5: BEGIN
         data = tmpdata.dec
         unc = tmpdata.decu
         str = 'Declination Averages'
      END
      6: BEGIN
         data = lgal
         unc = 0
         str = 'Galactic Longitude Averages'
      END
      7: BEGIN
         data = bgal
         unc = 0
         str = 'Galactic Latitude Averages'
      END
      8: BEGIN
         data = tmpdata.roll
         unc = tmpdata.rolu
         str = 'Roll Angle Averages'
      END
      9: BEGIN
         data = tmpdata.dec
         unc = tmpdata.decu
         str = 'Declination Averages'
      END
      10: BEGIN
         data = bgal
         unc = 0
         str = 'Galactic Latitude Averages'
      END
      11: BEGIN
         data = dst
         unc = 0
         str = 'Slew position Averages'
      END
      12: BEGIN
         data = tmpdata.vel * 60.
         unc = 0
         str = 'Slew speed Averages'
      END

      13: BEGIN
         pixch = pixcho(windowindex)
         data = tmpdata.back(pixch,*) * tmpdata.sens(pixch)
         unc = tmpdata.nois(pixch,*) * tmpdata.sens(pixch)
         str = 'Background Averages Pixel '+ $
          STRTRIM(STRING(pixch),2)
         IF degl_set NE 0 THEN $
          indnacc = WHERE(tmpdata.smfl(pixch,*) AND flg_glitch, notacc)
         indnac1 = WHERE(tmpdata.flag(pixch,*) AND 2B, notac1)
         IF wnd_set NE 0 THEN $
          indnac2 = WHERE(tmpdata.smfl(pixch,*) AND flg_speed, notac2)
      END
      
      14: BEGIN
         pixch = pixcho(windowindex)
         data = tmpdata.back(pixch,*) * tmpdata.sens(pixch)
         unc = tmpdata.nois(pixch,*) * tmpdata.sens(pixch)
         str = 'Background Averages Pixel '+ $
          STRTRIM(STRING(pixch),2)
         IF degl_set NE 0 THEN $
          indnacc = WHERE(tmpdata.smfl(pixch,*) AND flg_glitch, notacc)
         indnac1 = WHERE(tmpdata.flag(pixch,*) AND 2B, notac1)
         IF wnd_set NE 0 THEN $
          indnac2 = WHERE(tmpdata.smfl(pixch,*) AND flg_speed, notac2)
      END

      15: BEGIN
         data = tmpdata.htr(0,*)
         unc = 0
         str = 'H0-Transform Averages'
      END
      16: BEGIN
         data = tmpdata.htr(1,*)
         unc = 0
         str = 'HY-Transform Averages'
      END
      17: BEGIN
         data = tmpdata.htr(2,*)
         unc = 0
         str = 'HZ-Transform Averages'
      END
      18: BEGIN
         data = tmpdata.htr(3,*)
         unc = 0
         str = 'HC-Transform Averages'
      END
      19: BEGIN
         data = tmpdata.grad(0,*)
         unc = 0
         str = 'Absolute Gradient Averages'
      END
      20: BEGIN
         data = tmpdata.grad(2,*)
         unc = 0
         str = 'Gradient Direction Averages'
      END
      ELSE: MESSAGE, /INFO, 'Not allowed CASE'
   ENDCASE

; Prepare a Byte array to accomodate all strings including carriage returns
   bytstr = [BYTE(str),10b,13b,10b,13b]

   
   accarr = INTARR(N_ELEMENTS(data))

   IF degl_set NE 0 THEN BEGIN 
      IF	(wtype EQ 0 OR wtype EQ 1) AND $ 
       (notacc GT 0)   THEN  accarr(indnacc) = 1
   ENDIF

   IF (wtype EQ 0 OR wtype EQ 1) AND $ 
    (notac1 GT 0)   THEN  accarr(indnac1) = 1

   IF wnd_set NE 0 THEN BEGIN 
      IF	(wtype EQ 0 OR wtype EQ 1) AND $ 
       (notac2 GT 0)   THEN  accarr(indnac2) = 1
   ENDIF

   indacc = WHERE(accarr EQ 0)
   avr = avg(data(indacc))
   sig = sigma(data(indacc))
   str = 'Full measurement average: '+$
    STRING(avr)+'    +/-'+STRING(sig)								
   bytstr = [bytstr,BYTE(str),10b,13b]

; Now get the text and display it

   text = STRING(bytstr)

   IF wnd_set NE 0 AND degl_set NE 0 THEN BEGIN
      XDISPLAYFILE, "", $
       TITLE = "Average after Windowing and Deglitching ", $
       WIDTH = 100, $
       HEIGHT = 10, $
       TEXT = [text]
   ENDIF ELSE IF wnd_set NE 0 AND degl_set EQ 0 THEN BEGIN
      XDISPLAYFILE, "", $
       TITLE = "Average after Windowing ", $
       WIDTH = 100, $
       HEIGHT = 10, $
       TEXT = [text]
   ENDIF ELSE IF degl_set NE 0 AND wnd_set EQ 0 THEN BEGIN
      XDISPLAYFILE, "", $
       TITLE = "Average after Deglitching ", $
       WIDTH = 100, $
       HEIGHT = 10, $
       TEXT = [text]
   ENDIF ELSE BEGIN  
      XDISPLAYFILE, "", $
       TITLE = "Average - No Windowing, No Deglitching ", $
       WIDTH = 100, $
       HEIGHT = 10, $
       TEXT = [text]
   ENDELSE
END

; *********************************************************************
; *
; *********************************************************************
PRO median2nonch5, event

   COMMON pia_dsp2smc_cmn, tmpdata, point_sources, lgal, bgal, dst, view, $
    viewsize, nviews, viewoptions, viewbut_ctrl, overid 
   COMMON pia_dsp2ch5_cmn, pixcho, pixop, pixres, psymch, pixcount

   WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
   WIDGET_CONTROL, event.top, /HOURGLASS

   median2event5, windowindex

END

; *********************************************************************
; *
; *********************************************************************
PRO median2event5, windowindex

   COMMON pia_dsp2smc_cmn, tmpdata, point_sources, lgal, bgal, dst, view, $
    viewsize, nviews, viewoptions, viewbut_ctrl, overid 
   COMMON pia_dsp2ch5_cmn, pixcho, pixop, pixres, psymch, pixcount
   COMMON sm2_acc, wnd_set, back_set, degl_set, htr_set, afi_set, prc_set
@phtsm

   ytitle = viewoptions(view(windowindex).viewtype).viewylab

   wtype = view(windowindex).viewtype

   notacc = 0
   notac1 = 0
   notac2 = 0

   CASE wtype OF

      0: BEGIN
         pixch = pixcho(windowindex)
         data = tmpdata.flx(pixch,*) * tmpdata.sens(pixch)
         unc = tmpdata.flxu(pixch,*) * tmpdata.sens(pixch)
         str = 'Surface Brightness Median Pixel '+ $
          STRTRIM(STRING(pixch),2)
         IF degl_set NE 0 THEN $
          indnacc = WHERE(tmpdata.smfl(pixch,*) AND flg_glitch, notacc)
         indnac1 = WHERE(tmpdata.flag(pixch,*) AND 2B, notac1)
         IF wnd_set NE 0 THEN $
          indnac2 = WHERE(tmpdata.smfl(pixch,*) AND flg_speed, notac2)
      END
      
      1: BEGIN
         pixch = pixcho(windowindex)
         data = tmpdata.flx(pixch,*) * tmpdata.sens(pixch)
         unc = tmpdata.flxu(pixch,*) * tmpdata.sens(pixch)
         str = 'Surface Brightness Median Pixel '+ $
          STRTRIM(STRING(pixch),2)
         IF degl_set NE 0 THEN $
          indnacc = WHERE(tmpdata.smfl(pixch,*) AND flg_glitch, notacc)
         indnac1 = WHERE(tmpdata.flag(pixch,*) AND 2B, notac1)
         IF wnd_set NE 0 THEN $
          indnac2 = WHERE(tmpdata.smfl(pixch,*) AND flg_speed, notac2)
      END
      
      2: BEGIN
         pixch = pixcho(windowindex)
         data = tmpdata.smfl(pixch,*)
         unc = 0
         str = 'SeM Flag Median Pixel '+STRTRIM(STRING(pixch),2)
      END
      3: BEGIN
         data = tmpdata.tkey
         unc = 0
         str = 'Time Key Median'
      END
      4: BEGIN
         data = tmpdata.ra
         unc = tmpdata.rau
         str = 'Right Ascension Median'
      END
      5: BEGIN
         data = tmpdata.dec
         unc = tmpdata.decu
         str = 'Declination Median'
      END
      6: BEGIN
         data = lgal
         unc = 0
         str = 'Galactic Longitude Median'
      END
      7: BEGIN
         data = bgal
         unc = 0
         str = 'Galactic Latitude Median'
      END
      8: BEGIN
         data = tmpdata.roll
         unc = tmpdata.rolu
         str = 'Roll Angle Median'
      END
      9: BEGIN
         data = tmpdata.dec
         unc = tmpdata.decu
         str = 'Declination Median'
      END
      10: BEGIN
         data = bgal
         unc = 0
         str = 'Galactic Latitude Median'
      END
      11: BEGIN
         data = dst
         unc = 0
         str = 'Slew position Median'
      END
      12: BEGIN
         data = tmpdata.vel * 60.
         unc = 0
         str = 'Slew speed Median'
      END

      13: BEGIN
         pixch = pixcho(windowindex)
         data = tmpdata.back(pixch,*) * tmpdata.sens(pixch)
         unc = tmpdata.nois(pixch,*) * tmpdata.sens(pixch)
         str = 'Background Median Pixel '+ $
          STRTRIM(STRING(pixch),2)
         IF degl_set NE 0 THEN $
          indnacc = WHERE(tmpdata.smfl(pixch,*) AND flg_glitch, notacc)
         indnac1 = WHERE(tmpdata.flag(pixch,*) AND 2B, notac1)
         IF wnd_set NE 0 THEN $
          indnac2 = WHERE(tmpdata.smfl(pixch,*) AND flg_speed, notac2)
      END
      
      14: BEGIN
         pixch = pixcho(windowindex)
         data = tmpdata.back(pixch,*) * tmpdata.sens(pixch)
         unc = tmpdata.nois(pixch,*) * tmpdata.sens(pixch)
         str = 'Background Median Pixel '+ $
          STRTRIM(STRING(pixch),2)
         IF degl_set NE 0 THEN $
          indnacc = WHERE(tmpdata.smfl(pixch,*) AND flg_glitch, notacc)
         indnac1 = WHERE(tmpdata.flag(pixch,*) AND 2B, notac1)
         IF wnd_set NE 0 THEN $
          indnac2 = WHERE(tmpdata.smfl(pixch,*) AND flg_speed, notac2)
      END

      15: BEGIN
         data = tmpdata.htr(0,*)
         unc = 0
         str = 'H0-Transform Median'
      END
      16: BEGIN
         data = tmpdata.htr(1,*)
         unc = 0
         str = 'HY-Transform Median'
      END
      17: BEGIN
         data = tmpdata.htr(2,*)
         unc = 0
         str = 'HZ-Transform Median'
      END
      18: BEGIN
         data = tmpdata.htr(3,*)
         unc = 0
         str = 'HC-Transform Median'
      END
      19: BEGIN
         data = tmpdata.grad(0,*)
         unc = 0
         str = 'Absolute Gradient Median'
      END
      20: BEGIN
         data = tmpdata.grad(2,*)
         unc = 0
         str = 'Gradient Direction Median'
      END

      ELSE: MESSAGE, /INFO, 'Not allowed CASE'

   ENDCASE

; Prepare a Byte array to accomodate all strings including carriage returns
   bytstr = [BYTE(str),10b,13b,10b,13b]

   accarr = INTARR(N_ELEMENTS(data))

   IF degl_set NE 0 THEN BEGIN 
      IF	(wtype EQ 0 OR wtype EQ 1) AND $ 
       (notacc GT 0)   THEN  accarr(indnacc) = 1
   ENDIF

   IF (wtype EQ 0 OR wtype EQ 1) AND $ 
    (notac1 GT 0)   THEN  accarr(indnac1) = 1

   IF wnd_set NE 0 THEN BEGIN 
      IF	(wtype EQ 0 OR wtype EQ 1) AND $ 
       (notac2 GT 0)   THEN  accarr(indnac2) = 1
   ENDIF

   indacc = WHERE(accarr EQ 0)
   avr = median(data(indacc))
   sig = sigma(data(indacc))
   str = 'Full measurement median: '+$
    STRING(avr)+'    +/-'+STRING(sig)								
   bytstr = [bytstr,BYTE(str),10b,13b]

; Now get the text and display it

   text = STRING(bytstr)

   IF wnd_set NE 0 AND degl_set NE 0 THEN BEGIN
      XDISPLAYFILE, "", $
       TITLE = "Median calculation after Windowing and Deglitching ", $
       WIDTH = 100, $
       HEIGHT = 10, $
       TEXT = [text]
   ENDIF ELSE IF wnd_set NE 0 AND degl_set EQ 0 THEN BEGIN
      XDISPLAYFILE, "", $
       TITLE = "Median calculation after Windowing ", $
       WIDTH = 100, $
       HEIGHT = 10, $
       TEXT = [text]
   ENDIF ELSE IF degl_set NE 0 AND wnd_set EQ 0 THEN BEGIN
      XDISPLAYFILE, "", $
       TITLE = "Median calculation after Deglitching ", $
       WIDTH = 100, $
       HEIGHT = 10, $
       TEXT = [text]
   ENDIF ELSE BEGIN  
      XDISPLAYFILE, "", $
       TITLE = "Median calculation - No Windowing, No Deglitching ", $
       WIDTH = 100, $
       HEIGHT = 10, $
       TEXT = [text]
   ENDELSE
END

; *********************************************************************
; *
; *********************************************************************
PRO zoom2event5, event

   COMMON pia_dsp2smc_cmn, tmpdata, point_sources, lgal, bgal, dst, view, $
    viewsize, nviews, viewoptions, viewbut_ctrl, overid 
   COMMON pia_dsp2ch5_cmn, pixcho, pixop, pixres, psymch, pixcount
   COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices

   WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
   zoom2it5, windowindex        
END

; *********************************************************************
; *
; *********************************************************************
PRO zoom2fourier5, event

   COMMON pia_dsp2smc_cmn, tmpdata, point_sources, lgal, bgal, dst, view, $
    viewsize, nviews, viewoptions, viewbut_ctrl, overid 
   COMMON pia_dsp2ch5_cmn, pixcho, pixop, pixres, psymch, pixcount
   COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices

   WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
   zoom2it5, windowindex, fourier = 1
END

; *********************************************************************
; *
; *********************************************************************
PRO zoom2sync5, event

   COMMON pia_dsp2smc_cmn, tmpdata, point_sources, lgal, bgal, dst, view, $
    viewsize, nviews, viewoptions, viewbut_ctrl, overid 
   COMMON pia_dsp2ch5_cmn, pixcho, pixop, pixres, psymch, pixcount
   COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices

   WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
   zoom2it5, windowindex, overplot = 1        

END

; *********************************************************************
; *
; *********************************************************************
PRO zoomn2sync5, event

   COMMON pia_dsp2smc_cmn, tmpdata, point_sources, lgal, bgal, dst, view, $
    viewsize, nviews, viewoptions, viewbut_ctrl, overid 
   COMMON pia_dsp2ch5_cmn, pixcho, pixop, pixres, psymch, pixcount
   COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices

   WIDGET_CONTROL, event.id, GET_UVALUE = windowindex
   zoom2it5, windowindex, overplot = -1        

END

; *********************************************************************
; *
; *********************************************************************
PRO zoom2it5, windowindex, overplot=overplot, fourier=fourier

   COMMON pia_dsp2smc_cmn, tmpdata, point_sources, lgal, bgal, dst, view, $
    viewsize, nviews, viewoptions, viewbut_ctrl, overid 
   COMMON pia_dsp2ch5_cmn, pixcho, pixop, pixres, psymch, pixcount
   COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
   COMMON sm2_acc, wnd_set, back_set, degl_set, htr_set, afi_set, prc_set
@phtsm
@colour_indices

   IF (KEYWORD_SET(overplot)) THEN overplot = overplot ELSE overplot = 0
   IF (KEYWORD_SET(fourier)) THEN fourier = 1 ELSE fourier = 0

   xtitle = viewoptions(view(windowindex).viewtype).viewxlab
   ytitle = viewoptions(view(windowindex).viewtype).viewylab
   ytype = 0

   decode_admn, tmpdata.admn, title
   title = title + '  ' + tmpdata.unit

   get_convwh, tmpdata.admn, wheels, chmod, champ
   anntmp = title + $
    '  [' + wheels(0) + '  ' + wheels(1) + '  ' + $
    wheels(2) + ']  [' + chmod + '  ' + champ + ']'

   anntmp = anntmp+' (SMC level)'

   subtitle = ''
   charsize = 1.10
   IF overplot NE 0 THEN BEGIN
      xstyle = 0
      ystyle = 0
      IF zoom_color EQ -1 THEN zoom_color = green ELSE $
       zoom_color = zoom_color + 1
      IF zoom_color EQ 9 THEN zoom_color = 4
      zoom_psymch = zoom_psymch + 1
      IF zoom_psymch EQ 8 THEN zoom_psymch = 1
   ENDIF ELSE BEGIN
      xstyle = 0
      ystyle = 0
      zoom_color = -1
      zoom_psymch = psymch
   ENDELSE

   IF fourier EQ 1 THEN BEGIN
      xtitle = 'Frequency       [Hz]'
      ytitle = 'FFT of '+ytitle
      ytype = 1
   ENDIF
   
   CASE view(windowindex).viewtype OF

;Plot Surface Brightness values
      0: BEGIN
         pixch = pixcho(windowindex)
         str_pixch = STRTRIM(STRING(pixch+1),2)
         str_pixch = 'Surf. Brightness: Pixel '+str_pixch+' [MJy/sr]'
         ytitle = str_pixch 

         IF fourier EQ 1 THEN BEGIN
            xtitle = 'Frequency       [Hz]'
            ytitle = 'FFT of '+ytitle
            ytype = 1
         ENDIF
         
         pia_xplot, tmpdata.time, $
          tmpdata.flx(pixch,*) * tmpdata.sens(pixch), $
          tmpdata.flxu(pixch,*) * tmpdata.sens(pixch), $
          psym = zoom_psymch, xtitle=xtitle, fourier=fourier, $
          ytitle=ytitle, subtitle=subtitle, $
          title=title, ytype=ytype,  $
          overplot = overplot,  $
          charsize = charsize, color = zoom_color,     $       
          xstyle=xstyle, ystyle=ystyle, $
          legend=strmid(ytitle,0,18), $
          annotation=anntmp                    

         IF degl_set NE 0 AND fourier EQ 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(pixch,*) AND flg_glitch, nn)
            IF nn GT 0 THEN $
             PIA_XPLOT, tmpdata.time(indno), $
             tmpdata.flx(pixch,indno) * tmpdata.sens(pixch), $
             psym = 1, color=red, overplot=99, $
             legend= ' deglitched points'     
         ENDIF

         IF fourier EQ 0 THEN BEGIN
            indno = WHERE(tmpdata.flag(pixch,*) AND 2B, nn)
            IF nn GT 0 THEN $
             PIA_XPLOT, tmpdata.time(indno), $
             tmpdata.flx(pixch,indno) * tmpdata.sens(pixch), $
             psym = 7, color=red, overplot=99, $
             legend=' discarded points'
         ENDIF

         IF wnd_set NE 0 AND fourier EQ 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(pixch,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_XPLOT, tmpdata.time(indno), $
             tmpdata.flx(pixch,indno) * tmpdata.sens(pixch), $
             psym = 5, color=red, overplot=99, $
             legend= ' low-speed points'     
         ENDIF

      END

;Plot Surface Brightness values
      1: BEGIN
         pixch = pixcho(windowindex)
         str_pixch = STRTRIM(STRING(pixch+1),2)
         str_pixch = 'Surf. Brightness: Pixel '+str_pixch+' [MJy/sr]'
         ytitle = str_pixch 

         IF fourier EQ 1 THEN BEGIN
            xtitle = 'Frequency       [Hz]'
            ytitle = 'FFT of '+ytitle
            ytype = 1
         ENDIF
         
         pia_xplot, dst, $
          tmpdata.flx(pixch,*) * tmpdata.sens(pixch), $
          tmpdata.flxu(pixch,*) * tmpdata.sens(pixch), $
          psym = zoom_psymch, xtitle=xtitle, fourier=fourier, $
          ytitle=ytitle, subtitle=subtitle, $
          title=title, ytype=ytype,  $
          overplot = overplot,  $
          charsize = charsize, color = zoom_color,     $       
          xstyle=xstyle, ystyle=ystyle, $
          legend=strmid(ytitle,0,18), $
          annotation=anntmp                    

         IF degl_set NE 0 AND fourier EQ 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(pixch,*) AND flg_glitch, nn)
            IF nn GT 0 THEN $
             PIA_XPLOT, dst(indno), $
             tmpdata.flx(pixch,indno) * tmpdata.sens(pixch), $
             psym = 1, color=red, overplot=99, $
             legend= ' deglitched points'     
         ENDIF

         IF fourier EQ 0 THEN BEGIN
            indno = WHERE(tmpdata.flag(pixch,*) AND 2B, nn)
            IF nn GT 0 THEN $
             PIA_XPLOT, dst(indno), $
             tmpdata.flx(pixch,indno) * tmpdata.sens(pixch), $
             psym = 7, color=red, overplot=99, $
             legend=' discarded points'
         ENDIF

         IF wnd_set NE 0 AND fourier EQ 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(pixch,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_XPLOT, dst(indno), $
             tmpdata.flx(pixch,indno) * tmpdata.sens(pixch), $
             psym = 5, color=red, overplot=99, $
             legend= ' low-speed points'     
         ENDIF

      END
;Plot SeM flag values
      2: BEGIN
         pixch = pixcho(windowindex)
         str_pixch = STRTRIM(STRING(pixch+1),2)
         str_pixch = 'Serendipity Flag: Pixel '+str_pixch
         ytitle = str_pixch 

         IF fourier EQ 1 THEN BEGIN
            xtitle = 'Frequency       [Hz]'
            ytitle = 'FFT of '+ytitle
            ytype = 1
         ENDIF
         
         pia_xplot, tmpdata.time, $
          tmpdata.smfl(pixch,*), $ 
          psym = zoom_psymch, xtitle=xtitle, fourier=fourier, $
          ytitle=ytitle, subtitle=subtitle, $
          title=title, ytype=ytype,  $
          overplot = overplot,  $
          charsize = charsize, color = zoom_color,    $       
          xstyle=xstyle, ystyle=ystyle, $
          legend=strmid(ytitle,0,18), $
          annotation=anntmp              
      END
;Plot time keys
      3: BEGIN
         pia_xplot, tmpdata.time, tmpdata.tkey, psym = zoom_psymch, $
          xtitle=xtitle, fourier=fourier, ytitle=ytitle, $
          subtitle=subtitle, $
          title=title, ytype=ytype,  $
          overplot = overplot,  $
          charsize = charsize, color = zoom_color,     $       
          xstyle=xstyle, ystyle=ystyle, $
          legend=strmid(ytitle,0,18), $
          annotation=anntmp              
      END
;Plot right ascension values
      4: BEGIN
         pia_xplot, tmpdata.time, tmpdata.ra, tmpdata.rau, $
          psym = zoom_psymch, $
          xtitle=xtitle, fourier=fourier, ytitle=ytitle, $
          subtitle=subtitle, $
          title=title, ytype=ytype,  $
          overplot = overplot,  $
          charsize = charsize, color = zoom_color,    $       
          xstyle=xstyle, ystyle=ystyle, $
          legend=strmid(ytitle,0,18), $
          annotation=anntmp              
         
         IF wnd_set NE 0 AND fourier EQ 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(0,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_XPLOT, tmpdata.time(indno), $
             tmpdata.ra(indno), $
             psym = 5, color=red, overplot=99, $
             legend= ' low-speed points'
         ENDIF
      END
;Plot declination values
      5: BEGIN
         pia_xplot, tmpdata.time, tmpdata.dec, tmpdata.decu, $
          psym = zoom_psymch, $
          xtitle=xtitle, fourier=fourier, ytitle=ytitle, $
          subtitle=subtitle, $
          title=title, ytype=ytype,  $
          overplot = overplot,  $
          charsize = charsize, color = zoom_color,    $       
          xstyle=xstyle, ystyle=ystyle, $
          legend=strmid(ytitle,0,18), $
          annotation=anntmp              
         
         IF wnd_set NE 0 AND fourier EQ 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(0,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_XPLOT, tmpdata.time(indno), $
             tmpdata.dec(indno), $
             psym = 5, color=red, overplot=99, $
             legend= ' low-speed points'
         ENDIF
      END
;Plot galactic longitude values
      6: BEGIN
         pia_xplot, tmpdata.time, lgal, $
          psym = zoom_psymch, $
          xtitle=xtitle, fourier=fourier, ytitle=ytitle, $
          subtitle=subtitle, $
          title=title, ytype=ytype,  $
          overplot = overplot,  $
          charsize = charsize, color = zoom_color,    $       
          xstyle=xstyle, ystyle=ystyle, $
          legend=strmid(ytitle,0,18), $
          annotation=anntmp              
         
         IF wnd_set NE 0 AND fourier EQ 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(0,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_XPLOT, tmpdata.time(indno), $
             lgal(indno), $
             psym = 5, color=red, overplot=99, $
             legend= ' low-speed points'
         ENDIF
      END
;Plot galactic latitude values
      7: BEGIN
         pia_xplot, tmpdata.time, bgal, tmpdata.decu, $
          psym = zoom_psymch, $
          xtitle=xtitle, fourier=fourier, ytitle=ytitle, $
          subtitle=subtitle, $
          title=title, ytype=ytype,  $
          overplot = overplot,  $
          charsize = charsize, color = zoom_color,    $       
          xstyle=xstyle, ystyle=ystyle, $
          legend=strmid(ytitle,0,18), $
          annotation=anntmp              
         
         IF wnd_set NE 0 AND fourier EQ 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(0,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_XPLOT, tmpdata.time(indno), $
             bgal(indno), $
             psym = 5, color=red, overplot=99, $
             legend= ' low-speed points'
         ENDIF
      END
;Plot roll angle values
      8: BEGIN
         pia_xplot, tmpdata.time, tmpdata.roll, tmpdata.rolu, $
          psym = zoom_psymch, $
          xtitle=xtitle, fourier=fourier, ytitle=ytitle, $
          subtitle=subtitle, $
          title=title, ytype=ytype,  $
          overplot = overplot,  $
          charsize = charsize, color = zoom_color,    $       
          xstyle=xstyle, ystyle=ystyle, $
          legend=strmid(ytitle,0,18), $
          annotation=anntmp              

         IF wnd_set NE 0 AND fourier EQ 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(0,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_XPLOT, tmpdata.time(indno), $
             tmpdata.roll(indno), $
             psym = 5, color=red, overplot=99, $
             legend= ' low-speed points'
         ENDIF
      END
;Plot declination vs. right ascension values
      9: BEGIN
         pia_xplot, tmpdata.ra, tmpdata.dec, $
          psym = zoom_psymch, $
          xtitle=xtitle, fourier=fourier, ytitle=ytitle, $
          subtitle=subtitle, $
          title=title, ytype=ytype,  $
          overplot = overplot,  $
          charsize = charsize, color = zoom_color,    $       
          xstyle=xstyle, ystyle=ystyle, $
          legend=strmid(ytitle,0,18), $
          annotation=anntmp              
         
         IF wnd_set NE 0 AND fourier EQ 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(0,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_XPLOT, tmpdata.ra(indno), $
             tmpdata.dec(indno), $
             psym = 5, color=red, overplot=99, $
             legend= ' low-speed points'
         ENDIF
      END
;Plot galactic latitude vs. galactic longitude values
      10: BEGIN
         pia_xplot, lgal, bgal, $
          psym = zoom_psymch, $
          xtitle=xtitle, fourier=fourier, ytitle=ytitle, $
          subtitle=subtitle, $
          title=title, ytype=ytype,  $
          overplot = overplot,  $
          charsize = charsize, color = zoom_color,    $       
          xstyle=xstyle, ystyle=ystyle, $
          legend=strmid(ytitle,0,18), $
          annotation=anntmp              
         
         IF wnd_set NE 0 AND fourier EQ 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(0,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_XPLOT, lgal(indno), $
             bgal(indno), $
             psym = 5, color=red, overplot=99, $
             legend= ' low-speed points'
         ENDIF
      END
;Plot slew position values
      11: BEGIN
         pia_xplot, tmpdata.time, dst, $
          psym = zoom_psymch, $
          xtitle=xtitle, fourier=fourier, ytitle=ytitle, $
          subtitle=subtitle, $
          title=title, ytype=ytype,  $
          overplot = overplot,  $
          charsize = charsize, color = zoom_color,    $       
          xstyle=xstyle, ystyle=ystyle, $
          legend=strmid(ytitle,0,18), $
          annotation=anntmp              

         IF wnd_set NE 0 AND fourier EQ 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(0,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_XPLOT, tmpdata.time(indno), $
             dst(indno), $
             psym = 5, color=red, overplot=99, $
             legend= ' low-speed points'
         ENDIF
      END
;Plot slew speed values
      12: BEGIN
         pia_xplot, tmpdata.time, tmpdata.vel*60., $
          psym = zoom_psymch, $
          xtitle=xtitle, fourier=fourier, ytitle=ytitle, $
          subtitle=subtitle, $
          title=title, ytype=ytype,  $
          overplot = overplot,  $
          charsize = charsize, color = zoom_color,    $       
          xstyle=xstyle, ystyle=ystyle, $
          legend=strmid(ytitle,0,18), $
          annotation=anntmp              
         
         IF wnd_set NE 0 AND fourier EQ 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(0,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_XPLOT, tmpdata.time(indno), $
             tmpdata.vel(indno)*60., $
             psym = 5, color=red, overplot=99, $
             legend= ' low-speed points'
         ENDIF
      END

;Plot Background values
      13: BEGIN
         pixch = pixcho(windowindex)
         str_pixch = STRTRIM(STRING(pixch+1),2)
         str_pixch = 'Background: Pixel '+str_pixch+' [MJy/sr]'
         ytitle = str_pixch 

         IF fourier EQ 1 THEN BEGIN
            xtitle = 'Frequency       [Hz]'
            ytitle = 'FFT of '+ytitle
            ytype = 1
         ENDIF
         
         pia_xplot, tmpdata.time, $
          tmpdata.back(pixch,*) * tmpdata.sens(pixch), $
          tmpdata.nois(pixch,*) * tmpdata.sens(pixch), $
          psym = zoom_psymch, xtitle=xtitle, fourier=fourier, $
          ytitle=ytitle, subtitle=subtitle, $
          title=title, ytype=ytype,  $
          overplot = overplot,  $
          charsize = charsize, color = zoom_color,     $       
          xstyle=xstyle, ystyle=ystyle, $
          legend=strmid(ytitle,0,18), $
          annotation=anntmp                    

         IF degl_set AND fourier EQ 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(pixch,*) AND flg_glitch, nn)
            IF nn GT 0 THEN $
             PIA_XPLOT, tmpdata.time(indno), $
             tmpdata.back(pixch,indno) * tmpdata.sens(pixch), $
             psym = 1, color=red, overplot=99, $
             legend= ' deglitched points'     
         ENDIF

         IF fourier EQ 0 THEN BEGIN
            indno = WHERE(tmpdata.flag(pixch,*) AND 2B, nn)
            IF nn GT 0 THEN $
             PIA_XPLOT, tmpdata.time(indno), $
             tmpdata.back(pixch,indno) * tmpdata.sens(pixch), $
             psym = 7, color=red, overplot=99, $
             legend=' discarded points'
         ENDIF

         IF wnd_set NE 0 AND fourier EQ 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(pixch,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_XPLOT, tmpdata.time(indno), $
             tmpdata.back(pixch,indno) * tmpdata.sens(pixch), $
             psym = 5, color=red, overplot=99, $
             legend= ' low-speed points'     
         ENDIF

      END

;Plot Background values
      14: BEGIN
         pixch = pixcho(windowindex)
         str_pixch = STRTRIM(STRING(pixch+1),2)
         str_pixch = 'Background: Pixel '+str_pixch+' [MJy/sr]'
         ytitle = str_pixch 

         IF fourier EQ 1 THEN BEGIN
            xtitle = 'Frequency       [Hz]'
            ytitle = 'FFT of '+ytitle
            ytype = 1
         ENDIF
         
         pia_xplot, dst, $
          tmpdata.back(pixch,*) * tmpdata.sens(pixch), $
          tmpdata.nois(pixch,*) * tmpdata.sens(pixch), $
          psym = zoom_psymch, xtitle=xtitle, fourier=fourier, $
          ytitle=ytitle, subtitle=subtitle, $
          title=title, ytype=ytype,  $
          overplot = overplot,  $
          charsize = charsize, color = zoom_color,     $       
          xstyle=xstyle, ystyle=ystyle, $
          legend=strmid(ytitle,0,18), $
          annotation=anntmp                    

         IF degl_set AND fourier EQ 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(pixch,*) AND flg_glitch, nn)
            IF nn GT 0 THEN $
             PIA_XPLOT, dst(indno), $
             tmpdata.back(pixch,indno) * tmpdata.sens(pixch), $
             psym = 1, color=red, overplot=99, $
             legend= ' deglitched points'     
         ENDIF

         IF fourier EQ 0 THEN BEGIN
            indno = WHERE(tmpdata.flag(pixch,*) AND 2B, nn)
            IF nn GT 0 THEN $
             PIA_XPLOT, dst(indno), $
             tmpdata.back(pixch,indno) * tmpdata.sens(pixch), $
             psym = 7, color=red, overplot=99, $
             legend=' discarded points'
         ENDIF

         IF wnd_set NE 0 AND fourier EQ 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(pixch,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_XPLOT, dst(indno), $
             tmpdata.back(pixch,indno) * tmpdata.sens(pixch), $
             psym = 5, color=red, overplot=99, $
             legend= ' low-speed points'     
         ENDIF

      END

;Plot H0-transform values
      15: BEGIN
         pia_xplot, tmpdata.time, tmpdata.htr(0,*), $
          psym = zoom_psymch, $
          xtitle=xtitle, fourier=fourier, ytitle=ytitle, $
          subtitle=subtitle, $
          title=title, ytype=ytype,  $
          overplot = overplot,  $
          charsize = charsize, color = zoom_color,    $       
          xstyle=xstyle, ystyle=ystyle, $
          legend=strmid(ytitle,0,18), $
          annotation=anntmp              

         IF wnd_set NE 0 AND fourier EQ 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(0,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_XPLOT, tmpdata.time(indno), $
             tmpdata.htr(0,indno), $
             psym = 5, color=red, overplot=99, $
             legend= ' low-speed points'
         ENDIF
      END
;Plot HY-transform values
      16: BEGIN
         pia_xplot, tmpdata.time, tmpdata.htr(1,*), $
          psym = zoom_psymch, $
          xtitle=xtitle, fourier=fourier, ytitle=ytitle, $
          subtitle=subtitle, $
          title=title, ytype=ytype,  $
          overplot = overplot,  $
          charsize = charsize, color = zoom_color,    $       
          xstyle=xstyle, ystyle=ystyle, $
          legend=strmid(ytitle,0,18), $
          annotation=anntmp              

         IF wnd_set NE 0 AND fourier EQ 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(0,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_XPLOT, tmpdata.time(indno), $
             tmpdata.htr(1,indno), $
             psym = 5, color=red, overplot=99, $
             legend= ' low-speed points'
         ENDIF
      END
;Plot HZ-transform values
      17: BEGIN
         pia_xplot, tmpdata.time, tmpdata.htr(2,*), $
          psym = zoom_psymch, $
          xtitle=xtitle, fourier=fourier, ytitle=ytitle, $
          subtitle=subtitle, $
          title=title, ytype=ytype,  $
          overplot = overplot,  $
          charsize = charsize, color = zoom_color,    $       
          xstyle=xstyle, ystyle=ystyle, $
          legend=strmid(ytitle,0,18), $
          annotation=anntmp              

         IF wnd_set NE 0 AND fourier EQ 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(0,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_XPLOT, tmpdata.time(indno), $
             tmpdata.htr(2,indno), $
             psym = 5, color=red, overplot=99, $
             legend= ' low-speed points'
         ENDIF
      END
;Plot HC-transform values
      18: BEGIN
         pia_xplot, tmpdata.time, tmpdata.htr(3,*), $
          psym = zoom_psymch, $
          xtitle=xtitle, fourier=fourier, ytitle=ytitle, $
          subtitle=subtitle, $
          title=title, ytype=ytype,  $
          overplot = overplot,  $
          charsize = charsize, color = zoom_color,    $       
          xstyle=xstyle, ystyle=ystyle, $
          legend=strmid(ytitle,0,18), $
          annotation=anntmp              

         IF wnd_set NE 0 AND fourier EQ 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(0,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_XPLOT, tmpdata.time(indno), $
             tmpdata.htr(3,indno), $
             psym = 5, color=red, overplot=99, $
             legend= ' low-speed points'
         ENDIF
      END
;Plot absolute gradient values
      19: BEGIN
         pia_xplot, tmpdata.time, tmpdata.grad(0,*), $
          psym = zoom_psymch, $
          xtitle=xtitle, fourier=fourier, ytitle=ytitle, $
          subtitle=subtitle, $
          title=title, ytype=ytype,  $
          overplot = overplot,  $
          charsize = charsize, color = zoom_color,    $       
          xstyle=xstyle, ystyle=ystyle, $
          legend=strmid(ytitle,0,18), $
          annotation=anntmp              

         IF wnd_set NE 0 AND fourier EQ 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(0,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_XPLOT, tmpdata.time(indno), $
             tmpdata.grad(0,indno), $
             psym = 5, color=red, overplot=99, $
             legend= ' low-speed points'
         ENDIF
      END
;Plot gradient direction values
      20: BEGIN
         pia_xplot, tmpdata.time, tmpdata.grad(2,*), $
          psym = zoom_psymch, $
          xtitle=xtitle, fourier=fourier, ytitle=ytitle, $
          subtitle=subtitle, $
          title=title, ytype=ytype,  $
          overplot = overplot,  $
          charsize = charsize, color = zoom_color,    $       
          xstyle=xstyle, ystyle=ystyle, $
          legend=strmid(ytitle,0,18), $
          annotation=anntmp              

         IF wnd_set NE 0 AND fourier EQ 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(0,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_XPLOT, tmpdata.time(indno), $
             tmpdata.grad(2,indno), $
             psym = 5, color=red, overplot=99, $
             legend= ' low-speed points'
         ENDIF
      END

      ELSE: WIDGET_CONTROL, UPDATE_LABEL, $
       set_value = 'Unsupported View'
   ENDCASE

END


; *********************************************************************
; *
; *********************************************************************
PRO pia_reset2view5, windowindex, UPDATE_LABEL

   COMMON pia_dsp2smc_cmn, tmpdata, point_sources, lgal, bgal, dst, view, $
    viewsize, nviews, viewoptions, viewbut_ctrl, overid 
   COMMON pia_dsp2ch5_cmn, pixcho, pixop, pixres, psymch, pixcount
   COMMON sm2_acc, wnd_set, back_set, degl_set, htr_set, afi_set, prc_set
@phtsm
@colour_indices

   wset, view(windowindex).windownum ;set to draw in 

   ERASE, color = 100           ;erase the view


   IF NOT (KEYWORD_SET(UPDATE_LABEL)) THEN $
    UPDATE_LABEL = 0


   charsize = 1.2
   symsize = 0.5

   title = viewoptions(view(windowindex).viewtype).viewname
   xtitle = viewoptions(view(windowindex).viewtype).viewxlab
   ytitle = viewoptions(view(windowindex).viewtype).viewylab

   CASE view(windowindex).viewtype OF


;Plot Surface Brightness values
      0: BEGIN
         pixch = pixcho(windowindex)
         str_pixch = STRTRIM(STRING(pixch+1),2)
         str_pixch = 'Surf. Brightness: Pixel '+str_pixch+' [MJy/sr]'
         IF title NE '' THEN title = str_pixch 
         pia_plot, tmpdata.time, $
          tmpdata.flx(pixch,*) * tmpdata.sens(pixch), $
          yerr=tmpdata.flxu(pixch,*) * tmpdata.sens(pixch), $
          psym = psymch, xtitle=xtitle, $
          ytitle=ytitle,  $
          charsize = charsize, symsize = symsize

         IF degl_set NE 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(pixch,*) AND flg_glitch, nn)
            IF nn GT 0 THEN $
             PIA_OPLOT, tmpdata.time(indno), $
             tmpdata.flx(pixch,indno) * tmpdata.sens(pixch), $
             psym = 7, color=red
         ENDIF

         indno = WHERE(tmpdata.flag(pixch,*) AND 2B, nn)
         IF nn GT 0 THEN $
          PIA_OPLOT, tmpdata.time(indno), $
          tmpdata.flx(pixch,indno) * tmpdata.sens(pixch), $
          psym = 7, color=red

         IF wnd_set NE 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(pixch,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_OPLOT, tmpdata.time(indno), $
             tmpdata.flx(pixch,indno) * tmpdata.sens(pixch), $
             psym = 7, color=red
         ENDIF

         IF(keyword_set(UPDATE_LABEL)) THEN $
          WIDGET_CONTROL, update_label, $
          set_value = str_pixch  
         
      END
;Plot Surface Brightness values
      1: BEGIN
         pixch = pixcho(windowindex)
         str_pixch = STRTRIM(STRING(pixch+1),2)
         str_pixch = 'Surf. Brightness: Pixel '+str_pixch+' [MJy/sr]'
         IF title NE '' THEN title = str_pixch 
         pia_plot, dst, $
          tmpdata.flx(pixch,*) * tmpdata.sens(pixch), $
          yerr=tmpdata.flxu(pixch,*) * tmpdata.sens(pixch), $
          psym = psymch, xtitle=xtitle, $
          ytitle=ytitle,  $
          charsize = charsize, symsize = symsize

         IF degl_set NE 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(pixch,*) AND flg_glitch, nn)
            IF nn GT 0 THEN $
             PIA_OPLOT, dst(indno), $
             tmpdata.flx(pixch,indno) * tmpdata.sens(pixch), $
             psym = 7, color=red
         ENDIF

         indno = WHERE(tmpdata.flag(pixch,*) AND 2B, nn)
         IF nn GT 0 THEN $
          PIA_OPLOT, dst(indno), $
          tmpdata.flx(pixch,indno) * tmpdata.sens(pixch), $
          psym = 7, color=red

         IF wnd_set NE 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(pixch,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_OPLOT, dst(indno), $
             tmpdata.flx(pixch,indno) * tmpdata.sens(pixch), $
             psym = 7, color=red
         ENDIF

         IF(keyword_set(UPDATE_LABEL)) THEN $
          WIDGET_CONTROL, update_label, $
          set_value = str_pixch  
         
      END
;Plot SeM flag values
      2: BEGIN
         pixch = pixcho(windowindex)
         str_pixch = STRTRIM(STRING(pixch+1),2)
         str_pixch = 'Serendipity Flag: Pixel '+str_pixch
         IF title NE '' THEN title = str_pixch 
         pia_plot, tmpdata.time, $
          tmpdata.smfl(pixch,*), $
          psym = psymch, xtitle=xtitle, $
          ytitle=ytitle,  $
          charsize = charsize, symsize = symsize

         IF(keyword_set(UPDATE_LABEL)) THEN $
          WIDGET_CONTROL, update_label, $
          set_value = str_pixch  

      END
;Plot time keys
      3: BEGIN
         pia_plot, tmpdata.time, tmpdata.tkey, psym = psymch, $
          xtitle = xtitle, ytitle=ytitle,  $
          charsize = charsize, symsize = symsize

         IF(keyword_set(UPDATE_LABEL)) THEN $
          WIDGET_CONTROL, update_label, $
          set_value = 'Instrument Time Key'

      END
;Plot right ascension values
      4: BEGIN
         pia_plot, tmpdata.time, tmpdata.ra, $
          yerr=tmpdata.rau, $
          psym = psymch, $
          xtitle = xtitle, ytitle=ytitle,  $
          charsize = charsize, symsize = symsize

         IF(keyword_set(UPDATE_LABEL)) THEN $
          WIDGET_CONTROL, update_label, $
          set_value = 'RA (equ, J2000) vs. Time'

         IF wnd_set NE 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(0,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_OPLOT, tmpdata.time(indno), $
             tmpdata.ra(indno), $
             psym = 7, color=red
         ENDIF
         
      END
;Plot declination values
      5: BEGIN
         pia_plot, tmpdata.time, tmpdata.dec, $
          yerr=tmpdata.decu, $
          psym = psymch, $
          xtitle = xtitle, ytitle=ytitle,  $
          charsize = charsize, symsize = symsize

         IF wnd_set NE 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(0,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_OPLOT, tmpdata.time(indno), $
             tmpdata.dec(indno), $
             psym = 7, color=red
         ENDIF

         IF(keyword_set(UPDATE_LABEL)) THEN $
          WIDGET_CONTROL, update_label, $
          set_value = 'DEC (equ, J2000) vs. Time'

      END
;Plot galactic longitude values
      6: BEGIN
         pia_plot, tmpdata.time, lgal, $
          psym = psymch, $
          xtitle = xtitle, ytitle=ytitle,  $
          charsize = charsize, symsize = symsize

         IF wnd_set NE 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(0,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_OPLOT, tmpdata.time(indno), $
             lgal(indno), $
             psym = 7, color=red
         ENDIF

         IF(keyword_set(UPDATE_LABEL)) THEN $
          WIDGET_CONTROL, update_label, $
          set_value = 'l (galactic) vs. Time'

      END
;Plot galactic latitude values
      7: BEGIN
         pia_plot, tmpdata.time, bgal, $
          psym = psymch, $
          xtitle = xtitle, ytitle=ytitle,  $
          charsize = charsize, symsize = symsize

         IF wnd_set NE 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(0,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_OPLOT, tmpdata.time(indno), $
             bgal(indno), $
             psym = 7, color=red
         ENDIF

         IF(keyword_set(UPDATE_LABEL)) THEN $
          WIDGET_CONTROL, update_label, $
          set_value = 'b (galactic) vs. Time'

      END
;Plot roll angle values
      8: BEGIN
         pia_plot, tmpdata.time, tmpdata.roll, $
          yerr=tmpdata.rolu, $
          psym = psymch, $
          xtitle = xtitle, ytitle=ytitle,  $
          charsize = charsize, symsize = symsize

         IF wnd_set NE 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(0,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_OPLOT, tmpdata.time(indno), $
             tmpdata.roll(indno), $
             psym = 7, color=red
         ENDIF

         IF(keyword_set(UPDATE_LABEL)) THEN $
          WIDGET_CONTROL, update_label, $
          set_value = 'Roll Angle vs. Time'

      END
;Plot declination vs. right ascension values
      9: BEGIN
         pia_plot, tmpdata.ra, tmpdata.dec, $
          psym = psymch, $
          xtitle = xtitle, ytitle=ytitle,  $
          charsize = charsize, symsize = symsize

         IF wnd_set NE 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(0,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_OPLOT, tmpdata.ra(indno), $
             tmpdata.dec(indno), $
             psym = 7, color=red
         ENDIF

         IF(keyword_set(UPDATE_LABEL)) THEN $
          WIDGET_CONTROL, update_label, $
          set_value = 'DEC vs. RA (equ, J2000)'

      END
;Plot galactic latitude vs. galactic longitude values
      10: BEGIN
         pia_plot, lgal, bgal, $
          psym = psymch, $
          xtitle = xtitle, ytitle=ytitle,  $
          charsize = charsize, symsize = symsize

         IF wnd_set NE 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(0,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_OPLOT, lgal(indno), $
             bgal(indno), $
             psym = 7, color=red
         ENDIF

         IF(keyword_set(UPDATE_LABEL)) THEN $
          WIDGET_CONTROL, update_label, $
          set_value = 'b vs. l (galactic)'

      END
;Plot slew position values
      11: BEGIN
         pia_plot, tmpdata.time, dst, $
          psym = psymch, $
          xtitle = xtitle, ytitle=ytitle,  $
          charsize = charsize, symsize = symsize

         IF wnd_set NE 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(0,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_OPLOT, tmpdata.time(indno), $
             dst(indno), $
             psym = 7, color=red
         ENDIF
         
         IF(keyword_set(UPDATE_LABEL)) THEN $
          WIDGET_CONTROL, update_label, $
          set_value = 'Position vs. Time'

      END
;Plot slew speed values
      12: BEGIN
         pia_plot, tmpdata.time, tmpdata.vel*60., $
          psym = psymch, $
          xtitle = xtitle, ytitle=ytitle,  $
          charsize = charsize, symsize = symsize

         IF wnd_set NE 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(0,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_OPLOT, tmpdata.time(indno), $
             tmpdata.vel(indno)*60., $
             psym = 7, color=red
         ENDIF
         
         IF(keyword_set(UPDATE_LABEL)) THEN $
          WIDGET_CONTROL, update_label, $
          set_value = 'Slew speed vs. Time'

      END
;Plot Background values
      13: BEGIN
         pixch = pixcho(windowindex)
         str_pixch = STRTRIM(STRING(pixch+1),2)
         str_pixch = 'Background: Pixel '+str_pixch+' [MJy/sr]'
         IF title NE '' THEN title = str_pixch 
         pia_plot, tmpdata.time, $
          tmpdata.back(pixch,*) * tmpdata.sens(pixch), $
          yerr=tmpdata.nois(pixch,*) * tmpdata.sens(pixch), $
          psym = psymch, xtitle=xtitle, $
          ytitle=ytitle,  $
          charsize = charsize, symsize = symsize

         IF degl_set NE 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(pixch,*) AND flg_glitch, nn)
            IF nn GT 0 THEN $
             PIA_OPLOT, tmpdata.time(indno), $
             tmpdata.back(pixch,indno) * tmpdata.sens(pixch), $
             psym = 7, color=red
         ENDIF

         indno = WHERE(tmpdata.flag(pixch,*) AND 2B, nn)
         IF nn GT 0 THEN $
          PIA_OPLOT, tmpdata.time(indno), $
          tmpdata.back(pixch,indno) * tmpdata.sens(pixch), $
          psym = 7, color=red

         IF wnd_set NE 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(pixch,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_OPLOT, tmpdata.time(indno), $
             tmpdata.back(pixch,indno) * tmpdata.sens(pixch), $
             psym = 7, color=red
         ENDIF

         IF(keyword_set(UPDATE_LABEL)) THEN $
          WIDGET_CONTROL, update_label, $
          set_value = str_pixch  
         
      END
;Plot Background values
      14: BEGIN
         pixch = pixcho(windowindex)
         str_pixch = STRTRIM(STRING(pixch+1),2)
         str_pixch = 'Background: Pixel '+str_pixch+' [MJy/sr]'
         IF title NE '' THEN title = str_pixch 
         pia_plot, dst, $
          tmpdata.back(pixch,*) * tmpdata.sens(pixch), $
          yerr=tmpdata.nois(pixch,*) * tmpdata.sens(pixch), $
          psym = psymch, xtitle=xtitle, $
          ytitle=ytitle,  $
          charsize = charsize, symsize = symsize

         IF degl_set NE 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(pixch,*) AND flg_glitch, nn)
            IF nn GT 0 THEN $
             PIA_OPLOT, dst(indno), $
             tmpdata.back(pixch,indno) * tmpdata.sens(pixch), $
             psym = 7, color=red
         ENDIF

         indno = WHERE(tmpdata.flag(pixch,*) AND 2B, nn)
         IF nn GT 0 THEN $
          PIA_OPLOT, dst(indno), $
          tmpdata.back(pixch,indno) * tmpdata.sens(pixch), $
          psym = 7, color=red

         IF wnd_set NE 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(pixch,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_OPLOT, dst(indno), $
             tmpdata.back(pixch,indno) * tmpdata.sens(pixch), $
             psym = 7, color=red
         ENDIF

         IF(keyword_set(UPDATE_LABEL)) THEN $
          WIDGET_CONTROL, update_label, $
          set_value = str_pixch  
         
      END
;Plot H0-transform values
      15: BEGIN
         pia_plot, tmpdata.time, tmpdata.htr(0,*), $
          psym = psymch, $
          xtitle = xtitle, ytitle=ytitle,  $
          charsize = charsize, symsize = symsize

         IF wnd_set NE 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(0,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_OPLOT, tmpdata.time(indno), $
             tmpdata.htr(0,indno), $
             psym = 7, color=red
         ENDIF

         IF(keyword_set(UPDATE_LABEL)) THEN $
          WIDGET_CONTROL, update_label, $
          set_value = 'H0-Transform vs. Time'

      END
;Plot HY-transform values
      16: BEGIN
         pia_plot, tmpdata.time, tmpdata.htr(1,*), $
          psym = psymch, $
          xtitle = xtitle, ytitle=ytitle,  $
          charsize = charsize, symsize = symsize

         IF wnd_set NE 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(0,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_OPLOT, tmpdata.time(indno), $
             tmpdata.htr(1,indno), $
             psym = 7, color=red
         ENDIF

         IF(keyword_set(UPDATE_LABEL)) THEN $
          WIDGET_CONTROL, update_label, $
          set_value = 'HY-Transform vs. Time'

      END
;Plot HZ-transform values
      17: BEGIN
         pia_plot, tmpdata.time, tmpdata.htr(2,*), $
          psym = psymch, $
          xtitle = xtitle, ytitle=ytitle,  $
          charsize = charsize, symsize = symsize

         IF wnd_set NE 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(0,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_OPLOT, tmpdata.time(indno), $
             tmpdata.htr(2,indno), $
             psym = 7, color=red
         ENDIF

         IF(keyword_set(UPDATE_LABEL)) THEN $
          WIDGET_CONTROL, update_label, $
          set_value = 'HZ-Transform vs. Time'

      END
;Plot HC-transform values
      18: BEGIN
         pia_plot, tmpdata.time, tmpdata.htr(3,*), $
          psym = psymch, $
          xtitle = xtitle, ytitle=ytitle,  $
          charsize = charsize, symsize = symsize

         IF wnd_set NE 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(0,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_OPLOT, tmpdata.time(indno), $
             tmpdata.htr(3,indno), $
             psym = 7, color=red
         ENDIF

         IF(keyword_set(UPDATE_LABEL)) THEN $
          WIDGET_CONTROL, update_label, $
          set_value = 'HC-Transform vs. Time'

      END
;Plot absolute gradient values
      19: BEGIN
         pia_plot, tmpdata.time, tmpdata.grad(0,*), $
          psym = psymch, $
          xtitle = xtitle, ytitle=ytitle,  $
          charsize = charsize, symsize = symsize

         IF wnd_set NE 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(0,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_OPLOT, tmpdata.time(indno), $
             tmpdata.grad(0,indno), $
             psym = 7, color=red
         ENDIF

         IF(keyword_set(UPDATE_LABEL)) THEN $
          WIDGET_CONTROL, update_label, $
          set_value = 'Absolute gradient vs. Time'

      END
;Plot gradient direction values
      20: BEGIN
         pia_plot, tmpdata.time, tmpdata.grad(2,*), $
          psym = psymch, $
          xtitle = xtitle, ytitle=ytitle,  $
          charsize = charsize, symsize = symsize

         IF wnd_set NE 0 THEN BEGIN
            indno = WHERE(tmpdata.smfl(0,*) AND flg_speed, nn)
            IF nn GT 0 THEN $
             PIA_OPLOT, tmpdata.time(indno), $
             tmpdata.grad(2,indno), $
             psym = 7, color=red
         ENDIF

         IF(keyword_set(UPDATE_LABEL)) THEN $
          WIDGET_CONTROL, update_label, $
          set_value = 'Gradient direction vs. Time'

      END

      ELSE: WIDGET_CONTROL, UPDATE_LABEL, $
       set_value = 'Unsupported View'
   ENDCASE

END

; ***************************************************************************
;  Event handling routine for PIA display menu
; ****************************************************************************

PRO pia_dsmc2_event, event

@adm
@phtcs
@phtsm
@phtsmc
@phtacc

   COMMON pia_dsp2smc_cmn, tmpdata, point_sources, lgal, bgal, dst, view, $
    viewsize, nviews, viewoptions, viewbut_ctrl, overid 
   COMMON pia_dsp2ch5_cmn, pixcho, pixop, pixres, psymch, pixcount
   COMMON dispcust_cmn, psym, line
   COMMON smc2text, dattext_id, newheader
   COMMON dsp2smc_widg, pixbut, wndcont, aficont, fpscont, epscont, winhtcont, $
    winbtcont, winbpcont, deglcont
   COMMON sm2_acc, wnd_set, back_set, degl_set, htr_set, afi_set, prc_set
   COMMON pia_sm_widget_info, smcdi1_wid, smcdi2_wid


   WIDGET_CONTROL, event.id, get_uvalue = uvalue
   WIDGET_CONTROL, event.top, /HOURGLASS

   CASE uvalue OF


      "EXIT":  BEGIN
         WIDGET_CONTROL, event.top, /DESTROY 
      END


      "HELP": BEGIN
         IF !VERSION.OS NE 'vms' THEN $
          spawn, 'w3net $PIA_HTML/um/smc_window.html &' ELSE $
          spawn, 'w3net /pia_dsk/pia/html/um/smc_window.html'
      END

      "CUST": BEGIN
         pia_dispcust, GROUP=event.top
         psymch = psym
         FOR I=0,NVIEWS-1 DO BEGIN
            pia_reset2view5, i, view(i).controlid
         ENDFOR
      END

      "LOAD": BEGIN
; search for same file and detector type
         newdata = pickmeas(FTYPE="SMC", DTYPE=tmpdata.det)
         IF newdata NE '' THEN BEGIN

            datind = WHERE(phtsmc.admn EQ newdata, count)

            IF count EQ 0 THEN $
             MESSAGE, /INFO, 'Measurement not found!'
            IF count GT 1 THEN BEGIN

               measlist = phtsmc(datind).admn
               pia_multmeas, measlist

               datind = datind(measlist)

            ENDIF
            IF count NE 0 THEN BEGIN 
               pia_sm_load_ismc, phtsmc(datind(0)), tmpsmc		
; header update
               newheader = tmpsmc.hdr

; create working stucture
               PIA_SM_PSEWORK_CREATE, tmpsmc, newheader, tmpdata
               
; create point source structure
               point_sources = { Point_Source }
               
; calculate galactic coords
               ra1 = tmpdata.ra
               dec1 = tmpdata.dec
               precess, ra1, dec1, 2000, 1950
               euler, ra1, dec1, lgal, bgal, 1
               
; set selection params according to data header in the beginning
               wnd_set = FXPAR(newheader,'PRSM_WND')
               back_set = FXPAR(newheader,'PRSM_BCK')
               degl_set = FXPAR(newheader,'PRSM_DEG')
               prc_set = FXPAR(newheader,'PRSM_PRC')
               htr_set = 0
               afi_set = 0

               obj = FXPAR(tmpdata.hdr,'OBJECT')
               attra = FXPAR(tmpdata.hdr,'ATTRA')
               attdec = FXPAR(tmpdata.hdr,'ATTDEC')
               decode_admn, tmpdata.admn, dattext
               more_text = 'OBJ:' + obj + '-RA:' + $
                STRTRIM(STRING(attra),2) + $
                '-DEC:' + STRTRIM(STRING(attdec),2)
               dattext = 'SMC '+dattext+ ' - '+$
                tmpdata.unit+ ' - ' + more_text

               WIDGET_CONTROL, dattext_id, SET_VALUE = dattext  

               WIDGET_CONTROL, deglcont, SENSITIVE = 0
               WIDGET_CONTROL, winhtcont, SENSITIVE = 0
               WIDGET_CONTROL, aficont, SENSITIVE = 0
               WIDGET_CONTROL, fpscont, SENSITIVE = 1
               IF prc_set EQ 0 THEN $
                WIDGET_CONTROL, epscont, SENSITIVE = 0 $
               ELSE $
                WIDGET_CONTROL, epscont, SENSITIVE = 1

               FOR i = 0, nviews-1 DO BEGIN
                  WIDGET_CONTROL, viewbut_ctrl(i,15), SENSITIVE = 0
                  WIDGET_CONTROL, viewbut_ctrl(i,16), SENSITIVE = 0
                  WIDGET_CONTROL, viewbut_ctrl(i,17), SENSITIVE = 0
                  WIDGET_CONTROL, viewbut_ctrl(i,18), SENSITIVE = 0
                  WIDGET_CONTROL, viewbut_ctrl(i,19), SENSITIVE = 0
                  WIDGET_CONTROL, viewbut_ctrl(i,20), SENSITIVE = 0
               ENDFOR

               IF back_set NE 0 THEN BEGIN
                  FOR i = 0, nviews-1 DO BEGIN
                     WIDGET_CONTROL, viewbut_ctrl(i,13), SENSITIVE = 1
                     WIDGET_CONTROL, viewbut_ctrl(i,14), SENSITIVE = 1
                  ENDFOR
                  WIDGET_CONTROL, winbtcont, SENSITIVE = 1
                  WIDGET_CONTROL, winbpcont, SENSITIVE = 1
               ENDIF $
               ELSE BEGIN
                  FOR i = 0, nviews-1 DO BEGIN
                     WIDGET_CONTROL, viewbut_ctrl(i,13), SENSITIVE = 0
                     WIDGET_CONTROL, viewbut_ctrl(i,14), SENSITIVE = 0
                  ENDFOR
                  WIDGET_CONTROL, winbtcont, SENSITIVE = 0
                  WIDGET_CONTROL, winbpcont, SENSITIVE = 0
               ENDELSE

               
               FOR i=0, NVIEWS - 1 DO pia_reset2view5, i
            ENDIF
         ENDIF
      END	                  	

      "SAVEI": BEGIN
         pia_sm_psework_to_phtismc, tmpdata, newheader, phtismc
         PIA_SM_WRITE_ISMC, phtismc, newheader  
         indcs = WHERE(phtcs.unit EQ STRMID(phtismc.admn,4,8), count)
         IF count GT 0 THEN BEGIN
            PIA_LOAD_ICS, phtcs(indcs(0)), tmpcs
            PIA_WRITE_ICS, tmpcs
         ENDIF ELSE MESSAGE, /INFO, $
          'Compact Status not found in common, not saved' 
      END

      "SAVEF": BEGIN
         pia_sm_psework_to_phtismc, tmpdata, newheader, phtismc
         WRITE_SMC, phtismc, newheader  
      END

      "SHOWD": PIA_SHOWSTR, tmpdata, VALNAMES=phtsmc_desc, GROUP=event.top 

      "SM_PAR": PIA_SM_SERPAR_SET, GROUP=event.top

      "SM_RESET": BEGIN
         PIA_SM_PSEWORK_INIT, tmpdata, newheader
         
         wnd_set = 0
         back_set = 0
         degl_set = 0
         htr_set = 0
         afi_set = 0
         prc_set = 0
         
; clear log files
         smp_slew = FXPAR(newheader,'FILENAME')
         smp_file = !PIA_SERDIR+smp_slew
         OPENW, logfp, smp_file+'.log', /GET_LUN, /DELETE
         FREE_LUN, logfp
         OPENW, objfp, smp_file+'.obj', /GET_LUN, /DELETE
         FREE_LUN, objfp
         OPENW, gaussfp, smp_file+'.gauss.log', /GET_LUN, /DELETE
         FREE_LUN, gaussfp

         WIDGET_CONTROL, deglcont, SENSITIVE = 0
         WIDGET_CONTROL, winbtcont, SENSITIVE = 0
         WIDGET_CONTROL, winbpcont, SENSITIVE = 0
         WIDGET_CONTROL, winhtcont, SENSITIVE = 0
         WIDGET_CONTROL, aficont, SENSITIVE = 0
         WIDGET_CONTROL, fpscont, SENSITIVE = 1
         WIDGET_CONTROL, epscont, SENSITIVE = 0

         FOR i = 0, nviews-1 DO BEGIN
            WIDGET_CONTROL, viewbut_ctrl(i,13), SENSITIVE = 0
            WIDGET_CONTROL, viewbut_ctrl(i,14), SENSITIVE = 0
            WIDGET_CONTROL, viewbut_ctrl(i,15), SENSITIVE = 0
            WIDGET_CONTROL, viewbut_ctrl(i,16), SENSITIVE = 0
            WIDGET_CONTROL, viewbut_ctrl(i,17), SENSITIVE = 0
            WIDGET_CONTROL, viewbut_ctrl(i,18), SENSITIVE = 0
            WIDGET_CONTROL, viewbut_ctrl(i,19), SENSITIVE = 0
            WIDGET_CONTROL, viewbut_ctrl(i,20), SENSITIVE = 0
         ENDFOR
         FOR i=0, NVIEWS - 1 DO pia_reset2view5, i
      END

      "SM_WND": BEGIN
         smfl = tmpdata.smfl
         pia_sm_wnd, tmpdata
         idisc = WHERE( (tmpdata.smfl(0,*) OR tmpdata.smfl(1,*) OR $
                       tmpdata.smfl(2,*) OR tmpdata.smfl(3,*)) AND $
                       NOT flg_pia_1, ndisc)
         IF ndisc GE tmpdata.dims - 20 THEN BEGIN
            XDISPLAYFILE, "", $
             TITLE = "Nearly all points discarded ", $
             WIDTH = 70, $
             HEIGHT = 4, $
             TEXT = [" WARNING: Nearly all points of this slew are discarded.", $
                     "          You should select a lower slew speed threshold!", $
                     "          Operation ignored!" ]
            tmpdata.smfl = smfl
            wnd_set = 0
         ENDIF $
         ELSE BEGIN
            wnd_set = 1
            FXADDPAR, newheader, 'PRSM_WND', wnd_set
            FXADDPAR, newheader, 'PRSM_VEL', smp_vel
            FOR i=0, NVIEWS - 1 DO pia_reset2view5, i
         ENDELSE
      END		   

      "SM_SENS": BEGIN
         pia_sm_sensitivity, tmpdata, /use_flux
         FXADDPAR, newheader, 'PRSM_STY', 1
         FXADDPAR, newheader, 'PRSM_SY1', tmpdata.sens(0)
         FXADDPAR, newheader, 'PRSM_SY2', tmpdata.sens(1)
         FXADDPAR, newheader, 'PRSM_SY3', tmpdata.sens(2)
         FXADDPAR, newheader, 'PRSM_SY4', tmpdata.sens(3)

         FOR i=0, NVIEWS - 1 DO pia_reset2view5, i
      END
      
      "SM_BACK": BEGIN
         pia_sm_background, tmpdata
         FXADDPAR, newheader, 'PRSM_BCK', 1
         FXADDPAR, newheader, 'PRSM_BIT', smp_bckit

         pia_sm_sensitivity, tmpdata, /use_back
         FXADDPAR, newheader, 'PRSM_STY', 2
         FXADDPAR, newheader, 'PRSM_SY1', tmpdata.sens(0)
         FXADDPAR, newheader, 'PRSM_SY2', tmpdata.sens(1)
         FXADDPAR, newheader, 'PRSM_SY3', tmpdata.sens(2)
         FXADDPAR, newheader, 'PRSM_SY4', tmpdata.sens(3)
         
         pia_sm_noise, tmpdata
         FXADDPAR, newheader, 'PRSM_GN1', tmpdata.gnoi(0)
         FXADDPAR, newheader, 'PRSM_GN2', tmpdata.gnoi(1)
         FXADDPAR, newheader, 'PRSM_GN3', tmpdata.gnoi(2)
         FXADDPAR, newheader, 'PRSM_GN4', tmpdata.gnoi(3)

         back_set = 1

         FOR i = 0, nviews-1 DO BEGIN
            WIDGET_CONTROL, viewbut_ctrl(i,13), SENSITIVE = 1
            WIDGET_CONTROL, viewbut_ctrl(i,14), SENSITIVE = 1
         ENDFOR

         WIDGET_CONTROL, winbtcont, SENSITIVE = 1
         WIDGET_CONTROL, winbpcont, SENSITIVE = 1
         FOR i=0, NVIEWS - 1 DO pia_reset2view5, i
      END

      "SM_HTR": BEGIN
         pia_sm_htr, tmpdata
         htr_set = 1
         WIDGET_CONTROL, deglcont, SENSITIVE = 1
         WIDGET_CONTROL, winhtcont, SENSITIVE = 1
         WIDGET_CONTROL, aficont, SENSITIVE = 1
         WIDGET_CONTROL, fpscont, SENSITIVE = 1

         FOR i = 0, nviews-1 DO BEGIN
            WIDGET_CONTROL, viewbut_ctrl(i,15), SENSITIVE = 1
            WIDGET_CONTROL, viewbut_ctrl(i,16), SENSITIVE = 1
            WIDGET_CONTROL, viewbut_ctrl(i,17), SENSITIVE = 1
            WIDGET_CONTROL, viewbut_ctrl(i,18), SENSITIVE = 1
            WIDGET_CONTROL, viewbut_ctrl(i,19), SENSITIVE = 1
            WIDGET_CONTROL, viewbut_ctrl(i,20), SENSITIVE = 1
         ENDFOR

         FOR i=0, NVIEWS - 1 DO pia_reset2view5, i
      END

      "SM_DEGL": BEGIN
         pia_sm_degl, tmpdata
         degl_set = 1
         FXADDPAR, newheader, 'PRSM_DEG', 1
         FXADDPAR, newheader, 'PRSM_SGL', smp_snrgl
         FXADDPAR, newheader, 'PRSM_SPL', smp_snrpgl
         tmpdata.hdr = newheader
         FOR i=0, NVIEWS - 1 DO pia_reset2view5, i
      END

      "WIN_ST": BEGIN
         view(0).viewtype = 0
         pia_reset2view5, 0, view(0).controlid
         view(1).viewtype = 0
         pia_reset2view5, 1, view(1).controlid
         view(2).viewtype = 0
         pia_reset2view5, 2, view(2).controlid
         view(3).viewtype = 0
         pia_reset2view5, 3, view(3).controlid
      END
      
      "WIN_SP": BEGIN
         view(0).viewtype = 1
         pia_reset2view5, 0, view(0).controlid
         view(1).viewtype = 1
         pia_reset2view5, 1, view(1).controlid
         view(2).viewtype = 1
         pia_reset2view5, 2, view(2).controlid
         view(3).viewtype = 1
         pia_reset2view5, 3, view(3).controlid
      END
      
      "WIN_BT": BEGIN
         view(0).viewtype = 13
         pia_reset2view5, 0, view(0).controlid
         view(1).viewtype = 13
         pia_reset2view5, 1, view(1).controlid
         view(2).viewtype = 13
         pia_reset2view5, 2, view(2).controlid
         view(3).viewtype = 13
         pia_reset2view5, 3, view(3).controlid
      END
      
      "WIN_BP": BEGIN
         view(0).viewtype = 14
         pia_reset2view5, 0, view(0).controlid
         view(1).viewtype = 14
         pia_reset2view5, 1, view(1).controlid
         view(2).viewtype = 14
         pia_reset2view5, 2, view(2).controlid
         view(3).viewtype = 14
         pia_reset2view5, 3, view(3).controlid
      END
      
      "WIN_SME": BEGIN
         view(0).viewtype = 4
         pia_reset2view5, 0, view(0).controlid
         view(1).viewtype = 5
         pia_reset2view5, 1, view(1).controlid
         view(2).viewtype = 9
         pia_reset2view5, 2, view(2).controlid
         view(3).viewtype = 11
         pia_reset2view5, 3, view(3).controlid
      END
      
      "WIN_SMG": BEGIN
         view(0).viewtype = 6
         pia_reset2view5, 0, view(0).controlid
         view(1).viewtype = 7
         pia_reset2view5, 1, view(1).controlid
         view(2).viewtype = 10
         pia_reset2view5, 2, view(2).controlid
         view(3).viewtype = 11
         pia_reset2view5, 3, view(3).controlid
      END
      
      "WIN_HT": BEGIN
         view(0).viewtype = 15
         pia_reset2view5, 0, view(0).controlid
         view(1).viewtype = 16
         pia_reset2view5, 1, view(1).controlid
         view(2).viewtype = 17
         pia_reset2view5, 2, view(2).controlid
         view(3).viewtype = 18
         pia_reset2view5, 3, view(3).controlid
      END

      "HDR": BEGIN
         header = newheader
         IF N_ELEMENTS(header) EQ 0 THEN $
          MESSAGE, /INFO, 'No header defined' ELSE $
          pia_disp_hdr, header, tmpdata.admn, 'PHTSMC'
      END

      "CS": PIA_disp_cs,tmpdata.admn

      "ISREP": PIA_disp_isr,STRMID(tmpdata.admn,4,8)

      "SLEWMAP": BEGIN
         pia_sm_slewshow, tmpdata
      END

      "SLICES": BEGIN

         npix = 4
         nslice = N_ELEMENTS(tmpdata.flx(0,*))

         decode_admn, tmpdata.admn, tmpmeas

         PIA_XPLOT, indgen(npix) + 1, tmpdata.flx(0:npix-1,0), $
          TITLE='Time development of surf. brightness - '+$
          tmpmeas, xtitle=' Pixel # ', $
          ytitle='Surface brightness [MJy/sr]', $
          psym=10

         zoom_color = 1

         IF nslice GT 1 THEN BEGIN
            FOR I=1, nslice-1 DO BEGIN
               zoom_color = zoom_color + 1
               IF zoom_color EQ 9 THEN zoom_color = 1
               WAIT,0.5
               PIA_XPLOT, indgen(npix) + 1, tmpdata.flx(0:npix-1,i),$
                /overplot, color=zoom_color, psym=10
            ENDFOR
         ENDIF 
      END	  	 	

      "SLICES_3D": BEGIN

         npix = 4

         decode_admn, tmpdata.admn, tmpmeas

         PIA_XSurface, tmpdata.flx(0:npix-1,*), $
          title='Time evol. of surf. brightness - '+tmpmeas, $
          xtitle=' Pixel # ', ytitle='Time    [s]', $
          ztitle='Surface brightness [MJy/sr]', charsize=1.25, $
          wlego=1

      END	  	 	

      "SM_AFI": BEGIN         
         pia_sm_afi, tmpdata
         afi_set = 1
         FOR i=0, NVIEWS - 1 DO pia_reset2view5, i
      END

      "SM_FPSC": BEGIN
         pia_sm_psfind, tmpdata
         prc_set = 1
         FXADDPAR, newheader, 'PRSM_PRC', 1
         WIDGET_CONTROL, epscont, SENSITIVE = 1
         FOR i=0, NVIEWS - 1 DO pia_reset2view5, i
      END

      "SM_EPSC": BEGIN
         pia_sm_psfit, tmpdata, point_sources
         pia_sm_plot, tmpdata, point_sources

         WIDGET_CONTROL, deglcont, SENSITIVE = 0
         WIDGET_CONTROL, aficont, SENSITIVE = 0
         WIDGET_CONTROL, fpscont, SENSITIVE = 0
         WIDGET_CONTROL, epscont, SENSITIVE = 0
         FOR i=0, NVIEWS - 1 DO pia_reset2view5, i
      END

      "IRASPSC": BEGIN
         dist_max = 2.0d0/60. ; maximal source distance 2 arcmin
         pia_sm_disp_psc_list, tmpdata, dist_max
      END

      "IRASGAL": BEGIN
         dist_max = 2.0d0/60. ; maximal source distance 2 arcmin
         pia_sm_disp_irasgal_list, tmpdata, dist_max
      END

      "PIXCH": BEGIN
         old_pixcho = pixcho
         new_pixc = pia_pixchoice(GROUP=event.top, PIXC=pixcho)
         maxpix = max(new_pixc)
         minpix = min(new_pixc)
         junk = 0
         IF (tmpdata.det EQ 'C2' AND maxpix GT 3) OR $
          (minpix LT 0)  THEN BEGIN
            XDISPLAYFILE, "", $
             GROUP = event.top, $
             TITLE = "Warning ", $
             WIDTH = 30, $
             HEIGHT = 6, $
             TEXT = [" Your pixel choice is not valid ", $
                     " and will not be taken "]
            junk = 1
         ENDIF
         IF junk NE 1 THEN BEGIN  			
            FOR I=0,NVIEWS-1 DO BEGIN
               IF new_pixc(i) NE old_pixcho(i) THEN BEGIN
                  pixcho(i) = new_pixc(i)
                  WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
                  view(i).windownum = temp
                  pia_reset2view5, i, view(i).controlid
                  txtval = STRTRIM(STRING(i+1),2)
                  junk = where(new_pixc EQ old_pixcho(i), count)
                  IF count EQ 0 THEN $
                   WIDGET_CONTROL, pixbut(old_pixcho(i)), $
                   SET_VALUE = ' '
                  WIDGET_CONTROL, pixbut(pixcho(i)), $
                   SET_VALUE = txtval
               ENDIF
            ENDFOR
         ENDIF
      END

      "PIXCHSER": BEGIN
         old_pixcho = pixcho
         new_pixc = old_pixcho + nviews
         npix = 4
         new_pixc = new_pixc MOD npix
         
         FOR I=0,NVIEWS-1 DO BEGIN
            IF new_pixc(i) NE old_pixcho(i) THEN BEGIN
               pixcho(i) = new_pixc(i)
               WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
               view(i).windownum = temp
               pia_reset2view5, i, view(i).controlid
               txtval = STRTRIM(STRING(i+1),2)
               junk = where(new_pixc EQ old_pixcho(i), count)
               IF count EQ 0 THEN $
                WIDGET_CONTROL, pixbut(old_pixcho(i)), $
                SET_VALUE = ' '
               WIDGET_CONTROL, pixbut(pixcho(i)), $
                SET_VALUE = txtval
            ENDIF
         ENDFOR
      END

      "NVIEWS": BEGIN

         newviews = event.value + 1
         IF newviews NE nviews THEN BEGIN
            WIDGET_CONTROL, smcdi2_wid, /DESTROY
            pia_sm_dis2smc, NV = newviews, /redraw
         ENDIF
      END


      "HK" : BEGIN
         get_pht_hk,tmpdata.admn,phtcs_redu
         xdisp_hk
      END

   ENDCASE
   
   RETURN
END

; ****************************************************************************
;  PIA SM_Dis2SMC - menu definition procedure
; ****************************************************************************

PRO pia_sm_dis2SMC, GROUP=group, DATA=DATA, NV = NV, REDRAW=redraw


   COMMON pia_dsp2smc_cmn, tmpdata, point_sources, lgal, bgal, dst, view, $
    viewsize, nviews, viewoptions, viewbut_ctrl, overid 
   COMMON pia_dsp2ch5_cmn, pixcho, pixop, pixres, psymch, pixcount
   COMMON smc2text, dattext_id, newheader
   COMMON dsp2smc_widg, pixbut, wndcont, aficont, fpscont, epscont, winhtcont, $
    winbtcont, winbpcont, deglcont
   COMMON sm2_acc, wnd_set, back_set, degl_set, htr_set, afi_set, prc_set
   COMMON pia_sm_widget_info, smcdi1_wid, smcdi2_wid

; If already registered, start second SMC display

   IF Xregistered("pia_sm_dis2smc") NE 0 THEN BEGIN
      WIDGET_CONTROL, smcdi2_wid, /DESTROY
      RETURN
   END


   IF NOT KEYWORD_SET(redraw) THEN BEGIN
; load data from dynamical buffers into temporary structure
      PIA_SM_LOAD_ISMC, DATA, tmpsmc
      newheader = tmpsmc.hdr
      
; load work structure
      PIA_SM_PSEWORK_CREATE, tmpsmc, newheader, tmpdata

; create point source structure
      point_sources = { Point_Source }

; calculate slew speed
      ra = tmpdata.ra
      dec = tmpdata.dec
      dst = ra * 0.D0
      FOR i = 1, tmpdata.dims - 1 DO $
       dst(i) = dst(i-1) + sphdist(ra(i-1),dec(i-1),ra(i),dec(i))

; calculate galactic coords
      precess, ra, dec, 2000, 1950
      euler, ra, dec, lgal, bgal, 1
      
; set selection params according to data header in the beginning
      wnd_set = FXPAR(newheader,'PRSM_WND')
      back_set = FXPAR(newheader,'PRSM_BCK')
      degl_set = FXPAR(newheader,'PRSM_DEG')
      prc_set = FXPAR(newheader,'PRSM_PRC')
      htr_set = 0
      afi_set = 0
   ENDIF

; initialize file names of output files
         smp_slew = FXPAR(newheader,'FILENAME')
         smp_file = !PIA_SERDIR+smp_slew

; initialize views and pixels chosen
   IF KEYWORD_SET(NV) THEN NVIEWS = nv ELSE nviews = 4
   IF nviews GT 4 THEN nviews = 4
   pixcount = -1


   psymch = 4	
   pixcho = [1,2,3,0]
   pixop = 4
   pixres = 5

   viewsize = 220
   xsize = viewsize * 4 / nviews
   ysize = viewsize

   viewinstance = {vinst2, viewtype:0b, 	$ ;structure for   
                   controlid:0L,	$ ;each view	
                   windowid:0L,	$
                   windownum:0}	

   view = REPLICATE(viewinstance, NVIEWS) ; array of view struct.

   IF STRMID(tmpdata.det, 0,1) EQ 'P' THEN $
    FOR i=0,nviews-1 DO view(i).viewtype = i

   instance = {vopt2, viewname:'', $
               viewid:0, viewxlab:'', $
               viewylab:'' }    ;structures describing
   NVIEWOPTS = 21               ;each type of view 

   viewoptions = REPLICATE(instance, NVIEWOPTS)    
   viewbut_ctrl = LONARR(nviews,nviewopts)

   viewoptions(0).viewname = "Surf. Brightness vs. Time  " 
   viewoptions(0).viewid = 0
   viewoptions(0).viewylab = "Surf. Brightness [MJy/sr] "
   viewoptions(0).viewxlab = "Time        [s]"
   viewoptions(1).viewname = "Surf. Brightness vs. Pos.  "
   viewoptions(1).viewid = 1
   viewoptions(1).viewylab = "Surf. Brightness [MJy/sr] "
   viewoptions(1).viewxlab = "Slew pos. [degr]"
   viewoptions(2).viewname = "Serendipity Flag           "
   viewoptions(2).viewid = 2
   viewoptions(2).viewylab = "SeM Flag                  "
   viewoptions(2).viewxlab = "Time         [s]"
   viewoptions(3).viewname = "Time Key                   "
   viewoptions(3).viewid = 3
   viewoptions(3).viewylab = "Instrument Time Key       "
   viewoptions(3).viewxlab = "Time         [s]"
   viewoptions(4).viewname = "RA (equ, J2000) vs. Time   "
   viewoptions(4).viewid = 4
   viewoptions(4).viewylab = "RA     [degrees]"
   viewoptions(4).viewxlab = "Time         [s]"
   viewoptions(5).viewname = "DEC (equ, J2000) vs. Time  "
   viewoptions(5).viewid = 5
   viewoptions(5).viewylab = "DEC    [degrees]"
   viewoptions(5).viewxlab = "Time         [s]"
   viewoptions(6).viewname = "l (galactic) vs. Time      "
   viewoptions(6).viewid = 6
   viewoptions(6).viewylab = "l      [degrees]"
   viewoptions(6).viewxlab = "Time         [s]"
   viewoptions(7).viewname = "b (galactic) vs. Time      "
   viewoptions(7).viewid = 7
   viewoptions(7).viewylab = "b      [degrees]"
   viewoptions(7).viewxlab = "Time         [s]"
   viewoptions(8).viewname = "Roll Angle vs. Time        "
   viewoptions(8).viewid = 8
   viewoptions(8).viewylab = "ROLL   [degrees]"
   viewoptions(8).viewxlab = "Time         [s]"
   viewoptions(9).viewname = "DEC vs. RA (equ, J2000)    "
   viewoptions(9).viewid = 9
   viewoptions(9).viewylab = "DEC    [degrees]"
   viewoptions(9).viewxlab = "RA     [degrees]"
   viewoptions(10).viewname = "b vs. l (galactic)         "
   viewoptions(10).viewid = 10
   viewoptions(10).viewylab = "b      [degrees]"
   viewoptions(10).viewxlab = "l      [degrees]"
   viewoptions(11).viewname = "Position vs. Time          "
   viewoptions(11).viewid = 11
   viewoptions(11).viewylab = "Slew pos. [degr]"
   viewoptions(11).viewxlab = "Time         [s]"
   viewoptions(12).viewname = "Slew speed vs. Time        "
   viewoptions(12).viewid = 12
   viewoptions(12).viewylab = "Slew speed ['/s]"
   viewoptions(12).viewxlab = "Time         [s]"
   viewoptions(13).viewname = "Background vs. Time"
   viewoptions(13).viewid = 13
   viewoptions(13).viewylab = "Background [MJy/sr]"
   viewoptions(13).viewxlab = "Time            [s]"
   viewoptions(14).viewname = "Background vs. Pos."
   viewoptions(14).viewid = 14
   viewoptions(14).viewylab = "Background [MJy/sr]"
   viewoptions(14).viewxlab = "Slew pos. [degrees]"
   viewoptions(15).viewname = "H0-Transform vs. Time      "
   viewoptions(15).viewid = 15
   viewoptions(15).viewylab = "H0      [MJy/sr]"
   viewoptions(15).viewxlab = "Time         [s]"
   viewoptions(16).viewname = "HY-Transform vs. Time      "
   viewoptions(16).viewid = 16
   viewoptions(16).viewylab = "HY      [MJy/sr]"
   viewoptions(16).viewxlab = "Time         [s]"
   viewoptions(17).viewname = "HZ-Transform vs. Time      "
   viewoptions(17).viewid = 17
   viewoptions(17).viewylab = "HZ      [MJy/sr]"
   viewoptions(17).viewxlab = "Time         [s]"
   viewoptions(18).viewname = "HC-Transform vs. Time      "
   viewoptions(18).viewid = 18
   viewoptions(18).viewylab = "HC      [MJy/sr]"
   viewoptions(18).viewxlab = "Time         [s]"
   viewoptions(19).viewname = "Absolute Gradient vs. Time "
   viewoptions(19).viewid = 19
   viewoptions(19).viewylab = "Gradient [MJy/sr]"
   viewoptions(19).viewxlab = "Time         [s]"
   viewoptions(20).viewname = "Gradient Direction vs. Time"
   viewoptions(20).viewid = 20
   viewoptions(20).viewylab = "Grad. Dir. [degr]"
   viewoptions(20).viewxlab = "Time         [s]"

; top base

   smcdi2_wid = WIDGET_BASE( TITLE="PIA SMC 2nd Data Display", /COLUMN, $
                             XPAD = 20, YPAD = 20, SPACE = 20)

; control windows

   control = WIDGET_BASE(smcdi2_wid, /ROW)

   control_exit = WIDGET_BUTTON(control, VALUE="    Exit    ",$
                                UVALUE="EXIT")
   control_help = WIDGET_BUTTON(control, VALUE="    Help    ",$
                                UVALUE="HELP")
   control_cust = WIDGET_BUTTON(control, VALUE="  Customize ",$
                                UVALUE="CUST")


   junk = WIDGET_LABEL(control, VALUE = '     ')

   obj = FXPAR(tmpdata.hdr,'OBJECT')
   attra = FXPAR(tmpdata.hdr,'ATTRA')
   attdec = FXPAR(tmpdata.hdr,'ATTDEC')
   decode_admn, tmpdata.admn, dattext
   more_text = 'OBJ:' + obj + '-RA:' + STRTRIM(STRING(attra),2) + $
    '-DEC:' + STRTRIM(STRING(attdec),2)
   dattext = 'SMC '+dattext+ ' - '+tmpdata.unit+ ' - ' + more_text
   dattext_id = WIDGET_LABEL(control, VALUE = dattext)  

;------------------- the C mapping windows -------------------------

   junk = WIDGET_LABEL(control, VALUE = '     ')

   pixver = WIDGET_BASE(control, /COLUMN)
   junk = WIDGET_LABEL(pixver, VALUE='^ +Z')

   pixhor = WIDGET_BASE(pixver,/ROW)
   
   pixbut = intarr(4)
   FOR i=0,1 DO pixbut(i+2) = $
    WIDGET_BUTTON(pixhor, VALUE=' ',$
                  XOFFSET=3*i, $
                  UVALUE=i+2,$
                  EVENT_PRO = 'pixbut2event5')
   pixhor = WIDGET_BASE(pixver,/ROW,YOFFSET=10)
   FOR i=1,0,-1 DO pixbut(i) = $
    WIDGET_BUTTON(pixhor, VALUE=' ',$
                  XOFFSET=3*i, $
                  UVALUE=i,$
                  EVENT_PRO = 'pixbut2event5')
   junk = WIDGET_LABEL(pixhor, VALUE='> +Y') 

;----------------- the View windows are defined ------------------

   viewbase = WIDGET_BASE(smcdi2_wid, /ROW, SPACE=20)

   viewstorageids = LONARR(NVIEWS)
   overid = lonarr(NVIEWS)	   

   FOR viewindex = 0, NVIEWS - 1 DO BEGIN
      tempbase = WIDGET_BASE(viewbase, /FRAME, /COLUMN, $
                             EVENT_PRO = 'view2event5')
      view(viewindex).controlid = WIDGET_BUTTON(tempbase, VALUE="   ",$
                                                MENU = 2, UVALUE = viewindex, $
                                                EVENT_PRO = 'view2event5')
      view(viewindex).windowid = WIDGET_DRAW(tempbase, $
                                             XSIZE = xsize, YSIZE = ysize, $
                                             RETAIN = 2) 
      FOR i = 0, NVIEWOPTS - 1 DO BEGIN
         viewbut_ctrl(viewindex,i) = $
          WIDGET_BUTTON(view(viewindex).controlid, $
                        VALUE = viewoptions(i).viewname, UVALUE = i)
      ENDFOR

      zoombase = WIDGET_BASE(tempbase, /FRAME, /ROW)
      zoom = WIDGET_BUTTON(zoombase, $
                           VALUE = "Zoom & Print", $
                           UVALUE = viewindex, MENU = 2)

      dummy = WIDGET_BUTTON(zoom, $
                            VALUE = "New  Window", $
                            UVALUE = viewindex, EVENT_PRO = 'zoom2event5')

      synch = WIDGET_BUTTON(zoom, $
                            VALUE = "Overplot, same y-axis  ", $
                            UVALUE = viewindex, EVENT_PRO = 'zoom2sync5')
      nsynch = WIDGET_BUTTON(zoom, $
                             VALUE = "Overplot, new y-axis", $
                             UVALUE = viewindex, EVENT_PRO = 'zoomn2sync5')

      process = WIDGET_BUTTON(zoombase, $
                              VALUE = "Test processing", $
                              UVALUE = viewindex, MENU = 2)

      fourier = WIDGET_BUTTON(process, $
                              VALUE = "Fourier", $
                              UVALUE = viewindex, EVENT_PRO = 'zoom2fourier5')

      average = WIDGET_BUTTON(process, $
                              VALUE = "Average", $
                              UVALUE = viewindex, EVENT_PRO = 'average2nonch5')

      median = WIDGET_BUTTON(process, $
                             VALUE = "Median", $
                             UVALUE = viewindex, EVENT_PRO = 'median2nonch5')

   ENDFOR

   controlbase = WIDGET_BASE(smcdi2_wid, $
                             /ROW, $
                             SPACE = 40)


;----------------- the Data controls are defined ------------------

   datcont = WIDGET_BUTTON(controlbase, VALUE='Data', /MENU )
   id_2 = WIDGET_BUTTON(datcont, VALUE='Load', UVALUE='LOAD' )
   id_2 = WIDGET_BUTTON(datcont, VALUE='Save', /MENU )
   id_3 = WIDGET_BUTTON(id_2, VALUE='to PIA internal file', $
                        UVALUE='SAVEI' )
   id_3 = WIDGET_BUTTON(id_2, VALUE='to FITS external file', $
                        UVALUE='SAVEF' )
   id_2 = WIDGET_BUTTON(datcont, VALUE='Show Data', UVALUE='SHOWD' )

;---------------- the Selection controls are defined -----------------

   selcont = WIDGET_BUTTON(controlbase, VALUE='Selection', /MENU )
   id_2 = WIDGET_BUTTON(selcont, VALUE='Edit Serendipity parameters', $
                        UVALUE='SM_PAR')
   id_2 = WIDGET_BUTTON(selcont, VALUE='Reset flags and sensitivities', $
                        UVALUE='SM_RESET')
   wndcont = WIDGET_BUTTON(selcont, VALUE='Discard low-speed parts', $
                           UVALUE='SM_WND')

;---------------- the Correction controls are defined -----------------

   corrcont = WIDGET_BUTTON(controlbase, VALUE='Correction', /MENU )
   statcont = WIDGET_BUTTON(corrcont, VALUE='Global Statistics', /MENU)
   id_2 = WIDGET_BUTTON(statcont, VALUE='Sensitivity Calculation', $
                        UVALUE='SM_SENS')
   id_2 = WIDGET_BUTTON(statcont, VALUE=$
                        'Background/Sensitivity/Noise Calculation', $
                        UVALUE='SM_BACK')
   id_2 = WIDGET_BUTTON(corrcont, VALUE='Compute H-Transform ', $
                        UVALUE='SM_HTR' )
   deglcont = WIDGET_BUTTON(corrcont, VALUE='Deglitching', $
                            UVALUE='SM_DEGL')

;---------------- the Windows controls are defined -----------------

   windcont = WIDGET_BUTTON(controlbase, VALUE='Windows', /MENU )
   id_2 = WIDGET_BUTTON(windcont, VALUE='Surf. Brightness vs. Time', $
                        UVALUE='WIN_ST')
   id_2 = WIDGET_BUTTON(windcont, VALUE='Surf. Brightness vs. Slew Pos.', $
                        UVALUE='WIN_SP')
   winbtcont = WIDGET_BUTTON(windcont, VALUE='Background vs. Time', $
                             UVALUE='WIN_BT')
   winbpcont = WIDGET_BUTTON(windcont, VALUE='Background vs. Slew Pos.', $
                             UVALUE='WIN_BP')
   id_2 = WIDGET_BUTTON(windcont, VALUE='Sky Map, equatorial', $
                        UVALUE='WIN_SME')
   id_2 = WIDGET_BUTTON(windcont, VALUE='Sky Map, galactic', $
                        UVALUE='WIN_SMG')
   winhtcont = WIDGET_BUTTON(windcont, VALUE='H-Transforms', $
                             UVALUE='WIN_HT')

;---------------- the View controls are defined -----------------

   viewcont = WIDGET_BUTTON(controlbase, VALUE='View', /MENU )
   id_2 = WIDGET_BUTTON(viewcont, VALUE='Header Info ', UVALUE='HDR')
   id_2 = WIDGET_BUTTON(viewcont, VALUE='Compact Status ', UVALUE='CS')
   id_2 = WIDGET_BUTTON(viewcont, VALUE='IS Report ', UVALUE='ISREP')
   id_2 = WIDGET_BUTTON(viewcont, VALUE='Slewmap ', UVALUE='SLEWMAP')

;---------------- the Array controls are defined -----------------

   arraycont = WIDGET_BUTTON(controlbase, VALUE='Array', /MENU )
   id_2 = WIDGET_BUTTON(arraycont, VALUE='Time evolution', /MENU)
   id_3 = WIDGET_BUTTON(id_2, VALUE='Time slices ', UVALUE='SLICES')
   id_3 = WIDGET_BUTTON(id_2, VALUE='3-D view ', UVALUE='SLICES_3D')

   
;---------------- the Point Source Extractor controls are defined -------

   psccont = WIDGET_BUTTON(controlbase, VALUE='Point Sources', /MENU)
   aficont = WIDGET_BUTTON(psccont, VALUE='Apply adaptive filtering ', $
                           UVALUE='SM_AFI' )
   fpscont = WIDGET_BUTTON(psccont, VALUE='Find point source candidates ', $
                           UVALUE='SM_FPSC' )
   epscont = WIDGET_BUTTON(psccont, VALUE='Extract point sources ', $
                           UVALUE='SM_EPSC' )
   id_2 = WIDGET_BUTTON(psccont, VALUE='IRAS Point Sources ', UVALUE='IRASPSC')
   id_2 = WIDGET_BUTTON(psccont, VALUE='IRAS Galaxies & Quasars ', $
                        UVALUE='IRASGAL')

;---------------- the Pixel Choice controls are defined -----------------

   pixcont = WIDGET_BUTTON(controlbase, VALUE='Pixels', $
                           /MENU)
   pixch = WIDGET_BUTTON(pixcont, VALUE='Individual choice ', $
                         UVALUE='PIXCH' )
   pixch = WIDGET_BUTTON(pixcont, VALUE='Serial increment  ', $
                         UVALUE='PIXCHSER' )

;---------------- the number of views controls is defined -----------------

   nvbut = cw_bselector(controlbase, $
                        /FRAME, SET_VALUE=NVIEWS-1, $
                        UVALUE = 'NVIEWS', $
                        ['1 Plot', $
                         '2 Plots', $
                         '3 Plots', $
                         '4 Plots'])

;----------------------------------------------------------------------

   hkbutton=widget_button(controlbase,value=' HK ', uvalue ='HK')

;----------------------------------------------------------------------


; Realize widget

   WIDGET_CONTROL, smcdi2_wid, /REALIZE, /HOURGLASS

   WIDGET_CONTROL, deglcont, SENSITIVE = 0
   WIDGET_CONTROL, winhtcont, SENSITIVE = 0
   WIDGET_CONTROL, aficont, SENSITIVE = 0
   WIDGET_CONTROL, fpscont, SENSITIVE = 1
   IF prc_set EQ 0 THEN $
    WIDGET_CONTROL, epscont, SENSITIVE = 0

   FOR i = 0, nviews-1 DO BEGIN
      WIDGET_CONTROL, viewbut_ctrl(i,15), SENSITIVE = 0
      WIDGET_CONTROL, viewbut_ctrl(i,16), SENSITIVE = 0
      WIDGET_CONTROL, viewbut_ctrl(i,17), SENSITIVE = 0
      WIDGET_CONTROL, viewbut_ctrl(i,18), SENSITIVE = 0
      WIDGET_CONTROL, viewbut_ctrl(i,19), SENSITIVE = 0
      WIDGET_CONTROL, viewbut_ctrl(i,20), SENSITIVE = 0
   ENDFOR

   IF back_set EQ 0 THEN BEGIN
      FOR i = 0, nviews-1 DO BEGIN
         WIDGET_CONTROL, viewbut_ctrl(i,13), SENSITIVE = 0
         WIDGET_CONTROL, viewbut_ctrl(i,14), SENSITIVE = 0
      ENDFOR
      WIDGET_CONTROL, winbtcont, SENSITIVE = 0
      WIDGET_CONTROL, winbpcont, SENSITIVE = 0
   ENDIF

   IF nviews NE 4 THEN WIDGET_CONTROL, windcont, SENSITIVE = 0

   FOR i = 0, nviews - 1 DO BEGIN
      WIDGET_CONTROL, view(i).windowid, GET_VALUE = temp
      view(i).windownum = temp
      pia_reset2view5, i, view(i).controlid
      IF STRMID(tmpdata.det,0,1) EQ 'C' THEN BEGIN
         txtval = STRTRIM(STRING(i+1),2)
         WIDGET_CONTROL, pixbut(pixcho(i)), SET_VALUE = txtval
      ENDIF
   ENDFOR

   idisc = WHERE(tmpdata.flag(0,*) EQ 2 OR tmpdata.flag(1,*) EQ 2 OR $
                 tmpdata.flag(2,*) EQ 2 OR tmpdata.flag(3,*) EQ 2, ndisc)
   IF ndisc GE tmpdata.dims - 5 THEN $
    XDISPLAYFILE, "", $
    TITLE = "Nearly all points discarded ", $
    WIDTH = 70, $
    HEIGHT = 3, $
    TEXT = [" WARNING: Nearly all points of this slew are discarded.", $
            "          There is not very much you can do with it!" ]

   XManager, /NO_BLOCK, "pia_sm_dis2smc", smcdi2_wid, $
    EVENT_HANDLER = "pia_dsmc2_event", GROUP_LEADER=GROUP


   RETURN
END



