;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
PRO pia_sm_flatfield, isignal, osignal
;+
; NAME:
;       PIA_SM_FLATFIELD
;
; PURPOSE:
;	This routine applies a default flatfield to Serendipity SRD data
;
; CATEGORY:
;       PIA - processing
;
; CALLING SEQUENCE:
;       PIA_SM_FLATFIELD, Input_signal, Detector_name, Output_signal
;
; INPUTS:
;       Input_signal: A 2-dim array. The first dim is the number of pixels
;
; OUTPUTS:
;       Output_signal: Same dim as the input signal with the flatfield
;                      correction
;
; COMMON BLOCKS:
;       c200_srd_flat
;
; RESTRICTIONS:
;
; PROCEDURE:
;
; PROCEDURES USED:
;
; MODIFICATION HISTORY:
;       Written by:	Stefan Bogun
;                       August 1997
;	Modified (last) by SB:	December 1997
;       absolute path for the cal file 'c200_flat_corr_pixel1.sav' 
;                                                        (SB)  December 1997
;-

   ON_ERROR, 2

   COMMON c200_srd_flat, c200_flat_corr
   IF N_ELEMENTS(c200_flat_corr) EQ 0 THEN $
    RESTORE,'/data/serend/Software/calsave/c200_flat_corr_pixel1.sav'


   OSIGNAL = ISIGNAL

   FOR i=0,3 DO BEGIN
      SIGI = ISIGNAL(I,*)
      OSIGNAL(I,*) = c200_flat_corr(I,0) + c200_flat_corr(I,1)*SIGI + $
                     c200_flat_corr(I,2)*SIGI^2 + c200_flat_corr(I,3)*SIGI^3
   ENDFOR 

   END
      
