        PRO PIA_SM_load_ISMC , SMCDAT, tmpsmc 
;+
; NAME:
;       PIA_SM_load_ISMC
; PURPOSE:
;	Write a PHT-SMC (Serendipity Mode Calibrated Data) measurement from the dynamical 
;	structure SMCDAT (PHTSMC type) onto a temporary structure 
; CALLING SEQUENCE:
;       PIA_SM_load_ISMC, SMCDAT, tmpsmc
;
; INPUT:
;       SMCDAT 	: PHTSMC like dynamical structure
;
;
; RESTRICTIONS:
;       SMCDAT must exist
;
; PROCEDURES USED: 
;
; MODIFICATION HISTORY:
;       Written by P. Merluzzi                      	August 1995
;       Sky coordinates and roll angle                  August 1995
;       uncertainties added
;	updated according to new SMC structure		(SB, 26/07/96)
;	updated according to new SMC structure		(SB, 28/01/97)
;-
;
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 2 THEN MESSAGE, $
          'Syntax:  PIA_SM_load_ISMC, SMCDAT, tmpsmc'

;  Fill temporary variables from the handles
        HANDLE_VALUE, SMCDAT.HDR, HDR 
	HANDLE_VALUE, SMCDAT.TKEY, TKEY 
        HANDLE_VALUE, SMCDAT.TIME, TIME
        HANDLE_VALUE, SMCDAT.FLX, FLX
        HANDLE_VALUE, SMCDAT.FLXU, FLXU
        HANDLE_VALUE, SMCDAT.BACK, BACK
        HANDLE_VALUE, SMCDAT.NOIS, NOIS
        HANDLE_VALUE, SMCDAT.FLAG, FLAG
        HANDLE_VALUE, SMCDAT.SMFL, SMFL 
        HANDLE_VALUE, SMCDAT.RA, RA
        HANDLE_VALUE, SMCDAT.RAU, RAU
        HANDLE_VALUE, SMCDAT.DEC, DEC
        HANDLE_VALUE, SMCDAT.DECU, DECU
        HANDLE_VALUE, SMCDAT.ROLL, ROLL
        HANDLE_VALUE, SMCDAT.ROLU, ROLU
  
;  Fill the ISMC structure
	NAME = SMCDAT.ADMN
	
	tmpsmc = {UNIT: SMCDAT.UNIT, $     
        DET: SMCDAT.DET, $     
	ADMN: NAME, $
        ORDR: SMCDAT.ORDR, $ 
        DIMS: SMCDAT.DIMS, $
	HDR: [HDR], $
	TKEY: [TKEY], $
	TIME: [TIME], $
	FLX: [FLX], $
	FLXU: [FLXU], $
	BACK: [BACK], $
	NOIS: [NOIS], $
	FLAG: [FLAG], $
	SMFL: [SMFL], $
	RA: [RA], $
	RAU: [RAU], $
	DEC: [DEC], $
	DECU: [DECU], $
	ROLL: [ROLL], $
	ROLU: [ROLU]}

        RETURN
END

