;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_SM_PSEWORK_INIT
;
; PURPOSE:
;       Initializes a PIA Serendipity working structure
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       PIA_SM_PSEWORK_INIT, PSEWORK, HDR
;
; INPUTS:
;       PSEWORK: PIA Serendipity working structure
;       HDR:     PHTISMC header
;
; KEYWORD PARAMETERS:
;
; OUTPUTS:
;	PSEWORK: PIA Serendipity working structure
;       HDR:     PHTISMC header
;
; COMMON BLOCKS:
;	phtsm:		Serendipity dynamical structure
;
; PROCEDURES USED:
;
; MODIFICATION HISTORY:
;       Written by: 	Stefan Bogun (MPIA)			February 1997
;
;       correct initialization of SMFL flag                     (SB, 03/04/97)
;-

PRO PIA_SM_PSEWORK_INIT, psework, hdr

@phtsm

   psework.sens(*) = 1.0D0
   psework.back(*) = 0.0D0
   psework.nois(*) = 0.0D0
   psework.gnoi(*) = 0.0D0
   psework.smfl(*) = 0B

; initialize Serendipity flag
   ifl = WHERE(psework.flag EQ 1, nfl)
   IF nfl NE 0 THEN psework.smfl(ifl) = flg_pia_1 ; discarded by PIA
   ifl = WHERE(psework.flag EQ 2, nfl)
   IF nfl NE 0 THEN psework.smfl(ifl) = flg_pia_2 ; discarded by PIA

   FXADDPAR, hdr, 'PRSM_WND', 0
   FXADDPAR, hdr, 'PRSM_VEL', 0
   FXADDPAR, hdr, 'PRSM_STY', 0
   FXADDPAR, hdr, 'PRSM_SY1', 1.0
   FXADDPAR, hdr, 'PRSM_SY2', 1.0
   FXADDPAR, hdr, 'PRSM_SY3', 1.0
   FXADDPAR, hdr, 'PRSM_SY4', 1.0
   FXADDPAR, hdr, 'PRSM_BCK', 0
   FXADDPAR, hdr, 'PRSM_BIT', 0
   FXADDPAR, hdr, 'PRSM_GN1', 0.0
   FXADDPAR, hdr, 'PRSM_GN2', 0.0
   FXADDPAR, hdr, 'PRSM_GN3', 0.0
   FXADDPAR, hdr, 'PRSM_GN4', 0.0
   FXADDPAR, hdr, 'PRSM_DEG', 0
   FXADDPAR, hdr, 'PRSM_SGL', 0
   FXADDPAR, hdr, 'PRSM_SPL', 0
   FXADDPAR, hdr, 'PRSM_PRC', 0

   RETURN
END
