;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_SM_PSEWORK_TO_PHTISMC
;
; PURPOSE:
;       Stores the data from a PIA Serendipity working structure back to
;       a phtismc structure
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       PIA_SM_PSEWORK_INIT, PSEWORK, HDR, PHTISMC
;
; INPUTS:
;	PSEWORK: PIA Serendipity working structure
;       HDR:     PHTISMC header
;
; KEYWORD PARAMETERS:
;
; OUTPUTS:
;       PHTISMC: PIA phtismc structure
;
; COMMON BLOCKS:
;
; PROCEDURES USED:
;
; MODIFICATION HISTORY:
;       Written by: 	Stefan Bogun (MPIA)			February 1997
;-

PRO PIA_SM_PSEWORK_TO_PHTISMC, psework, hdr, phtismc

   unit = psework.unit
   det = psework.det
   admn = psework.admn
   ordr = psework.ordr
   dims = psework.dims
   tkey = psework.tkey
   time = psework.time
   flx = psework.flx
   flxu = psework.flxu
   back = psework.back
   nois = psework.nois
   flag = psework.flag
   smfl = psework.smfl
   ra = psework.ra
   rau = psework.rau
   dec = psework.dec
   decu = psework.decu
   roll = psework.roll
   rolu = psework.rolu

   phtismc = { unit:unit, $
               det: det, $
               admn: admn, $
               ordr: ordr, $
               dims: dims, $
               hdr: hdr, $
               tkey: tkey, $
               time: time, $
               flx: flx, $
               flxu: flxu, $
               back: back, $
               nois: nois, $
               flag: flag, $
               smfl: smfl, $
               ra: ra, $
               rau: rau, $
               dec: dec, $
               decu: decu, $
               roll: roll, $
               rolu: rolu }

   RETURN
END



