





Pro  PIA_SM_SEPREP,   WorkStructure,  _EXTRA=EXTRA
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

;+
; NAME:
;        PIA_SM_SEPREP
;
; PURPOSE:
;        Main Routine for Modeling of Background, equalizing sensitivities and
;        calculating global statistics of Serendipity Slews
;
; CATEGORY:
;        ISOPHOT, PIA, Serendipity Survey
;
; CALLING SEQUENCE:
;        PIA_SM_SEPREP, PHT_SM_WorkStructure
;
; INPUTS:
;        PHT_SM_WorkStructure
;
; KEYWORD PARAMETERS:
;        any keyword parameters are passed to all other routines
;
; OUTPUTS:
;        Results are written to
;               WorkStructure.back     (Background)
;               WorkStructure.sens     (Sensitivity Factors)
;               WorkStructure.gnoi     (Global Noise data)
;
; COMMON BLOCKS:
;
; PROCEDURES USED:
;        PIA_SM_Background
;        PIA_SM_Sensitivity
;        PIA_SM_Noise
;
; NOTES:
;
; REVISION HISTORY:
;        Written   Ver 1.0     M. Stickel, MPIA/IDC    December 18, 1996
;        Written   Ver 1.1     M. Stickel, MPIA/IDC    April, 1997
;-




; /* include Serendipity Dynamical Structure /*

@phtsm


print, ' <pia_sm_seprep> starting ... '

; /* ... debugging needed ? */

InternalDebug = 0
If (Keyword_set (Debug))  $
   then begin
      InternalDebug = 1
   endif

; /* copy needed data from workstructure to temporary arrays */

SM_Flux   = WorkStructure.flx (*,*)
SM_Flags  = WorkStructure.smfl (*,*)

; /* get size of data */

Dimen = Size (SM_Flux)
NoPixels = Dimen (1)
NoData   = Dimen (2)

; /* get the different flags separately */

PIA1Flags     = SM_Flags (*,*)  AND  flg_pia_1
PIA2Flags     = SM_Flags (*,*)  AND  flg_pia_2
GlitchFlags   = SM_Flags (*,*)  AND  flg_glitch
PSESrcFlags   = SM_Flags (*,*)  AND  flg_source
PSCandFlags   = SM_Flags (*,*)  AND  flg_srccand

LowSpeedFlags = SM_Flags (*,*)  AND  flg_speed

; /* cut out the interesting high speed part of the slew              */
; /* for the background a few additional points are used on each side */

HighSpeedIndex = Where (LowSpeedFlags (0,*)  NE   flg_speed)

HighSpeedFrom  = HighSpeedIndex (0)
HighSpeedUntil = HighSpeedIndex (N_Elements (HighSpeedIndex)-1)


; /* check for PIA2 flags and ignore 'em at both ends  */

PIA2StartGood = IntArr (NoPixels)
PIA2EndGood   = IntArr (NoPixels)

PIA2StartGood (*) = HighSpeedFrom
PIA2EndGood   (*) = HighSpeedUntil

For i = 0 , NoPixels-1  do begin

CheckPIA2left:
   If (PIA2Flags (i , HighSpeedFrom)  eq  flg_pia_2)  $
      then begin
   	 For l = HighSpeedFrom , HighSpeedUntil , 1   do begin
   	    If (PIA2Flags (i , l) ne flg_pia_2)  $
   	       then begin
   		  PIA2StartGood (i) = l
   		  Goto , CheckPIA2right
   	       endif
   	 EndFor
      endif

CheckPIA2right:
   If (PIA2Flags (i , HighSpeedUntil)  eq  flg_pia_2)   $
      then begin
   	 For l = HighSpeedUntil , HighSpeedFrom , -1   do begin
   	    If (PIA2Flags (i , l) ne flg_pia_2)  $
   	       then begin
   		  PIA2EndGood (i) = l
   		  Goto , CheckPIAend
   	       endif
   	 EndFor
      endif

CheckPIAend:

EndFor

FitFrom  = PIA2StartGood (*)
FitUntil = PIA2EndGood (*)

If (InternalDebug eq 1)  $
   then begin
      print, ' <pia_sm_background> HighSPeedFrom, HighSpeedUntil = ' , HighSpeedFrom , HighSpeedUntil
      print, ' <pia_sm_background> FitFrom  = ' , FitFrom
      print, ' <pia_sm_background> FitUntil = ' , FitUntil
   endif


; /* prepare the masks from other processing steps */

PIA_SM_ConvSMFlagsMask,   SM_Flags, FitFlagMask, /Good

PartitionFlags = 0 * (FitFlagMask (*,*)) + 1
For i = 0 , NoPixels-1  do begin
   PIA2Index      = Where (PIA2Flags(i,*)    eq  flg_pia_2,   NoPIA2)
   If (NoPIA2   gt 0)    then  PartitionFlags (i,PIA2Index) = 0
EndFor

;;  >> ; /* get the estimation of slew background    */
;;  >>
;;  >> PIA_SM_Background,  SM_Flux, FitFlagMask, PartitionFlags, FitFrom, FitUntil,    $
;;  >>                   Background, OutlierMask,   $
;;  >>                   _EXTRA=EXTRA, /FilterMorph
;;  >> ;;;               /OnlySecond, _EXTRA=EXTRA , /PLOT
;;  >> ;;;               /OnlySecond, /Plot, /debug, _EXTRA=EXTRA
;;  >>

; /* get the estimation of slew background    */


print, ' <pia_sm_seprep> calling background ... '

PIA_SM_NewBackground,  SM_Flux, FitFlagMask, PartitionFlags, FitFrom, FitUntil,    $
                  Background, Noise, FinalSigma, $
                  _EXTRA=EXTRA, /FilterMorph
;;                  _EXTRA=EXTRA, /FilterMorph , /Debug




; /* put all the stuff back into workstructure */

WorkStructure.back (*,*)   = SM_Flux (*,*)
For i = 0 , NoPixels-1  do begin
   WorkStructure.back (i,FitFrom(i):FitUntil(i)) = Background (i,FitFrom(i):FitUntil(i))
EndFor
SM_Back  = WorkStructure.back (*,*)


;window,/free
Diff = SM_Flux - SM_Back
Diffsum = Diff (0,*) +  Diff (1,*) +  Diff (2,*) +  Diff (3,*)
;Diffsum = abs (Diff (0,*) *  Diff (1,*) *  Diff (2,*) *  Diff (3,*))
For i = 0 , N_elements(Diffsum)-1  do begin
   Diffsum (i) = pia_sm_med ([Diff(0,i), Diff(1,i), Diff(2,i), Diff(3,i)])
;;   Diffsum (i) = (Diff(0,i)+Diff(1,i)+Diff(2,i)+Diff(3,i)) - $
;;                 max([Diff(0,i), Diff(1,i), Diff(2,i), Diff(3,i)])
Endfor





;;  >>
;;  >> ; /* Merge GoodMask with OutlierMask from Backfit */
;;  >>
;;  >> PIA_SM_ConvSMFlagsMask,   SM_Flags, GoodMask, /Good
;;  >>
;;  >> For i = 0 , NoPixels-1  do begin
;;  >>    IndexOutlier =  Where (OutlierMask (i,*) GT 0, NOutlier)
;;  >>    IF (NOutlier GT 0)  $
;;  >>       THEN BEGIN
;;  >>          GoodMask (i , IndexOutlier) = 0
;;  >>       ENDIF
;;  >> EndFor
;;  >>
;;  >>



; /* make a good mask from the difference flux-back */

PIA_SM_ConvSMFlagsMask,   SM_Flags, GoodMask, /Good

FOR  i= 0 , NoPixels-1 , 1  DO BEGIN

   HighThresh = 5.0 * FinalSigma(i)

   Difference =  Transpose (SM_Flux (i,*) - SM_Back (i,*))

   PIA_SM_1D_OutlierRazor,  Difference, OutputVals, NOutVals,   $
      		         Mask_Outliers, HighThresh=HighThresh , /absolute , /cutvalue

   OutlierIndex =  Where (Mask_Outliers GT 0 , NOutlier)
   IF (NOutlier GT 0)   $
      THEN BEGIN
         GoodMask (i,OutlierIndex) = 0
      ENDIF

   IF (FitFrom  (i) GT 0)       THEN GoodMask (i,0:FitFrom(i)-1) = 0
   IF (FitUntil (i) LT NoData)  THEN GoodMask (i,(FitUntil(i)+1):NoData-1) = 0

ENDFOR




; /* relative scaling of estimated background */

print, ' <pia_sm_seprep> calling sensitivity ... '

ScaleFactors = PIA_SM_Sensitivity  (Background , GoodMask, _EXTRA=EXTRA)

WorkStructure.sens (*)  = ScaleFactors (*)




; /* global statistics  */

print, ' <pia_sm_seprep> calling noise ... '

Difference              = SM_Flux - SM_Back

PIA_SM_Noise,  Difference, GoodMask, GlobalStatistics,  $
               SlewNoise, _EXTRA=EXTRA
;;;;               SlewNoise, _EXTRA=EXTRA , /Debug

WorkStructure.gnoi (*)  = GlobalStatistics (*,1)

WorkStructure.nois (*,*) = SlewNoise (*,*)




; /* ... debugging needed ? */

If (InternalDebug eq 1)  $
   then begin
      print, ' <pia_sm_stat> Scalefactors = ' , Scalefactors
      print, ' <pia_sm_stat> Globalstatistics = ' , globalstatistics
   endif



; /* ... well done ! */


print, ' <pia_sm_seprep> ended ... '



Return
End






















Pro      PIA_SM_SESAME,      workstructure,    _EXTRA=EXTRA
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


; /* include Serendipity Dynamical Structure /*

@phtsm

print, ' <pia_sm_sesame> starting ... '

; /* use SubPixel - Fitting /*

SubPixelUsed =  'Y'
SubPixelUsed =  'N'


; /* ... debugging needed ? */

InternalDebug = 0
If (Keyword_set (Debug))  $
   then begin
      InternalDebug = 1
   endif



If (InternalDebug eq 1)  $
   then begin
      print, ' <pia_sm_fitfind> UseFrom / UseUntil = ' , UseFrom , UseUntil
   endif


; /* copy flags from workstructure to temporary array */

SM_Flags  = WorkStructure.smfl (*,*)

PIA_SM_ConvSMFlagsMask,   SM_Flags, GoodMask, /Good

UseFrom  = Min (Where (GoodMask (0 , *)  GT  0))
UseUntil = Max (Where (GoodMask (0 , *)  GT  0))


; /* copy needed data from workstructure to temporary arrays */

Flux        = WorkStructure.flx  (* , UseFrom:UseUntil)
FluxErr     = WorkStructure.flxu (* , UseFrom:UseUntil)
Back        = WorkStructure.back (* , UseFrom:UseUntil)
RACenter    = WorkStructure.ra   (UseFrom:UseUntil)
DecCenter   = WorkStructure.dec  (UseFrom:UseUntil)
RAPosit     = WorkStructure.rap  (* , UseFrom:UseUntil)
DecPosit    = WorkStructure.decp (* , UseFrom:UseUntil)
RollAngle   = WorkStructure.roll (UseFrom:UseUntil)
GlobalNoise = WorkStructure.gnoi (*)
SlewNoise   = WorkStructure.nois (*,UseFrom:UseUntil)
SlewName    = WorkStructure.admn

; /* get the pixel and subpixel coordinates */

PIA_SM_PixelCoord,   RACenter, DecCenter, RollAngle,  RAPosit, DecPosit,  $
                     RAPixelCorn, DecPixelCorn
;;                     /Rectangular


PIA_SM_SubPixelCoord,   RACenter, DecCenter, RollAngle,    $
                        RASubPixel, DecSubPixel
;;                     /Rectangular



; /* get size of data */

Dimen   = Size (Flux)
NPixels = Dimen (1)
NData   = Dimen (2)

CosmicMask =  IntArr (NPixels , NData)
CosmicMask (*,*) = 0

SumDiff      = FltArr (NData)

DiffFlux     = Flux (*,*) - Back (*,*)
SmCLDiffFlux = 0.0 * DiffFlux (*,*)

Sensitiv = WorkStructure.sens (*)
For i = 0 , NPixels-1  do begin
   DiffFlux (i,*) = DiffFlux (i,*) * Sensitiv (i)
   Back     (i,*) = Back     (i,*) * Sensitiv (i)
   Flux     (i,*) = Flux     (i,*) * Sensitiv (i)
EndFor

PIA_SM_SelectDetectPixels,   GlobalNoise, UsePixelIndex


For i = 0 , NPixels-1  do begin

   Diff = Transpose (DiffFlux (i,*))

   PIA_SM_CosmicCleaner, Diff, MaskCosmic, CleanDiff, $
			      FilterSize=1, Neighbors=3,             $
			      FindThresh=5.0,  RemoveThresh=4.0,       $
			      Degree=4

   CosmicMask (i,*) =  MaskCosmic (*)

   PIA_SM_Filter,   CleanDiff,  SmClDiff , /Hanning

   DiffFlux (i,*)     = CleanDiff (*)

   SmCLDiffFlux (i,*) = SmClDiff (*)

   SumDiff (*) = SumDiff (*) + (Float(UsePixelIndex(i)) * SmClDiff (*))

EndFor

SumDiff (*) = 0.25 * SumDiff (*)

; *** added (SB, 08/07/97) ***
SMFlagUsed = SM_Flags(* , UseFrom:UseUntil)
IndexGlitch = where(CosmicMask NE 0, NGlitch)
IF NGlitch GT 0 THEN BEGIN
   SMFlagUsed(IndexGlitch) = SMFlagUsed(IndexGlitch) OR flg_glitch
   WorkStructure.smfl  (* , UseFrom:UseUntil) = SMFlagUsed
ENDIF

;; plot, sumdiff, /xst, /yst, title='sumdiff'


GoodMask = IntArr (NPixels , NData)
GoodMask (*,*) = 1


SumDiffSigma = PIA_SM_ROBUST_SIGMA  (SumDiff)

TooNegativ = Where (SumDiff LT  (-4.0 * SumDiffSigma) , NTooNegativ)
IF (NTooNegativ GT 0)  THEN  SumDiff(TooNegativ) =  0.0

SumDiffSigma = PIA_SM_ROBUST_SIGMA  (SumDiff)

PIA_SM_WMR_Filtering , SumDiff, WaveFiltSumDiff, WaveFiltNoise,   $
                SumDiffFinalSigma, Thresh=5.,              $
                NoIter=10, Notrans=7 ,                     $
                InitSigma=SumDiffSigma , /Robust

;;SumDiffSigma = SumDiffFinalSigma
;;WMR_Filtering , SumDiff, WaveFiltSumDiff, WaveFiltNoise, SumDiffFinalSigma, thresh=5.,    $
;;                NoIter=10, Notrans=7 , InitSigma=SumDiffSigma



PIA_SM_RunningSigma,  WaveFiltNoise, RunningSigma, 100


yvec = RunningSigma
xvec = Findgen(n_elements(RunningSigma))
FitPara =  PIA_SM_ROBUST_POLY_FIT (XVec , YVec , 2 , YFit)
RunningSigma = YFit

PIA_SM_WMR_FilteringVecSig , SumDiff, WaveFiltSumDiff,     $
                      WaveFiltNoise, SumDiffFinalSigma, thresh=3.,    $
                      NoIter=10, Notrans=7 , InitSigma=RunningSigma , /Robust



PIA_SM_Morph_1D_Process, WaveFiltSumDiff , MorphWaveFiltSumDiff , 33 , 9 , 1 , /gauss , /tophat


Detectthresh = 3.0 * SumDiffFinalSigma
LowThresh    = 0.3 * SumDiffFinalSigma

PIA_SM_OutlierInterval,  MorphWaveFiltSumDiff, CumuSrcMask ,        $
                         StartWindows , EndWindows,                 $
                         NWindows , HighCut=DetectThresh, LowCut=LowThresh


;;>>
;;>>
;;>> PIA_SM_1D_OutlierRazor,  MorphWaveFiltSumDiff , ClippedSumDiff, NClipData, CumuSrcMask,      $
;;>>                          HighThresh=DetectThresh, LowThresh=LowThresh,                  $
;;>>                          /CUTVALUE,  /PLOT, _EXTRA=EXTRA
;;>>
;;>> ScrMask = Max(WaveFiltSumDiff) - (0.1 * CumuSrcMask * (Max(WaveFiltSumDiff)-Min(WaveFiltSumDiff)))
;;>> ;;--OPlot, ScrMask, psym=10
;;>>
;;>>


;; -->>Detectthresh = 3.0 * SumDiffFinalSigma
;; -->>PIA_SM_ClippMask,    WaveFiltSumDiff, CumuSrcMask, HighCut=Detectthresh



IF ((SubPixelUsed EQ "Y")  OR   (SubPixelUsed EQ "y"))  $
   THEN BEGIN
      PIA_SM_SourceEstimator, Flux, FluxErr, DiffFlux, Back, GoodMask, CumuSrcMask,   $
                           RAPosit, DecPosit, RollAngle, RASubPixel, DecSubPixel,     $
                           Fit1DResults, Peaks, Sigmas, FWHMs, Centres,               $
                           GlobalNoise, Fit2DInputs, Fit2DResults,                    $
                           SrcParams, UncSrcParams,                                   $
                           SrcStart, SrcEnd, SrcFitStart, SrcFitEnd, NWinds,      $
                           UsedPixels, ChiSqVec, NoFitPointsVec, Distances,           $
                           /Gauss2DPlane, /SubPixel,       $
                           _EXTRA=EXTRA



   ENDIF ELSE BEGIN
      PIA_SM_SourceEstimator, Flux, FluxErr, DiffFlux, Back, GoodMask, CumuSrcMask,   $
                           RAPosit, DecPosit, RollAngle, RASubPixel, DecSubPixel,     $
                           Fit1DResults, Peaks, Sigmas, FWHMs, Centres,               $
                           GlobalNoise, Fit2DInputs, Fit2DResults,                    $
                           SrcParams, UncSrcParams,                                   $
                           SrcStart, SrcEnd, SrcFitStart, SrcFitEnd, NWinds,      $
                           UsedPixels, ChiSqVec, NoFitPointsVec, Distances,           $
                           /Gauss2DPlane,        $
                           _EXTRA=EXTRA
   ENDELSE


IF ((SubPixelUsed EQ "Y")  OR   (SubPixelUsed EQ "y"))  $
   THEN BEGIN
      PIA_SM_Plotter, SlewName, Flux, (Flux-Back), Back,               $
                DiffFlux, FluxErr, SlewNoise, SumDiff, WaveFiltSumDiff,     $
	        WaveFiltNoise, RunningSigma, CosmicMask,    $
                Fit2DInputs, Fit2DResults, Fit1DResults,  $
   		SrcParams, UncSrcParams, CumuSrcMask,            $
                SrcStart, SrcEnd, SrcFitStart, SrcFitEnd, NWinds,         $
                RACenter, DecCenter, RollAngle,                  $
                RAPosit, DecPosit ,  RAPixelCorn , DecPixelCorn, $
   		/SubPixel, _EXTRA=EXTRA
   ENDIF ELSE BEGIN
      PIA_SM_Plotter, SlewName, Flux, (Flux-Back), Back,               $
                DiffFlux, FluxErr, SlewNoise, SumDiff, WaveFiltSumDiff,     $
	        WaveFiltNoise, RunningSigma, CosmicMask,     $
                Fit2DInputs, Fit2DResults, Fit1DResults,         $
   		SrcParams, UncSrcParams, CumuSrcMask,            $
                SrcStart, SrcEnd, SrcFitStart, SrcFitEnd, NWinds,         $
                RACenter, DecCenter, RollAngle,                  $
                RAPosit, DecPosit ,  RAPixelCorn , DecPixelCorn, $
   		_EXTRA=EXTRA
   ENDELSE



If (NWinds gt 0)  $
   then begin
      IF ((SubPixelUsed EQ "Y")  OR   (SubPixelUsed EQ "y"))  $
         THEN BEGIN
            PIA_SM_Logger,  Flux, DiffFlux, FluxErr, Back,                    $
                      SrcParams, UncSrcParams, ChiSqVec, NoFitPointsVec,      $
                      Fit2DInputs, Fit2DResults, Src1DFitParams,              $
                      SrcStart, SrcEnd, SrcFitStart, SrcFitEnd, NWinds,       $
   		      UsedPixels, SlewName, GlobalNoise, Sensitiv,            $
   		      Distances, /Gauss2DPlane, /SubPixel, _EXTRA=EXTRA

         ENDIF ELSE BEGIN
            PIA_SM_Logger,  Flux, DiffFlux, FluxErr, Back,                    $
                      SrcParams, UncSrcParams, ChiSqVec, NoFitPointsVec,      $
                      Fit2DInputs, Fit2DResults, Src1DFitParams,              $
                      SrcStart, SrcEnd, SrcFitStart, SrcFitEnd, NWinds,       $
   		      UsedPixels, SlewName, GlobalNoise, Sensitiv,            $
   		      Distances, /Gauss2DPlane, _EXTRA=EXTRA
         ENDELSE


   endif



PIA_SM_Saver, SlewName, Flux, (Flux-Back), Back,               $
                DiffFlux, FluxErr, SlewNoise, SumDiff, WaveFiltSumDiff,     $
	        WaveFiltNoise, RunningSigma, CosmicMask,     $
                Fit2DInputs, Fit2DResults, Fit1DResults,         $
   		SrcParams, UncSrcParams, CumuSrcMask,            $
                SrcStart, SrcEnd, SrcFitStart, SrcFitEnd, NWinds, $
   		UsedPixels, GlobalNoise, Sensitiv, Distances,    $
                RACenter, DecCenter, RollAngle,                  $
                RAPosit, DecPosit ,  RAPixelCorn , DecPixelCorn, $
   		_EXTRA=EXTRA



print, ' <pia_sm_sesame> ended ... '

Return
End










