


Pro   PIA_SM_WMR_FilteringVecSig,    Data,  FilteredData, NoiseData, FinalSigma,     $
                              ThreshHold=ThreshHold,                          $
                              NoIterations=NoIterations, InitSigma=InitSigma, $
                              Convergence=Convergence,                        $
                              NoTransformLevels=NoTransformLevels,            $
                              Absolute=Absolute, RobustSigma=RobustSigma,     $
                              DataSupport=DataSupport,                        $
                              Plot=Plot, Debug=Debug, _EXTRA=EXTRA
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

; allows InitSigma as vector



InternalDebug = 0
If (Keyword_set (Debug))  $
   then begin
      InternalDebug = 1
   endif


NData            = N_Elements (Data)

FilteredData     = FltArr (NData)
FilteredData (*) = 0.0

NoiseData        = FltArr (NData)
NoiseData (*)    = 0.0

FinalSigma       =  0.0

ProcSigma        = FltArr (NData)
If (N_Elements (InitSigma) le 0)  $
   then begin
     If (     Keyword_Set (RobustSigma))   $
        then BEGIN
           ProcSigma (*) = PIA_SM_ROBUST_SIGMA (Data)
        ENDIF


     If (NOT  Keyword_Set (RobustSigma))   $
        THEN BEGIN
           PIA_SM_MeanSigma, Data, Average, DataSigma
           ProcSigma (*) = DataSigma
        ENDIF

   endif
If (N_Elements (InitSigma) gt 0)  then  ProcSigma (*) = InitSigma (*)


if  (KEYWORD_SET (DEBUG))  or  (InternalDebug eq 1)  then begin
   print, ' <WMR-Filtering> procsigma = ' , procsigma
endif


ProcThresh = 3.0
If (N_Elements (ThreshHold) gt 0)  then  ProcThresh = ThreshHold

ProcConvergence = 1.0E-4
If (N_Elements (Convergence) gt 0)  then  ProcConvergence = Convergence

ProcIterations = 10
If (N_Elements (NoIterations) gt 0)  then ProcIterations = NoIterations

ProcTransLevels = 7
If (N_Elements (NoTransformLevels) gt 0)  then ProcTransLevels = NoTransformLevels


If (Keyword_Set (DataSupport))  $
   then begin
      PIA_SM_ATROU_1D_WaveletTransform,   Data, DataTransform,    $
                                   ProcTransLevels, /MirrorPadding

      If (Keyword_Set (Absolute))  $
         then begin
             PIA_SM_MultiResolSupportVecSig,   DataTransform, ProcSigma, ProcThresh,   $
                                        ProcTransLevels, DataSupport,    $
                                        /tabular , /absolute
      	 endif else begin
             PIA_SM_MultiResolSupportVecSig,   DataTransform, ProcSigma, ProcThresh,   $
                                        ProcTransLevels, DataSupport,    $
                                        /tabular
      	 endelse

   endif



For i = 0 , ProcIterations  do begin

   if  (KEYWORD_SET (DEBUG))  or  (InternalDebug eq 1)  then begin
      print, ' <WMR-Filtering>  ... running iteration ' , i
   endif

   ErrorData = Data (*) - FilteredData (*)

   if (i eq 0)  $
      then begin
         SigmaErrorOld = PIA_SM_ROBUST_SIGMA (ErrorData)
      endif else begin
         SigmaErrorNew = PIA_SM_ROBUST_SIGMA (ErrorData)
         If ((N_Elements (Convergence) gt 0)   AND   $
             (abs ((SigmaErrorOld - SigmaErrorNew) / SigmaErrorOld) lt ProcConvergence))  then  Return
         SigmaErrorOld = SigmaErrorNew
      endelse


   If (NOT  Keyword_Set (DataSupport))  $
      then begin
      	 PIA_SM_ATROU_1D_WaveletTransform,    ErrorData , ErrorTransform ,    $
                                       ProcTransLevels , /MirrorPadding

      	 If (Keyword_Set (Absolute))  $
      	     then begin
      		PIA_SM_MultiResolSupportVecSig, ErrorTransform, ProcSigma, ProcThresh,   $
                                         ProcTransLevels, ErrorSupport,   $
                                         /tabular , /absolute
      	     endif else begin
      		PIA_SM_MultiResolSupportVecSig, ErrorTransform, ProcSigma, ProcThresh,   $
                                         ProcTransLevels, ErrorSupport, /tabular
      	     endelse

      	 if (i eq 0)  $
      	    then begin
      	       CumuErrorSupport = ErrorSupport
      	    endif else begin
      	       CumuErrorSupport = CumuErrorSupport + ErrorSupport
      	    endelse

      	 PIA_SM_MultiResolCoeffRetain,   ErrorTransform, CumuErrorSupport, ErrorKeptCoeff

      	 PIA_SM_MultiResolReconstruct,   ErrorKeptCoeff, ErrorReconstruct

      	 FilteredData (*) = FilteredData (*) + ErrorReconstruct (*)

         If (Keyword_set (Plot))  $
            then begin
               plot , FilteredData (*) , title='wavelet filtering ...'
            endif

      endif

   If (Keyword_Set (DataSupport))  $
      then begin
      	 PIA_SM_ATROU_1D_WaveletTransform,    ErrorData , ErrorTransform ,   $
                                       ProcTransLevels , /MirrorPadding

      	 PIA_SM_MultiResolCoeffRetain,   ErrorTransform, DataSupport, ErrorKeptCoeff

      	 PIA_SM_MultiResolReconstruct,   ErrorKeptCoeff, ErrorReconstruct

      	 FilteredData (*) = FilteredData (*) + ErrorReconstruct (*)

         If (Keyword_set (Plot))  $
            then begin
               plot , FilteredData (*) , title='wavelet filtering ...'
            endif
      endif

EndFor

NoiseData (*) = Data (*) - FilteredData (*)

If (     Keyword_Set (RobustSigma))   $
   then    FinalSigma = PIA_SM_ROBUST_SIGMA (NoiseData)

If (NOT  Keyword_Set (RobustSigma))   $
   then    PIA_SM_MeanSigma, NoiseData, Average, FinalSigma

If (Keyword_set (Plot))  $
   then begin
      plot , NoiseData (*) , title='noise from wavelet filtering ...'
   endif

Return
End










Pro   PIA_SM_WMR_Filtering,          Data,  FilteredData, NoiseData, FinalSigma,     $
                              ThreshHold=ThreshHold,                          $
                              NoIterations=NoIterations, InitSigma=InitSigma, $
                              Convergence=Convergence,                        $
                              NoTransformLevels=NoTransformLevels,            $
                              Absolute=Absolute, RobustSigma=RobustSigma,     $
                              DataSupport=DataSupport,                        $
                              Plot=Plot, Debug=Debug, _EXTRA=EXTRA
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


InternalDebug = 0
If (Keyword_set (Debug))  $
   then begin
      InternalDebug = 1
   endif


NData            = N_Elements (Data)

FilteredData     = FltArr (NData)
FilteredData (*) = 0.0

NoiseData        = FltArr (NData)
NoiseData (*)    = 0.0

FinalSigma       =  0.0

If (N_Elements (InitSigma) le 0)  $
   then begin
     If (     Keyword_Set (RobustSigma))   $
        then    ProcSigma = PIA_SM_ROBUST_SIGMA (Data)

     If (NOT  Keyword_Set (RobustSigma))   $
        then    PIA_SM_MeanSigma, Data, Average, ProcSigma
   endif
If (N_Elements (InitSigma) gt 0)  then  ProcSigma = InitSigma


if  (KEYWORD_SET (DEBUG))  or  (InternalDebug eq 1)  then begin
   print, ' <WMR-Filtering> procsigma = ' , procsigma
endif


ProcThresh = 3.0
If (N_Elements (ThreshHold) gt 0)  then  ProcThresh = ThreshHold

ProcConvergence = 1.0E-4
If (N_Elements (Convergence) gt 0)  then  ProcConvergence = Convergence

ProcIterations = 10
If (N_Elements (NoIterations) gt 0)  then ProcIterations = NoIterations

ProcTransLevels = 7
If (N_Elements (NoTransformLevels) gt 0)  then ProcTransLevels = NoTransformLevels


If (Keyword_Set (DataSupport))  $
   then begin
      PIA_SM_ATROU_1D_WaveletTransform,   Data, DataTransform,    $
                                   ProcTransLevels, /MirrorPadding

      If (Keyword_Set (Absolute))  $
         then begin
             PIA_SM_MultiResolSupport,   DataTransform, ProcSigma, ProcThresh,   $
                                  ProcTransLevels, DataSupport,    $
                                  /tabular , /absolute
      	 endif else begin
             PIA_SM_MultiResolSupport,   DataTransform, ProcSigma, ProcThresh,   $
                                  ProcTransLevels, DataSupport,    $
                                  /tabular
      	 endelse

   endif



For i = 0 , ProcIterations  do begin

   if  (KEYWORD_SET (DEBUG))  or  (InternalDebug eq 1)  then begin
      print, ' <WMR-Filtering>  ... running iteration ' , i
   endif

   ErrorData = Data (*) - FilteredData (*)

   if (i eq 0)  $
      then begin
         SigmaErrorOld = PIA_SM_ROBUST_SIGMA (ErrorData)
      endif else begin
         SigmaErrorNew = PIA_SM_ROBUST_SIGMA (ErrorData)
         If ((N_Elements (Convergence) gt 0)   AND   $
             (abs ((SigmaErrorOld - SigmaErrorNew) / SigmaErrorOld) lt ProcConvergence))  then  Return
         SigmaErrorOld = SigmaErrorNew
      endelse


   If (NOT  Keyword_Set (DataSupport))  $
      then begin
      	 PIA_SM_ATROU_1D_WaveletTransform,    ErrorData , ErrorTransform ,    $
                                       ProcTransLevels , /MirrorPadding

      	 If (Keyword_Set (Absolute))  $
      	     then begin
      		PIA_SM_MultiResolSupport,       ErrorTransform, ProcSigma, ProcThresh,   $
                                         ProcTransLevels, ErrorSupport,   $
                                         /tabular , /absolute
      	     endif else begin
      		PIA_SM_MultiResolSupport,       ErrorTransform, ProcSigma, ProcThresh,   $
                                         ProcTransLevels, ErrorSupport, /tabular
      	     endelse

      	 if (i eq 0)  $
      	    then begin
      	       CumuErrorSupport = ErrorSupport
      	    endif else begin
      	       CumuErrorSupport = CumuErrorSupport + ErrorSupport
      	    endelse

      	 PIA_SM_MultiResolCoeffRetain,   ErrorTransform, CumuErrorSupport, ErrorKeptCoeff

      	 PIA_SM_MultiResolReconstruct,   ErrorKeptCoeff, ErrorReconstruct

      	 FilteredData (*) = FilteredData (*) + ErrorReconstruct (*)

         If (Keyword_set (Plot))  $
            then begin
               plot , FilteredData (*) , title='wavelet filtering ...'
            endif

      endif

   If (Keyword_Set (DataSupport))  $
      then begin
      	 PIA_SM_ATROU_1D_WaveletTransform,    ErrorData , ErrorTransform ,   $
                                       ProcTransLevels , /MirrorPadding

      	 PIA_SM_MultiResolCoeffRetain,   ErrorTransform, DataSupport, ErrorKeptCoeff

      	 PIA_SM_MultiResolReconstruct,   ErrorKeptCoeff, ErrorReconstruct

      	 FilteredData (*) = FilteredData (*) + ErrorReconstruct (*)

         If (Keyword_set (Plot))  $
            then begin
               plot , FilteredData (*) , title='wavelet filtering ...'
            endif
      endif

EndFor

NoiseData (*) = Data (*) - FilteredData (*)

If (     Keyword_Set (RobustSigma))   $
   then    FinalSigma = PIA_SM_ROBUST_SIGMA (NoiseData)

If (NOT  Keyword_Set (RobustSigma))   $
   then    PIA_SM_MeanSigma, NoiseData, Average, FinalSigma

If (Keyword_set (Plot))  $
   then begin
      plot , NoiseData (*) , title='noise from wavelet filtering ...'
   endif

Return
End


















Pro  PIA_SM_ATROU_1D_WaveletTransform,     Data,  WaveletTransform,  NoLevels,  $
                                    mirrorpadding=mirrorpadding
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


BSplineCoeff  = [1./16. , 1./4. , 3./8. , 1./4. , 1./16.]
BSplineLength = 5


NData = N_Elements (Data)

WaveletTransform         = FltArr (NData , NoLevels+2)
WaveletTransform (* , 0) = Data (*)

WaveletFiltered          = FltArr (NData , NoLevels+2)
WaveletFiltered  (* , 0) = Data (*)

If (NoLevels le 0)  then  Return

For j = 1 , NoLevels+1  do begin

   Step = 2^(j-1)

   PreviousData = WaveletFiltered (* , (j-1))

   For i = 0L , NData-1  do begin

      if (Keyword_set (mirrorpadding))   $
   	 then begin
   	    iminus1 = i - Step
   	    If (iminus1 lt 0)  then   iminus1 = -iminus1
   	    iminus2 = i - 2*Step
   	    If (iminus2 lt 0)  then   iminus2 = -iminus2

   	    iplus1 = i + Step
   	    If (iplus1 ge NData)  then   iplus1 = 2*NData-2 - iplus1
   	    iplus2 = i + 2*Step
   	    If (iplus2 ge NData)  then   iplus2 = 2*NData-2 - iplus2
   	 endif else begin
   	    iminus1 = (i - Step) > 0
   	    iminus2 = (i - 2*Step) > 0

   	    iplus1 = (i + Step) < (NData-1)
   	    iplus2 = (i + 2*Step) < (NData-1)
   	 endelse

      UseIndex = [iminus2, iminus1, i, iplus1, iplus2]

      WaveletFiltered (i,j) = Total (BSplineCoeff(*) * PreviousData(UseIndex))
;      WaveletFiltered (i,j) =  (3./8.*PreviousData(i))  +  $
;                               (1./4.*(PreviousData(iminus1)+PreviousData(iplus1)))  +  $
;                               (1./16.*(PreviousData(iminus2)+PreviousData(iplus2)))


   EndFor

EndFor

WaveletTransform (*,*) = WaveletFiltered (*,*)
For i = 1 , NoLevels   do begin
   WaveletTransform (*,i) = WaveletFiltered (*,i-1) - WaveletFiltered (*,i)
EndFor

Return
End













Pro   PIA_SM_MultiResolReconstruct,   DataTransform,   DataReconstruct
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

DataSize = Size (DataTransform)

NData    = DataSize(1)
NLevels  = DataSize(2)

DataReconstruct     = FltArr (NData)
DataReconstruct (*) = 0.0

For i = 1 , NLevels-1  do begin
   DataReconstruct (*) = DataReconstruct (*) + DataTransform (*,i)
EndFor

Return
End










Pro   PIA_SM_MultiResolCoeffRetain,   MultiResolTransform,  MultiResolSupport,    $
                               MultiResolKeptCoeff
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

DataSize = Size (MultiResolTransform)
NData    = DataSize(1)
NLevel   = DataSize(2)

MultiResolKeptCoeff              = MultiResolTransform (*,*)   *      $
                                   (MultiResolSupport (*,*)  <  1.0)
MultiResolKeptCoeff (*,0)        = MultiResolTransform (*,0)
MultiResolKeptCoeff (*,NLevel-1) = MultiResolTransform (*,NLevel-1)

Return
End









Pro   PIA_SM_MultiResolSupport,   MultiResolTransform, SigmaOrigData, Threshhold, NoLevels,  $
                           MultiResolSupport,                                         $
                           Absolute=Absolute, LevelWiseStdDev=LevelWiseStdDev,        $
                           TabularStdDev=TabularStdDev, GlobalValue=GlobalValue
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

RelStdDevTable = [0.721618,  0.286209,  0.178281,  0.121010, 0.0831040,   $
                  0.0588543, 0.0446171, 0.0289142, 0.0177307]

DataSize = Size (MultiResolTransform)
NData    = DataSize(1)
NLevel   = DataSize(2)

MultiResolSupport       = FltArr (NData , NLevel)
MultiResolSupport (*,*) = 0.0

For i = 1 , NLevel-2 do begin

   If ((NOT Keyword_Set (LevelWiseStdDev))  AND  (NOT Keyword_Set (GlobalValue))   $
                                            AND  (NOT Keyword_Set (TabularStdDev)))  $
      then begin
         LevelSigma      = PIA_SM_ROBUST_SIGMA (MultiResolTransform (*,i))
         LevelSigmaTotal = SigmaOrigData * LevelSigma
      endif

   If (Keyword_Set (LevelWiseStdDev))  $
      then begin
         LevelSigma      = PIA_SM_ROBUST_SIGMA (MultiResolTransform (*,i))
         LevelSigmaTotal = SigmaOrigData * LevelSigma
      endif

   If (Keyword_Set (GlobalValue))  $
      then begin
         LevelSigmaTotal = 1.0
      endif

   If (Keyword_Set (TabularStdDev))  $
      then begin
         LevelSigmaTotal = SigmaOrigData * RelStdDevTable (i-1)
      endif


   If (Keyword_Set (Absolute))  $
      then begin
         SignificantIndex = Where (abs (MultiResolTransform(*,i)) gt abs(LevelSigmaTotal*ThreshHold) , NSignificant)
      endif

   If (NOT Keyword_Set (Absolute))  $
      then begin
         SignificantIndex = Where (MultiResolTransform(*,i)  gt  (LevelSigmaTotal*ThreshHold) , NSignificant)
      endif


   If (NSignificant gt 0)  $
      then begin
         MultiResolSupport (SignificantIndex , i) = 1.0
      endif

EndFor

Return
End









Pro   PIA_SM_MultiResolSupportVecSig,   MultiResolTransform, SigmaOrigData, Threshhold, NoLevels,  $
                           MultiResolSupport,                                         $
                           Absolute=Absolute, LevelWiseStdDev=LevelWiseStdDev,        $
                           TabularStdDev=TabularStdDev, GlobalValue=GlobalValue
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

;
; accepts SigmaOrigData as Vector !
;
;


RelStdDevTable = [0.721618,0.286209,0.178281,0.121010,0.0831040,0.0588543, 0.0446171, 0.0289142, 0.0177307]

DataSize = Size (MultiResolTransform)
NData    = DataSize(1)
NLevel   = DataSize(2)

MultiResolSupport       = FltArr (NData , NLevel)
MultiResolSupport (*,*) = 0.0

For i = 1 , NLevel-2 do begin

   If ((NOT Keyword_Set (LevelWiseStdDev))  AND  (NOT Keyword_Set (GlobalValue))   $
                                            AND  (NOT Keyword_Set (TabularStdDev)))  $
      then begin
         LevelSigma          = PIA_SM_ROBUST_SIGMA (MultiResolTransform (*,i))
         LevelSigmaTotal (0) = SigmaOrigData * LevelSigma
      endif

   If (Keyword_Set (LevelWiseStdDev))  $
      then begin
         LevelSigma          = PIA_SM_ROBUST_SIGMA (MultiResolTransform (*,i))
         LevelSigmaTotal (0) = SigmaOrigData * LevelSigma
      endif

   If (Keyword_Set (GlobalValue))  $
      then begin
         LevelSigmaTotal (0) = 1.0
      endif

   If (Keyword_Set (TabularStdDev))  $
      then begin
         LevelSigmaTotal = SigmaOrigData (*) * RelStdDevTable (i-1)
      endif


   If (Keyword_Set (Absolute))  $
      then begin
         SignificantIndex = Where (abs (MultiResolTransform(*,i)) gt abs(LevelSigmaTotal(*)*ThreshHold) , NSignificant)
      endif

   If (NOT Keyword_Set (Absolute))  $
      then begin
         SignificantIndex = Where (MultiResolTransform(*,i)  gt  (LevelSigmaTotal(*)*ThreshHold) , NSignificant)
      endif


   If (NSignificant gt 0)  $
      then begin
         MultiResolSupport (SignificantIndex , i) = 1.0
      endif

EndFor

Return
End









Function   PIA_SM_ReverseVector,  Vector
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

NData        = N_Elements (Vector)
LstDataInd   = NData - 1
Result       = FltArr (NData)

For i = 0 , LstDataInd do begin
   k = LstDataInd - i
   Result (k) = Vector (i)
EndFor

Return, Result
End










