;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       PIA_SM_WRITE_ISMC
; PURPOSE:
;	Write a PHT-SMC (Serendipity Surface brightness data) measurement 
;	from a temporary structure SMCDAT (PHTSMC type) onto an IDL savefile  
; CATEGORY:
;	PIA - graphics
;	PIA - I/O
; CALLING SEQUENCE:
;       PIA_SM_WRITE_ISMC, SMCDAT, TMPHDR
;
; INPUT:
;       PHTISMC : PHTSMC like temporary structure
;
; OPTIONAL INPUT:
;       TMPHDR 	: Temporary header
;
; OUTPUT:
;       IDL save file
;
; RESTRICTIONS:
;
; PROCEDURES USED:
;
; MODIFICATION HISTORY:
;       Written by: S. Bogun
;	August 96 Version 3.5
;	updated according to new SMC structure		(SB, 28/01/97)
;
;-
PRO pia_sm_write_ismc_event, event

COMMON pht_wrtismc_cmn, file, phtismc, text1 

	WIDGET_CONTROL, event.id, GET_UVALUE=uvalue

	CASE uvalue OF

          'SAVE': BEGIN

       		SAVE, PHTISMC, FILE=!INTDIR+file, /XDR
                WIDGET_CONTROL, event.top, /DESTROY

          END

          'CANCEL': BEGIN

                WIDGET_CONTROL, event.top, /DESTROY

          END

	  'TEXT2': BEGIN

		WIDGET_CONTROL, event.id, GET_VALUE=file
		file = STRTRIM(file(0),2)
		junk = FINDFILE(file, COUNT=count)
		text = $
   'The file '+file +' has now been found '+STRTRIM(STRING(count),2)+' time(s)' 
		WIDGET_CONTROL, text1, SET_VALUE=text
		 
          END
        ENDCASE

        RETURN
        END



        PRO PIA_SM_WRITE_ISMC, SMCDAT, tmphdr 


	COMMON pht_wrtismc_cmn, file, phtismc, text1 

;
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  PIA_SM_WRITE_ISMC, PHTISMC [, tmphdr] '

;  If temp hdr passed replace it in the SMCDAT structure
	IF KEYWORD_SET(tmphdr) THEN hdr = tmphdr ELSE hdr = smcdat.hdr
                                                                     
	phtismc = {UNIT: SMCDAT.UNIT, $
        		DET: SMCDAT.DET, $
        		ADMN: SMCDAT.ADMN, $
        		ORDR: SMCDAT.ORDR, $
        		DIMS: SMCDAT.DIMS, $
        		HDR:  HDR, $
			TKEY: SMCDAT.TKEY, $
			TIME: SMCDAT.TIME, $
			FLX: SMCDAT.FLX, $
			FLXU: SMCDAT.FLXU, $
			BACK: SMCDAT.BACK, $
			NOIS: SMCDAT.NOIS, $
			FLAG: SMCDAT.FLAG, $
			SMFL: SMCDAT.SMFL, $
			RA: SMCDAT.RA, $
			RAU: SMCDAT.RAU, $
			DEC: SMCDAT.DEC, $
			DECU: SMCDAT.DECU, $
			ROLL: SMCDAT.ROLL, $
			ROLU: SMCDAT.ROLU}

 
;  Write it out: Widget ask for name: default: adm naming convention 
	FILE=PHTISMC.ADMN+'.ISMC'
	junk = FINDFILE(!intdir+FILE, COUNT=count)

	textbase = WIDGET_BASE(TITLE = 'Saving SMC structures with PIA', $ 
		XSIZE=850, /COLUMN)

	lbase = WIDGET_BASE(textbase, /ROW)
	label = WIDGET_LABEL(lbase, VALUE = 'Save under:       ')
	text2 = WIDGET_TEXT(lbase,  $
	  VAL = FILE, /EDITABLE,  $
	  XSIZE=80, YSIZE=1, /FRAME, UVALUE = 'TEXT2')

	lbase = WIDGET_BASE(textbase, /ROW)
	label = WIDGET_LABEL(lbase, VALUE = 'But be careful:  ')
	text1 = WIDGET_TEXT(lbase, $
	  VAL = $
     'The file '+FILE +' has been found '+STRTRIM(STRING(count),2)+' time(s)',$
	  XSIZE=80, YSIZE=1)

	lbase = WIDGET_BASE(textbase, /ROW)
	label = WIDGET_LABEL(lbase, VALUE = 'Another name? ')
	text3 = WIDGET_TEXT(lbase, $
	  VAL = 'You can enter a new name in the upper field and press enter ',$
	  XSIZE=80, YSIZE=1)

	textcontrol = WIDGET_BASE(textbase,/ROW)

	junk = WIDGET_LABEL(textcontrol, VALUE = '                          ')
	save = WIDGET_BUTTON(textcontrol, VALUE = '  Save  ', $
			/FRAME, UVALUE = 'SAVE') 	
	junk = WIDGET_LABEL(textcontrol, VALUE = '                          ')
	cancel = WIDGET_BUTTON(textcontrol, VALUE = '  Cancel  ', $
			/FRAME, UVALUE = 'CANCEL') 	

        WIDGET_CONTROL, textbase, /REALIZE, TLB_SET_XOFFSET=150, $
                        TLB_SET_YOFFSET=150


        XManager, /NO_BLOCK, "pia_sm_write_ismc", textbase, GROUP=group
	
        RETURN
END



