;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO READ_ISMC, NAME, IPOS, PATH = PATH, ADMN = ADMN   ;;, $ 
       ;; N_CHANAME = n_chaname;+
; NAME:
;       READ_ISMC
; PURPOSE:
;	READ a PHTISMC (Interactive Serendipity measurement) file 
;	into the dynamical structure PHTSMC  
; CATEGORY:
;	PIA - I/O
; CALLING SEQUENCE:
;       READ_ISMC, NAME, PATH = PATH
;
; INPUT:
;       NAME 	: SMC-savefile name
;
; OPTIONAL INPUT:
;	PATH    : path for the file
;
; OUTPUT KEYWORD:
;	ADMN    : administration name (phtsmc.admn)
;
; RESTRICTIONS:
;       NAME must be a valid PHTISMC file 
;
; PROCEDURES USED: 
;       Common Block(s) or @ procedure(s):
;               adm
;               phtsmc
;
; MODIFICATION HISTORY:
;       Written by: S. Bogun (MPIA)			   August 1996
;	adapted from READ_ISRD written by C. Gabriel (ESA/ESTEC-SAI)		
;	updated according to new SMC structure		   (SB, 28/01/97)	
;	Keyword admn added & filename in HDR (CG/SB)	   May 1997
;       Simplified way of asigning name and saving (JA/SB) May 1997
;	V6.3
;-
;
@adm
@phtsmc
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
         'Syntax:  READ_ISMC, NAME, [PATH = PATH]'

;  check name for extension ISMC, name should not contain it!!
        ext_name = '.ISMC'
        trim_pos = strpos(name,ext_name)
        IF trim_pos ne -1 then tmpname = STRMID(name,0,trim_pos) $ 
        ELSE tmpname = name

; create filename esp if path is set
        if keyword_set(PATH) then $
         filename = PATH + TMPNAME + ext_name $
        else BEGIN
           revers_name = STR_REVERSE(tmpname)
           IF !version.os EQ "VMS" THEN $
            ind = STRPOS(revers_name,']') ELSE $
            ind = STRPOS(revers_name,'/') 
           IF ind eq -1 THEN tmpname = revers_name ELSE $ 	    
            tmpNAME = STRMID(revers_name,0,ind)
           tmpname = STR_REVERSE(tmpname)
           filename = name
        ENDELSE

;  Restore the save file
	RESTORE, FILENAME
	admn = PHTISMC.admn
	hdr = phtismc.hdr

; Put filename into header - If = official measname then put a 0

	FXADDPAR, hdr, 'PIA_MNAM', tmpname, $
	 "Name chosen for measurement by PIA user", BEFORE='XTENSION'

;  Fill the phtsmc buffer
	fill_smc, PHTISMC, hdr
	
;  Get the position within the PHTSMC structure 
        IPOS = N_elements(phtsmc) - 1

        RETURN
        END
