;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
pro set_colours

;+
; NAME:
;       set_colours
; PURPOSE:
; 	Loads the color tables for the CEB plotting 
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;        set_colours
;
; INPUT PARAMETERS:
;        NONE
;
; OUTPUT PARAMETERS:
;       NONE
;
; RESTRICTIONS:
;       NONE
; 
; METHOD:
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               colour_indices
;
; MODIFICATION HISTORY:
;       Written by: S. R. Williams
;	Oct 95 Version 3.5
;	White copied to position 10 (CG)		February 1996
;	Loading the b-w table first (CG)		July 1996
;	Loading the individual colors in the last 12
;	positions and inserting rainbow in first 116	May 1999
;	V7.4
;	Bug for lila colour fixed (CG)			May 2000
;	V9.0
;-
@colour_indices

; Set up colours, load first the b-w table

loadct, 0

black    = 0 + 117
red      = 1 + 117 
green    = 2 + 117 
blue     = 3 + 117
yellow   = 4 + 117
cyan     = 5 + 117
magenta  = 6 + 117
orange   = 7 + 117
beige    = 8 + 117
lila     = 9 + 117
white    = 10 + 117


; Set up graph colours

redorig=fltarr(128)
greenorig=fltarr(128)
blueorig=fltarr(128)

redorig(0 + 117:9 + 117)=[0.0, 1.0, 0.5, 0.5, 1.0, 0.5, 1.0, 1.0, 1.0, 1.0]
greenorig(0 + 117:9 + 117)=[0.0, 0.5, 1.0, 0.5, 1.0, 1.0, 0.5, 0.6, 0.8, 0.8]
blueorig(0 + 117:9 + 117)=[0.0, 0.5, 0.5, 1.0, 0.5, 1.0, 1.0, 0.0, 0.6, 1.0]

; Set up image display colours

redorig(10:28) = findgen(19)/18
redorig(29:39) = fltarr(11) + 1.0

greenorig(10:22) = fltarr(13)
greenorig(23:39) = findgen(17)/16

blueorig(10:29) = fltarr(20)
blueorig(30:39) = findgen(10)/9

; set white now to 10
redorig(10+117) = redorig(39)
greenorig(10+117) = greenorig(39)
blueorig(10+117) = blueorig(39)

; Load colour table

tvlct,255*redorig,255*greenorig,255*blueorig

loadct, 13, ncolors=!d.n_colors-12, bottom=1

end
