;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;	SET_ORBPOS
; PURPOSE:
;	Given a revolution and date compute the orbital position 
; CATEGORY:
;       PIA - utilities
;
; CALLING SEQUENCE:
;       orbpos = set_orbpos(rev, date)
;INPUT: 
;	rev: Revolution number
;	date: Date in the format "16-DEC-1995  7:19:14.00". Is is compatible 
;		with tag unit as read from PIA data structures. 
;OUTPUT: 
;	orbpos: Orbital position in units of 2.4hrs
;
; PROCEDURES USED:
;       ASTRO LIB:
;		juldate
;       INTERNAL:
;		read_allperigee
;		unit2juldate
;
; MODIFICATION HISTORY:
;       Written by:     Jose Acosta (PIDT - MPIA)       December 1997
;
;-


FUNCTION SET_ORBPOS, rev, date

COMMON ALL_PERIGEE, allperigee

; check if structure allperigee is already defined, if not then call
; read_allperigee

IF n_elements(allperigee) eq 0 THEN read_allperigee, error=error

orbpos =0.

  ind_orb = WHERE(allperigee.rev eq rev, ntmp)
   
IF ntmp gt 0 then orbpos = unit2juldate(date) - allperigee(ind_orb(0)).date $
  ELSE BEGIN 
    PRINT, 'Error: Perigee time can not be found for this revolution '
    PRINT, 'Get new file from PIA WEB Homepage (Main -> Help)' 
    RETURN, orbpos
  ENDELSE  

;check if extrapolation is used
IF STRPOS(STRUPCASE(STRTRIM(allperigee(ind_orb(0)).psf,2)),'EXTRAPOLATED') NE -1 THEN $ 
  BEGIN 
    PRINT, 'Warning: Perigee time is extrapolated for this revolution '
    PRINT, STRING(7B),'Please update ALL_PERIGEE file. '+ $ 
          '   You can get it via PIA WEB Homepage (Main -> Help)'    
ENDIF 
  
IF orbpos gt 1. OR orbpos le 0. THEN $ 
      PRINT,'Warning: Given date and revolution do not match'    
 
RETURN, orbpos

end
