;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO SET_RESPONSE_FROM_INTERPOL, resps, det, pos 
;+
; NAME:
;       SET_RESPONSE_FROM_INTERPOL
; PURPOSE:
;	Copy response information contained in double-responses buffer into
;	single response buffer (eg for the case of one not valid) 
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       SET_RESPONSE_FROM_INTERPOL, resps, det, pos
;
; INPUT:
;       resps: double response buffer
;	    A structure containing
;		resp1: responsivity calculated with the fcs1 measurement
;		respun1: resp1 uncertainty
;		time1: measurement's date (taken from fcs1.unit)
;		orig1n: admn name 1st FCS
;		orig1f: filter 1st FCS
;		orig1m: method used 1st FCS
;		resp2: responsivity calculated with the fcs2 measurement
;		respun2: resp2 uncertainty
;		time2: measurement's date (taken from fcs2.unit)
;		orig2n: admn name 2nd FCS
;		orig2f: filter 2nd FCS
;		orig2m: method used 2nd FCS
;	det:    detector used
;	pos:    either 1 or 2, indicating which response to be taken 
;
; KEYWORD:
;
; OUTPUT:
;	(none) phtrespact contents are modified
; 
;	resps: A structure containing
;		resp1: responsivity calculated with the fcs1 measurement
;		respun1: resp1 uncertainty
;		time1: measurement's date (taken from fcs1.unit)
;		orig1n: admn name 1st FCS
;		orig1f: filter 1st FCS
;		orig1m: method used 1st FCS
;		resp2: responsivity calculated with the fcs2 measurement
;		respun2: resp2 uncertainty
;		time2: measurement's date (taken from fcs2.unit)
;		orig2n: admn name 2nd FCS
;		orig2f: filter 2nd FCS
;		orig2m: method used 2nd FCS
;
; RESTRICTIONS:
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phtresact
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel 			May 2002
;	V10.0
;
;-
@phtresact
	
	IF pos EQ 1 THEN BEGIN
		resp = resps.resp1
		respun = resps.respun1
		orign = resps.orig1n
		origm = resps.orig1m
		origf = resps.orig1f
	ENDIF ELSE IF pos EQ 2 THEN BEGIN
		resp = resps.resp2
		respun = resps.respun2
		orign = resps.orig2n
		origm = resps.orig2m
		origf = resps.orig2f
	ENDIF

	CASE STRUPCASE(STRMID(det,0,2)) OF
		'P1': BEGIN
			p1respact = resp
			p1respunc = respun
			respact_origin.p1n = orign
			respact_origin.p1f = origf
			respact_origin.p1m = origm
		END
		'P2': BEGIN
			p2respact = resp
			p2respunc = respun
			respact_origin.p2n = orign
			respact_origin.p2f = origf
			respact_origin.p2m = origm
		END
		'P3': BEGIN
			p3respact = resp
			p3respunc = respun
			respact_origin.p3n = orign
			respact_origin.p3f = origf
			respact_origin.p3m = origm
		END
		'C1': BEGIN
			C1respact = resp
			C1respunc = respun
			respact_origin.c1n = orign
			respact_origin.c1f = origf
			respact_origin.c1m = origm
		END
		'C2': BEGIN
			c2respact = resp
			c2respunc = respun
			respact_origin.c2n = orign
			respact_origin.c2f = origf
			respact_origin.c2m = origm
		END
		ELSE: MESSAGE, /INFO, 'Not recognized detector'
	ENDCASE	   

	RETURN
	END