;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
 PRO sgchopcor, tmpdata 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       SGCHOPCOR
;
; PURPOSE:
;       Perform the correction for signal losses in a chopped measurement.
;       
;
; CATEGORY:
;       PIA - processing
;
; CALLING SEQUENCE:
;       SGCHOPCORR, tmpdata
;
; INPUT PARAMETERS:
;	tmpdata: Background subtracted measurement
;        
; OUTPUT PARAMETERS:
;       
;
; MODIFICATION HISTORY:
;       Written by: J. Acosta                           NOVEMBER 1997
;       Version 6.6
;-
;
 

ON_ERROR, 2

@phtchopcor

; select the correction per detector
CASE tmpdata.det OF
   'P1': corrsig_tab = chopcorr_str.p1corr
   'P2': corrsig_tab = chopcorr_str.p2corr
   'P3': corrsig_tab = chopcorr_str.p3corr
   'C1': corrsig_tab = chopcorr_str.c1corr
   'C2': corrsig_tab = chopcorr_str.c2corr
   'SL': corrsig_tab = chopcorr_str.slcorr
ENDCASE   


chop_dsg = chopcorr_str.chop_dsg

;compute the time per chopper plateau: product of t_reset * Number of DRs 
give_cs, tmpdata, cs, record, conv_cs
intt = 2.^(7-cs.intt(record))
ndr = FLOAT(conv_cs.ndr(record))
tinchop = ROUND(intt*ndr)

;select the corresponding chopper frequency 
ind_timechop = WHERE(chopcorr_str.inchop_time EQ tinchop, ntime)
IF ntime NE 1 THEN BEGIN 
   info = 'Not adequate chopper frequency'
   MESSAGE, info
ENDIF

ind_tchop  = ind_timechop(0)

npix = pixel_det(tmpdata.det)
aversg = tmpdata.aver(0:npix-1,*)
aversg_corr =  aversg
avuncsg = tmpdata.avun(0:npix-1,*)
flagsg = tmpdata.flag(0:npix-1,*)

npos = N_ELEMENTS(aversg(0,*))

;corrections are in log-scale
FOR ipos = 0, npos-1 DO BEGIN 
  FOR ipix=0, npix-1 DO BEGIN 
    avertmp = ABS(aversg(ipix,ipos))
    IF aversg(ipix,ipos) LT 0 THEN sgtmp = -1 ELSE sgtmp = 1
    ind_sigint = WHERE(chop_dsg GE avertmp,nsigup)
    IF nsigup EQ 0 THEN nsigup = nsigup + 1
    nsiglo = nsigup-1 
    lcorrsg = corrsig_tab(nsiglo,ipix,ind_tchop,0) +                           $ 
        (corrsig_tab(nsigup,ipix,ind_tchop,0) -                                $
        corrsig_tab(nsiglo,ipix,ind_tchop,0))*                                 $ 
        (alog10(avertmp)-chop_dsg(nsiglo))/(chop_dsg(nsigup)-chop_dsg(nsiglo))
    aversg_corr(ipix,ipos) = 10.^lcorrsg * sgtmp  
  ENDFOR  
  
tmpdata.aver(0:npix-1,*) = aversg_corr
  
ENDFOR
RETURN
END
