;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO Sky_Coords, xa, ya, RA, Dec, Roll_Ang, RA_Unc, Dec_Unc, Roll_Unc
;+
; Name:
;	Sky_Coords
;
; Purpose:
;	Maps image co-ordinates onto equatorial co-ordinates
; CATEGORY:
;	PIA - processing
;
; Input:
;	xa: x image co-ordinate
;	ya: y image co-ordinate
;
; Output:
;	RA: RA of co-ordinate
;	Dec: Dec of co-ordinate
;	Roll_Ang: Roll Angle
;	RA_Unc: Uncertainty in the RA
;	Dec_Unc: Uncertainty in the Dec
;	Roll_Unc: Uncertainty in the roll
;
; Restrictions: 
;	Assumes the raster_info common block has been initialised
;
; Procedures Called:
;       Common Block(s) or @ procedure(s):
;
; Modification History:
;	Written by: Huw Morris (adapted from Simon Williams)
;	Oct 95 Version 3.5
;- 

@raster_info

	ON_ERROR, 0                      ; Return to calling procedure

; Convert input RA and Dec to radians
	Rad_Ra = DOUBLE(Ins_Ra * !DTOR)   
	Rad_Dec = DOUBLE(Ins_Dec * !DTOR)

; Calculation of uncertainties is TBD
	RA_Unc = 0d0
	Dec_Unc = 0d0
	Roll_Unc = 0d0

; Convert image co-ordinates to tangential plane co-ordinates
	Xi = -xa * !DPI / 180d0
	Eta = ya * !DPI / 180d0

; Calculate the sin/cosine of the Declination of the Raster Centre
	SDec = SIN(Rad_Dec)
	CDec = COS(Rad_Dec)

; Define a constant K used in subsequent processing
	K = CDec - Eta * SDec

; Calculate difference in Ra values
	Radif = ATAN(Xi, K)

; Calculate the Ra - normalise to 0-360
	Ra = Radif+Rad_RA * !RADEG
        Ra = Ra MOD 360
;	IF (RA LT 0.0) THEN RA = RA + 360.0

; Calculate the Declination and convert back to degrees
	Dec = ATAN(SDec + Eta * CDec, SQRT(Xi * Xi + K * K))
	Dec = Dec * !RADEG

; No variation can presently be calculated in the roll angle
	Roll_Ang  = Roll
                     
	END
