;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO SPD_DISC, tmpdata, flagarr
;+
; NAME:
;       spd_disc
; PURPOSE:
;       Return a flag array with flag=2 for all the chopper plateaux
;       discarded using the bitflag system
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       spd_disc, tmpdata, flagarr
;
; INPUT PARAMETERS:
;       tmpdata: PHTSPD type temporary structure
;
; OUTPUT PARAMETERS:
;       flagarr: Flag array of dimensions (# pixels, # chopper plateaux)
;		 # pixels does not include resistor and open pixel  
;
; RESTRICTIONS:
;       NONE
; 
; METHOD:
;       Use the SPD discard criteria within PHTACC to flag all chopper
;       plateaux to be deselected        
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phtacc
;
; MODIFICATION HISTORY:
;       Written by: Carlos GABRIEL
;	Oct 95 Version 3.5
;	Changed according to bitflag system (CG)
;	V7.4
;
;-
@phtacc
;
	ON_ERROR, 2

; Check number of parameters
	IF N_PARAMS() NE 2 THEN MESSAGE, /INFO, $
		'Syntax: spd_disc, tmpdata, flagarr'

; Fill flagarr first with discarded chopper plateaux
        dim1 = n_elements(tmpdata.mnpw(*,0))

        flagarr = intarr(dim1,tmpdata.dims)

	get_validflag, tmpdata.flag(0:dim1-1,*), 'SPD', redflag, $
	   det=tmpdata.det
	   
	decode_piaflag, 'SPD', 'NSIG_1', tmpdata.flag(0:dim1-1,*), uflag, $
	   det=tmpdata.det
	
        FOR i=0,dim1-1 DO BEGIN
                scpdisc = WHERE(redflag(i,*) EQ 1, ncount)
                IF ncount gt 0 THEN flagarr(i,scpdisc) = 2
                scpdisc = WHERE(uflag EQ 1, ncount)
                IF ncount gt 0 THEN flagarr(i,scpdisc) = 1
        ENDFOR
		 	 

	RETURN
	END
