;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO SPD_INIT, index=index 
;+
; NAME:
;       spd_init
; PURPOSE:
;       Initializes the structure PHTSPD defining the contents as
;	a template structure PHTSPD_TYPE. It can be used for clearing
;	the whole SPD structure, in case this should show as necessary. 
; CATEGORY:
;	PIA - initialization
;
; CALLING SEQUENCE:
;       SPD_INIT
;
; INPUT PARAMETERS:
;	None       
;
; OUTPUT PARAMETERS: 
;	None
;
; KEYWORDS:
;	Index:	If set, only those will be deleted from buffer
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phtspd
;               phtspd_init
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel
;	Oct 95 Version 3.5
;	Keyword index for clearing set of records added (CG+JA)	May 1997
;	V6.3
;-

@phtspd

	nelbuf = N_ELEMENTS(phtspd)
	IF nelbuf EQ 1 THEN RETURN

	flag = intarr(nelbuf)
	
	IF NOT KEYWORD_SET(index) THEN index = indgen(nelbuf-1)+1

	flag(index) = 1
		
	nele = N_ELEMENTS(index)

  if nele ge 1 then $
    for i = 0, nele - 1 do $
      for ihan = spd_first_handle, spd_last_handle do $
	handle_free, phtspd(index(i)).(ihan)

	ind = WHERE(flag EQ 0)
	phtspd = phtspd(ind)
	


END

