;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO SRD_INIT, index=index 
;+
; NAME:
;       srd_init
; PURPOSE:
;       Initializes the structure PHTSRD defining the contents as
;	a template structure PHTSRD_TYPE. It can be used for clearing
;	the whole SRD structure, in case this should show as necessary. 
; CATEGORY:
;	PIA - initialization
;
; CALLING SEQUENCE:
;       SRD_INIT
;
; INPUT PARAMETERS:
;	None       
;
; OUTPUT PARAMETERS: 
;	None
;
; KEYWORDS:
;	Index:	If set, only those will be deleted from buffer
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phtsrd
;               phtsrd_init
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel
;	Oct 95 Version 3.5
;	Free handles added (CG)			January 1996
;	mod to use srd_first_handle and srd_last_handle   (WMT) May 1996
;	Keyword index for clearing set of records added (CG+JA)	May 1997
;	V6.3
;-

@phtsrd

	nelbuf = N_ELEMENTS(phtsrd)
	IF nelbuf EQ 1 THEN RETURN

	flag = intarr(N_ELEMENTS(phtsrd))
	
	IF NOT KEYWORD_SET(index) THEN index = indgen(nelbuf-1)+1

	flag(index) = 1
		
	nele = N_ELEMENTS(index)

	IF nele GE 1 THEN $
	   FOR I = 0, nele - 1 DO $
		FOR ihan = srd_first_handle, srd_last_handle DO $
		  HANDLE_FREE, phtsrd(index(i)).(ihan)

	ind = WHERE(flag EQ 0)
	phtsrd = phtsrd(ind)
	
END

