;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       SUBDARK_SCP
;
; PURPOSE:
;       Subtract dark current at scp level, log info into the header. 
;	It checks if the dark current has been subtracted before.
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;       subdark_scp, scptmp, hdr
;
; INPUTS:
;	scptmp:    Temporal phtscp structure
;
; OPTIONAL INPUTS:
;       hdr:	   Current header 
;
; COMMON BLOCKS:
;       none
; PROCEDURES USED:
;	PIA Procedure(s):
;		darkcur
;       Astrolib:
;		fxpar, fxaddpar
;
; MODIFICATION HISTORY:
;       Written by: 	Jose Acosta (ISO-SOC, Vilspa)	May 1997
;	V6.3
;	Bug fixed: bringing back updated header
;-
PRO subdark_scp, tmpscp, hdr

   IF N_ELEMENTS(hdr) eq 0 THEN hdr = tmpscp.hdr
   
   dark_done = fxpar(hdr,'PRS_DARK',count=count)
 
   detpix = pixel_det(tmpscp.det)
   
   ; prevent to subtract dark current twice
   IF count gt 0 THEN BEGIN
      message, 'Dark Current subtraction already performed, skipped',/continue
      RETURN
   ENDIF   
    
   darkcur, tmpscp.aver(0:detpix-1,*), tmpscp.det, outaver
   darkcur, tmpscp.medi(0:detpix-1,*), tmpscp.det, outmedi
   darkcur, tmpscp.q1me(0:detpix-1,*), tmpscp.det, outq1me
   darkcur, tmpscp.q3me(0:detpix-1,*), tmpscp.det, outq3me
		   
   tmpscp.aver(0:detpix-1,*) = outaver
   tmpscp.medi(0:detpix-1,*) = outmedi
   tmpscp.q1me(0:detpix-1,*) = outq1me
   tmpscp.q3me(0:detpix-1,*) = outq3me
   
   
   ; write info into the header
   fxaddpar, hdr, 'PRS_DARK',1,'Dark Current subtracted ', BEFORE='XTENSION'
   
RETURN

END   
