;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.!
 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             !
 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             !
 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;      UNIT2JULDATE
;
; PURPOSE:
;	convert the usual format of date ("DD-Mon-YYYY HH:MM:SS.S") to reduced 
;	Julian date
; CATEGORY:
;       PIA - utilities
;
; CALLING SEQUENCE:
;       jd = unit2juldate(date)
;INPUT: 
;	date: Date in the format "16-DEC-1995  7:19:14.00". Is is compatible 
;		with tag unit as read from PIA data structures. 
;OUTPUT: 
;	jd: Reduced julian date
;
; PROCEDURES USED:
;       ASTRO LIB:
;		juldate
; MODIFICATION HISTORY:
;       Written by:     Jose Acosta (PIDT - MPIA)       December 1997
;
;-
FUNCTION unit2juldate, unittmp

months = ['   ','JAN','FEB','MAR','APR','MAY','JUN','JUL','AUG','SEP','OCT',$
        'NOV','DEC']
        
        
        ; compute julian date
            dayom = fix(gettok(unittmp,'-'))
            month_name = gettok(unittmp,'-') 
            year = fix(gettok(unittmp,' '))
            hour = fix(gettok(unittmp,':'))
            minute = fix(gettok(unittmp,':'))
            sec = float(strtrim(strmid(unittmp,0,5)))
            
            nmonth = where(months eq month_name)
            nmonth = nmonth(0)
            rday = dayom + (hour+ minute/60. + sec/3600.)/24.    
 
            juldate,[year,nmonth,rday],jdate
            
RETURN, jdate

END            
           
