;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;+
; NAME:
;       WHEELS2ID
;
; PURPOSE:
;       Returns the filter and aperture id's corresponding to the 
;	wheels and detector specified
;
; CATEGORY:
;	PIA - processing
;
; CALLING SEQUENCE:
;	wheels2id, det, wheels, filt_id, aper_id, lambda=lambda
;
; INPUT:
;	det:		Detector name
;	wheels:		3-array containing the wheel positions
;
; OUTPUT:
;	filt_id:	Official filter identifier - (string)      
;	aper_id:	Official aperture identifier - (string)       
;
; OPTIONAL OUTPUT:
;	lambda:		Central Wavelength
;	area:		Aperture area (in mm^2)
;
; COMMON BLOCKS:
;	phtapertures:	Apertures and their sizes
;	phtfilter:	Filters' IDs
;
; MODIFICATION HISTORY:
;       Written by: Carlos GABRIEL (ESA-SAI)	November 1995
;	Bug with C filters fixed (CG)		December 1995
;	Adapted for phtapert CB from OMEGA (CG)	February 1998
;	V7.0
;-
PRO wheels2id, det, wheels, filt_id, aper_id, lambda, area

@phtfilter 	
@phtapert

	ON_ERROR, 2
	
;
; Check the number of parameters
;
	IF N_PARAMS() LT 4 THEN MESSAGE, $
	   'Syntax: WHEELS2ID, DET, WHEELS, FILT_ID, APER_ID[, lambda, area] '


	IF N_ELEMENTS(wheels) NE 3 THEN BEGIN
		MESSAGE, /info, 'Wheels must be a 3 elements array, returning'
		RETURN
	ENDIF
	
; initialize phtfilter and/or phtapertures if not yet

	IF N_ELEMENTS(c1filters) EQ 0 THEN phtfilter_init
	IF N_ELEMENTS(p_area) EQ 0 THEN READ_OMEGA

	allcfilters = ['Free_ap',c1filters, c2filters,'C_cut']
	allpfilters = [p1filters, p2filters, p3filters]
	  
	CASE STRMID(det,0,1) OF
	
		'C': BEGIN
	  		filt_id = allcfilters(wheels(1) - 1)
	  		aper_id = 'unique'
			lambda = FLOAT(STRMID(filt_id,3,4))
			IF STRMID(det,0,2) EQ 'C2' THEN area = c2_area(0) ELSE $
							area = c1_area(0) 
	  	END
		'P': BEGIN
	  		filt_id = allpfilters(wheels(2) - 1)
	  	  aper_id = $
	  	    STRING(FORMAT='(f5.2)',P_DIAMY(WHEELS(1)-1,0))
			lambda = FLOAT(STRMID(filt_id,3,4))
			area = P_AREA(wheels(1)-1,0)
		END
		ELSE:

	ENDCASE
	  	
	RETURN
	END
