;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	PRO WRITE_ACC, $
		NSEL,DRN,NDR1,NDRN,MIR,MAR,ANR,MINV,MAXV,SIGF, $
		SIG1,SIGN,MIS,MAS,ANS,CPN,MIC,MAC,ACP,SPN,MSC,MCC,ACC
;+
; NAME:
;	WRITE_ACC
; PURPOSE:
;	To write acceptance criteria for read-outs 
;	into the read-out acceptance block
; CATEGORY:
;	PIA - I/O
;
; CALLING SEQUENCE:
;	WRITE_ACC, NSEL,DRN,NDR1,NDRN,MIR,MAR,ANR,SIG1,SIGN,MIS,MAS,ANS,$
;		   CPN,MIC,MAC,ACP,MINV,MAXV
;
; INPUT PARAMETERS:
;	NSEL	: 1 if general NDR selection rules used, 0 if not 
;	DRN	: 0 if DR to be accepted, 1 if not 
;	NDR1	: 0 if first NDR to be accepted, 1 if not
;	NDRN	: Array of NDRs to be neglected
;       MIR	: First Read-out (absolute) to be accepted
;	MAR  	: Last Read-out (absolute) to be accepted
;	ANR	: Any Read-out (absolute) to be neglected
;	MINV	: Minimum voltage to be accepted
;	MAXV	: Maximum voltage to be accepted 
;	SIGF	: Structure giving the fraction to be taken for chopped/n.chop.
;	SIG1	: 0 if first Signal/Chopper Plateau to be accepted, 1 if not
;	SIGN	: Array of Signals/Ch.Plateau to be neglected
;       MIS	: First Signal (absolute) to be accepted
;	MAS  	: Last Signal (absolute) to be accepted
;	ANS	: Any Signal (absolute) to be neglected
;	CPN	: Array of contiguous Ch.Plateaux to be neglected
;	MIC	: First Chopper Plateau to be accepted
;	MAC	: Last Chopper Plateau to be accepted
;	ACP	: Array of non-contiguous Ch.Plateaux to be neglected
;	SPN	: Array of contiguous Ch.Plateaux to be neglected (SPD level)
;	MSC	: First Chopper Plateau to be accepted (SPD level)
;	MCC	: Last Chopper Plateau to be accepted  (SPD level)
;	ACC	: Array of non-contiguous Ch.Plateaux to be neglected (SPD level)
;
;
; OUTPUT PARAMETERS:
;	NONE
;
; RESTRICTIONS:
;	NONE
;
; METHOD:
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phtacc
;
; MODIFICATION HISTORY:
;	Written by: C. Gabriel
;	Oct 95 Version 3.5
;-
;
; Needed common blocks :
;	PHTACC
;
@phtacc
 On_ERROR,2                                          ;Return to caller
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 22 THEN MESSAGE, $
 'Syntax:  WRITE_ACC,NSELNDR,DRNACC,NDR1,NDRNACC,MINR,MAXR,ANYR,MINVOLT,MAXVOLT,'+$
 'SIGFRAC,SIG1ACC,SIGNACC,MINSIG,MAXSIG,ANYSIG,SCPNACC,MINCP,MAXCP,ANYCP,'+$
 'SPDNACC,MINSCP,MAXSCP,ANYSCP'
 
	NSELNDR = NSEL
        DRNACC = DRN
	NDR1NAC = NDR1
	NDRNACC = NDRN
	MINR = MIR
	MAXR = MAR
	ANYR = ANR
	MINVOLT = MINV
	MAXVOLT = MAXV
	SIGTNACC = SIGF
	SIG1ACC = SIG1
	SIGNACC = SIGN
	MINSIG = MIS
	MAXSIG = MAS
	ANYSIG = ANS
	SCPNACC = CPN
	MINCP = MIC
	MAXCP = MAC
        ANYCP = ACP
	SPDNACC = SPN
	MINSCP = MSC
	MAXSCP = MCC
        ANYSCP = ACC
	RETURN
	END
