;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  PRO write_darkcstr, det, newdarkcstr, REPLACE=replace
;+
; NAME:
;       WRITE_DARKCSTR
; PURPOSE:
;       Append a new structure to the dark current structure corresponding 
;	to det 
; CATEGORY:
;	PIA - I/O
; CATEGORY:
;       
; CALLED SEQUENCE:
;       WRITE_DARKCSTR, DETECTOR_NAME, newdarkcstr, [,/REPLACE]
; INPUTS:
;       DETECTOR_NAME: ONE OF THESE STRINGS -- P1, P2, P3, C1, C2, SL
;       darkcurr: the corresponding new dark current structure
; OPTIONAL INPUTS:
;       NONE
; KEYWORD PARAMETERS:
;       REPLACE:  the new structure will replace the old one. If not
;		  set then it will be appended
; PROCEDURE:
; MODIFICATION HISTORY:
;       WRITTEN BY: Carlos GABRIEL
;	Oct 95 Version 3.5
;       Replace version included (Jacosta) June 96
;-
ON_ERROR, 2

	detind = STRMID(STRUPCASE(det),0,2)

	CASE detind of 
		'SL': darkcur_str = {SLDARKSTR_typ}
		'C2': darkcur_str = {C2DARKSTR_typ}
		'C1': darkcur_str = {C1DARKSTR_typ}
		ELSE: darkcur_str = {PDARKSTR_typ}
	ENDCASE

	filename = !CALSAVE+ detind + 'CALDARKC_STR.SAV'
        res = findfile(filename, count = count)
 
        IF count NE 0 THEN RESTORE, filename ELSE replace = 1

	if keyword_set (replace) then darkcur_str = newdarkcstr $
	   else darkcur_str = [darkcur_str, newdarkcstr]
	
	SAVE, darkcur_str, FILE=filename, /XDR
END

