;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  PRO write_detdarkcur, det, darkcur, fitsfil = fitsfil, comment = comment, $
			version = version 
;+
; NAME:
;     WRITE_DETDARKCUR
; PURPOSE:
;	Write a PHT-subsystem DARK CURRENT to a STRING ARRAY containing all dark
;	currents (same format as PDARKCUR)
; CATEGORY:
;	PIA - I/O
; CALLING SEQUENCE:
;	WRITE_DETDARKCUR, det, darkcur [,fitsfile=fitsfile] 
;
; INPUT:
;       det: PHT-subsystem
;       darkcur: Dark current array corresponding to det
;
; OPTIONAL INPUT:
;       FITSFIL : The name of the fitsfile (without extension) in case
;		   that a FITS file should be written
;	COMMENT : The comment line in the fits header, string type
;       VERSION : the version number, string type, less than 8 chars
;                 default is 0001
;
; PROCEDURES USED: 
;       Common Block(s) or @ procedure(s):
;               phtdarkcur
;       PIA Procedure(s):
;               get_darkcur
;               write_dark
; MODIFICATION HISTORY:
;       Written by: Carlos GABRIEL
;	Oct 95 Version 3.5
;	Swapping C2 pixels for FITS file  (CG) 	December 1996
;	V5.5		
;
;-
@phtdarkcur
  ON_ERROR, 2
; Check the number of parameters
  if n_params() lt 2 then message, $
    'Syntax: WRITE_DETDARKCUR, DET, DARKCUR [, FITSFILE=FITSFILE, COMMENT=COMMENT, VERSION=VERSION]'

  IF KEYWORD_SET(FITSFIL) THEN BEGIN
	fits = 1
	filename = fitsfil
  ENDIF ELSE BEGIN
	fits = 0
	filename = 'NOFILE'

  ENDELSE
  
  GET_DARKCUR,'P1', darkp1
  GET_DARKCUR,'P2', darkp2
  GET_DARKCUR,'P3', darkp3
  GET_DARKCUR,'C1', dark1c
  GET_DARKCUR,'C2', dark2c
  GET_DARKCUR,'SL', darks
  
  CASE STRMID(det,0,2) of
	'P1': darkp1 = darkcur 
	'P2': darkp2 = darkcur 
	'P3': darkp3 = darkcur 
	'C1': dark1c = darkcur 
	'C2': BEGIN
		IF (FITS) THEN $
		  C2P_IA2PIPE, darkcur, dark2c ELSE $
		  dark2c = darkcur
	      END	 
	'SL': darks = darkcur 
  ENDCASE

  WRITE_DARK, FILENAME, DARKP1, DARKP2, DARKP3, DARK1C, DARK2C, DARKS, $
                   COMMENT = COMMENT, VERSION = VERSION, FITS = fits
   
  RETURN
  END
