;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  PRO write_fcspre_str, det, newfcspre_str, REPLACE = replace
;+
; NAME:
;       WRITE_FCSPRE_STR
; PURPOSE:
;       Append new records to the FCS Pre-reduced Signal Table corresponding 
;	to det, using the keyword REPLACE it will replace the whole structure
; CATEGORY:
;	PIA - I/O
; CATEGORY:
;       
; CALLED SEQUENCE:
;       WRITE_FCSPRE_STR, DETECTOR_NAME, newfcspre_str
; INPUTS:
;       DETECTOR_NAME: ONE OF THESE STRINGS -- P1, P2, P3, C1, C2
;       newfcsprestr: the corresponding new FCS Pre-reduced Signal Table
; OPTIONAL INPUTS:
;       NONE
; KEYWORD PARAMETERS:
;       NONE
; PROCEDURE:
; MODIFICATION HISTORY:
;       WRITTEN BY: Carlos GABRIEL (ESA/VILSPA)		October 1995
;	keyword replace introduced - JAcosta            June 1996
;-
ON_ERROR, 2

	detind = STRMID(STRUPCASE(det),0,2)

	CASE detind of 
		'C2': fcspre_str = {C2FCSPRE_typ}
		'C1': fcspre_str = {C1FCSPRE_typ}
		ELSE: fcspre_str = {PFCSPRE_typ}
	ENDCASE

	filename = !CALSAVE+ detind + 'CALFCS_PRE_STR.SAV'

	if not keyword_set(REPLACE) then begin
		RESTORE, filename
	        fcspre_str = [fcspre_str, newfcspre_str]
	endif else fcspre_str = newfcspre_str
	
	SAVE, fcspre_str, FILE=filename, /XDR
END

