;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO WRITE_IAAP, IND, FNAME = fname, PATH = path, INFO = INFO
;+
; NAME:
;       WRITE_IAAP
; PURPOSE:
;	Write a PHT-AAP (Auto Analysis) measurement from the dynamical 
;	structure PHTAAP onto an IDL savefile  
; CATEGORY:
;	PIA - I/O
; CALLING SEQUENCE:
;       WRITE_IAAP, PHTAAP_INDEX, FNAME = FNAME, PATH =PATH, INFO = INFO
;
; INPUT:
;       PHTAAP_INDEX 	: Index of the measurement within PHTAAP
;
; OPTIONAL KEYWORD:
;	FNAME   :  name of the save file, by default PHTSCP.ADMN is used
;	PATH	:  directory where the internal file is saved
;
; OUTPUT:
;	IDL save file
;
; RESTRICTIONS:
;       PHTAAP(PHTSCP_INDEX) must exist
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phtscp
;
; MODIFICATION HISTORY:
;       Written by: J. Acosta
;	Feb. 98 Version 7.0
;
;-
;
;
@phtaap
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  WRITE_IAAP, PHTAAP_INDEX, FNAME=FNAME, PATH = PATH, INFO=INFO'

	pia_load_iaap, phtaap(ind), phtiaap

	IF  KEYWORD_SET(FNAME) THEN NAME = fname ELSE NAME = phtiaap.admn

	IF NOT KEYWORD_SET(PATH) THEN PATH = !INTDIR 
	
	file = PATH+'/'+NAME+'.IAAP'
	
;  Write it out: use adm naming convention 
	SAVE, PHTIAAP, FILE=file

	INFO = 'Saving AAP measurement into '+ file
	
        RETURN
        END
