;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO WRITE_ICLA, IND 
;+
; NAME:
;       WRITE_ICLA
; PURPOSE:
;	Write a PHT-CLA (Calibration A) measurement from the dynamical 
;	structure PHTCLA onto an IDL savefile  
; CATEGORY:
;	PIA - I/O
; CALLING SEQUENCE:
;       WRITE_ICLA, PHTCLA_INDEX
;
; INPUT:
;       PHTCLA_INDEX 	: Index of the measurement within PHTCLA
; OUTPUT:
;	IDL save file
;
;
; RESTRICTIONS:
;       PHTCLA(PHTCLA_INDEX) must exist
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phtcla
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel
;	Oct 95 Version 3.5
;
;-
;
;
@phtcla
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  WRITE_ICLA, PHTCLA_INDEX'

;  Fill temporary variables from the handles
        HANDLE_VALUE, PHTCLA(IND).RPID, RPID
        HANDLE_VALUE, PHTCLA(IND).QFLG, QFLG 
	HANDLE_VALUE, PHTCLA(IND).QSTA, QSTA 
        HANDLE_VALUE, PHTCLA(IND).STAT, STAT
        HANDLE_VALUE, PHTCLA(IND).CPOS, CPOS 
        HANDLE_VALUE, PHTCLA(IND).FCS1, FCS1   
	HANDLE_VALUE, PHTCLA(IND).FCS2, FCS2 
        HANDLE_VALUE, PHTCLA(IND).TEMP, TEMP
        HANDLE_VALUE, PHTCLA(IND).TIME, TIME
        HANDLE_VALUE, PHTCLA(IND).BIAS, BIAS   
        HANDLE_VALUE, PHTCLA(IND).PIXL, PIXL
        HANDLE_VALUE, PHTCLA(IND).PUNC, PUNC

;  Fill the ICLA structure
	NAME = PHTCLA(IND).ADMN
	
	PHTICLA = {UNIT: PHTCLA(IND).UNIT, $     
        DET: PHTCLA(IND).DET, $     
	ADMN: NAME, $
        ORDR: PHTCLA(IND).ORDR, $ 
        DIMS: PHTCLA(IND).DIMS, $
        DWEL: PHTCLA(IND).DWEL, $
        RPID: RPID, $ 
        QFLG: QFLG, $ 
	QSTA: QSTA, $ 
        STAT: STAT, $
        CPOS: CPOS, $ 
        FCS1: FCS1, $   
	FCS2: FCS2, $ 
        TEMP: TEMP, $
        TIME: TIME, $
        BIAS: BIAS, $   
        PIXL: PIXL, $   
        PUNC: PUNC}

;  Write it out: use adm naming convention 
	SAVE, PHTICLA, FILE=NAME+'.ICLA'
        RETURN
        END

