;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO WRITE_ISCP, IND, FNAME = fname, PATH = path, INFO = INFO
;+
; NAME:
;       WRITE_ISCP
; PURPOSE:
;	Write a PHT-SCP (Signal Data) measurement from the dynamical 
;	structure PHTSCP onto an IDL savefile  
; CATEGORY:
;	PIA - I/O
; CALLING SEQUENCE:
;       WRITE_ISCP, PHTSCP_INDEX, FNAME = FNAME, PATH =PATH, INFO = INFO
;
; INPUT:
;       PHTSCP_INDEX 	: Index of the measurement within PHTSRD
;
; OPTIONAL KEYWORD:
;	FNAME   :  name of the save file, by default PHTSCP.ADMN is used
;	PATH	:  directory where the internal file is saved
;
; OUTPUT:
;	IDL save file
;
; RESTRICTIONS:
;       PHTSCP(PHTSCP_INDEX) must exist
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phtscp
;
; MODIFICATION HISTORY:
;       Written by: J. Acosta
;	Apr 97 Version 6.2
;
;-
;
;
@phtscp
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  WRITE_ISCP, PHTSCP_INDEX, FNAME=FNAME, PATH = PATH, INFO=INFO'

	pia_load_iscp, phtscp(ind), phtiscp

	IF  KEYWORD_SET(FNAME) THEN NAME = fname ELSE NAME = phtiscp.admn

	IF NOT KEYWORD_SET(PATH) THEN PATH = !INTDIR 
	
	file = PATH+'/'+NAME+'.ISCP'
	
;  Write it out: use adm naming convention 
	SAVE, PHTISCP, FILE=file

	INFO = 'Saving SCP measurement into '+ file
	
        RETURN
        END
