;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        PRO WRITE_ISRD, IND, FNAME = FNAME, PATH = path, INFO = info
;+
; NAME:
;       WRITE_ISRD
; PURPOSE:
;	Write a PHT-SRD (Signal Data) measurement from the dynamical 
;	structure PHTSRD onto an IDL savefile  
; CATEGORY:
;	PIA - I/O
; CALLING SEQUENCE:
;       WRITE_ISRD, PHTSRD_INDEX, FNAME = FNAME, PATH =PATH
;
; INPUT:
;       PHTSRD_INDEX 	: Index of the measurement within PHTSRD
;
; OPTIONAL KEYWORD:
;	FNAME   :  name of the save file, by default PHTSRD.ADMN is used
;	PATH	:  directory where the internal file is saved
;
; OUTPUT:
;	IDL save file
;
; RESTRICTIONS:
;       PHTSRD(PHTSRD_INDEX) must exist
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               phtsrd
;
; MODIFICATION HISTORY:
;       Written by: C. Gabriel
;	Oct 95 Version 3.5
;	Modification to include options path and fname (JAcosta) 	Apr. 97
;
;-
;
;
@phtsrd
;
        ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 1 THEN MESSAGE, $
          'Syntax:  WRITE_ISRD, PHTSRD_INDEX, PATH = PATH'

	pia_load_isrd, phtsrd(ind), phtisrd

	IF  KEYWORD_SET(FNAME) THEN NAME = fname ELSE NAME = phtisrd.admn

	IF NOT KEYWORD_SET(PATH) THEN PATH = !INTDIR 
	
	file = PATH+'/'+NAME+'.ISRD'
	
;  Write it out: use adm naming convention 
	SAVE, PHTISRD, FILE=file 
	
	INFO = 'Saving SRD measurement into '+ file
	
        RETURN
        END
