;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  PRO write_respstr, det, newrespstr, replace=replace
;+
; NAME:
;       WRITE_RESPSTR
; PURPOSE:
;       Append new records to the RESP current structure corresponding 
;	to det 
; CATEGORY:
;	PIA - I/O
; CATEGORY:
;       
; CALLED SEQUENCE:
;       WRITE_RESPSTR, DETECTOR_NAME, newrespstr
; INPUTS:
;       DETECTOR_NAME: ONE OF THESE STRINGS -- P1, P2, P3, C1, C2
;       newrespstr: the corresponding new FCS powers structure
; OPTIONAL INPUTS:
;       NONE
; KEYWORD PARAMETERS:
;       REPLACE: replace RESP structure through new records
; PROCEDURE:
; MODIFICATION HISTORY:
;       WRITTEN BY: Carlos GABRIEL
;       Modified by: Wai-Ming Tai
;	Oct 95 Version 3.5
;	Replacing of old structure possible (CG)	January 1996
;-
ON_ERROR, 2

	detind = STRMID(STRUPCASE(det),0,2)

	CASE detind of 
		'C2': resp_str = {C2RESPSTR_typ}
		'C1': resp_str = {C1RESPSTR_typ}
		ELSE: resp_str = {PRESPSTR_typ}
	ENDCASE

	filename = !CALSAVE+ detind + 'CALRESP_STR.SAV'
	RESTORE, filename

	IF not KEYWORD_SET(replace) THEN BEGIN 
	  resp_str = [resp_str, newrespstr] 
	ENDIF ELSE BEGIN
	   fileback = !CALSAVE+ detind + 'CALRESP_STR.OLD'
	   SAVE, resp_str, FILE=fileback, /XDR
	   resp_str = newrespstr
	ENDELSE
	
	SAVE, resp_str, FILE=filename, /XDR
END

