;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  PRO write_scp, tmpdata, tmphdr, filename = filename
;+
; NAME:
;     WRITE_SCP
; PURPOSE:
;	Write a PHT-SCP (Signal Per Chopper Plat.) measurement from a temporary 
;	structure PHTSCP onto a fits file
; CATEGORY:
;	PIA - I/O
; CALLING SEQUENCE:
;       WRITE_SCP, TMPDATA[, tmphdr]
;
; INPUT:
;       tmpdata	: PHTSCP structure
;       filename: filename to store the fitsfile
;
; OPTIONAL INPUT:
;       tmphdr	: PHTSCP header 
;
;
; RESTRICTIONS:
;       tmpdata must be a valid PHTSCP structure
;
; PROCEDURES USED: 
;       Common Block(s) or @ procedure(s):
;               phtscp
;	Astronomical Library:
;		size_struct
;
; MODIFICATION HISTORY:
;       Written by: W. M. Tai
;	Modified (last) by: C Gabriel			November 1996
;	V5.x
;	Y2K Compliance (CG)		Jun 1999
;	V7.4
;
;-
@phtscp
;
  ON_ERROR, 2

ENDLINE = 'END' + STRING(REPLICATE(32B, 77))  ; END LINE
BLANKLINE = STRING(REPLICATE(32B, 80))        ; BLANK LINE


CASE TMPDATA.DET OF

'C1': BEGIN
; C100
  BUF_TYPE = { time: 0.0, $
	       aver: fltarr(11), $
	       avun: fltarr(11),$
	       medi: fltarr(11),$
	       q1me: fltarr(11),$
	       q3me: fltarr(11),$
	       flag: intarr(11),$
	       chop: 0.0, $
	       step: 0, $
	       fcsn: 0, $
	       temp: 0.0, $
	       fcs1: 0.0, $
	       fcs2: 0.0, $
	       tkey: 0.0, $
	       rpid: bytarr(2), $
	       arsi: fltarr(11), $
	       andr: fltarr(11), $
	       avsd: fltarr(11) }

  comment = 'PHT C100 SCP'
  tform_code = 'P1SC'

      END
'C2': BEGIN
; C200 
  BUF_TYPE = { time: 0.0, $
	       aver: fltarr(6), $
	       avun: fltarr(6),$
	       medi: fltarr(6),$
	       q1me: fltarr(6),$
	       q3me: fltarr(6),$
	       flag: intarr(6),$
	       chop: 0.0, $
	       step: 0, $
	       fcsn: 0, $
	       temp: 0.0, $
	       fcs1: 0.0, $
	       fcs2: 0.0, $
	       tkey: 0.0, $
	       rpid: bytarr(2), $
	       arsi: fltarr(6), $
	       andr: fltarr(6), $
	       avsd: fltarr(6) }
  comment = 'PHT C200 SCP'
  tform_code = 'P2SC'

      END
'SL': BEGIN
; S
  BUF_TYPE = { time: 0.0, $
	       aver: fltarr(132), $
	       avun: fltarr(132),$
	       medi: fltarr(132),$
	       q1me: fltarr(132),$
	       q3me: fltarr(132),$
	       flag: intarr(132),$
	       chop: 0.0, $
	       step: 0, $
	       fcsn: 0, $
	       temp: 0.0, $
	       fcs1: 0.0, $
	       fcs2: 0.0, $
	       tkey: 0.0, $
	       rpid: bytarr(2), $
	       arsi: fltarr(132), $
	       andr: fltarr(132), $
	       avsd: fltarr(132) }
  comment = 'PHT-S SCP'
  tform_code = 'PSSC'

      END
ELSE:
ENDCASE
IF STRMID(TMPDATA.DET, 0, 1) EQ 'P' THEN BEGIN
; P
  BUF_TYPE = { time: 0.0, $
	       aver: fltarr(1), $
	       avun: fltarr(1),$
	       medi: fltarr(1),$
	       q1me: fltarr(1),$
	       q3me: fltarr(1),$
	       flag: intarr(1),$
	       chop: 0.0, $
	       step: 0, $
	       fcsn: 0, $
	       temp: 0.0, $
	       fcs1: 0.0, $
	       fcs2: 0.0, $
	       tkey: 0.0, $
	       rpid: bytarr(2), $
	       arsi: fltarr(1), $
	       andr: fltarr(1), $
	       avsd: fltarr(1) }
  comment = 'PHT-P SCP'
  tform_code = 'PPSC'

ENDIF

; Calculate the naxis size from the buf_type structure
  nchars = size_struct(buf_type)
  strnaxis1 = strtrim(string(nchars))
  naxis1 = string(replicate(32b, 20 - strlen(strnaxis1))) + strnaxis1

; Create the tag name for the extended header
  tags = tag_names(buf_type)
  ntags = n_tags( buf_type)

; this is a dummy, we will get rid of it later
  ttype = ['        ']

; calculate the interger or floating type code for fits header
; note that we only interested in two types here
  for t=0, ntags-1 do begin
    s = size(buf_type.(t))
    n_elem = s( s(0)+2)
    field_type = s( s(0)+1)
    case field_type of
      1:  fits_type = 'B'
      2:  fits_type = 'I'
      4:  fits_type = 'E'
      5:  fits_type = 'D'
    else:
    endcase
    
; put everything together, note the max number of blank space is 8
    sfield = strtrim(string(n_elem), 2)
    ttype = [ttype, sfield + fits_type + string(replicate(32b, 7 - strlen(sfield)))]
  endfor
; put the correct ttype by taking out the first dummy element
  ttype = ttype(1:ntags)
;
; Get the header from the phtscp record
;
  IF KEYWORD_SET(tmphdr) THEN hdr = tmphdr ELSE $
  hdr = tmpdata.HDR  ; get the extended header
  keyword = strmid(hdr, 0, 8)
;
; Creating the NAXIS, COMMENT, FILENAME and DATE lines for the primary header

  naxis = 'NAXIS   =                    0 / number of data axes                            '
  comm_line = 'COMMENT                                                                         '
  fname_line = 'FILENAME=                      / File name assigned in ISO archive              '
  date_line = "DATE    = '1999-01-01'         / Date of creating file                          "
  fname = "'" + tmpdata.admn + "_SCP'  "
  strput, fname_line, fname, 10
  strput, comm_line, comment, 11
  get_sysdate, date 
  strput, date_line, date, 11
;
; Find the index of the COMMENT, FILENAME  and DATE lines
;
  comment_ind = where(keyword EQ 'COMMENT ')
  file_ind = where(keyword EQ 'FILENAME')
  date_ind = where(keyword EQ 'DATE    ')
  xtension = where(keyword EQ 'XTENSION')
  hdr(comment_ind) = comm_line
  hdr(file_ind) = fname_line
  hdr(date_ind) = date_line

; extract the unit from tmpdata and split to scpdate and scptime
  unit = strtrim(tmpdata.unit, 2)
  unitlen = strlen(unit)
  tmppos = strpos(unit, ' ')
  tmp = "'" + strmid(unit, 0, tmppos) + "'"
  scpdate = blankline
  strput, scpdate , 'SCP_DATE='
  strput, scpdate, tmp, 10
  strput, scpdate, '/ SCP_DATE field in the PHTSCP', 31
  tmp = "'" + strmid(unit, tmppos + 1, unitlen - tmppos - 1) + "'"
  scptime = blankline
  strput, scptime , 'SCP_TIME='
  strput, scptime, tmp, 10
  strput, scptime, '/ SCP_TIME field in the PHTSCP', 31

; create a DET line
  detline = blankline
  strput, detline, 'SCP_DET ='
  det = "'" + strtrim(tmpdata.det, 2) + "'"
  strput, detline, det, 10
  strput, detline, '/ DETECTOR', 31

; create a ORDR line
  ordrline = blankline
  strput, ordrline, 'SCP_ORDR='
  ordr = strtrim(string(tmpdata.ordr), 2)
  len = strlen(ordr)
  strput, ordrline, ordr, (30 - len)>10
  strput, ordrline, '/', 31

; create a DIMS line
  dimsline = blankline
  strput, dimsline, 'SCP_DIMS='
  dims = strtrim(string(tmpdata.dims), 2)
  len = strlen(dims)
  strput, dimsline, dims, (30 - len)>10
  strput, dimsline, '/', 31

; put into the primary header
phdr = [hdr(0:1), naxis, hdr( 2 : xtension(0) - 1 ), $
	scpdate, scptime, detline, ordrline, dimsline, endline]

;
; pad the rest of the record with blank line for a 2880 bytes fits record
;
  trail = n_elements(phdr) mod 36
  if trail gt 0 then phdr = [phdr, replicate(blankline, 36 - trail)]

eheader = [ $
"XTENSION= 'BINTABLE'           / Binary table FITS extension                    ", $
"BITPIX  =                    8 / 8 BITS character format                        ", $
"NAXIS   =                    2 / Tables are 2-d character array                 ", $
"NAXIS1  =                      / Characters in a row                            ", $
"NAXIS2  =                      / Number of rows in a table                      ", $
"PCOUNT  =                    0 / Parameter count always 0                       ", $
"GCOUNT  =                    1 / Group count always 1                           ", $
"TFIELDS =                      / No of columns in table                         "]

; NAXIS1
;
  temp = eheader(3)
  strput, temp, naxis1, 10
  eheader(3) = temp

; NAXIS2
  naxis2 = string(tmpdata.dims)
  len = strlen(naxis2)
  temp = eheader(4)
  strput, temp, naxis2, (30 - len)>10
  eheader(4) = temp

; TFIELDS
  TFIELDS = strtrim(ntags, 2)
  temp = eheader(7)
  len = strlen(tfields)
  strput, temp, tfields, (30 - len)>10
  eheader(7) = temp
;
; The rest of the extended header
;

  tform = tform_code + tag_names(buf_type)

; create a dummy for hdr_buf
  hdr_buf = ['    ']

  for i = 0, ntags - 1 do begin
; create the form line
    temp = "TFORM   = '        '           /" + string(replicate(32b, 48))
    strput, temp, strtrim(i+1, 2), 5
    strput, temp, ttype(i), 11
    hdr_buf = [hdr_buf, temp]
; create the type line
    temp = "TTYPE   = '        '           /" + string(replicate(32b, 48))
    strput, temp, strtrim(i+1, 2), 5
    strput, temp, tform(i), 11
    hdr_buf = [hdr_buf, temp]
  endfor


  hdr_buf = hdr_buf(1:2*ntags)

  eheader = [eheader(0:7), hdr_buf, endline]
  eend = n_elements(eheader)
  trail = eend mod 36
  if trail gt 0 then eheader = [eheader, replicate(blankline, 36 - trail)]
  time = tmpdata.time
  aver = tmpdata.aver
  avun = tmpdata.avun
  medi = tmpdata.medi
  q1me = tmpdata.q1me
  q3me = tmpdata.q3me
  flag = tmpdata.flag
  chop = tmpdata.chop
  step = tmpdata.step
  fcsn = tmpdata.fcsn
  temp = tmpdata.temp
  fcs1 = tmpdata.fcs1
  fcs2 = tmpdata.fcs2
  tkey = tmpdata.tkey
  rpid = tmpdata.rpid
  arsi = tmpdata.arsi
  andr = tmpdata.andr
  avsd = tmpdata.avsd
  byteorder, time, /ftoxdr
  byteorder, aver, /ftoxdr
  byteorder, avun, /ftoxdr
  byteorder, medi, /ftoxdr
  byteorder, q1me, /ftoxdr
  byteorder, q3me, /ftoxdr
  byteorder, flag, /htons
  byteorder, chop, /ftoxdr
  byteorder, step, /htons
  byteorder, fcsn, /htons
  byteorder, temp, /ftoxdr
  byteorder, fcs1, /ftoxdr
  byteorder, fcs2, /ftoxdr
  byteorder, tkey, /ftoxdr
  byteorder, arsi, /ftoxdr
  byteorder, andr, /ftoxdr
  byteorder, avsd, /ftoxdr
  BUF = REPLICATE(BUF_TYPE, TMPDATA.DIMS)
  IF STRMID(TMPDATA.DET, 0, 1) EQ 'P' AND N_ELEMENTS(aver) GT 1 THEN BEGIN
;   There is a bug in IDL 3.6.1 that 1 x Y array is very different
;   from >2 X Y array. That is assignment is not allowed in the first
;   case.
    buf.aver = transpose(aver)
    buf.avun = transpose(avun)
    buf.medi = transpose(medi)
    buf.q1me = transpose(q1me)
    buf.q3me = transpose(q3me)
    buf.flag = transpose(flag)
    buf.arsi = transpose(arsi)
    buf.andr = transpose(andr)
    buf.avsd = transpose(avsd)
  ENDIF ELSE BEGIN
    buf.aver = aver
    buf.avun = avun
    buf.medi = medi
    buf.q1me = q1me
    buf.q3me = q3me
    buf.flag = flag
    buf.arsi = arsi
    buf.andr = andr
    buf.avsd = avsd
  ENDELSE
  buf.time = time
  buf.chop = chop
  buf.step = step
  buf.fcsn = fcsn
  buf.temp = temp
  buf.fcs1 = fcs1
  buf.fcs2 = fcs2
  buf.tkey = tkey
  buf.rpid = rpid

; added filename as an alternative filename
  if keyword_set(filename) then $
    fitsfile = filename else $
  fitsfile = !INTDIR + tmpdata.admn + '_SCP.FITS'

  openw, unit, fitsfile, /block, /get_lun

  naxis2 = tmpdata.dims
  trail = (nchars * naxis2) mod 2880
  pad = bytarr( 2880 - trail )

  writeu, unit, byte(phdr), byte(eheader), buf, pad
  free_lun, unit
END
