;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
   PRO write_selndr, filename, tpp1sndr, tpp2sndr, tpp3sndr, $
                     tpc1sndr, tpc2sndr, tpsssndr, tpslsndr, $
	             drflag = drflag, username = username, $
		     pipelinename = pipelinename, $
		     comment = comment, version = version
;+
; NAME:
;     WRITE_SELNDR
; PURPOSE:
;	Write a PHT SELNDR to a FITS file.
; CATEGORY:
;	PIA - I/O
; CALLING SEQUENCE:
;       WRITE_SELNDR, FILENAME, PP1SNDR, PP2SNDR, PP3SNDR,  
;                   PC1SNDR, PC2SNDR, PSSSNDR, PSLSNDR, DRFLAG,
;		    PIPELINENAME = PIPELINENAME,
;                   USERNAME = USERNAME, COMMENT = COMMENT, VERSION = VERSION 
;
; INPUT:
;       PP1SNDR, PP2SNDR, PP3SNDR: Long interger array
;       PC1SNDR, PC2SNDR, PSSSNDR, PSLSNDR: Long interger array
;
; OPTIONAL INPUT:
;       DRFLAG: integer
;	PIPELINENAME: string type, default is the pipeline product name
;       USERNAME : the username line in the fits header, string type
;       COMMENT : the comment line in the fits header, string type
;       VERSION : the version number, string type, less than 8 chars
;                 default is 0001
;
; PROCEDURES USED: 
;
; MODIFICATION HISTORY:
;       Written by: W. M. Tai
;	Modified by: C Gabriel
;	Oct 95 Version 3.5
;
;-
;
;
  on_error, 2
  ENDLINE = 'END' + STRING(REPLICATE(32B, 77))  ; END LINE
  BLANKLINE = STRING(REPLICATE(32B, 80))        ; BLANK LINE
  if keyword_set(username) then begin
    if strlen(username) > 8 then begin
      message, 'Maximum length for username is 8 characters long'
      return
    endif
  endif
      tcomment = 'PHT NDR selection'
      tdrflag = 1000
      tform = [ $
        "TFORM1  = '1J      '           /                                                ", $
        "TTYPE1  = 'PP1SNDR '           / NDRs to discard (PHT_P1)                       ", $
        "TFORM2  = '1J      '           /                                                ", $
        "TTYPE2  = 'PP2SNDR '           / NDRs to discard (PHT_P2)                       ", $
        "TFORM3  = '1J      '           /                                                ", $
        "TTYPE3  = 'PP3SNDR '           / NDRs to discard (PHT_P3)                       ", $
        "TFORM4  = '1J      '           /                                                ", $
        "TTYPE4  = 'PFILSNDR'           / Filler                                         ", $
        "TFORM5  = '1J      '           /                                                ", $
        "TTYPE5  = 'PSSSNDR '           / NDRs to discard (PHT_SS)                       ", $
        "TFORM6  = '1J      '           /                                                ", $
        "TTYPE6  = 'PSLSNDR '           / NDRs to discard (PHT_SL)                       ", $
        "TFORM7  = '1J      '           /                                                ", $
        "TTYPE7  = 'PC1SNDR '           / NDRs to discard (PHT_C100)                     ", $
        "TFORM8  = '1J      '           /                                                ", $
        "TTYPE8  = 'PC2SNDR '           / NDRs to discard (PHT_C200)                     ", $
        "DRFLAG  =                      / Flag to include DR                             "]
  phdr = [ $
  "SIMPLE  =                    T / file does conform to FITS standard" + $
  string(replicate(32b, 13)), $
  "BITPIX  =                    8 / number of bits per data pixel" + $
  string(replicate(32b, 18)), $
  "NAXIS   =                    0 / number of data axes" + $
  string(replicate(32b, 28)), $
  "EXTEND  =                    T / FITS dataset may contain extensions" + $
  string(replicate(32b, 12)), $
  "ORIGIN  = 'ESA     '           / European Space Agency" + $
  string(replicate(32b, 26)), $
  "TELESCOP= 'ISO     '           / Infrared Space Observatory" + $
  string(replicate(32b, 21)), $
  "INSTRUME= 'PHT     '           / Instrument used" + $
  string(replicate(32b, 32)), $
  "COMMENT" + $
  string(replicate(32b, 73)), $
  "FILENAME=                      / File name assigned in ISO archive" + $
  string(replicate(32b, 14)), $
  "DATE    = '        '           / Date of creating file" + $
  string(replicate(32b, 26)), $
  "FILEVERS= '        '           / Version ID assigned in ISO archive" + $
  string(replicate(32b, 13)), $
  "PIA_VERS=                      / Internal (user) PIA-CAL Version" + $
  string(replicate(32B, 16)), $
  "USERNAME=                      / Unofficial data product" + $
  string(replicate(32b, 24)), endline ]

; Write out the comment line
  temp = phdr(7)
  if keyword_set(comment) then tcomment = comment 
  strput, temp, tcomment, 11
  phdr(7) = temp

; Write out the filename 
; Note that if the pipeline filename is given in the parameter, it takes
; the pipelinename otherwise it would be the default pipeline name.
    if keyword_set(pipelinename) then pfilename = pipelinename else $
	pfilename = 'PSELNDR'
    fname_line = phdr(8)
    fname = "'" + pfilename + "'"
    strput, fname_line,  fname, 10
    phdr(8) = fname_line

; Write out the date
    monthstr = ['JAN', 'FEB', 'MAR', 'APR', 'MAY', 'JUN', 'JUL', 'AUG', $
  	 'SEP', 'OCT', 'NOV', 'DEC']
    monthseq = ['01', '02', '03', '04', '05', '06', '07', '08', $
  	 '09', '10', '11', '12']
    sysdate = systime()
    monthind = where(monthstr eq strupcase(strmid(sysdate, 4, 3)))
    date = strmid(sysdate, 8, 2) + '/' + monthseq(monthind(0)) + '/' + $
         strmid(sysdate, 22, 2)
    date_line = phdr(9)
    strput, date_line, date, 11
    phdr(9) = date_line
  
; Write out the version line
  if keyword_set(version) then tver = version else tver = '0001'
  tver = "'" + tver + "'"
  temp = phdr(11)
  strput, temp, tver, 11
  phdr(11) = temp
  
; Write out the username line
  if keyword_set(username) then begin
    temp = phdr(12)
    username = "'" + username + "'"
    strput, temp, username, 11
    phdr(12) = temp
  endif


; Create the Extended FITS header
;
  eheader = [ $
  "XTENSION= 'BINTABLE'           / Binary table FITS extension                    ", $
  "BITPIX  =                    8 / 8 BITS character format                        ", $
  "NAXIS   =                    2 / Tables are 2-d character array                 ", $
  "NAXIS1  =                   32 / Characters in a row                            ", $
  "NAXIS2  =                      / Number of rows in a table                      ", $
  "PCOUNT  =                    0 / Parameter count always 0                       ", $
  "GCOUNT  =                    1 / Group count always 1                           ", $
  "TFIELDS =                    8 / No of columns in table                         ", $
  tform, endline]
  
; NAXIS2
  dims = n_elements(tpp1sndr)
  naxis2 = string(dims)
  len = strlen(naxis2)
  temp = eheader(4)
  strput, temp, naxis2, (30 - len)>10
  eheader(4) = temp

; DRFLAG
  if keyword_set(drflag) then tdrflag = drflag
  flag = string(tdrflag)
  len = strlen(flag)
  temp = eheader(24)
  strput, temp, flag, (30 - len)>10
  eheader(24) = temp

  phdrsize = 36 - (n_elements(phdr) mod 36)
  ehdrsize = 36 - (n_elements(eheader) mod 36)
  hdr = [phdr, replicate(blankline, phdrsize), eheader, $
	  replicate(blankline, ehdrsize)]

  buf_type = { pp1sndr : 0L, $
               pp2sndr : 0L, $
               pp3sndr : 0L, $
               pfilsndr : 0L, $
               psssndr : 0L, $
               pslsndr : 0L, $
               pc1sndr : 0L, $
               pc2sndr : 0L}

  buf = replicate(buf_type, dims)

  byteorder, tpp1sndr, tpp2sndr, tpp3sndr, tpsssndr, $
             tpslsndr, tpc1sndr, tpc2sndr, /htonl

  buf.pp1sndr = tpp1sndr
  buf.pp2sndr = tpp2sndr
  buf.pp3sndr = tpp3sndr
  buf.psssndr = tpsssndr
  buf.pslsndr = tpslsndr
  buf.pc1sndr = tpc1sndr
  buf.pc2sndr = tpc2sndr

  fitsfile = !CALSAVE + filename + '.FITS'
  openw, unit, fitsfile, /block, /get_lun

  trail = (32 * dims) mod 2880
  pad = bytarr( 2880 - trail )
  writeu, unit, byte(hdr), buf, pad
   
  free_lun, unit
END
