;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  PRO write_spd, tmpdata, tmphdr, filename = filename
;+
; NAME:
;     WRITE_SPD
; PURPOSE:
;	Write a PHT-SPD (Standard Processed Data) measurement from a temporary 
;	structure PHTSPD onto a fits file
; CATEGORY:
;	PIA - I/O
; CALLING SEQUENCE:
;       WRITE_SPD, TMPDATA[, tmphdr]
;
; INPUT:
;       tmpdata	: PHTSPD structure
; 
; OPTIONAL INPUT:
;	tmphdr	: PHTSPD header
;       filename: filename to store the fitsfile
;
; RESTRICTIONS:
;       tmpdata must be a valid PHTSPD structure
;
; PROCEDURES USED: 
;       Common Block(s) or @ procedure(s):
;               phtspd
;
; MODIFICATION HISTORY:
;       Written by: W. M. Tai
;	Modified (last) by: C Gabriel			November 1996
;	V5.x
;	mod SPD_UNIT line to make sure the unit is
;	19 chars long         WMT                       Feb 1997
;	Bug for P-raster mode fixed +
;	 bug for keywords TFORM fixed  (CG)		Oct 1997
;	V6.5
;	Bug for SL case (wrong position of ') fixed (CG) May 1998
;	V7.2
;	Y2K Compliance (CG)		Jun 1999
;	V7.4
;
;-
@phtspd
;
  ON_ERROR, 2
ENDLINE = 'END' + STRING(REPLICATE(32B, 77))  ; END LINE
BLANKLINE = STRING(REPLICATE(32B, 80))        ; BLANK LINE

CASE TMPDATA.DET OF

'C1': BEGIN
; C100
  BUF_TYPE = { gpsctkey: 0L, $
	       gpscrpid: bytarr(2), $
	       gpscfill: 0,$
	       kyid: 0,$
	       mnum: 0,$
	       spar: 0, $
	       filt: 0, $
	       aper: 0, $
	       polz: 0, $
	       ndrs: 0, $
	       cstp: 0, $
	       dwel: 0L, $
	       meas: 0L, $
	       cpos: 0L, $
	       mnpw: fltarr(9), $
	       mnpu: fltarr(9), $
	       mdpw: fltarr(9), $
	       q1pw: fltarr(9), $
	       q3pw: fltarr(9), $
	       plen: 0L, $
	       flag: bytarr(9), $ 
	       fill: bytarr(3) }
  TFIELDS = '22'
  comment = 'PHT-C100 Standard Processed Data'
  naxis1 = string(replicate(32b, 17)) + '232'
  nchars = 232
  tform = ['1I      ', '1I      ', $
           '1I      ', '1I      ', '1I      ', '1I      ', '1I      ', $
           '1I      ', '1J      ', '1J      ', '1J      ', $
           '9E      ', '9E      ', '9E      ', '9E      ', '9E      ', $
           '1J      ', '9B      ', '3B      ']
  ttype_code = 'PC1S'
  ttype = ['KYID', 'MNUM', 'SPAR', 'FILT', 'APER', $
	   'POLZ', 'NDRS', 'CSTP', 'DWEL', $
	   'MEAS', 'CPOS', 'MNPW', 'MNPU', 'MDPW', $
  	   'Q1PW', 'Q3PW', 'PLEN', 'FLAG', 'FILL']

      END
'C2': BEGIN
; C200 
  BUF_TYPE = { gpsctkey: 0L, $
	       gpscrpid: bytarr(2), $
	       gpscfill: 0,$
	       kyid: 0,$
	       mnum: 0,$
	       spar: 0, $
	       filt: 0, $
	       aper: 0, $
	       polz: 0, $
	       ndrs: 0, $
	       cstp: 0, $
	       dwel: 0L, $
	       meas: 0L, $
	       cpos: 0L, $
	       mnpw: fltarr(4), $
	       mnpu: fltarr(4), $
	       mdpw: fltarr(4), $
	       q1pw: fltarr(4), $
	       q3pw: fltarr(4), $
	       plen: 0L, $
	       flag: bytarr(4)}
  TFIELDS = '21'
  comment = 'PHT-C200 Standard Processed Data'
  naxis1 = string(replicate(32b, 17)) + '124'
  nchars = 124
  tform = ['1I      ', '1I      ', $
           '1I      ', '1I      ', '1I      ', '1I      ', '1I      ', $
           '1I      ', '1J      ', '1J      ', '1J      ', $
           '4E      ', '4E      ', '4E      ', '4E      ', '4E      ', $
           '1J      ', '4B      ']
  ttype_code = 'PC2S'
  ttype = ['KYID', 'MNUM', 'SPAR', 'FILT', 'APER', $
	   'POLZ', 'NDRS', 'CSTP', 'DWEL', $
	   'MEAS', 'CPOS', 'MNPW', 'MNPU', 'MDPW', $
  	   'Q1PW', 'Q3PW', 'PLEN', 'FLAG']

      END
'SL': BEGIN
; SL
  BUF_TYPE = { gpsctkey: 0L, $
	       gpscrpid: bytarr(2), $
	       gpscfill: 0,$
	       kyid: 0,$
	       mnum: 0,$
	       spar: intarr(3), $
	       polz: 0, $
	       ndrs: 0, $
	       cstp: 0, $
	       dwel: 0L, $
	       meas: 0L, $
	       cpos: 0L, $
	       mnpw: fltarr(64), $
	       mnpu: fltarr(64), $
	       mdpw: fltarr(64), $
	       q1pw: fltarr(64), $
	       q3pw: fltarr(64), $
	       plen: 0L, $
	       flag: bytarr(64)}
  TFIELDS = '19'
  comment = 'PHT-SL Standard Processed Data'
  naxis1 = string(replicate(32b, 16)) + '1384'
  nchars = 1384
  tform = ['1I      ', '1I      ', $
           '3I      ', '1I      ', '1I      ', '1I      ', $
           '1J      ', '1J      ', '1J      ', $
           '64E     ', '64E     ', '64E     ', '64E     ', '64E     ', $
           '1J      ', '64B     ']
  ttype_code = 'PSLS'
  ttype = ['KYID', 'MNUM', 'SPAR', $
	   'POLZ', 'NDRS', 'CSTP', 'DWEL', $
	   'MEAS', 'CPOS', 'MNPW', 'MNPU', 'MDPW', $
  	   'Q1PW', 'Q3PW', 'PLEN', 'FLAG']

      END
'SS': BEGIN
; SS
  BUF_TYPE = { gpsctkey: 0L, $
	       gpscrpid: bytarr(2), $
	       gpscfill: 0,$
	       kyid: 0,$
	       mnum: 0,$
	       spar: intarr(3), $
	       polz: 0, $
	       ndrs: 0, $
	       cstp: 0, $
	       dwel: 0L, $
	       meas: 0L, $
	       cpos: 0L, $
	       mnpw: fltarr(64), $
	       mnpu: fltarr(64), $
	       mdpw: fltarr(64), $
	       q1pw: fltarr(64), $
	       q3pw: fltarr(64), $
	       plen: 0L, $
	       flag: bytarr(64)}
  TFIELDS = '19'
  comment = 'PHT-SS Standard Processed Data'
  naxis1 = string(replicate(32b, 16)) + '1384'
  nchars = 1384
  tform = ['1I      ', '1I      ', $
           '3I      ', '1I      ', '1I      ', '1I      ', $
           '1J      ', '1J      ', '1J      ', $
           '64E     ', '64E     ', '64E     ', '64E     ', '64E     ', $
           '1J      ', '64B     ']
  ttype_code = 'PSSS
  ttype = ['KYID', 'MNUM', 'SPAR', $
	   'POLZ', 'NDRS', 'CSTP', 'DWEL', $
	   'MEAS', 'CPOS', 'MNPW', 'MNPU', 'MDPW', $
  	   'Q1PW', 'Q3PW', 'PLEN', 'FLAG']

      END
ELSE:
ENDCASE
IF STRMID(TMPDATA.DET, 0, 1) EQ 'P' THEN BEGIN
; P
  BUF_TYPE = { gpsctkey: 0L, $
	       gpscrpid: bytarr(2), $
	       gpscfill: 0,$
	       kyid: 0,$
	       mnum: 0,$
	       spar: 0, $
	       filt: 0, $
	       aper: 0, $
	       polz: 0, $
	       ndrs: 0, $
	       cstp: 0, $
	       dwel: 0L, $
	       meas: 0L, $
	       cpos: 0L, $
	       mnpw: 0.0, $
	       mnpu: 0.0, $
	       mdpw: 0.0, $
	       q1pw: 0.0, $
	       q3pw: 0.0, $
	       plen: 0L, $
	       flag: bytarr(1), $ 
	       fill: bytarr(3) }
  TFIELDS = '22'
  comment = 'PHT-P Standard Processed Data'
  naxis1 = string(replicate(32b, 18)) + '64'
  nchars = 64
  tform = ['1I      ', '1I      ', $
           '1I      ', '1I      ', '1I      ', '1I      ', '1I      ', $
           '1I      ', '1J      ', '1J      ', '1J      ', $
           '1E      ', '1E      ', '1E      ', '1E      ', '1E      ', $
           '1J      ', '1B      ', '3B      ']
  ttype_code = 'PP' + strmid(tmpdata.det, 1, 1) + 'S'
  ttype = ['KYID', 'MNUM', 'SPAR', 'FILT', 'APER', $
	   'POLZ', 'NDRS', 'CSTP', 'DWEL', $
	   'MEAS', 'CPOS', 'MNPW', 'MNPU', 'MDPW', $
  	   'Q1PW', 'Q3PW', 'PLEN', 'FLAG', 'FILL']

ENDIF
;
; Get the header from the phtsrd record
;
  IF KEYWORD_SET(tmphdr) THEN hdr = tmphdr ELSE $
  hdr = tmpdata.HDR  ; get the extended header
  keyword = strmid(hdr, 0, 8)
;
; Creating the NAXIS, COMMENT, FILENAME and DATE lines for the primary header

  naxis = 'NAXIS   =                    0 / number of data axes                            '
  comm_line = 'COMMENT                                                                         '
  fname_line = 'FILENAME=                      / File name assigned in ISO archive              '
  fname = "'" + tmpdata.admn + "_SPD'  "
  strput, fname_line, fname, 10
  strput, comm_line, comment, 11
  date_line = "DATE    = '1999-01-01'         / Date of creating file                          "
  get_sysdate, date 
  strput, date_line, date, 11
;
; Find the index of the COMMENT, FILENAME  and DATE lines
;
  comment_ind = where(keyword EQ 'COMMENT ')
  file_ind = where(keyword EQ 'FILENAME')
  date_ind = where(keyword EQ 'DATE    ')
  xtension = where(keyword EQ 'XTENSION')
  hdr(comment_ind) = comm_line
  hdr(file_ind) = fname_line
  hdr(date_ind) = date_line

; create a UNIT line 
  unitline = blankline
  strput, unitline, 'SPD_UNIT='
; make sure that the unit is less than 19 chars long, wmt, Feb 97
  unit = "'" + strtrim(strmid(tmpdata.unit, 0, 18), 2) + "'"
  strput, unitline, unit, 10
  strput, unitline, '/ UNIT field in the PHTSPD', 31

; create a DET line
  detline = blankline
  strput, detline, 'SPD_DET ='
  det = "'" + strtrim(tmpdata.det, 2) + "'"
  strput, detline, det, 10
  strput, detline, '/ DETECTOR', 31

; create a ORDR line
  ordrline = blankline
  strput, ordrline, 'SPD_ORDR='
  ordr = strtrim(string(tmpdata.ordr), 2)
  len = strlen(ordr)
  strput, ordrline, ordr, (30 - len)>10
  strput, ordrline, '/', 31

; create a DIMS line
  dimsline = blankline
  strput, dimsline, 'SPD_DIMS='
  dims = strtrim(string(tmpdata.dims), 2)
  len = strlen(dims)
  strput, dimsline, dims, (30 - len)>10
  strput, dimsline, '/', 31

; create a number of measurements line
  nmeas = 'NMEAS   =                    1 / number of measurements                         '

; put into the primary header - naxis taken out by bugs fixing
phdr = [hdr(0: xtension(0) - 1 ), $
	unitline, detline, ordrline, dimsline, nmeas, endline]
nnn_ax = FXPAR(phdr, 'NAXIS', count=count)
IF count EQ 0 THEN phdr = [hdr(0:1), naxis, hdr(2:*)]

;
; pad the rest of the record with blank line for a 2880 bytes fits record
;
  trail = n_elements(phdr) mod 36
  if trail gt 0 then phdr = [phdr, replicate(blankline, 36 - trail)]

eheader = [ $
"XTENSION= 'BINTABLE'           / Binary table FITS extension                    ", $
"BITPIX  =                    8 / 8 BITS character format                        ", $
"NAXIS   =                    2 / Tables are 2-d character array                 ", $
"NAXIS1  =                      / Characters in a row                            ", $
"NAXIS2  =                      / Number of rows in a table                      ", $
"PCOUNT  =                    0 / Parameter count always 0                       ", $
"GCOUNT  =                    1 / Group count always 1                           ", $
"TFIELDS =                      / No of columns in table                         "]

; NAXIS1
;
  temp = eheader(3)
  strput, temp, naxis1, 10
  eheader(3) = temp
; NAXIS2
  naxis2 = string(tmpdata.dims)
  len = strlen(naxis2)
  temp = eheader(4)
  strput, temp, naxis2, (30 - len)>10
  eheader(4) = temp
; TFIELDS
  temp = eheader(7)
  len = strlen(tfields)
  strput, temp, tfields, (30 - len)>10
  eheader(7) = temp
;
; The rest of the extended header
;
  s0 = "TFORM1  = '1J      '           /" + string(replicate(32b, 48))
  s1 = "TTYPE1  = 'GPSCTKEY'           /" + string(replicate(32b, 48))
  s2 = "TFORM2  = '2B      '           /" + string(replicate(32b, 48))
  s3 = "TTYPE2  = 'GPSCRPID'           /" + string(replicate(32b, 48))
  s4 = "TFORM3  = '1I      '           /" + string(replicate(32b, 48))
  s5 = "TTYPE3  = 'GPSCFILL'           /" + string(replicate(32b, 48))
  tformline = "TFORM   = '        '           /" + string(replicate(32b, 48))
  ttypeline = "TTYPE   = '        '           /" + string(replicate(32b, 48))

  hdr_buf = [s0, s1, s2, s3, s4, s5]

  ttype = ttype_code + ttype

; the ntfields doesn't include the first three fields, ie tkey, rpid and
; fill
  ntfields = fix(tfields) - 4
  for i = 0, ntfields do begin
    temp = tformline
    strput, temp, strtrim(string(i + 4), 1), 5
    strput, temp, tform(i), 11
    hdr_buf = [hdr_buf, temp]
    temp = ttypeline
    strput, temp, strtrim(string(i + 4), 1), 5
    strput, temp, ttype(i), 11
    hdr_buf = [hdr_buf, temp]
  endfor

  eheader = [eheader(0:7), hdr_buf, endline]
  eend = n_elements(eheader)
  trail = eend mod 36
  if trail gt 0 then eheader = [eheader, replicate(blankline, 36 - trail)]

  tkey = long(tmpdata.tkey)

; The following code for the rpid is based on the single value of the rpid
  rpid = bytarr(2, tmpdata.dims)
  if n_elements(rpid) eq 2 then $
    rpid(*) = byte(tmpdata.rpid) $
  else $
    for i = 0, tmpdata.dims - 1 do rpid(*, i) = tmpdata.rpid(i)

;  kyid = tmpdata.kyid
  polz = tmpdata.polz
  ndrs = tmpdata.ndrs
  cstp = tmpdata.cstp
  dwel = long(tmpdata.dwel)
  meas = long(tmpdata.meas)
  cpos = long(tmpdata.cpos)
  mnpw = tmpdata.mnpw
  mnpu = tmpdata.mnpu
  mdpw = tmpdata.mdpw
  q1pw = tmpdata.q1pw
  q3pw = tmpdata.q3pw
  flag = byte(tmpdata.flag)

  BUF = REPLICATE(BUF_TYPE, TMPDATA.DIMS)

; There are no filt and aper fields in the SS/SL spd
  if strmid(tmpdata.det, 0, 1) ne 'S' then begin
    filt = tmpdata.filt
    aper = tmpdata.aper
    byteorder, filt, aper, /htons
    buf.filt = filt
    buf.aper = aper
  endif

  byteorder, polz, ndrs, cstp, /htons
  byteorder, dwel, meas, cpos, tkey, /htonl
  byteorder, mnpw, mnpu, mdpw, q1pw, q3pw, /ftoxdr

  IF STRMID(TMPDATA.DET, 0, 1) EQ 'P' AND N_ELEMENTS(mnpw) GT 1 THEN BEGIN
;   There is a bug in IDL 3.6.1 that 1 x Y array is very different
;   from >2 X Y array. That is assignment is not allowed in the first
;   case.
    buf.mnpw = transpose(mnpw)
    buf.mnpu = transpose(mnpu)
    buf.mdpw = transpose(mdpw)
    buf.q1pw = transpose(q1pw)
    buf.q3pw = transpose(q3pw)
    buf.flag = transpose(flag)
  ENDIF ELSE BEGIN
    buf.mnpw = mnpw
    buf.mnpu = mnpu
    buf.mdpw = mdpw
    buf.q1pw = q1pw
    buf.q3pw = q3pw
    if strmid(tmpdata.det, 0, 1) eq 'S' then $
      buf.flag = flag(0:63) $
    else $
    buf.flag = flag
  ENDELSE

  buf.gpsctkey = tkey
  buf.gpscrpid = rpid
  buf.polz = polz
  buf.ndrs = ndrs
  buf.cstp = cstp
  buf.dwel = dwel
  buf.meas = meas
  buf.cpos = cpos

  naxis2 = tmpdata.dims
  trail = (nchars * naxis2) mod 2880
  pad = bytarr( 2880 - trail )

; added filename as an alternative filename
  if keyword_set(filename) then $
    fitsfile = filename else $
  fitsfile = !INTDIR + tmpdata.admn + '_SPD.FITS'

  openw, unit, fitsfile, /block, /get_lun
  writeu, unit, byte(phdr), byte(eheader), buf, pad
  free_lun, unit
END


