;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
;!                                                                             !
;! This routine belongs to the PHT Interactive Analysis Package PIA.           !
;!                                                                             !
;! PIA is a joint development by the ESA Astrophysics Division and the ISOPHOT !
;! Consortium led by the Max Planck Institute for Astronomy (MPIA), Heidelberg.! 
;! Contributing ISOPHOT Consortium institutes are DIAS, RAL, AIP, MPIK, and    !
;! MPIA.                                                                       !
;!                                                                             ! 
;! Its use and distribution are free, as long as this header text is not       !
;! removed, or changed. When publishing ISOPHOT Data reduced with this analysis!
;! package, please mention this in the acknowledgement.                        !
;!                                                                             !
;! No warranties for installation/ support/ maintenance are given.             ! 
;!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
pro xdisp_hk_event,event

;+
; NAME:
;       xdisp_hk
; PURPOSE:
;       Display hk status and analog data depending on the time.
; CATEGORY:
;	PIA - graphics
;
; CALLING SEQUENCE:
;        xdisp_hk
;
; INPUT PARAMETERS:
;        NONE
;
; OUTPUT PARAMETERS:
;       NONE
;
; RESTRICTIONS:
;       NONE
; 
; METHOD:
;       Check, if the data is status or analog. Print status data in a
;       table and analog data in a curve, both in relation with the time        
;
; PROCEDURES USED:
;       Common Block(s) or @ procedure(s):
;               colour_indices
;               phthk
;               phthk
;       PIA Procedure(s):
;               get_boundaries
;               pia_xplot
;
; MODIFICATION HISTORY:
;       Written by: Andreas Karch
;	Oct 95 Version 3.5
;	Overplot with same axis capability added (CG)	April 1997
;	V6.2
;-

; when an event occurs, check if it the quit button or the list

@phthk
common xdisp_hk_plot_mode,plot_mode
COMMON pia_dspchz_cmn, zoom_psymch, zoom_linech, zoom_color
@colour_indices

widget_control,event.id,get_uvalue=uvalue

case uvalue of
  'quit'  : begin
             widget_control,event.top,/destroy
             end

;get boundaries returns in idb_f_bounds the index of the last status value
;all list elements with higher index are analog

   'list' :begin
            get_boundaries,idb,idb_f_bounds
            if event.index le idb_f_bounds(1) then begin
             xdisplayfile,title=idb(1,event.index),$
		text= string(timestep_redu)+'      '+$
                      hkout(event.index, *),width=40
            endif else begin            
           
            if plot_mode  eq -1 then begin
              if zoom_color eq -1 then zoom_color=red else $
                   zoom_color=zoom_color+1
                   if zoom_color eq 9 then zoom_color=1
              zoom_psymch=zoom_psymch+1
                   if zoom_psymch eq 8 then zoom_psymch=1 
           endif else begin
               zoom_color=-1
               zoom_psymch=4 
           endelse            

            pia_xplot,timestep_redu,reform(float(hkout(event.index,*))),$
                              title=idb(1,event.index),$
                              psym=zoom_psymch,                  $
                              xtitle='Time    [s]',     $
			      ytitle=idb(1,event.index), $
                              overplot=plot_mode,$
                              color=zoom_color
            endelse 
            end

;set the oplot or the plot flag
 
   'PLOT' : BEGIN
             CASE event.value of
              0: plot_mode=0
              1: plot_mode=99
              2: plot_mode=-1
             ENDCASE
	    END
	    
    else : MESSAGE, /INFO, ' not allowed value'
endcase

return 
end


;here comes the main program. It creates the widgets and sets the plot_mode flag

pro xdisp_hk

common xdisp_hk_plot_mode
plot_mode=0

@phthk

 base=widget_base(title='xdisp_hk', /column )
 list  = widget_list(base,value=idb(1,*),uvalue='list',ysize=30)
 stdbut= CW_BGROUP(base, LABEL_TOP='Plot & Print', $
 		/EXCLUSIVE, /FRAME, ROW=3,SET_VALUE=0, $
 		UVALUE='PLOT', $
 		["New Plot & Print     ",$
 		 "Overplot, Same Y Axis",$
 		 "Overplot, New Y Axis "]) 

 but  = widget_button(base,value='QUIT',uvalue='quit')

widget_control,base,/realize

Xmanager,No_BLOCK=1,'xdisp_hk',base,GROUP=group
end
      
